@@ -228,22 +228,22 @@ View::View( Part *part, TQWidget *parent, ActionManagerImpl* actionManager, cons
 
     TQVBoxLayout *lt = new TQVBoxLayout( this );
 
-    m_horizontalSplitter = new TQSplitter(Qt::Horizontal, this);
+    m_horizontalSplitter = new TQSplitter(TQt::Horizontal, this);
 
     m_horizontalSplitter->setOpaqueResize(true);
     lt->addWidget(m_horizontalSplitter);
 
-    connect (Kernel::self()->fetchQueue(), TQT_SIGNAL(fetched(Feed*)), this, TQT_SLOT(slotFeedFetched(Feed*)));
-    connect (Kernel::self()->fetchQueue(), TQT_SIGNAL(signalStarted()), this, TQT_SLOT(slotFetchingStarted()));
-    connect (Kernel::self()->fetchQueue(), TQT_SIGNAL(signalStopped()), this, TQT_SLOT(slotFetchingStopped()));
+    connect (Kernel::self()->fetchQueue(), TQ_SIGNAL(fetched(Feed*)), this, TQ_SLOT(slotFeedFetched(Feed*)));
+    connect (Kernel::self()->fetchQueue(), TQ_SIGNAL(signalStarted()), this, TQ_SLOT(slotFetchingStarted()));
+    connect (Kernel::self()->fetchQueue(), TQ_SIGNAL(signalStopped()), this, TQ_SLOT(slotFetchingStopped()));
 
-    connect(Kernel::self()->tagSet(), TQT_SIGNAL(signalTagAdded(const Tag&)), this, TQT_SLOT(slotTagCreated(const Tag&)));
-    connect(Kernel::self()->tagSet(), TQT_SIGNAL(signalTagRemoved(const Tag&)), this, TQT_SLOT(slotTagRemoved(const Tag&)));
+    connect(Kernel::self()->tagSet(), TQ_SIGNAL(signalTagAdded(const Tag&)), this, TQ_SLOT(slotTagCreated(const Tag&)));
+    connect(Kernel::self()->tagSet(), TQ_SIGNAL(signalTagRemoved(const Tag&)), this, TQ_SLOT(slotTagRemoved(const Tag&)));
 
     m_listTabWidget = new ListTabWidget(m_horizontalSplitter);
     m_actionManager->initListTabWidget(m_listTabWidget);
 
-    connect(m_listTabWidget, TQT_SIGNAL(signalNodeSelected(TreeNode*)), this, TQT_SLOT(slotNodeSelected(TreeNode*)));
+    connect(m_listTabWidget, TQ_SIGNAL(signalNodeSelected(TreeNode*)), this, TQ_SLOT(slotNodeSelected(TreeNode*)));
 
     if (!Settings::showTaggingGUI())
         m_listTabWidget->setViewMode(ListTabWidget::single);
@@ -251,16 +251,16 @@ View::View( Part *part, TQWidget *parent, ActionManagerImpl* actionManager, cons
     m_feedListView = new NodeListView( this, "feedtree" );
     m_listTabWidget->addView(m_feedListView, i18n("Feeds"), TDEGlobal::iconLoader()->loadIcon("folder", TDEIcon::Small));
 
-    connect(m_feedListView, TQT_SIGNAL(signalContextMenu(TDEListView*, TreeNode*, const TQPoint&)), this, TQT_SLOT(slotFeedTreeContextMenu(TDEListView*, TreeNode*, const TQPoint&)));
+    connect(m_feedListView, TQ_SIGNAL(signalContextMenu(TDEListView*, TreeNode*, const TQPoint&)), this, TQ_SLOT(slotFeedTreeContextMenu(TDEListView*, TreeNode*, const TQPoint&)));
 
-    connect(m_feedListView, TQT_SIGNAL(signalDropped (KURL::List &, TreeNode*,
-            Folder*)), this, TQT_SLOT(slotFeedURLDropped (KURL::List &,
+    connect(m_feedListView, TQ_SIGNAL(signalDropped (KURL::List &, TreeNode*,
+            Folder*)), this, TQ_SLOT(slotFeedURLDropped (KURL::List &,
             TreeNode*, Folder*)));
 
     m_tagNodeListView = new NodeListView(this);
     m_listTabWidget->addView(m_tagNodeListView, i18n("Tags"), TDEGlobal::iconLoader()->loadIcon("rss_tag", TDEIcon::Small));
 
-    connect(m_tagNodeListView, TQT_SIGNAL(signalContextMenu(TDEListView*, TreeNode*, const TQPoint&)), this, TQT_SLOT(slotFeedTreeContextMenu(TDEListView*, TreeNode*, const TQPoint&)));
+    connect(m_tagNodeListView, TQ_SIGNAL(signalContextMenu(TDEListView*, TreeNode*, const TQPoint&)), this, TQ_SLOT(slotFeedTreeContextMenu(TDEListView*, TreeNode*, const TQPoint&)));
 
 
     ProgressManager::self()->setFeedList(m_feedList);
@@ -268,10 +268,10 @@ View::View( Part *part, TQWidget *parent, ActionManagerImpl* actionManager, cons
     m_tabs = new TabWidget(m_horizontalSplitter);
     m_actionManager->initTabWidget(m_tabs);
 
-    connect( m_part, TQT_SIGNAL(signalSettingsChanged()), m_tabs, TQT_SLOT(slotSettingsChanged()));
+    connect( m_part, TQ_SIGNAL(signalSettingsChanged()), m_tabs, TQ_SLOT(slotSettingsChanged()));
 
-    connect( m_tabs, TQT_SIGNAL( currentFrameChanged(Frame *) ), this,
-            TQT_SLOT( slotFrameChanged(Frame *) ) );
+    connect( m_tabs, TQ_SIGNAL( currentFrameChanged(Frame *) ), this,
+            TQ_SLOT( slotFrameChanged(Frame *) ) );
 
     TQWhatsThis::add(m_tabs, i18n("You can view multiple articles in several open tabs."));
 
@@ -287,39 +287,39 @@ View::View( Part *part, TQWidget *parent, ActionManagerImpl* actionManager, cons
 
     mainTabLayout->addWidget(m_searchBar);
 
-    m_articleSplitter = new TQSplitter(Qt::Vertical, m_mainTab, "panner2");
+    m_articleSplitter = new TQSplitter(TQt::Vertical, m_mainTab, "panner2");
 
     m_articleList = new ArticleListView( m_articleSplitter, "articles" );
     m_actionManager->initArticleListView(m_articleList);
 
-    connect( m_articleList, TQT_SIGNAL(signalMouseButtonPressed(int, const Article&, const TQPoint &, int)), this, TQT_SLOT(slotMouseButtonPressed(int, const Article&, const TQPoint &, int)));
+    connect( m_articleList, TQ_SIGNAL(signalMouseButtonPressed(int, const Article&, const TQPoint &, int)), this, TQ_SLOT(slotMouseButtonPressed(int, const Article&, const TQPoint &, int)));
 
     // use selectionChanged instead of clicked
-    connect( m_articleList, TQT_SIGNAL(signalArticleChosen(const Article&)),
-                this, TQT_SLOT( slotArticleSelected(const Article&)) );
-    connect( m_articleList, TQT_SIGNAL(signalDoubleClicked(const Article&, const TQPoint&, int)),
-                this, TQT_SLOT( slotOpenArticleExternal(const Article&, const TQPoint&, int)) );
+    connect( m_articleList, TQ_SIGNAL(signalArticleChosen(const Article&)),
+                this, TQ_SLOT( slotArticleSelected(const Article&)) );
+    connect( m_articleList, TQ_SIGNAL(signalDoubleClicked(const Article&, const TQPoint&, int)),
+                this, TQ_SLOT( slotOpenArticleExternal(const Article&, const TQPoint&, int)) );
 
     m_articleViewer = new ArticleViewer(m_articleSplitter, "article_viewer");
     m_articleViewer->setSafeMode();  // disable JS, Java, etc...
 
     m_actionManager->initArticleViewer(m_articleViewer);
 
-    connect(m_searchBar, TQT_SIGNAL(signalSearch(const Akregator::Filters::ArticleMatcher&, const Akregator::Filters::ArticleMatcher&)), m_articleList, TQT_SLOT(slotSetFilter(const Akregator::Filters::ArticleMatcher&, const Akregator::Filters::ArticleMatcher&)));
+    connect(m_searchBar, TQ_SIGNAL(signalSearch(const Akregator::Filters::ArticleMatcher&, const Akregator::Filters::ArticleMatcher&)), m_articleList, TQ_SLOT(slotSetFilter(const Akregator::Filters::ArticleMatcher&, const Akregator::Filters::ArticleMatcher&)));
 
-    connect(m_searchBar, TQT_SIGNAL(signalSearch(const Akregator::Filters::ArticleMatcher&, const Akregator::Filters::ArticleMatcher&)), m_articleViewer, TQT_SLOT(slotSetFilter(const Akregator::Filters::ArticleMatcher&, const Akregator::Filters::ArticleMatcher&)));
+    connect(m_searchBar, TQ_SIGNAL(signalSearch(const Akregator::Filters::ArticleMatcher&, const Akregator::Filters::ArticleMatcher&)), m_articleViewer, TQ_SLOT(slotSetFilter(const Akregator::Filters::ArticleMatcher&, const Akregator::Filters::ArticleMatcher&)));
 
-    connect( m_articleViewer, TQT_SIGNAL(urlClicked(const KURL&, Viewer*, bool, bool)),
-             this, TQT_SLOT(slotUrlClickedInViewer(const KURL&, Viewer*, bool, bool)) );
+    connect( m_articleViewer, TQ_SIGNAL(urlClicked(const KURL&, Viewer*, bool, bool)),
+             this, TQ_SLOT(slotUrlClickedInViewer(const KURL&, Viewer*, bool, bool)) );
 
-    connect( m_articleViewer->browserExtension(), TQT_SIGNAL(mouseOverInfo(const KFileItem *)),
-                                            this, TQT_SLOT(slotMouseOverInfo(const KFileItem *)) );
+    connect( m_articleViewer->browserExtension(), TQ_SIGNAL(mouseOverInfo(const KFileItem *)),
+                                            this, TQ_SLOT(slotMouseOverInfo(const KFileItem *)) );
 
-    connect( m_part, TQT_SIGNAL(signalSettingsChanged()), m_articleViewer, TQT_SLOT(slotPaletteOrFontChanged()));
+    connect( m_part, TQ_SIGNAL(signalSettingsChanged()), m_articleViewer, TQ_SLOT(slotPaletteOrFontChanged()));
     TQWhatsThis::add(m_articleViewer->widget(), i18n("Browsing area."));
     mainTabLayout->addWidget( m_articleSplitter );
 
-    m_mainFrame=new Frame(TQT_TQOBJECT(this), m_part, m_mainTab, i18n("Articles"), false);
+    m_mainFrame=new Frame(this, m_part, m_mainTab, i18n("Articles"), false);
     connectFrame(m_mainFrame);
     m_tabs->addFrame(m_mainFrame);
 
@@ -342,17 +342,17 @@ View::View( Part *part, TQWidget *parent, ActionManagerImpl* actionManager, cons
     }
 
     m_fetchTimer = new TQTimer(this);
-    connect( m_fetchTimer, TQT_SIGNAL(timeout()), this, TQT_SLOT(slotDoIntervalFetches()) );
+    connect( m_fetchTimer, TQ_SIGNAL(timeout()), this, TQ_SLOT(slotDoIntervalFetches()) );
     m_fetchTimer->start(1000*60);
 
     // delete expired articles once per hour
     m_expiryTimer = new TQTimer(this);
-    connect(m_expiryTimer, TQT_SIGNAL(timeout()), this,
-            TQT_SLOT(slotDeleteExpiredArticles()) );
+    connect(m_expiryTimer, TQ_SIGNAL(timeout()), this,
+            TQ_SLOT(slotDeleteExpiredArticles()) );
     m_expiryTimer->start(3600*1000);
 
     m_markReadTimer = new TQTimer(this);
-    connect(m_markReadTimer, TQT_SIGNAL(timeout()), this, TQT_SLOT(slotSetCurrentArticleReadDelayed()) );
+    connect(m_markReadTimer, TQ_SIGNAL(timeout()), this, TQ_SLOT(slotSetCurrentArticleReadDelayed()) );
 
     switch (Settings::viewMode())
     {
@@ -372,7 +372,7 @@ View::View( Part *part, TQWidget *parent, ActionManagerImpl* actionManager, cons
         m_searchBar->slotSetText(Settings::textFilter());
     }
 
-    TQTimer::singleShot(1000, this, TQT_SLOT(slotDeleteExpiredArticles()) );
+    TQTimer::singleShot(1000, this, TQ_SLOT(slotDeleteExpiredArticles()) );
     m_part->mergePart(m_articleViewer);
 }
 
@@ -433,17 +433,17 @@ void View::slotOpenNewTab(const KURL& url, bool background)
 {
     PageViewer* page = new PageViewer(this, "page");
 
-    connect( m_part, TQT_SIGNAL(signalSettingsChanged()), page, TQT_SLOT(slotPaletteOrFontChanged()));
+    connect( m_part, TQ_SIGNAL(signalSettingsChanged()), page, TQ_SLOT(slotPaletteOrFontChanged()));
 
-    connect( page, TQT_SIGNAL(setTabIcon(const TQPixmap&)),
-            this, TQT_SLOT(setTabIcon(const TQPixmap&)));
-    connect( page, TQT_SIGNAL(urlClicked(const KURL &, Viewer*, bool, bool)),
-            this, TQT_SLOT(slotUrlClickedInViewer(const KURL &, Viewer*, bool, bool)) );
+    connect( page, TQ_SIGNAL(setTabIcon(const TQPixmap&)),
+            this, TQ_SLOT(setTabIcon(const TQPixmap&)));
+    connect( page, TQ_SIGNAL(urlClicked(const KURL &, Viewer*, bool, bool)),
+            this, TQ_SLOT(slotUrlClickedInViewer(const KURL &, Viewer*, bool, bool)) );
 
-    Frame* frame = new Frame(TQT_TQOBJECT(this), page, page->widget(), i18n("Untitled"));
+    Frame* frame = new Frame(this, page, page->widget(), i18n("Untitled"));
     frame->setAutoDeletePart(true); // delete page viewer when removing the tab
 
-    connect(page, TQT_SIGNAL(setWindowCaption (const TQString &)), frame, TQT_SLOT(setTitle (const TQString &)));
+    connect(page, TQ_SIGNAL(setWindowCaption (const TQString &)), frame, TQ_SLOT(setTitle (const TQString &)));
     connectFrame(frame);
     m_tabs->addFrame(frame);
 
@@ -466,12 +466,12 @@ void View::setTabIcon(const TQPixmap& icon)
 
 void View::connectFrame(Frame *f)
 {
-    connect(f, TQT_SIGNAL(statusText(const TQString &)), this, TQT_SLOT(slotStatusText(const TQString&)));
-    connect(f, TQT_SIGNAL(captionChanged (const TQString &)), this, TQT_SLOT(slotCaptionChanged (const TQString &)));
-    connect(f, TQT_SIGNAL(loadingProgress(int)), this, TQT_SLOT(slotLoadingProgress(int)) );
-    connect(f, TQT_SIGNAL(started()), this, TQT_SLOT(slotStarted()));
-    connect(f, TQT_SIGNAL(completed()), this, TQT_SLOT(slotCompleted()));
-    connect(f, TQT_SIGNAL(canceled(const TQString &)), this, TQT_SLOT(slotCanceled(const TQString&)));
+    connect(f, TQ_SIGNAL(statusText(const TQString &)), this, TQ_SLOT(slotStatusText(const TQString&)));
+    connect(f, TQ_SIGNAL(captionChanged (const TQString &)), this, TQ_SLOT(slotCaptionChanged (const TQString &)));
+    connect(f, TQ_SIGNAL(loadingProgress(int)), this, TQ_SLOT(slotLoadingProgress(int)) );
+    connect(f, TQ_SIGNAL(started()), this, TQ_SLOT(slotStarted()));
+    connect(f, TQ_SIGNAL(completed()), this, TQ_SLOT(slotCompleted()));
+    connect(f, TQ_SIGNAL(canceled(const TQString &)), this, TQ_SLOT(slotCanceled(const TQString&)));
 }
 
 void View::slotStatusText(const TQString &c)
@@ -647,7 +647,7 @@ void View::slotNormalView()
             m_articleViewer->slotShowSummary(m_listTabWidget->activeView()->selectedNode());
     }
 
-    m_articleSplitter->setOrientation(Qt::Vertical);
+    m_articleSplitter->setOrientation(TQt::Vertical);
     m_viewMode = NormalView;
 
     Settings::setViewMode( m_viewMode );
@@ -671,7 +671,7 @@ void View::slotWidescreenView()
             m_articleViewer->slotShowSummary(m_listTabWidget->activeView()->selectedNode());
     }
 
-    m_articleSplitter->setOrientation(Qt::Horizontal);
+    m_articleSplitter->setOrientation(TQt::Horizontal);
     m_viewMode = WidescreenView;
 
     Settings::setViewMode( m_viewMode );
@@ -841,8 +841,8 @@ void View::slotOpenURL(const KURL& url, Viewer* currentViewer, BrowserRun::Openi
          KParts::URLArgs args = currentViewer ? currentViewer->browserExtension()->urlArgs() : KParts::URLArgs();
 
         BrowserRun* r = new BrowserRun(this, currentViewer, url, args, mode);
-        connect(r, TQT_SIGNAL(signalOpenInViewer(const KURL&, Akregator::Viewer*, Akregator::BrowserRun::OpeningMode)),
-            this, TQT_SLOT(slotOpenURLReply(const KURL&, Akregator::Viewer*, Akregator::BrowserRun::OpeningMode)));
+        connect(r, TQ_SIGNAL(signalOpenInViewer(const KURL&, Akregator::Viewer*, Akregator::BrowserRun::OpeningMode)),
+            this, TQ_SLOT(slotOpenURLReply(const KURL&, Akregator::Viewer*, Akregator::BrowserRun::OpeningMode)));
     }
 }
 
@@ -1109,7 +1109,7 @@ void View::slotFeedFetched(Feed *feed)
 
 void View::slotMouseButtonPressed(int button, const Article& article, const TQPoint &, int)
 {
-    if (button == Qt::MidButton)
+    if (button == TQt::MidButton)
     {
         KURL link = article.link();
         switch (Settings::mMBBehaviour())
@@ -1518,13 +1518,13 @@ void View::saveProperties(TDEConfig* config)
 
 void View::connectToFeedList(FeedList* feedList)
 {
-    connect(feedList->rootNode(), TQT_SIGNAL(signalChanged(TreeNode*)), this, TQT_SLOT(slotSetTotalUnread()));
+    connect(feedList->rootNode(), TQ_SIGNAL(signalChanged(TreeNode*)), this, TQ_SLOT(slotSetTotalUnread()));
     slotSetTotalUnread();
 }
 
 void View::disconnectFromFeedList(FeedList* feedList)
 {
-    disconnect(feedList->rootNode(), TQT_SIGNAL(signalChanged(TreeNode*)), this, TQT_SLOT(slotSetTotalUnread()));
+    disconnect(feedList->rootNode(), TQ_SIGNAL(signalChanged(TreeNode*)), this, TQ_SLOT(slotSetTotalUnread()));
 }
 
 void View::updateTagActions()
