@@ -26,7 +26,7 @@ class Estate;
 
 class LIBATLANTIC_EXPORT Auction : public TQObject
 {
-Q_OBJECT
+TQ_OBJECT
   
 
 public:
