@@ -106,7 +106,7 @@ ProjectConfigurationDlg::ProjectConfigurationDlg( TQListView *_prjList, TrollPro
     prjWidget = _prjWidget;
     //  m_projectConfiguration = conf;
     m_targetLibraryVersion->setValidator( new TQRegExpValidator(
-                                              TQRegExp( "\\d+(\\.\\d+)?(\\.\\d+)" ), TQT_TQOBJECT(this) ) );
+                                              TQRegExp( "\\d+(\\.\\d+)?(\\.\\d+)" ), this ) );
     customVariables->setSortColumn(0);
     customVariables->setSortOrder(TQt::Ascending);
     mocdir_url->completionObject()->setMode(KURLCompletion::DirCompletion);
@@ -327,89 +327,6 @@ void ProjectConfigurationDlg::updateProjectConfiguration()
     else
         myProjectItem->removeValue( "CONFIG", "windows" );
 
-    //TQt4 libs
-    if ( prjWidget->m_part->isTQt4Project() )
-    {
-        if ( checkDebugReleaseMode->isChecked() )
-            myProjectItem->addValue( "CONFIG", "debug_and_release" );
-        else
-            myProjectItem->removeValue( "CONFIG", "debug_and_release" );
-
-        if ( checkTestlib->isChecked() )
-            myProjectItem->addValue( "CONFIG", "qtestlib" );
-        else
-            myProjectItem->removeValue( "CONFIG", "qtestlib" );
-        if ( checkAssistant->isChecked() )
-            myProjectItem->addValue( "CONFIG", "assistant" );
-        else
-            myProjectItem->removeValue( "CONFIG", "assistant" );
-        if ( checkUiTools->isChecked() )
-            myProjectItem->addValue( "CONFIG", "uitools" );
-        else
-            myProjectItem->removeValue( "CONFIG", "uitools" );
-        if ( checkQDBus->isChecked() )
-            myProjectItem->addValue( "CONFIG", "dbus" );
-        else
-            myProjectItem->removeValue( "CONFIG", "dbus" );
-        if ( checkBuildAll->isChecked() )
-            myProjectItem->addValue( "CONFIG", "build_all" );
-        else
-            myProjectItem->removeValue( "CONFIG", "build_all" );
-        if ( checkQtHelp->isChecked() )
-            myProjectItem->addValue( "CONFIG", "help" );
-        else
-            myProjectItem->removeValue( "CONFIG", "help" );
-
-        if ( checkQt4Core->isChecked() )
-            myProjectItem->addValue( "QT", "core" );
-        else
-            myProjectItem->removeValue( "QT", "core" );
-        if ( checkQt4Gui->isChecked() )
-            myProjectItem->addValue( "QT", "gui" );
-        else
-            myProjectItem->removeValue( "QT", "gui" );
-        if ( checkQt4SQL->isChecked() )
-            myProjectItem->addValue( "QT", "sql" );
-        else
-            myProjectItem->removeValue( "QT", "sql" );
-        if ( checkQt4SVG->isChecked() )
-            myProjectItem->addValue( "QT", "svg" );
-        else
-            myProjectItem->removeValue( "QT", "svg" );
-        if ( checkQt4XML->isChecked() )
-            myProjectItem->addValue( "QT", "xml" );
-        else
-            myProjectItem->removeValue( "QT", "xml" );
-        if ( checkQt4Network->isChecked() )
-            myProjectItem->addValue( "QT", "network" );
-        else
-            myProjectItem->removeValue( "QT", "network" );
-        if ( checkQt3Support->isChecked() )
-            myProjectItem->addValue( "QT", "qt3support" );
-        else
-            myProjectItem->removeValue( "QT", "qt3support" );
-        if ( checkQt4OpenGL->isChecked() )
-            myProjectItem->addValue( "QT", "opengl" );
-        else
-            myProjectItem->removeValue( "QT", "opengl" );
-        if ( checkQtScript->isChecked() )
-            myProjectItem->addValue( "QT", "script" );
-        else
-            myProjectItem->removeValue( "QT", "script" );
-        if ( checkQtWebKit->isChecked() )
-            myProjectItem->addValue( "QT", "webkit" );
-        else
-            myProjectItem->removeValue( "QT", "webkit" );
-        if ( checkQtXmlPatterns->isChecked() )
-            myProjectItem->addValue( "QT", "xmlpatterns" );
-        else
-            myProjectItem->removeValue( "QT", "xmlpatterns" );
-        if ( checkPhonon->isChecked() )
-            myProjectItem->addValue( "QT", "phonon" );
-        else
-            myProjectItem->removeValue( "QT", "phonon" );
-    }
-
     TQStringList confValues = myProjectItem->scope->variableValues( "CONFIG" );
     TQStringList extraValues = TQStringList::split( " ", editConfigExtra->text() );
     for ( TQStringList::iterator it = confValues.begin() ; it != confValues.end() ; ++it )
@@ -667,8 +584,6 @@ void ProjectConfigurationDlg::updateControls()
         {
             sharedRadio->setChecked( true );
             checkPlugin->setEnabled( true );
-            if( prjWidget->m_part->isTQt4Project() )
-                checkDesigner->setEnabled( true );
             m_targetLibraryVersion->setText( myProjectItem->scope->variableValues( "VERSION" ).front() );
         }
         else
@@ -805,92 +720,6 @@ void ProjectConfigurationDlg::updateControls()
     else
         checkWindows->setChecked( false );
 
-    //TQt4 libs
-    if ( prjWidget->m_part->isTQt4Project() )
-    {
-
-        if ( configValues.findIndex( "assistant" ) != -1 )
-            checkAssistant->setChecked( true );
-        else
-            checkAssistant->setChecked( false );
-        if ( configValues.findIndex( "qtestlib" ) != -1 )
-            checkTestlib->setChecked( true );
-        else
-            checkTestlib->setChecked( false );
-        if ( configValues.findIndex( "uitools" ) != -1 )
-            checkUiTools->setChecked( true );
-        else
-            checkUiTools->setChecked( false );
-        if ( configValues.findIndex( "dbus" ) != -1 )
-            checkQDBus->setChecked( true );
-        else
-            checkQDBus->setChecked( false );
-        if ( configValues.findIndex( "build_all" ) != -1 )
-            checkBuildAll->setChecked( true );
-        else
-            checkBuildAll->setChecked( false );
-        if ( configValues.findIndex( "help" ) != -1 )
-            checkQtHelp->setChecked( true );
-        else
-            checkQtHelp->setChecked( false );
-
-        TQStringList qtLibs = myProjectItem->scope->variableValues( "QT" );
-        if ( qtLibs.findIndex( "core" ) != -1 )
-            checkQt4Core->setChecked( true );
-        else
-            checkQt4Core->setChecked( false );
-        if ( qtLibs.findIndex( "gui" ) != -1 )
-            checkQt4Gui->setChecked( true );
-        else
-            checkQt4Gui->setChecked( false );
-        if ( qtLibs.findIndex( "sql" ) != -1 )
-            checkQt4SQL->setChecked( true );
-        else
-            checkQt4SQL->setChecked( false );
-        if ( qtLibs.findIndex( "xml" ) != -1 )
-            checkQt4XML->setChecked( true );
-        else
-            checkQt4XML->setChecked( false );
-        if ( qtLibs.findIndex( "network" ) != -1 )
-            checkQt4Network->setChecked( true );
-        else
-            checkQt4Network->setChecked( false );
-        if ( qtLibs.findIndex( "svg" ) != -1 )
-            checkQt4SVG->setChecked( true );
-        else
-            checkQt4SVG->setChecked( false );
-        if ( qtLibs.findIndex( "opengl" ) != -1 )
-            checkQt4OpenGL->setChecked( true );
-        else
-            checkQt4OpenGL->setChecked( false );
-        if ( qtLibs.findIndex( "qt3support" ) != -1 )
-            checkQt3Support->setChecked( true );
-        else
-            checkQt3Support->setChecked( false );
-        if ( qtLibs.findIndex( "script" ) != -1 )
-            checkQtScript->setChecked( true );
-        else
-            checkQtScript->setChecked( false );
-        if ( qtLibs.findIndex( "phonon" ) != -1 )
-            checkPhonon->setChecked( true );
-        else
-            checkPhonon->setChecked( false );
-        if ( qtLibs.findIndex( "webkit" ) != -1 )
-            checkQtWebKit->setChecked( true );
-        else
-            checkQtWebKit->setChecked( false );
-        if ( qtLibs.findIndex( "xmlpatterns" ) != -1 )
-            checkQtXmlPatterns->setChecked( true );
-        else
-            checkQtXmlPatterns->setChecked( false );
-
-        checkDebugReleaseMode->setEnabled( true );
-        checkBuildAll->setEnabled( true );
-        groupQt4Libs->setEnabled( checkQt->isChecked() );
-        rccdir_url->setEnabled( true );
-        rccdir_label->setEnabled( true );
-    }
-
     //fill the custom config edit
     TQStringList extraValues;
     for ( TQStringList::const_iterator it = configValues.begin() ; it != configValues.end() ; ++it )
@@ -1882,10 +1711,6 @@ void ProjectConfigurationDlg::groupLibrariesChanged( int )
         checkPlugin->setEnabled( true );
         checkDesigner->setEnabled( checkPlugin->isChecked() );
     }
-    else if ( checkPlugin->isChecked() && prjWidget->m_part->isTQt4Project() )
-    {
-        checkDesigner->setEnabled( true );
-    }
     else
     {
         checkDesigner->setEnabled( false );
@@ -1978,14 +1803,6 @@ void ProjectConfigurationDlg::groupTemplateChanged( int )
 
 void ProjectConfigurationDlg::groupRequirementsChanged( int )
 {
-    if ( checkQt->isChecked() && prjWidget->m_part->isTQt4Project() )
-    {
-        groupQt4Libs->setEnabled( true );
-    }
-    else
-    {
-        groupQt4Libs->setEnabled( false );
-    }
     activateApply( 0 );
 }
 
@@ -2170,5 +1987,3 @@ void ProjectConfigurationDlg::customVarChanged()
     }
     activateApply( 0 );
 }
-
-// kate: space-indent on; indent-width 4; tab-width 4; replace-tabs on
