@@ -52,7 +52,7 @@ namespace QGpgME {
 namespace Kleo {
 
   class KDE_EXPORT QGpgMEKeyGenerationJob : public KeyGenerationJob, private QGpgMEJob {
-    Q_OBJECT
+    TQ_OBJECT
      TQGPGME_JOB
   public:
     QGpgMEKeyGenerationJob( GpgME::Context * context );
