@@ -1420,7 +1420,7 @@ void QtTableView::resizeEvent( TQResizeEvent * )
 
 void QtTableView::wheelEvent( TQWheelEvent * e )
 {
-    if( e->orientation() ==Qt::Vertical && vScrollBar && vScrollBar->isVisible() )
+    if( e->orientation() ==TQt::Vertical && vScrollBar && vScrollBar->isVisible() )
         TQApplication::sendEvent( vScrollBar, e );
 }
 
@@ -1443,7 +1443,7 @@ TQScrollBar *QtTableView::verticalScrollBar() const
 {
     QtTableView *that = (QtTableView*)this; // semantic const
     if ( !vScrollBar ) {
-	TQScrollBar *sb = new TQScrollBar( Qt::Vertical, that );
+	TQScrollBar *sb = new TQScrollBar( TQt::Vertical, that );
 #ifndef TQT_NO_CURSOR
 	sb->setCursor( arrowCursor );
 #endif
@@ -1451,12 +1451,12 @@ TQScrollBar *QtTableView::verticalScrollBar() const
 	TQ_CHECK_PTR(sb);
 	sb->setTracking( FALSE );
 	sb->setFocusPolicy( TQWidget::NoFocus );
-	connect( sb, TQT_SIGNAL(valueChanged(int)),
-		 TQT_SLOT(verSbValue(int)));
-	connect( sb, TQT_SIGNAL(sliderMoved(int)),
-		 TQT_SLOT(verSbSliding(int)));
-	connect( sb, TQT_SIGNAL(sliderReleased()),
-		 TQT_SLOT(verSbSlidingDone()));
+	connect( sb, TQ_SIGNAL(valueChanged(int)),
+		 TQ_SLOT(verSbValue(int)));
+	connect( sb, TQ_SIGNAL(sliderMoved(int)),
+		 TQ_SLOT(verSbSliding(int)));
+	connect( sb, TQ_SIGNAL(sliderReleased()),
+		 TQ_SLOT(verSbSlidingDone()));
 	sb->hide();
 	that->vScrollBar = sb;
 	return sb;
@@ -1474,7 +1474,7 @@ TQScrollBar *QtTableView::horizontalScrollBar() const
 {
     QtTableView *that = (QtTableView*)this; // semantic const
     if ( !hScrollBar ) {
-	TQScrollBar *sb = new TQScrollBar( Qt::Horizontal, that );
+	TQScrollBar *sb = new TQScrollBar( TQt::Horizontal, that );
 #ifndef TQT_NO_CURSOR
 	sb->setCursor( arrowCursor );
 #endif
@@ -1482,12 +1482,12 @@ TQScrollBar *QtTableView::horizontalScrollBar() const
 	sb->setFocusPolicy( TQWidget::NoFocus );
 	TQ_CHECK_PTR(sb);
 	sb->setTracking( FALSE );
-	connect( sb, TQT_SIGNAL(valueChanged(int)),
-		 TQT_SLOT(horSbValue(int)));
-	connect( sb, TQT_SIGNAL(sliderMoved(int)),
-		 TQT_SLOT(horSbSliding(int)));
-	connect( sb, TQT_SIGNAL(sliderReleased()),
-		 TQT_SLOT(horSbSlidingDone()));
+	connect( sb, TQ_SIGNAL(valueChanged(int)),
+		 TQ_SLOT(horSbValue(int)));
+	connect( sb, TQ_SIGNAL(sliderMoved(int)),
+		 TQ_SLOT(horSbSliding(int)));
+	connect( sb, TQ_SIGNAL(sliderReleased()),
+		 TQ_SLOT(horSbSlidingDone()));
 	sb->hide();
 	that->hScrollBar = sb;
 	return sb;
