@@ -49,7 +49,7 @@ StyledButton::StyledButton(TQWidget* parent, const char* name)
     setMinimumSize( minimumSizeHint() );
     setAcceptDrops( TRUE );
 
-    connect( this, SIGNAL(clicked()), SLOT(onEditor()));
+    connect( this, TQ_SIGNAL(clicked()), TQ_SLOT(onEditor()));
 }
 
 StyledButton::StyledButton( const TQBrush& b, TQWidget* parent, const char* name, WFlags f )
