@@ -52,7 +52,7 @@ class TQPalette;
 #if defined(QT_PLUGIN)
 #define Q_EXPORT_STYLE_PLATINUM
 #else
-#define Q_EXPORT_STYLE_PLATINUM Q_EXPORT
+#define Q_EXPORT_STYLE_PLATINUM TQ_EXPORT
 #endif
 
 class Q_EXPORT_STYLE_PLATINUM TQPlatinumStyle : public TQWindowsStyle
