@@ -248,11 +248,11 @@ FileRenamerWidget::FileRenamerWidget(TQWidget *parent) :
         m_category->insertItem(category);
     }
 
-    connect(m_exampleDialog, TQT_SIGNAL(signalShown()), TQT_SLOT(exampleDialogShown()));
-    connect(m_exampleDialog, TQT_SIGNAL(signalHidden()), TQT_SLOT(exampleDialogHidden()));
-    connect(m_exampleDialog, TQT_SIGNAL(dataChanged()), TQT_SLOT(dataSelected()));
-    connect(m_exampleDialog, TQT_SIGNAL(fileChanged(const TQString &)),
-            this,            TQT_SLOT(fileSelected(const TQString &)));
+    connect(m_exampleDialog, TQ_SIGNAL(signalShown()), TQ_SLOT(exampleDialogShown()));
+    connect(m_exampleDialog, TQ_SIGNAL(signalHidden()), TQ_SLOT(exampleDialogHidden()));
+    connect(m_exampleDialog, TQ_SIGNAL(dataChanged()), TQ_SLOT(dataSelected()));
+    connect(m_exampleDialog, TQ_SIGNAL(fileChanged(const TQString &)),
+            this,            TQ_SLOT(fileSelected(const TQString &)));
 
     exampleTextChanged();
 }
@@ -347,10 +347,10 @@ unsigned FileRenamerWidget::addRowCategory(TagType category)
     row.upButton->setFlat(true);
     row.downButton->setFlat(true);
 
-    upMapper->connect(row.upButton, TQT_SIGNAL(clicked()), TQT_SLOT(map()));
-    upMapper->setMapping(TQT_TQOBJECT(row.upButton), id);
-    downMapper->connect(row.downButton, TQT_SIGNAL(clicked()), TQT_SLOT(map()));
-    downMapper->setMapping(TQT_TQOBJECT(row.downButton), id);
+    upMapper->connect(row.upButton, TQ_SIGNAL(clicked()), TQ_SLOT(map()));
+    upMapper->setMapping(row.upButton, id);
+    downMapper->connect(row.downButton, TQ_SIGNAL(clicked()), TQ_SLOT(map()));
+    downMapper->setMapping(row.downButton, id);
 
     TQString labelText = TQString("<b>%1</b>").arg(TagRenamerOptions::tagTypeText(category));
     TQLabel *label = new TQLabel(labelText, frame);
@@ -359,12 +359,12 @@ unsigned FileRenamerWidget::addRowCategory(TagType category)
 
     TQVBox *options = new TQVBox(frame);
     row.enableButton = new KPushButton(i18n("Remove"), options);
-    toggleMapper->connect(row.enableButton, TQT_SIGNAL(clicked()), TQT_SLOT(map()));
-    toggleMapper->setMapping(TQT_TQOBJECT(row.enableButton), id);
+    toggleMapper->connect(row.enableButton, TQ_SIGNAL(clicked()), TQ_SLOT(map()));
+    toggleMapper->setMapping(row.enableButton, id);
 
     row.optionsButton = new KPushButton(i18n("Options"), options);
-    mapper->connect(row.optionsButton, TQT_SIGNAL(clicked()), TQT_SLOT(map()));
-    mapper->setMapping(TQT_TQOBJECT(row.optionsButton), id);
+    mapper->connect(row.optionsButton, TQ_SIGNAL(clicked()), TQ_SLOT(map()));
+    mapper->setMapping(row.optionsButton, id);
 
     row.widget->show();
     m_rows.append(row);
@@ -378,10 +378,10 @@ unsigned FileRenamerWidget::addRowCategory(TagType category)
 
 void FileRenamerWidget::moveSignalMappings(unsigned oldId, unsigned newId)
 {
-    mapper->setMapping(TQT_TQOBJECT(m_rows[oldId].optionsButton), newId);
-    downMapper->setMapping(TQT_TQOBJECT(m_rows[oldId].downButton), newId);
-    upMapper->setMapping(TQT_TQOBJECT(m_rows[oldId].upButton), newId);
-    toggleMapper->setMapping(TQT_TQOBJECT(m_rows[oldId].enableButton), newId);
+    mapper->setMapping(m_rows[oldId].optionsButton, newId);
+    downMapper->setMapping(m_rows[oldId].downButton, newId);
+    upMapper->setMapping(m_rows[oldId].upButton, newId);
+    toggleMapper->setMapping(m_rows[oldId].enableButton, newId);
 }
 
 bool FileRenamerWidget::removeRow(unsigned id)
@@ -448,7 +448,7 @@ bool FileRenamerWidget::removeRow(unsigned id)
     // We can insert another row now, make sure GUI is updated to match.
     m_insertCategory->setEnabled(true);
 
-    TQTimer::singleShot(0, this, TQT_SLOT(exampleTextChanged()));
+    TQTimer::singleShot(0, this, TQ_SLOT(exampleTextChanged()));
     return true;
 }
 
@@ -462,8 +462,8 @@ void FileRenamerWidget::addFolderSeparatorCheckbox()
     l->addWidget(cb, 0, AlignCenter);
     cb->setChecked(false);
 
-    connect(cb, TQT_SIGNAL(toggled(bool)),
-            TQT_SLOT(exampleTextChanged()));
+    connect(cb, TQ_SIGNAL(toggled(bool)),
+            TQ_SLOT(exampleTextChanged()));
 
     temp->show();
 }
@@ -480,15 +480,15 @@ void FileRenamerWidget::createTagRows()
     m_rows.reserve(categoryOrder.count());
     m_folderSwitches.reserve(categoryOrder.count() - 1);
 
-    mapper       = new TQSignalMapper(TQT_TQOBJECT(this), "signal mapper");
-    toggleMapper = new TQSignalMapper(TQT_TQOBJECT(this), "toggle mapper");
-    upMapper     = new TQSignalMapper(TQT_TQOBJECT(this), "up button mapper");
-    downMapper   = new TQSignalMapper(TQT_TQOBJECT(this), "down button mapper");
+    mapper       = new TQSignalMapper(this, "signal mapper");
+    toggleMapper = new TQSignalMapper(this, "toggle mapper");
+    upMapper     = new TQSignalMapper(this, "up button mapper");
+    downMapper   = new TQSignalMapper(this, "down button mapper");
 
-    connect(mapper,       TQT_SIGNAL(mapped(int)), TQT_SLOT(showCategoryOption(int)));
-    connect(toggleMapper, TQT_SIGNAL(mapped(int)), TQT_SLOT(slotRemoveRow(int)));
-    connect(upMapper,     TQT_SIGNAL(mapped(int)), TQT_SLOT(moveItemUp(int)));
-    connect(downMapper,   TQT_SIGNAL(mapped(int)), TQT_SLOT(moveItemDown(int)));
+    connect(mapper,       TQ_SIGNAL(mapped(int)), TQ_SLOT(showCategoryOption(int)));
+    connect(toggleMapper, TQ_SIGNAL(mapped(int)), TQ_SLOT(slotRemoveRow(int)));
+    connect(upMapper,     TQ_SIGNAL(mapped(int)), TQ_SLOT(moveItemUp(int)));
+    connect(downMapper,   TQ_SIGNAL(mapped(int)), TQ_SLOT(moveItemDown(int)));
 
     m_mainFrame = new TQVBox(m_mainView->viewport());
     m_mainFrame->setMargin(10);
@@ -687,7 +687,7 @@ void FileRenamerWidget::moveItem(unsigned id, MovementDirection direction)
     layout->insertWidget(2 * pos, w);
     layout->invalidate();
 
-    TQTimer::singleShot(0, this, TQT_SLOT(exampleTextChanged()));
+    TQTimer::singleShot(0, this, TQ_SLOT(exampleTextChanged()));
 }
 
 unsigned FileRenamerWidget::idOfPosition(unsigned position) const
