@@ -81,11 +81,11 @@ class PluginView : public KXMLGUIClient
 
 extern "C"
 {
-  void* init_katefiletemplates()
-  {
-    TDEGlobal::locale()->insertCatalogue("katefiletemplates");
-    return new KatePluginFactory;
-  }
+	KDE_EXPORT void* init_katefiletemplates()
+	{
+		TDEGlobal::locale()->insertCatalogue("katefiletemplates");
+		return new KatePluginFactory;
+	}
 }
 
 KatePluginFactory::KatePluginFactory()
@@ -133,11 +133,11 @@ KateFileTemplates::KateFileTemplates( TQObject* parent, const char* name )
   // We plug them into each view's menus, and update them centrally, so that
   // new plugins can automatically become visible in all windows.
   (void) new TDEAction ( i18n("Any File..."), 0, this,
-                        TQT_SLOT( slotAny() ), m_actionCollection,
+                        TQ_SLOT( slotAny() ), m_actionCollection,
                         "file_template_any" );
   // recent templates
   m_acRecentTemplates = new TDERecentFilesAction( i18n("&Use Recent"), 0, this,
-                        TQT_SLOT(slotOpenTemplate(const KURL &)),
+                        TQ_SLOT(slotOpenTemplate(const KURL &)),
                         m_actionCollection,
                         "file_templates_recent" );
   m_acRecentTemplates->loadEntries( kapp->config(), "Recent Templates" );
@@ -150,12 +150,12 @@ KateFileTemplates::KateFileTemplates( TQObject* parent, const char* name )
     m_dw->addDir( *it, true );
   }
 
-  connect( m_dw, TQT_SIGNAL(dirty(const TQString&)),
-           this, TQT_SLOT(updateTemplateDirs(const TQString&)) );
-  connect( m_dw, TQT_SIGNAL(created(const TQString&)),
-           this, TQT_SLOT(updateTemplateDirs(const TQString&)) );
-  connect( m_dw, TQT_SIGNAL(deleted(const TQString&)),
-           this, TQT_SLOT(updateTemplateDirs(const TQString&)) );
+  connect( m_dw, TQ_SIGNAL(dirty(const TQString&)),
+           this, TQ_SLOT(updateTemplateDirs(const TQString&)) );
+  connect( m_dw, TQ_SIGNAL(created(const TQString&)),
+           this, TQ_SLOT(updateTemplateDirs(const TQString&)) );
+  connect( m_dw, TQ_SIGNAL(deleted(const TQString&)),
+           this, TQ_SLOT(updateTemplateDirs(const TQString&)) );
 
   m_templates.setAutoDelete( true );
   updateTemplateDirs();
@@ -249,7 +249,7 @@ void KateFileTemplates::addView(Kate::MainWindow *win)
   PluginView *view = new PluginView ();
 
   (void) new TDEAction( i18n("&Manage Templates..."), 0,
-      this, TQT_SLOT(slotEditTemplate()),
+      this, TQ_SLOT(slotEditTemplate()),
       view->actionCollection(), "settings_manage_templates" );
 
   (void)new TDEActionMenu( i18n("New From &Template"), "text-x-makefile",
@@ -316,10 +316,10 @@ void KateFileTemplates::refreshMenu( PluginView *v )
     if ( ! m_templates.at( i )->icon.isEmpty() )
       submenus[m_templates.at( i )->group]->insertItem(
         SmallIconSet( m_templates.at( i )->icon ),
-        m_templates.at( i )->tmplate, this, TQT_SLOT(slotOpenTemplate( int )), 0, i );
+        m_templates.at( i )->tmplate, this, TQ_SLOT(slotOpenTemplate( int )), 0, i );
     else
       submenus[m_templates.at( i )->group]->insertItem(
-        m_templates.at( i )->tmplate, this, TQT_SLOT(slotOpenTemplate( int )), 0, i );
+        m_templates.at( i )->tmplate, this, TQ_SLOT(slotOpenTemplate( int )), 0, i );
 
     // add whatsthis containing the description and author
     TQString w ( m_templates.at( i )->description );
@@ -623,7 +623,7 @@ KateTemplateInfoWidget::KateTemplateInfoWidget( TQWidget *parent, TemplateInfo *
   if ( doc )
   {
     TQPopupMenu *m = new TQPopupMenu( btnHighlight );
-    connect( m, TQT_SIGNAL( activated( int ) ), this, TQT_SLOT( slotHlSet( int ) ) );
+    connect( m, TQ_SIGNAL( activated( int ) ), this, TQ_SLOT( slotHlSet( int ) ) );
     TQDict<TQPopupMenu> submenus;
     for ( uint n = 0; n < doc->hlModeCount(); n++ )
     {
@@ -635,7 +635,7 @@ KateTemplateInfoWidget::KateTemplateInfoWidget( TQWidget *parent, TemplateInfo *
         {
           TQPopupMenu *sm = new TQPopupMenu();
           submenus.insert( text, sm );
-          connect( sm, TQT_SIGNAL( activated( int ) ), this, TQT_SLOT( slotHlSet( int ) ) );
+          connect( sm, TQ_SIGNAL( activated( int ) ), this, TQ_SLOT( slotHlSet( int ) ) );
           m->insertItem( text, sm );
         }
 
@@ -699,7 +699,7 @@ KateTemplateWizard::KateTemplateWizard( TQWidget *parent, KateFileTemplates *kft
   btnTmpl = new TQPushButton( page );
   glo->addWidget( btnTmpl, 6, 2 );
   TQPopupMenu *m = new TQPopupMenu( btnTmpl );
-  connect( m, TQT_SIGNAL( activated( int ) ), this, TQT_SLOT( slotTmplateSet( int ) ) );
+  connect( m, TQ_SIGNAL( activated( int ) ), this, TQ_SLOT( slotTmplateSet( int ) ) );
 
   TQDict<TQPopupMenu> submenus;
   for ( uint i = 0; i < kft->templates().count(); i++ )
@@ -707,7 +707,7 @@ KateTemplateWizard::KateTemplateWizard( TQWidget *parent, KateFileTemplates *kft
     if ( ! submenus[ kft->templates().at( i )->group ] )
     {
       TQPopupMenu *sm = new TQPopupMenu();
-      connect( sm, TQT_SIGNAL( activated( int ) ), this, TQT_SLOT( slotTmplateSet( int ) ) );
+      connect( sm, TQ_SIGNAL( activated( int ) ), this, TQ_SLOT( slotTmplateSet( int ) ) );
       submenus.insert( kft->templates().at( i )->group, sm );
       m->insertItem( kft->templates().at( i )->group, sm );
     }
@@ -717,8 +717,8 @@ KateTemplateWizard::KateTemplateWizard( TQWidget *parent, KateFileTemplates *kft
   }
   btnTmpl->setPopup( m );
 
-  connect( bgOrigin, TQT_SIGNAL(clicked(int)), this, TQT_SLOT(slotStateChanged(int)) );
-  connect( urOrigin, TQT_SIGNAL(textChanged(const TQString&)), this, TQT_SLOT(slotStateChanged(const TQString&)) );
+  connect( bgOrigin, TQ_SIGNAL(clicked(int)), this, TQ_SLOT(slotStateChanged(int)) );
+  connect( urOrigin, TQ_SIGNAL(textChanged(const TQString&)), this, TQ_SLOT(slotStateChanged(const TQString&)) );
 
   glo->addMultiCell( new TQSpacerItem( 1, 1, TQSizePolicy::Expanding, TQSizePolicy::Expanding ), 7, 7, 1, 2 );
 
@@ -775,9 +775,9 @@ KateTemplateWizard::KateTemplateWizard( TQWidget *parent, KateFileTemplates *kft
   urLocation = new KURLRequester( page );
   glo->addWidget( urLocation, 6, 2 );
 
-  connect( bgLocation, TQT_SIGNAL(clicked(int)), this, TQT_SLOT(slotStateChanged(int)) );
-  connect( urLocation, TQT_SIGNAL(textChanged(const TQString&)), this, TQT_SLOT(slotStateChanged(const TQString&)) );
-  connect( leTemplateFileName, TQT_SIGNAL(textChanged(const TQString &)), this, TQT_SLOT(slotStateChanged(const TQString &)) );
+  connect( bgLocation, TQ_SIGNAL(clicked(int)), this, TQ_SLOT(slotStateChanged(int)) );
+  connect( urLocation, TQ_SIGNAL(textChanged(const TQString&)), this, TQ_SLOT(slotStateChanged(const TQString&)) );
+  connect( leTemplateFileName, TQ_SIGNAL(textChanged(const TQString &)), this, TQ_SLOT(slotStateChanged(const TQString &)) );
 
   glo->addMultiCell( new TQSpacerItem( 1, 1, TQSizePolicy::Expanding, TQSizePolicy::Expanding ), 7, 7, 1, 2 );
 
@@ -827,7 +827,7 @@ KateTemplateWizard::KateTemplateWizard( TQWidget *parent, KateFileTemplates *kft
 
   addPage( page, i18n("Create Template") );
   kdDebug()<<"=== Adding summary page at "<<endl;
-  connect( this, TQT_SIGNAL(selected(const TQString&)), this, TQT_SLOT(slotStateChanged(const TQString&)) );
+  connect( this, TQ_SIGNAL(selected(const TQString&)), this, TQ_SLOT(slotStateChanged(const TQString&)) );
 }
 
 void KateTemplateWizard::slotTmplateSet( int idx )
@@ -1108,26 +1108,26 @@ KateTemplateManager::KateTemplateManager( KateFileTemplates *kft, TQWidget *pare
   lvTemplates = new TDEListView( this );
   lvTemplates->addColumn( i18n("Template") );
   lo->addMultiCellWidget( lvTemplates, 1, 1, 1, 6 );
-  connect( lvTemplates, TQT_SIGNAL(selectionChanged()), this, TQT_SLOT(slotUpdateState()) );
+  connect( lvTemplates, TQ_SIGNAL(selectionChanged()), this, TQ_SLOT(slotUpdateState()) );
 
   btnNew = new TQPushButton( i18n("New..."), this );
-  connect( btnNew, TQT_SIGNAL(clicked()), kft, TQT_SLOT(slotCreateTemplate()) );
+  connect( btnNew, TQ_SIGNAL(clicked()), kft, TQ_SLOT(slotCreateTemplate()) );
   lo->addWidget( btnNew, 2, 2 );
 
   btnEdit = new TQPushButton( i18n("Edit..."), this );
-  connect( btnEdit, TQT_SIGNAL(clicked()), this, TQT_SLOT( slotEditTemplate()) );
+  connect( btnEdit, TQ_SIGNAL(clicked()), this, TQ_SLOT( slotEditTemplate()) );
   lo->addWidget( btnEdit, 2, 3 );
 
   btnRemove = new TQPushButton( i18n("Remove"), this );
-  connect( btnRemove, TQT_SIGNAL(clicked()), this, TQT_SLOT(slotRemoveTemplate()) );
+  connect( btnRemove, TQ_SIGNAL(clicked()), this, TQ_SLOT(slotRemoveTemplate()) );
   lo->addWidget( btnRemove, 2, 4 );
 
   btnUpload = new TQPushButton( i18n("Upload..."), this );
-  connect( btnUpload, TQT_SIGNAL(clicked()), this, TQT_SLOT(slotUpload()) );
+  connect( btnUpload, TQ_SIGNAL(clicked()), this, TQ_SLOT(slotUpload()) );
   lo->addWidget( btnUpload, 2, 5 );
 
   btnDownload = new TQPushButton( i18n("Download..."), this );
-  connect( btnDownload, TQT_SIGNAL(clicked()), this, TQT_SLOT(slotDownload()) );
+  connect( btnDownload, TQ_SIGNAL(clicked()), this, TQ_SLOT(slotDownload()) );
   lo->addWidget( btnDownload, 2, 6 );
 
   lo->setColStretch( 1, 1 );
