@@ -272,7 +272,7 @@ void KBgEngineFIBS::getSetupPages(KDialogBase *nb)
 		lem[i] = new TQLineEdit(autoMsg[i], gbm);
 		gl->addWidget(cbm[i], i, 0);
 		gl->addWidget(lem[i], i, 1);
-		connect(cbm[i], TQT_SIGNAL(toggled(bool)), lem[i], TQT_SLOT(setEnabled(bool)));
+		connect(cbm[i], TQ_SIGNAL(toggled(bool)), lem[i], TQ_SLOT(setEnabled(bool)));
 		cbm[i]->setChecked(useAutoMsg[i]);
 		lem[i]->setEnabled(useAutoMsg[i]);
 		TQWhatsThis::add(lem[i], TQWhatsThis::textFor(cbm[i]));
@@ -838,8 +838,8 @@ void KBgEngineFIBS::fibsRequestInvitation(const TQString &player)
 	if (!invitationDlg) {
 		TQString p = player;
 		invitationDlg = new KBgInvite("invite");
-		connect(invitationDlg, TQT_SIGNAL(inviteCommand(const TQString &)), this, TQT_SLOT(handleCommand(const TQString &)));
-		connect(invitationDlg, TQT_SIGNAL(dialogDone()), this, TQT_SLOT(invitationDone()));
+		connect(invitationDlg, TQ_SIGNAL(inviteCommand(const TQString &)), this, TQ_SLOT(handleCommand(const TQString &)));
+		connect(invitationDlg, TQ_SIGNAL(dialogDone()), this, TQ_SLOT(invitationDone()));
 	}
 	invitationDlg->setPlayer(player);
 	invitationDlg->show();
@@ -2094,55 +2094,55 @@ KBgEngineFIBS::KBgEngineFIBS(TQWidget *parent, TQString *name, TQPopupMenu *pmen
 	/*
 	 * No connection, not playing, ready for login
 	 */
-	connection = new TQSocket(TQT_TQOBJECT(parent), "fibs connection");
+	connection = new TQSocket(parent, "fibs connection");
 	playing = false;
 	login = true;
 
-	connect(connection, TQT_SIGNAL(hostFound()),            this, TQT_SLOT(hostFound()));
-	connect(connection, TQT_SIGNAL(connected()),            this, TQT_SLOT(connected()));
-	connect(connection, TQT_SIGNAL(error(int)),             this, TQT_SLOT(connError(int)));
-	connect(connection, TQT_SIGNAL(connectionClosed()),     this, TQT_SLOT(connectionClosed()));
-	connect(connection, TQT_SIGNAL(delayedCloseFinished()), this, TQT_SLOT(connectionClosed()));
-	connect(connection, TQT_SIGNAL(readyRead()),            this, TQT_SLOT(readData()));
+	connect(connection, TQ_SIGNAL(hostFound()),            this, TQ_SLOT(hostFound()));
+	connect(connection, TQ_SIGNAL(connected()),            this, TQ_SLOT(connected()));
+	connect(connection, TQ_SIGNAL(error(int)),             this, TQ_SLOT(connError(int)));
+	connect(connection, TQ_SIGNAL(connectionClosed()),     this, TQ_SLOT(connectionClosed()));
+	connect(connection, TQ_SIGNAL(delayedCloseFinished()), this, TQ_SLOT(connectionClosed()));
+	connect(connection, TQ_SIGNAL(readyRead()),            this, TQ_SLOT(readData()));
 
-	connect(this, TQT_SIGNAL(serverString(const TQString &)), this, TQT_SLOT(sendData(const TQString &)));
+	connect(this, TQ_SIGNAL(serverString(const TQString &)), this, TQ_SLOT(sendData(const TQString &)));
 
 	/*
 	 * No invitation dialog
 	 */
 	invitationDlg = 0;
 
-	connect(this, TQT_SIGNAL(fibsWhoInfo(const TQString &)), this, TQT_SLOT(changeJoin(const TQString &)));
-	connect(this, TQT_SIGNAL(fibsLogout (const TQString &)), this, TQT_SLOT(cancelJoin(const TQString &)));
-	connect(this, TQT_SIGNAL(gameOver()), this, TQT_SLOT(endGame()));
+	connect(this, TQ_SIGNAL(fibsWhoInfo(const TQString &)), this, TQ_SLOT(changeJoin(const TQString &)));
+	connect(this, TQ_SIGNAL(fibsLogout (const TQString &)), this, TQ_SLOT(cancelJoin(const TQString &)));
+	connect(this, TQ_SIGNAL(gameOver()), this, TQ_SLOT(endGame()));
 
 	/*
 	 * Creating, initializing and connecting the player list
 	 */
 	playerlist = new KFibsPlayerList(0, "fibs player list");
 
-	connect(this, TQT_SIGNAL(fibsWhoInfo(const TQString &)), playerlist, TQT_SLOT(changePlayer(const TQString &)));
-	connect(this, TQT_SIGNAL(fibsLogout (const TQString &)), playerlist, TQT_SLOT(deletePlayer(const TQString &)));
-	connect(this, TQT_SIGNAL(fibsWhoEnd()),           playerlist, TQT_SLOT(stopUpdate()));
-	connect(this, TQT_SIGNAL(fibsConnectionClosed()), playerlist, TQT_SLOT(stopUpdate()));
-	connect(this, TQT_SIGNAL(changePlayerStatus(const TQString &, int, bool)),
-		playerlist, TQT_SLOT(changePlayerStatus(const TQString &, int, bool)));
-	connect(playerlist, TQT_SIGNAL(fibsCommand(const TQString &)), this, TQT_SLOT(handleCommand(const TQString &)));
-	connect(playerlist, TQT_SIGNAL(fibsInvite(const TQString &)), this, TQT_SLOT(fibsRequestInvitation(const TQString &)));
+	connect(this, TQ_SIGNAL(fibsWhoInfo(const TQString &)), playerlist, TQ_SLOT(changePlayer(const TQString &)));
+	connect(this, TQ_SIGNAL(fibsLogout (const TQString &)), playerlist, TQ_SLOT(deletePlayer(const TQString &)));
+	connect(this, TQ_SIGNAL(fibsWhoEnd()),           playerlist, TQ_SLOT(stopUpdate()));
+	connect(this, TQ_SIGNAL(fibsConnectionClosed()), playerlist, TQ_SLOT(stopUpdate()));
+	connect(this, TQ_SIGNAL(changePlayerStatus(const TQString &, int, bool)),
+		playerlist, TQ_SLOT(changePlayerStatus(const TQString &, int, bool)));
+	connect(playerlist, TQ_SIGNAL(fibsCommand(const TQString &)), this, TQ_SLOT(handleCommand(const TQString &)));
+	connect(playerlist, TQ_SIGNAL(fibsInvite(const TQString &)), this, TQ_SLOT(fibsRequestInvitation(const TQString &)));
 
 	/*
 	 * Create, initialize and connect the chat window
 	 */
 	chatWindow = new KBgChat(0, "chat window");
 
-	connect(this, TQT_SIGNAL(chatMessage(const TQString &)), chatWindow, TQT_SLOT(handleData(const TQString &)));
-	connect(this, TQT_SIGNAL(fibsStartNewGame(const TQString &)), chatWindow, TQT_SLOT(startGame(const TQString &)));
-	connect(this, TQT_SIGNAL(gameOver()), chatWindow, TQT_SLOT(endGame()));
-	connect(this, TQT_SIGNAL(fibsLogout (const TQString &)), chatWindow, TQT_SLOT(deletePlayer(const TQString &)));
-	connect(chatWindow, TQT_SIGNAL(fibsCommand(const TQString &)), this, TQT_SLOT(handleCommand(const TQString &)));
-	connect(chatWindow, TQT_SIGNAL(fibsRequestInvitation(const TQString &)), this, TQT_SLOT(fibsRequestInvitation(const TQString &)));
-	connect(chatWindow, TQT_SIGNAL(personalMessage(const TQString &)), this, TQT_SLOT(personalMessage(const TQString &)));
-	connect(playerlist, TQT_SIGNAL(fibsTalk(const TQString &)), chatWindow, TQT_SLOT(fibsTalk(const TQString &)));
+	connect(this, TQ_SIGNAL(chatMessage(const TQString &)), chatWindow, TQ_SLOT(handleData(const TQString &)));
+	connect(this, TQ_SIGNAL(fibsStartNewGame(const TQString &)), chatWindow, TQ_SLOT(startGame(const TQString &)));
+	connect(this, TQ_SIGNAL(gameOver()), chatWindow, TQ_SLOT(endGame()));
+	connect(this, TQ_SIGNAL(fibsLogout (const TQString &)), chatWindow, TQ_SLOT(deletePlayer(const TQString &)));
+	connect(chatWindow, TQ_SIGNAL(fibsCommand(const TQString &)), this, TQ_SLOT(handleCommand(const TQString &)));
+	connect(chatWindow, TQ_SIGNAL(fibsRequestInvitation(const TQString &)), this, TQ_SLOT(fibsRequestInvitation(const TQString &)));
+	connect(chatWindow, TQ_SIGNAL(personalMessage(const TQString &)), this, TQ_SLOT(personalMessage(const TQString &)));
+	connect(playerlist, TQ_SIGNAL(fibsTalk(const TQString &)), chatWindow, TQ_SLOT(fibsTalk(const TQString &)));
 
 	/*
 	 * Creating, initializing and connecting the menu
@@ -2156,9 +2156,9 @@ KBgEngineFIBS::KBgEngineFIBS(TQWidget *parent, TQString *name, TQPopupMenu *pmen
 	/*
 	 * Initialize the FIBS submenu - this is also put in the play menu
 	 */
-	conAction  = new TDEAction(i18n("&Connect"),    0, this, TQT_SLOT(   connectFIBS()), this);
-	newAction  = new TDEAction(i18n("New Account"), 0, this, TQT_SLOT(    newAccount()), this);
-	disAction  = new TDEAction(i18n("&Disconnect"), 0, this, TQT_SLOT(disconnectFIBS()), this);
+	conAction  = new TDEAction(i18n("&Connect"),    0, this, TQ_SLOT(   connectFIBS()), this);
+	newAction  = new TDEAction(i18n("New Account"), 0, this, TQ_SLOT(    newAccount()), this);
+	disAction  = new TDEAction(i18n("&Disconnect"), 0, this, TQ_SLOT(disconnectFIBS()), this);
 
 	conAction->setEnabled(true ); conAction->plug(menu);
 	disAction->setEnabled(false); disAction->plug(menu);
@@ -2166,7 +2166,7 @@ KBgEngineFIBS::KBgEngineFIBS(TQWidget *parent, TQString *name, TQPopupMenu *pmen
 
 	menu->insertSeparator();
 
-	(invAction  = new TDEAction(i18n("&Invite..."), 0, this, TQT_SLOT(inviteDialog()), this))->plug(menu);
+	(invAction  = new TDEAction(i18n("&Invite..."), 0, this, TQ_SLOT(inviteDialog()), this))->plug(menu);
 
 	/*
 	 * Create and fill the response menu. This is for all these: type this or
@@ -2174,8 +2174,8 @@ KBgEngineFIBS::KBgEngineFIBS(TQWidget *parent, TQString *name, TQPopupMenu *pmen
 	 */
 	cmdMenuID = menu->insertItem(i18n("&Commands"), cmdMenu); {
 
-		(actAway  = new TDEAction(i18n("Away"), 0, this, TQT_SLOT(away()), this))->plug(cmdMenu);
-		(actBack  = new TDEAction(i18n("Back"), 0, this, TQT_SLOT(back()), this))->plug(cmdMenu);
+		(actAway  = new TDEAction(i18n("Away"), 0, this, TQ_SLOT(away()), this))->plug(cmdMenu);
+		(actBack  = new TDEAction(i18n("Back"), 0, this, TQ_SLOT(back()), this))->plug(cmdMenu);
 
 		actAway->setEnabled(true);
 		actBack->setEnabled(false);
@@ -2192,14 +2192,14 @@ KBgEngineFIBS::KBgEngineFIBS(TQWidget *parent, TQString *name, TQPopupMenu *pmen
 			fibsOpt[i] = 0;
 
 		fibsOpt[OptReady]   = new TDEToggleAction(i18n("Ready to Play"),
-							0, this, TQT_SLOT(toggle_ready()),   this);
+							0, this, TQ_SLOT(toggle_ready()),   this);
 		fibsOpt[OptRatings] = new TDEToggleAction(i18n("Show Rating Computations"),
-							0, this, TQT_SLOT(toggle_ratings()), this);
+							0, this, TQ_SLOT(toggle_ratings()), this);
 		fibsOpt[OptRatings]->setCheckedState(i18n("Hide Rating Computations"));
 		fibsOpt[OptGreedy]  = new TDEToggleAction(i18n("Greedy Bearoffs"),
-							0, this, TQT_SLOT(toggle_greedy()),  this);
+							0, this, TQ_SLOT(toggle_greedy()),  this);
 		fibsOpt[OptDouble]  = new TDEToggleAction(i18n("Ask for Doubles"),
-							0, this, TQT_SLOT(toggle_double()),  this);
+							0, this, TQ_SLOT(toggle_double()),  this);
 
 		for (int i = 0; i < NumFIBSOpt; i++)
 			if (fibsOpt[i])
@@ -2213,16 +2213,16 @@ KBgEngineFIBS::KBgEngineFIBS(TQWidget *parent, TQString *name, TQPopupMenu *pmen
 	 */
 	respMenuID = menu->insertItem(i18n("&Response"), respMenu); {
 
-		(actAccept  = new TDEAction(i18n("Accept"), 0, this, TQT_SLOT(accept()), this))->plug(respMenu);
-		(actReject  = new TDEAction(i18n("Reject"), 0, this, TQT_SLOT(reject()), this))->plug(respMenu);
+		(actAccept  = new TDEAction(i18n("Accept"), 0, this, TQ_SLOT(accept()), this))->plug(respMenu);
+		(actReject  = new TDEAction(i18n("Reject"), 0, this, TQ_SLOT(reject()), this))->plug(respMenu);
 
 		actAccept->setEnabled(false);
 		actReject->setEnabled(false);
 
 		respMenu->insertSeparator();
 
-		(actConti  = new TDEAction(i18n("Join"),  0, this, TQT_SLOT(match_conti()), this))->plug(respMenu);
-		(actLeave  = new TDEAction(i18n("Leave"), 0, this, TQT_SLOT(match_leave()), this))->plug(respMenu);
+		(actConti  = new TDEAction(i18n("Join"),  0, this, TQ_SLOT(match_conti()), this))->plug(respMenu);
+		(actLeave  = new TDEAction(i18n("Leave"), 0, this, TQ_SLOT(match_leave()), this))->plug(respMenu);
 
 		actConti->setEnabled(false);
 		actLeave->setEnabled(false);
@@ -2235,14 +2235,14 @@ KBgEngineFIBS::KBgEngineFIBS(TQWidget *parent, TQString *name, TQPopupMenu *pmen
 	joinMenuID = menu->insertItem(i18n("&Join"), joinMenu); {
 		numJoin = -1;
 
-		actJoin[0] = new TDEAction("", 0, this, TQT_SLOT(join_0()), this);
-		actJoin[1] = new TDEAction("", 0, this, TQT_SLOT(join_1()), this);
-		actJoin[2] = new TDEAction("", 0, this, TQT_SLOT(join_2()), this);
-		actJoin[3] = new TDEAction("", 0, this, TQT_SLOT(join_3()), this);
-		actJoin[4] = new TDEAction("", 0, this, TQT_SLOT(join_4()), this);
-		actJoin[5] = new TDEAction("", 0, this, TQT_SLOT(join_5()), this);
-		actJoin[6] = new TDEAction("", 0, this, TQT_SLOT(join_6()), this);
-		actJoin[7] = new TDEAction("", 0, this, TQT_SLOT(join_7()), this);
+		actJoin[0] = new TDEAction("", 0, this, TQ_SLOT(join_0()), this);
+		actJoin[1] = new TDEAction("", 0, this, TQ_SLOT(join_1()), this);
+		actJoin[2] = new TDEAction("", 0, this, TQ_SLOT(join_2()), this);
+		actJoin[3] = new TDEAction("", 0, this, TQ_SLOT(join_3()), this);
+		actJoin[4] = new TDEAction("", 0, this, TQ_SLOT(join_4()), this);
+		actJoin[5] = new TDEAction("", 0, this, TQ_SLOT(join_5()), this);
+		actJoin[6] = new TDEAction("", 0, this, TQ_SLOT(join_6()), this);
+		actJoin[7] = new TDEAction("", 0, this, TQ_SLOT(join_7()), this);
 	}
 
 	menu->setItemEnabled(joinMenuID, false);
@@ -2255,11 +2255,11 @@ KBgEngineFIBS::KBgEngineFIBS(TQWidget *parent, TQString *name, TQPopupMenu *pmen
 	 */
 	menu->insertSeparator();
 
-	(listAct = new TDEToggleAction(i18n("&Player List"), 0, this, TQT_SLOT(showList()), this))->plug(menu);
-	(chatAct = new TDEToggleAction(i18n("&Chat"),        0, this, TQT_SLOT(showChat()), this))->plug(menu);
+	(listAct = new TDEToggleAction(i18n("&Player List"), 0, this, TQ_SLOT(showList()), this))->plug(menu);
+	(chatAct = new TDEToggleAction(i18n("&Chat"),        0, this, TQ_SLOT(showChat()), this))->plug(menu);
 
-	connect(playerlist, TQT_SIGNAL(windowVisible(bool)), listAct, TQT_SLOT(setChecked(bool)));
-	connect(chatWindow, TQT_SIGNAL(windowVisible(bool)), chatAct, TQT_SLOT(setChecked(bool)));
+	connect(playerlist, TQ_SIGNAL(windowVisible(bool)), listAct, TQ_SLOT(setChecked(bool)));
+	connect(chatWindow, TQ_SIGNAL(windowVisible(bool)), chatAct, TQ_SLOT(setChecked(bool)));
 
 	/*
 	 * Create message IDs. This sets up a lot of regular expressions.
@@ -2287,7 +2287,7 @@ KBgEngineFIBS::KBgEngineFIBS(TQWidget *parent, TQString *name, TQPopupMenu *pmen
 	// FIXME: move the start to connect...
 
 	keepaliveTimer = new TQTimer(this);
-	connect(keepaliveTimer, TQT_SIGNAL(timeout()), this, TQT_SLOT(keepAlive()));
+	connect(keepaliveTimer, TQ_SIGNAL(timeout()), this, TQ_SLOT(keepAlive()));
 	keepaliveTimer->start(1200000);
 }
 
