@@ -1,5 +1,4 @@
-/* Yo Emacs, this -*- C++ -*-
-
+/*
   Copyright (C) 1999-2001 Jens Hoefkens
   jens@hoefkens.com
 
@@ -28,7 +27,7 @@
 #include <config.h>
 #endif
 
-#include <kgame.h>
+#include <kgame/kgame.h>
 #include <kdemacros.h>
 class TQObject;
 class KPlayer;
@@ -39,7 +38,7 @@ class KPlayer;
  */
 class KDE_EXPORT KBgGame : public KGame
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 
 public:
