@@ -119,11 +119,11 @@ KBgEngineOffline::KBgEngineOffline(TQWidget *parent, TQString *name, TQPopupMenu
     /*
      * Create engine specific actions
      */
-    d->mNew  = new TDEAction(i18n("&New Game..."),    0, this, TQT_SLOT(newGame()),  this);
-    d->mSwap = new TDEAction(i18n("&Swap Colors"), 0, this, TQT_SLOT(swapColors()), this);
+    d->mNew  = new TDEAction(i18n("&New Game..."),    0, this, TQ_SLOT(newGame()),  this);
+    d->mSwap = new TDEAction(i18n("&Swap Colors"), 0, this, TQ_SLOT(swapColors()), this);
 
     d->mEdit = new TDEToggleAction(i18n("&Edit Mode"), 0, this,
-                                 TQT_SLOT(toggleEditMode()), this);
+                                 TQ_SLOT(toggleEditMode()), this);
     d->mEdit->setChecked(false);
 
     /*
@@ -143,13 +143,13 @@ KBgEngineOffline::KBgEngineOffline(TQWidget *parent, TQString *name, TQPopupMenu
      * initialize the commit timeout
      */
     ct = new TQTimer(this);
-    connect(ct, TQT_SIGNAL(timeout()), this, TQT_SLOT(done()));
+    connect(ct, TQ_SIGNAL(timeout()), this, TQ_SLOT(done()));
 
     /*
      * internal statue variables
      */
     d->mRollFlag = d->mUndoFlag = d->mGameFlag = d->mDoneFlag = false;
-    connect(this, TQT_SIGNAL(allowCommand(int, bool)), this, TQT_SLOT(setAllowed(int, bool)));
+    connect(this, TQ_SIGNAL(allowCommand(int, bool)), this, TQ_SLOT(setAllowed(int, bool)));
 
     /*
      * Restore last stored settings
