@@ -62,7 +62,7 @@ MainQtWidget::MainQtWidget()
 
 	// we split the main view into 2 parts, one for the tasks, one for the
 	// statistics
-	TQSplitter* splitter = new TQSplitter(Qt::Horizontal, this,"TQSplitter");
+	TQSplitter* splitter = new TQSplitter(TQt::Horizontal, this,"TQSplitter");
 	setCentralWidget(splitter);
 
 	// the iconlist, where the user can choose the different exercises
@@ -94,18 +94,18 @@ MainQtWidget::MainQtWidget()
 	splitter->setResizeMode(m_statview, TQSplitter::FollowSizeHint);
 
 	// we must change the status of the menubar before another page is shown
-	TQObject::connect(m_exercises, TQT_SIGNAL(aboutToShowPage(TQWidget *)), this, TQT_SLOT(slotAboutToShowPage(TQWidget *)));
+	TQObject::connect(m_exercises, TQ_SIGNAL(aboutToShowPage(TQWidget *)), this, TQ_SLOT(slotAboutToShowPage(TQWidget *)));
 
 	// connect signals of the exercises and StatisticView, so that StatisticView
 	// gets informed about how the user solved a given task (wrong or correct)
-	TQObject::connect(m_taskview, TQT_SIGNAL(signalTaskSolvedCorrect()), m_statview, TQT_SLOT(addCorrect()));
-	TQObject::connect(m_taskview, TQT_SIGNAL(signalTaskSolvedWrong()), m_statview, TQT_SLOT(addWrong()));
-	TQObject::connect(m_exerciseCompare, TQT_SIGNAL(signalExerciseSolvedCorrect()), m_statview, TQT_SLOT(addCorrect()));
-	TQObject::connect(m_exerciseCompare, TQT_SIGNAL(signalExerciseSolvedWrong()), m_statview, TQT_SLOT(addWrong()));
-	TQObject::connect(m_exerciseConvert, TQT_SIGNAL(signalExerciseSolvedCorrect()), m_statview, TQT_SLOT(addCorrect()));
-	TQObject::connect(m_exerciseConvert, TQT_SIGNAL(signalExerciseSolvedWrong()), m_statview, TQT_SLOT(addWrong()));
-	TQObject::connect(m_exerciseFactorize, TQT_SIGNAL(signalExerciseSolvedCorrect()), m_statview, TQT_SLOT(addCorrect()));
-	TQObject::connect(m_exerciseFactorize, TQT_SIGNAL(signalExerciseSolvedWrong()), m_statview, TQT_SLOT(addWrong()));
+	TQObject::connect(m_taskview, TQ_SIGNAL(signalTaskSolvedCorrect()), m_statview, TQ_SLOT(addCorrect()));
+	TQObject::connect(m_taskview, TQ_SIGNAL(signalTaskSolvedWrong()), m_statview, TQ_SLOT(addWrong()));
+	TQObject::connect(m_exerciseCompare, TQ_SIGNAL(signalExerciseSolvedCorrect()), m_statview, TQ_SLOT(addCorrect()));
+	TQObject::connect(m_exerciseCompare, TQ_SIGNAL(signalExerciseSolvedWrong()), m_statview, TQ_SLOT(addWrong()));
+	TQObject::connect(m_exerciseConvert, TQ_SIGNAL(signalExerciseSolvedCorrect()), m_statview, TQ_SLOT(addCorrect()));
+	TQObject::connect(m_exerciseConvert, TQ_SIGNAL(signalExerciseSolvedWrong()), m_statview, TQ_SLOT(addWrong()));
+	TQObject::connect(m_exerciseFactorize, TQ_SIGNAL(signalExerciseSolvedCorrect()), m_statview, TQ_SLOT(addCorrect()));
+	TQObject::connect(m_exerciseFactorize, TQ_SIGNAL(signalExerciseSolvedWrong()), m_statview, TQ_SLOT(addWrong()));
 
 #if (TDE_VERSION_MINOR>=3) && (TDE_VERSION_MAJOR>=3)
 #else
@@ -155,19 +155,19 @@ void MainQtWidget::setupActions()
 {
 	// new task action
 	m_NewTaskAction = new TDEAction(i18n("&New"), "document-new", TDEStdAccel::shortcut(TDEStdAccel::New),
-				      TQT_TQOBJECT(this), TQT_SLOT(NewTask()),
+				      this, TQ_SLOT(NewTask()),
 				      actionCollection(), "NewTask");
 
 	// quit action
-	KStdAction::quit(TQT_TQOBJECT(kapp), TQT_SLOT(quit()), actionCollection());
+	KStdAction::quit(kapp, TQ_SLOT(quit()), actionCollection());
 
 	//
-	KStdAction::preferences(TQT_TQOBJECT(this),  TQT_SLOT( slotPrefs() ), actionCollection());
+	KStdAction::preferences(this,  TQ_SLOT( slotPrefs() ), actionCollection());
 
 	// a label just describing the Number of terms ComboBox
 	m_NrOfTermsLabel = new TQLabel(i18n("Terms:"), 0, "tde toolbar widget");
 	m_NrOfTermsLabelAction = new KWidgetAction(m_NrOfTermsLabel, i18n("Terms:"), ALT+Key_E,
-						   TQT_TQOBJECT(this), TQT_SLOT(NrOfTermsBoxSlot()),
+						   this, TQ_SLOT(NrOfTermsBoxSlot()),
 						   actionCollection(), "NrOfTermsLabelAction");
 
 	// the ComboBox holding possible values for term number
@@ -179,15 +179,15 @@ void MainQtWidget::setupActions()
 	m_NrOfTermsBox->setCurrentItem(m_nrRatios - 2);
 	TQToolTip::add( m_NrOfTermsBox, i18n( "The number of terms you want" ) );
 	TQWhatsThis::add( m_NrOfTermsBox, i18n( "Choose the number of terms (2, 3, 4 or 5) you want for calculating fractions." ) );
-	m_NrOfTermsBoxAction = new KWidgetAction(m_NrOfTermsBox, i18n("Number of Terms"), ALT+Key_E, TQT_TQOBJECT(this), TQT_SLOT(NrOfTermsBoxSlot()), actionCollection(), "NrOfTermsBoxAction");
+	m_NrOfTermsBoxAction = new KWidgetAction(m_NrOfTermsBox, i18n("Number of Terms"), ALT+Key_E, this, TQ_SLOT(NrOfTermsBoxSlot()), actionCollection(), "NrOfTermsBoxAction");
 
 	// now connect the ComboBox's signal textChanged() to the slot function
-	TQObject::connect(m_NrOfTermsBox, TQT_SIGNAL(activated(int)), TQT_TQOBJECT(this), TQT_SLOT(NrOfTermsBoxSlot()));
+	TQObject::connect(m_NrOfTermsBox, TQ_SIGNAL(activated(int)), this, TQ_SLOT(NrOfTermsBoxSlot()));
 
 	// a label just describing the max. main denominator ComboBox
 	m_MaxMainDenominatorLabel = new TQLabel(i18n("Max. main denominator:"), 0, "tde toolbar widget");
 	m_MaxMainDenominatorLabelAction = new KWidgetAction(m_MaxMainDenominatorLabel, i18n("Max. main denominator:"), ALT+Key_D,
-							    TQT_TQOBJECT(this), TQT_SLOT(MaxMainDenominatorBoxSlot()),
+							    this, TQ_SLOT(MaxMainDenominatorBoxSlot()),
 							    actionCollection(), "MaxMainDenominatorLabelAction");
 
 	// the ComboBox holding possible values for the max. main denominator
@@ -209,16 +209,16 @@ void MainQtWidget::setupActions()
 		case 50 : m_MaxMainDenominatorBox->setCurrentItem(3);
 					 break;
 	}
-	m_MaxMainDenominatorBoxAction = new KWidgetAction(m_MaxMainDenominatorBox, i18n("Maximal Main Denominator"), ALT+Key_D, TQT_TQOBJECT(this), TQT_SLOT(MaxMainDenominatorBoxSlot()), actionCollection(), "MaxMainDenominatorBoxAction");
+	m_MaxMainDenominatorBoxAction = new KWidgetAction(m_MaxMainDenominatorBox, i18n("Maximal Main Denominator"), ALT+Key_D, this, TQ_SLOT(MaxMainDenominatorBoxSlot()), actionCollection(), "MaxMainDenominatorBoxAction");
 
 	// now connect the ComboBox's signal textChanged() to the slot function
-	TQObject::connect(m_MaxMainDenominatorBox, TQT_SIGNAL(activated(int)),
-			 this, TQT_SLOT(MaxMainDenominatorBoxSlot()));
+	TQObject::connect(m_MaxMainDenominatorBox, TQ_SIGNAL(activated(int)),
+			 this, TQ_SLOT(MaxMainDenominatorBoxSlot()));
 
 	// a label just describing the operation ComboBox
 	m_OperationLabel = new TQLabel(i18n("Operations:"), 0, "tde toolbar widget");
 	m_OperationLabelAction = new KWidgetAction(m_OperationLabel, i18n("Operations:"), ALT+Key_O,
-						   TQT_TQOBJECT(this), TQT_SLOT(OperationBoxSlot()),
+						   this, TQ_SLOT(OperationBoxSlot()),
 						   actionCollection(), "OperationLabelAction");
 
 	// the ComboBox holding possible combinations for operations
@@ -236,10 +236,10 @@ void MainQtWidget::setupActions()
 	}
 	TQToolTip::add( m_OperationBox, i18n( "The operations you want" ) );
 	TQWhatsThis::add( m_OperationBox, i18n( "Choose the type of operations you want for calculating fractions: Addition/Substraction, Multiplication/Division or All Operations Mixed. If you choose All Operations Mixed, the program will randomly choose addition, substraction, multiplication and/or division." ) );
-	m_OperationBoxAction = new KWidgetAction(m_OperationBox, i18n("Operations:"), ALT+Key_O, TQT_TQOBJECT(this), TQT_SLOT(OperationBoxSlot()), actionCollection(), "OperationBoxAction");
+	m_OperationBoxAction = new KWidgetAction(m_OperationBox, i18n("Operations:"), ALT+Key_O, this, TQ_SLOT(OperationBoxSlot()), actionCollection(), "OperationBoxAction");
 
 	// now connect the ComboBox's signal textChanged() to the slot function
-	TQObject::connect(m_OperationBox, TQT_SIGNAL(activated(int)), this, TQT_SLOT(OperationBoxSlot()));
+	TQObject::connect(m_OperationBox, TQ_SIGNAL(activated(int)), this, TQ_SLOT(OperationBoxSlot()));
 	
 #if (TDE_VERSION_MINOR>=3) && (TDE_VERSION_MAJOR>=3)
 	if (!initialGeometrySet())
@@ -428,12 +428,12 @@ void MainQtWidget::slotPrefs()
 
 	// User edited the configuration - update your local copies of the 
 	// configuration data 
-	connect(configDialog, TQT_SIGNAL(settingsChanged()), this, TQT_SLOT(slotApplySettings()) ); 
+	connect(configDialog, TQ_SIGNAL(settingsChanged()), this, TQ_SLOT(slotApplySettings()) ); 
  
 	configDialog->show();
 /*
 	SettingsDialog * dlg = new SettingsDialog(this);
-	connect(dlg, TQT_SIGNAL(configChanged()), this, TQT_SLOT(slotApplySettings()));
+	connect(dlg, TQ_SIGNAL(configChanged()), this, TQ_SLOT(slotApplySettings()));
 
 	dlg->exec();
 
