@@ -63,7 +63,7 @@ KBackgroundRenderer::KBackgroundRenderer(int desk, int screen, bool drawBackgrou
     m_TilingEnabled = false;
 
     m_pTimer = new TQTimer(this);
-    connect(m_pTimer, TQT_SIGNAL(timeout()), TQT_SLOT(render()));
+    connect(m_pTimer, TQ_SIGNAL(timeout()), TQ_SLOT(render()));
 }
 
 
@@ -239,8 +239,8 @@ int KBackgroundRenderer::doBackground(bool quit)
         delete m_pProc;
         m_pProc = new KShellProcess;
         *m_pProc << file;
-        connect(m_pProc, TQT_SIGNAL(processExited(TDEProcess *)),
-                TQT_SLOT(slotBackgroundDone(TDEProcess *)));
+        connect(m_pProc, TQ_SIGNAL(processExited(TDEProcess *)),
+                TQ_SLOT(slotBackgroundDone(TDEProcess *)));
         m_pProc->start(KShellProcess::NotifyOnExit);
         retval = Wait;
         break;
@@ -384,7 +384,7 @@ wp_load:
 	    wpmode = NoWallpaper;
 	    goto wp_out;
 	}
-	m_Wallpaper = m_Wallpaper.convertDepth(32, Qt::DiffuseAlphaDither);
+	m_Wallpaper = m_Wallpaper.convertDepth(32, TQt::DiffuseAlphaDither);
 
 	// If we're previewing, scale the wallpaper down to make the preview
 	// look more like the real desktop.
@@ -628,7 +628,7 @@ void KBackgroundRenderer::fullWallpaperBlend()
 	m_Image = m_Background.copy();
 
 	if (m_Image.depth() < 32)
-	    m_Image = m_Image.convertDepth(32, Qt::DiffuseAlphaDither);
+	    m_Image = m_Image.convertDepth(32, TQt::DiffuseAlphaDither);
 
     } else {
 	m_Image.create(w, h, 32);
@@ -1160,7 +1160,7 @@ void KVirtualBGRenderer::desktopResized()
     {
         delete m_pPixmap;
         m_pPixmap = new TQPixmap(m_size);
-        m_pPixmap->fill(Qt::black);
+        m_pPixmap->fill(TQt::black);
     }
 
     initRenderers();
@@ -1228,7 +1228,7 @@ void KVirtualBGRenderer::initRenderers()
         KCrossBGRender *r = new KCrossBGRender(m_desk, eScreen, m_bDrawBackgroundPerScreen, m_pConfig);
         m_renderer.insert( i, r );
         r->setSize(renderSize(i));
-        connect( r, TQT_SIGNAL(imageDone(int,int)), this, TQT_SLOT(screenDone(int,int)) );
+        connect( r, TQ_SIGNAL(imageDone(int,int)), this, TQ_SLOT(screenDone(int,int)) );
     }
 }
 
@@ -1317,7 +1317,7 @@ void KVirtualBGRenderer::start()
         // If are screen sizes do not properly tile the overall virtual screen
         // size, then we want the untiled parts to be black for use in desktop
         // previews, etc
-        m_pPixmap->fill(Qt::black);
+        m_pPixmap->fill(TQt::black);
     }
 
     m_bFinished.fill(false);
