@@ -585,7 +585,7 @@ void MenuBarEditor::paintEvent( TQPaintEvent * )
 {
     TQPainter p( this );
     TQRect r = rect();
-    style().tqdrawPrimitive( TQStyle::PE_PanelMenuBar, &p,
+    style().drawPrimitive( TQStyle::PE_PanelMenuBar, &p,
 			   r, colorGroup() );
     drawItems( p );
 }
@@ -616,7 +616,7 @@ void MenuBarEditor::mouseDoubleClickEvent( TQMouseEvent * e )
 
 void MenuBarEditor::mouseMoveEvent( TQMouseEvent * e )
 {
-    if ( e->state() & Qt::LeftButton ) {
+    if ( e->state() & TQt::LeftButton ) {
 	if ( ( e->pos() - mousePressPos ).manhattanLength() > 3 ) {
 	    bool itemCreated = FALSE;
 	    bool isSeparator = FALSE;
@@ -818,7 +818,7 @@ void MenuBarEditor::keyPressEvent( TQKeyEvent * e )
 void MenuBarEditor::focusOutEvent( TQFocusEvent * e )
 {
     TQWidget * fw = tqApp->focusWidget();
-    if ( e->lostFocus() && !::tqqt_cast<PopupMenuEditor*>(fw) )
+    if ( e->lostFocus() && !::tqt_cast<PopupMenuEditor*>(fw) )
 	hideItem();
     update();
 }
