@@ -135,7 +135,7 @@ void WidgetDatabase::setupDataBase( int id )
 
     r = new WidgetDatabaseRecord;
     r->iconSet = "designer_pushbutton.png";
-    r->name = TQPUSHBUTTON_OBJECT_NAME_STRING;
+    r->name = "TQPushButton";
     r->group = widgetGroup( "Buttons" );
     r->toolTip = "Push Button";
     r->isCommon = TRUE;
@@ -144,7 +144,7 @@ void WidgetDatabase::setupDataBase( int id )
 
     r = new WidgetDatabaseRecord;
     r->iconSet = "designer_toolbutton.png";
-    r->name = TQTOOLBUTTON_OBJECT_NAME_STRING;
+    r->name = "TQToolButton";
     r->group = widgetGroup( "Buttons" );
     r->toolTip = "Tool Button";
 
@@ -152,7 +152,7 @@ void WidgetDatabase::setupDataBase( int id )
 
     r = new WidgetDatabaseRecord;
     r->iconSet = "designer_radiobutton.png";
-    r->name = TQRADIOBUTTON_OBJECT_NAME_STRING;
+    r->name = "TQRadioButton";
     r->group = widgetGroup( "Buttons" );
     r->toolTip = "Radio Button";
     r->isCommon = TRUE;
@@ -161,7 +161,7 @@ void WidgetDatabase::setupDataBase( int id )
 
     r = new WidgetDatabaseRecord;
     r->iconSet = "designer_checkbox.png";
-    r->name = TQCHECKBOX_OBJECT_NAME_STRING;
+    r->name = "TQCheckBox";
     r->group = widgetGroup( "Buttons" );
     r->toolTip = "Check Box";
     r->isCommon = TRUE;
@@ -170,7 +170,7 @@ void WidgetDatabase::setupDataBase( int id )
 
     r = new WidgetDatabaseRecord;
     r->iconSet = "designer_groupbox.png";
-    r->name = TQGROUPBOX_OBJECT_NAME_STRING;
+    r->name = "TQGroupBox";
     r->group = widgetGroup( "Containers" );
     r->toolTip = "Group Box";
     r->isContainer = TRUE;
@@ -179,7 +179,7 @@ void WidgetDatabase::setupDataBase( int id )
 
     r = new WidgetDatabaseRecord;
     r->iconSet = "designer_buttongroup.png";
-    r->name = TQBUTTONGROUP_OBJECT_NAME_STRING;
+    r->name = "TQButtonGroup";
     r->group = widgetGroup( "Containers" );
     r->toolTip = "Button Group";
     r->isContainer = TRUE;
@@ -189,7 +189,7 @@ void WidgetDatabase::setupDataBase( int id )
 
     r = new WidgetDatabaseRecord;
     r->iconSet = "designer_frame.png";
-    r->name = TQFRAME_OBJECT_NAME_STRING;
+    r->name = "TQFrame";
     r->group = widgetGroup( "Containers" );
     r->toolTip = "Frame";
     r->isContainer = TRUE;
@@ -198,7 +198,7 @@ void WidgetDatabase::setupDataBase( int id )
 
     r = new WidgetDatabaseRecord;
     r->iconSet = "designer_tabwidget.png";
-    r->name = TQTABWIDGET_OBJECT_NAME_STRING;
+    r->name = "TQTabWidget";
     r->group = widgetGroup( "Containers" );
     r->toolTip = "Tabwidget";
     r->isContainer = TRUE;
@@ -207,7 +207,7 @@ void WidgetDatabase::setupDataBase( int id )
 
     r = new WidgetDatabaseRecord;
     r->iconSet = "designer_widgetstack.png";
-    r->name = TQWIDGETSTACK_OBJECT_NAME_STRING;
+    r->name = "TQWidgetStack";
     r->group = widgetGroup( "Containers" );
     r->toolTip = "Widget Stack";
     r->isContainer = TRUE;
@@ -216,7 +216,7 @@ void WidgetDatabase::setupDataBase( int id )
 
     r = new WidgetDatabaseRecord;
     r->iconSet = "designer_toolbox.png";
-    r->name = TQTOOLBOX_OBJECT_NAME_STRING;
+    r->name = "TQToolBox";
     r->group = widgetGroup( "Containers" );
     r->toolTip = "Tool Box";
     r->isContainer = TRUE;
@@ -225,7 +225,7 @@ void WidgetDatabase::setupDataBase( int id )
 
     r = new WidgetDatabaseRecord;
     r->iconSet = "designer_listbox.png";
-    r->name = TQLISTBOX_OBJECT_NAME_STRING;
+    r->name = "TQListBox";
     r->group = widgetGroup( "Views" );
     r->toolTip = "List Box";
     r->isCommon = TRUE;
@@ -234,7 +234,7 @@ void WidgetDatabase::setupDataBase( int id )
 
     r = new WidgetDatabaseRecord;
     r->iconSet = "designer_listview.png";
-    r->name = TQLISTVIEW_OBJECT_NAME_STRING;
+    r->name = "TQListView";
     r->group = widgetGroup( "Views" );
     r->toolTip = "List View";
 
@@ -243,7 +243,7 @@ void WidgetDatabase::setupDataBase( int id )
 #if !defined(TQT_NO_ICONVIEW) || defined(UIC)
     r = new WidgetDatabaseRecord;
     r->iconSet = "designer_iconview.png";
-    r->name = TQICONVIEW_OBJECT_NAME_STRING;
+    r->name = "TQIconView";
     r->group = widgetGroup( "Views" );
     r->toolTip = "Icon View";
 
@@ -253,7 +253,7 @@ void WidgetDatabase::setupDataBase( int id )
 #if !defined(TQT_NO_TABLE)
     r = new WidgetDatabaseRecord;
     r->iconSet = "designer_table.png";
-    r->name = TQTABLE_OBJECT_NAME_STRING;
+    r->name = "TQTable";
     r->group = widgetGroup( "Views" );
     r->toolTip = "Table";
 
@@ -264,7 +264,7 @@ void WidgetDatabase::setupDataBase( int id )
     r = new WidgetDatabaseRecord;
     r->iconSet = "designer_datatable.png";
     r->includeFile = "tqdatatable.h";
-    r->name = TQDATATABLE_OBJECT_NAME_STRING;
+    r->name = "TQDataTable";
     r->group = widgetGroup( "Database" );
     r->toolTip = "Data Table";
 
@@ -273,7 +273,7 @@ void WidgetDatabase::setupDataBase( int id )
 
     r = new WidgetDatabaseRecord;
     r->iconSet = "designer_lineedit.png";
-    r->name = TQLINEEDIT_OBJECT_NAME_STRING;
+    r->name = "TQLineEdit";
     r->group = widgetGroup( "Input" );
     r->toolTip = "Line Edit";
     r->isCommon = TRUE;
@@ -282,7 +282,7 @@ void WidgetDatabase::setupDataBase( int id )
 
     r = new WidgetDatabaseRecord;
     r->iconSet = "designer_spinbox.png";
-    r->name = TQSPINBOX_OBJECT_NAME_STRING;
+    r->name = "TQSpinBox";
     r->group = widgetGroup( "Input" );
     r->toolTip = "Spin Box";
     r->isCommon = TRUE;
@@ -291,7 +291,7 @@ void WidgetDatabase::setupDataBase( int id )
 
     r = new WidgetDatabaseRecord;
     r->iconSet = "designer_dateedit.png";
-    r->name = TQDATEEDIT_OBJECT_NAME_STRING;
+    r->name = "TQDateEdit";
     r->group = widgetGroup( "Input" );
     r->toolTip = "Date Edit";
     r->includeFile = "tqdatetimeedit.h";
@@ -300,7 +300,7 @@ void WidgetDatabase::setupDataBase( int id )
 
     r = new WidgetDatabaseRecord;
     r->iconSet = "designer_timeedit.png";
-    r->name = TQTIMEEDIT_OBJECT_NAME_STRING;
+    r->name = "TQTimeEdit";
     r->group = widgetGroup( "Input" );
     r->toolTip = "Time Edit";
     r->includeFile = "tqdatetimeedit.h";
@@ -309,7 +309,7 @@ void WidgetDatabase::setupDataBase( int id )
 
     r = new WidgetDatabaseRecord;
     r->iconSet = "designer_datetimeedit.png";
-    r->name = TQDATETIMEEDIT_OBJECT_NAME_STRING;
+    r->name = "TQDateTimeEdit";
     r->group = widgetGroup( "Input" );
     r->toolTip = "Date-Time Edit";
     r->includeFile = "tqdatetimeedit.h";
@@ -318,7 +318,7 @@ void WidgetDatabase::setupDataBase( int id )
 
     r = new WidgetDatabaseRecord;
     r->iconSet = "designer_multilineedit.png";
-    r->name = TQMULTILINEEDIT_OBJECT_NAME_STRING;
+    r->name = "TQMultiLineEdit";
     r->group = widgetGroup( "Temp" );
     r->toolTip = "Multi Line Edit";
 
@@ -326,7 +326,7 @@ void WidgetDatabase::setupDataBase( int id )
 
     r = new WidgetDatabaseRecord;
     r->iconSet = "designer_richtextedit.png";
-    r->name = TQTEXTEDIT_OBJECT_NAME_STRING;
+    r->name = "TQTextEdit";
     r->group = widgetGroup( "Input" );
     r->toolTip = "Rich Text Edit";
     r->isCommon = TRUE;
@@ -335,7 +335,7 @@ void WidgetDatabase::setupDataBase( int id )
 
     r = new WidgetDatabaseRecord;
     r->iconSet = "designer_combobox.png";
-    r->name = TQCOMBOBOX_OBJECT_NAME_STRING;
+    r->name = "TQComboBox";
     r->group = widgetGroup( "Input" );
     r->toolTip = "Combo Box";
     r->isCommon = TRUE;
@@ -344,7 +344,7 @@ void WidgetDatabase::setupDataBase( int id )
 
     r = new WidgetDatabaseRecord;
     r->iconSet = "designer_slider.png";
-    r->name = TQSLIDER_OBJECT_NAME_STRING;
+    r->name = "TQSlider";
     r->group = widgetGroup( "Input" );
     r->toolTip = "Slider";
 
@@ -352,7 +352,7 @@ void WidgetDatabase::setupDataBase( int id )
 
     r = new WidgetDatabaseRecord;
     r->iconSet = "designer_scrollbar.png";
-    r->name = TQSCROLLBAR_OBJECT_NAME_STRING;
+    r->name = "TQScrollBar";
     r->group = widgetGroup( "Input" );
     r->toolTip = "Scrollbar";
 
@@ -360,7 +360,7 @@ void WidgetDatabase::setupDataBase( int id )
 
     r = new WidgetDatabaseRecord;
     r->iconSet = "designer_dial.png";
-    r->name = TQDIAL_OBJECT_NAME_STRING;
+    r->name = "TQDial";
     r->group = widgetGroup( "Input" );
     r->toolTip = "Dial";
 
@@ -368,7 +368,7 @@ void WidgetDatabase::setupDataBase( int id )
 
     r = new WidgetDatabaseRecord;
     r->iconSet = "designer_label.png";
-    r->name = TQLABEL_OBJECT_NAME_STRING;
+    r->name = "TQLabel";
     r->group = widgetGroup( "Temp" );
     r->toolTip = "Label";
 
@@ -395,7 +395,7 @@ void WidgetDatabase::setupDataBase( int id )
 
     r = new WidgetDatabaseRecord;
     r->iconSet = "designer_lcdnumber.png";
-    r->name = TQLCDNUMBER_OBJECT_NAME_STRING;
+    r->name = "TQLCDNumber";
     r->group = widgetGroup( "Display" );
     r->toolTip = "LCD Number";
 
@@ -413,7 +413,7 @@ void WidgetDatabase::setupDataBase( int id )
 
     r = new WidgetDatabaseRecord;
     r->iconSet = "designer_progress.png";
-    r->name = TQPROGRESSBAR_OBJECT_NAME_STRING;
+    r->name = "TQProgressBar";
     r->group = widgetGroup( "Display" );
     r->toolTip = "Progress Bar";
 
@@ -421,7 +421,7 @@ void WidgetDatabase::setupDataBase( int id )
 
     r = new WidgetDatabaseRecord;
     r->iconSet = "designer_textview.png";
-    r->name = TQTEXTVIEW_OBJECT_NAME_STRING;
+    r->name = "TQTextView";
     r->group = widgetGroup( "Temp" );
     r->toolTip = "Text View";
 
@@ -429,7 +429,7 @@ void WidgetDatabase::setupDataBase( int id )
 
     r = new WidgetDatabaseRecord;
     r->iconSet = "designer_textbrowser.png";
-    r->name = TQTEXTBROWSER_OBJECT_NAME_STRING;
+    r->name = "TQTextBrowser";
     r->group = widgetGroup( "Display" );
     r->toolTip = "Text Browser";
 
@@ -445,21 +445,21 @@ void WidgetDatabase::setupDataBase( int id )
     append( r );
 
     r = new WidgetDatabaseRecord;
-    r->name = TQWIDGET_OBJECT_NAME_STRING;
+    r->name = "TQWidget";
     r->isForm = TRUE;
     r->group = widgetGroup( "Forms" );
 
     append( r );
 
     r = new WidgetDatabaseRecord;
-    r->name = TQDIALOG_OBJECT_NAME_STRING;
+    r->name = "TQDialog";
     r->group = widgetGroup( "Forms" );
     r->isForm = TRUE;
 
     append( r );
 
     r = new WidgetDatabaseRecord;
-    r->name = TQWIZARD_OBJECT_NAME_STRING;
+    r->name = "TQWizard";
     r->group = widgetGroup( "Forms" );
     r->isContainer = TRUE;
 
@@ -473,7 +473,7 @@ void WidgetDatabase::setupDataBase( int id )
     append( r );
 
     r = new WidgetDatabaseRecord;
-    r->name = TQLAYOUTWIDGET_OBJECT_NAME_STRING;
+    r->name = "TQLayoutWidget";
     r->group = widgetGroup( "Temp" );
     r->includeFile = "";
     r->isContainer = TRUE;
@@ -481,7 +481,7 @@ void WidgetDatabase::setupDataBase( int id )
     append( r );
 
     r = new WidgetDatabaseRecord;
-    r->name = TQSPLITTER_OBJECT_NAME_STRING;
+    r->name = "TQSplitter";
     r->group = widgetGroup( "Temp" );
     r->includeFile = "tqsplitter.h";
     r->isContainer = TRUE;
@@ -514,7 +514,7 @@ void WidgetDatabase::setupDataBase( int id )
 
     r = new WidgetDatabaseRecord;
     r->iconSet = "";
-    r->name = TQMAINWINDOW_OBJECT_NAME_STRING;
+    r->name = "TQMainWindow";
     r->includeFile = "tqmainwindow.h";
     r->group = widgetGroup( "Temp" );
     r->isContainer = TRUE;
@@ -541,7 +541,7 @@ void WidgetDatabase::setupDataBase( int id )
 
     r = new WidgetDatabaseRecord;
     r->iconSet = "";
-    r->name = TQSCROLLVIEW_OBJECT_NAME_STRING;
+    r->name = "TQScrollView";
     r->includeFile = "tqscrollview.h";
     r->group = widgetGroup( "Temp" );
     r->isContainer = TRUE;
@@ -551,7 +551,7 @@ void WidgetDatabase::setupDataBase( int id )
 #ifndef TQT_NO_SQL
     r = new WidgetDatabaseRecord;
     r->iconSet = "";
-    r->name = TQDATABROWSER_OBJECT_NAME_STRING;
+    r->name = "TQDataBrowser";
     r->includeFile = "tqdatabrowser.h";
     r->group = widgetGroup( "Database" );
     r->toolTip = "Data Browser";
@@ -562,7 +562,7 @@ void WidgetDatabase::setupDataBase( int id )
 
     r = new WidgetDatabaseRecord;
     r->iconSet = "";
-    r->name = TQDATAVIEW_OBJECT_NAME_STRING;
+    r->name = "TQDataView";
     r->includeFile = "tqdataview.h";
     r->group = widgetGroup( "Database" );
     r->toolTip = "Data View";
@@ -760,7 +760,7 @@ TQString WidgetDatabase::createWidgetName( int id )
 {
     setupDataBase( id );
     TQString n = className( id );
-    if ( n == TQLAYOUTWIDGET_OBJECT_NAME_STRING )
+    if ( n == "TQLayoutWidget" )
 	n = "Layout";
     if ( n[ 0 ] == 'Q' && n[ 1 ].lower() != n[ 1 ] )
 	n = n.mid( 1 );
@@ -787,7 +787,7 @@ int WidgetDatabase::idFromClassName( const TQString &name )
     if ( i )
 	return *i;
     if ( name == "FormWindow" )
-	return idFromClassName( TQLAYOUTWIDGET_OBJECT_NAME_STRING );
+	return idFromClassName( "TQLayoutWidget" );
 #ifdef UIC
     setupDataBase( -2 );
     i = className2Id->find( name );
