@@ -72,9 +72,9 @@ TopLevel::TopLevel (TQWidget *, const char *name)
   windowList->append( this );
 
   statusbar_timer = new TQTimer(this);
-  connect(statusbar_timer, TQT_SIGNAL(timeout()),this,TQT_SLOT(timer_slot()));
+  connect(statusbar_timer, TQ_SIGNAL(timeout()),this,TQ_SLOT(timer_slot()));
 
-  connect(kapp,TQT_SIGNAL(tdedisplayPaletteChanged()),this,TQT_SLOT(set_colors()));
+  connect(kapp,TQ_SIGNAL(tdedisplayPaletteChanged()),this,TQ_SLOT(set_colors()));
 
   setupStatusBar();
   setupActions();
@@ -107,24 +107,24 @@ void TopLevel::setupEditWidget()
     eframe = new KEdit (this, "eframe");
     eframe->setOverwriteEnabled(true);
 
-    connect(eframe, TQT_SIGNAL(CursorPositionChanged()),this,
-           TQT_SLOT(statusbar_slot()));
-    connect(eframe, TQT_SIGNAL(toggle_overwrite_signal()),this,
-           TQT_SLOT(toggle_overwrite()));
-    connect(eframe, TQT_SIGNAL(gotUrlDrop(TQDropEvent*)), this,
-           TQT_SLOT(urlDrop_slot(TQDropEvent*)));
-    connect(eframe, TQT_SIGNAL(undoAvailable(bool)),undoAction,
-           TQT_SLOT(setEnabled(bool)));
-    connect(eframe, TQT_SIGNAL(redoAvailable(bool)),redoAction,
-           TQT_SLOT(setEnabled(bool)));
-    connect(eframe, TQT_SIGNAL(copyAvailable(bool)),cutAction,
-           TQT_SLOT(setEnabled(bool)));
-    connect(eframe, TQT_SIGNAL(copyAvailable(bool)),copyAction,
-           TQT_SLOT(setEnabled(bool)));
-    connect( eframe, TQT_SIGNAL(selectionChanged()),this,
-           TQT_SLOT(slotSelectionChanged()));
-    connect( eframe, TQT_SIGNAL(modificationChanged( bool)),
-           TQT_SLOT(setFileCaption()));
+    connect(eframe, TQ_SIGNAL(CursorPositionChanged()),this,
+           TQ_SLOT(statusbar_slot()));
+    connect(eframe, TQ_SIGNAL(toggle_overwrite_signal()),this,
+           TQ_SLOT(toggle_overwrite()));
+    connect(eframe, TQ_SIGNAL(gotUrlDrop(TQDropEvent*)), this,
+           TQ_SLOT(urlDrop_slot(TQDropEvent*)));
+    connect(eframe, TQ_SIGNAL(undoAvailable(bool)),undoAction,
+           TQ_SLOT(setEnabled(bool)));
+    connect(eframe, TQ_SIGNAL(redoAvailable(bool)),redoAction,
+           TQ_SLOT(setEnabled(bool)));
+    connect(eframe, TQ_SIGNAL(copyAvailable(bool)),cutAction,
+           TQ_SLOT(setEnabled(bool)));
+    connect(eframe, TQ_SIGNAL(copyAvailable(bool)),copyAction,
+           TQ_SLOT(setEnabled(bool)));
+    connect( eframe, TQ_SIGNAL(selectionChanged()),this,
+           TQ_SLOT(slotSelectionChanged()));
+    connect( eframe, TQ_SIGNAL(modificationChanged( bool)),
+           TQ_SLOT(setFileCaption()));
 
     undoAction->setEnabled(false);
     redoAction->setEnabled(false);
@@ -163,20 +163,20 @@ void TopLevel::setupEditWidget()
   right_mouse_button = new TQPopupMenu;
 
   right_mouse_button->insertItem (i18n("Open..."),
-				  this, 	TQT_SLOT(file_open()));
+				  this, 	TQ_SLOT(file_open()));
   right_mouse_button->insertItem (SmallIcon("document-save"),i18n("Save"),
-				  this, 	TQT_SLOT(file_save()));
+				  this, 	TQ_SLOT(file_save()));
   right_mouse_button->insertItem (SmallIcon("document-save-as"),i18n("Save As..."),
-				  this, TQT_SLOT(file_save_as()));
+				  this, TQ_SLOT(file_save_as()));
   right_mouse_button->insertSeparator(-1);
   right_mouse_button->insertItem(i18n("Copy"),
-				 this, TQT_SLOT(copy()));
+				 this, TQ_SLOT(copy()));
   right_mouse_button->insertItem(i18n("Paste"),
-				 this, TQT_SLOT(paste()));
+				 this, TQ_SLOT(paste()));
   right_mouse_button->insertItem(i18n("Cut"),
-				 this, TQT_SLOT(cut()));
+				 this, TQ_SLOT(cut()));
   right_mouse_button->insertItem(i18n("Select All"),
-				 this, TQT_SLOT(select_all()));
+				 this, TQ_SLOT(select_all()));
   eframe->installRBPopup(right_mouse_button);
   */
 }
@@ -193,42 +193,42 @@ void TopLevel::slotSelectionChanged()
 void TopLevel::setupActions()
 {
     // setup File menu
-    KStdAction::openNew(TQT_TQOBJECT(this), TQT_SLOT(file_new()), actionCollection());
-    KStdAction::open(TQT_TQOBJECT(this), TQT_SLOT(file_open()), actionCollection());
-    recent = KStdAction::openRecent(TQT_TQOBJECT(this), TQT_SLOT(openRecent(const KURL&)),
+    KStdAction::openNew(this, TQ_SLOT(file_new()), actionCollection());
+    KStdAction::open(this, TQ_SLOT(file_open()), actionCollection());
+    recent = KStdAction::openRecent(this, TQ_SLOT(openRecent(const KURL&)),
                                           actionCollection());
-    KStdAction::save(TQT_TQOBJECT(this), TQT_SLOT(file_save()), actionCollection());
-    KStdAction::saveAs(TQT_TQOBJECT(this), TQT_SLOT(file_save_as()), actionCollection());
-    KStdAction::close(TQT_TQOBJECT(this), TQT_SLOT(file_close()), actionCollection());
-    KStdAction::print(TQT_TQOBJECT(this), TQT_SLOT(print()), actionCollection());
-    KStdAction::mail(TQT_TQOBJECT(this), TQT_SLOT(mail()), actionCollection());
-    KStdAction::quit(TQT_TQOBJECT(this), TQT_SLOT(close()), actionCollection());
+    KStdAction::save(this, TQ_SLOT(file_save()), actionCollection());
+    KStdAction::saveAs(this, TQ_SLOT(file_save_as()), actionCollection());
+    KStdAction::close(this, TQ_SLOT(file_close()), actionCollection());
+    KStdAction::print(this, TQ_SLOT(print()), actionCollection());
+    KStdAction::mail(this, TQ_SLOT(mail()), actionCollection());
+    KStdAction::quit(this, TQ_SLOT(close()), actionCollection());
 
     // setup edit menu
-    undoAction = KStdAction::undo(TQT_TQOBJECT(this), TQT_SLOT(undo()), actionCollection());
-    redoAction = KStdAction::redo(TQT_TQOBJECT(this), TQT_SLOT(redo()), actionCollection());
-    cutAction = KStdAction::cut(TQT_TQOBJECT(this), TQT_SLOT(cut()), actionCollection());
-    copyAction = KStdAction::copy(TQT_TQOBJECT(this), TQT_SLOT(copy()), actionCollection());
-    KStdAction::pasteText(TQT_TQOBJECT(this), TQT_SLOT(paste()), actionCollection());
-    KStdAction::selectAll(TQT_TQOBJECT(this), TQT_SLOT(select_all()), actionCollection());
-    KStdAction::find(TQT_TQOBJECT(this), TQT_SLOT(search()), actionCollection());
-    KStdAction::findNext(TQT_TQOBJECT(this), TQT_SLOT(search_again()), actionCollection());
-    KStdAction::replace(TQT_TQOBJECT(this), TQT_SLOT(replace()), actionCollection());
+    undoAction = KStdAction::undo(this, TQ_SLOT(undo()), actionCollection());
+    redoAction = KStdAction::redo(this, TQ_SLOT(redo()), actionCollection());
+    cutAction = KStdAction::cut(this, TQ_SLOT(cut()), actionCollection());
+    copyAction = KStdAction::copy(this, TQ_SLOT(copy()), actionCollection());
+    KStdAction::pasteText(this, TQ_SLOT(paste()), actionCollection());
+    KStdAction::selectAll(this, TQ_SLOT(select_all()), actionCollection());
+    KStdAction::find(this, TQ_SLOT(search()), actionCollection());
+    KStdAction::findNext(this, TQ_SLOT(search_again()), actionCollection());
+    KStdAction::replace(this, TQ_SLOT(replace()), actionCollection());
 
-    (void)new TDEAction(i18n("&Insert File..."), 0, TQT_TQOBJECT(this), TQT_SLOT(file_insert()),
+    (void)new TDEAction(i18n("&Insert File..."), 0, this, TQ_SLOT(file_insert()),
                       actionCollection(), "insert_file");
-    (void)new TDEAction(i18n("In&sert Date"), 0, TQT_TQOBJECT(this), TQT_SLOT(insertDate()),
+    (void)new TDEAction(i18n("In&sert Date"), 0, this, TQ_SLOT(insertDate()),
                       actionCollection(), "insert_date");
-    (void)new TDEAction(i18n("Cl&ean Spaces"), 0, TQT_TQOBJECT(this), TQT_SLOT(clean_space()),
+    (void)new TDEAction(i18n("Cl&ean Spaces"), 0, this, TQ_SLOT(clean_space()),
                       actionCollection(), "clean_spaces");
 
     // setup Tools menu
-    KStdAction::spelling(TQT_TQOBJECT(this), TQT_SLOT(spellcheck()), actionCollection());
+    KStdAction::spelling(this, TQ_SLOT(spellcheck()), actionCollection());
 
     // setup Go menu
-    KStdAction::gotoLine(TQT_TQOBJECT(this), TQT_SLOT(gotoLine()), actionCollection());
+    KStdAction::gotoLine(this, TQ_SLOT(gotoLine()), actionCollection());
 
-    KStdAction::preferences(TQT_TQOBJECT(this), TQT_SLOT(showSettings()), actionCollection());
+    KStdAction::preferences(this, TQ_SLOT(showSettings()), actionCollection());
 }
 
 void TopLevel::setupStatusBar()
@@ -388,20 +388,20 @@ void TopLevel::spellcheck()
   statusBar()->changeItem(i18n("Spellcheck:  Started."), ID_GENERAL);
 
   initSpellConfig();
-  tdespell = new KSpell(this, i18n("Spellcheck"), TQT_TQOBJECT(this),
-	TQT_SLOT( spell_started(KSpell *)), tdespellconfigOptions);
+  tdespell = new KSpell(this, i18n("Spellcheck"), this,
+	TQ_SLOT( spell_started(KSpell *)), tdespellconfigOptions);
 
-  connect (tdespell, TQT_SIGNAL ( death()),
-          this, TQT_SLOT ( spell_finished( )));
+  connect (tdespell, TQ_SIGNAL ( death()),
+          this, TQ_SLOT ( spell_finished( )));
 
-  connect (tdespell, TQT_SIGNAL (progress (unsigned int)),
-          this, TQT_SLOT (spell_progress (unsigned int)));
-  connect (tdespell, TQT_SIGNAL (misspelling (const TQString &, const TQStringList &, unsigned int)),
-          eframe, TQT_SLOT (misspelling (const TQString &, const TQStringList &, unsigned int)));
-  connect (tdespell, TQT_SIGNAL (corrected (const TQString &, const TQString &, unsigned int)),
-          eframe, TQT_SLOT (corrected (const TQString &, const TQString &, unsigned int)));
-  connect (tdespell, TQT_SIGNAL (done(const TQString&)),
-		 this, TQT_SLOT (spell_done(const TQString&)));
+  connect (tdespell, TQ_SIGNAL (progress (unsigned int)),
+          this, TQ_SLOT (spell_progress (unsigned int)));
+  connect (tdespell, TQ_SIGNAL (misspelling (const TQString &, const TQStringList &, unsigned int)),
+          eframe, TQ_SLOT (misspelling (const TQString &, const TQStringList &, unsigned int)));
+  connect (tdespell, TQ_SIGNAL (corrected (const TQString &, const TQString &, unsigned int)),
+          eframe, TQ_SLOT (corrected (const TQString &, const TQString &, unsigned int)));
+  connect (tdespell, TQ_SIGNAL (done(const TQString&)),
+		 this, TQ_SLOT (spell_done(const TQString&)));
 }
 
 
@@ -831,7 +831,7 @@ void TopLevel::showSettings()
   initSpellConfig();
   TDEConfigDialog* dialog = new SettingsDialog(this, "settings", Prefs::self(), tdespellconfigOptions);
 
-  connect(dialog, TQT_SIGNAL(settingsChanged()), this, TQT_SLOT(updateSettings()));
+  connect(dialog, TQ_SIGNAL(settingsChanged()), this, TQ_SLOT(updateSettings()));
   dialog->show();
 }
 
@@ -1333,7 +1333,7 @@ SettingsDialog::SettingsDialog(TQWidget *parent, const char *name,TDEConfigSkele
   // Spelling
   addPage(spellConfig, i18n("Spelling"),
   	  "tools-check-spelling", i18n("Spelling Checker"));
-  connect(spellConfig, TQT_SIGNAL(configChanged()), this, TQT_SLOT(slotSpellConfigChanged()));
+  connect(spellConfig, TQ_SIGNAL(configChanged()), this, TQ_SLOT(slotSpellConfigChanged()));
 
   // Miscellaneous
   Misc *miscOptions = new Misc(0, "MiscSettings");
