@@ -88,12 +88,12 @@ void KEducaBuilder::init()
     form2Layout->setMargin( 0 );
 
     _split = new TQSplitter( mainView );
-    _split->setOrientation( Qt::Vertical );
+    _split->setOrientation( TQt::Vertical );
 
     _listAnswer = new TDEListBox( _split, "_listAnswer" );
     _listAnswer->setSizePolicy( TQSizePolicy( (TQSizePolicy::SizeType)7, (TQSizePolicy::SizeType)7, _listAnswer->sizePolicy().hasHeightForWidth() ) );
-    connect( _listAnswer,  TQT_SIGNAL( highlighted(TQListBoxItem *) ), TQT_TQOBJECT(this), TQT_SLOT( slotPreview(TQListBoxItem *) ) );
-    connect( _listAnswer,  TQT_SIGNAL( doubleClicked(TQListBoxItem *) ), TQT_TQOBJECT(this), TQT_SLOT( slotEditbyList(TQListBoxItem *) ) );
+    connect( _listAnswer,  TQ_SIGNAL( highlighted(TQListBoxItem *) ), this, TQ_SLOT( slotPreview(TQListBoxItem *) ) );
+    connect( _listAnswer,  TQ_SIGNAL( doubleClicked(TQListBoxItem *) ), this, TQ_SLOT( slotEditbyList(TQListBoxItem *) ) );
 
     _preview = new TQTextView( _split, "_preview" );
     _preview->setFrameShape( TQTextView::NoFrame );
@@ -111,21 +111,21 @@ void KEducaBuilder::init()
 /** Init menu bar settings */
 void KEducaBuilder::initMenuBar()
 {
-    KStdAction::openNew(TQT_TQOBJECT(this), TQT_SLOT( slotFileOpenNew() ), actionCollection());
-    KStdAction::open   (TQT_TQOBJECT(this), TQT_SLOT( slotFileOpen() ), actionCollection());
-    (void)new TDEAction(i18n("Open &Gallery..."), 0, 0, TQT_TQOBJECT(this), TQT_SLOT( slotGallery() ), actionCollection(), "open_gallery");
-    _recentFiles = KStdAction::openRecent(TQT_TQOBJECT(this), TQT_SLOT ( slotFileOpenURL(const KURL &)), actionCollection());
-    KStdAction::save   (TQT_TQOBJECT(this), TQT_SLOT( slotFileSave() ), actionCollection());
-    KStdAction::saveAs (TQT_TQOBJECT(this), TQT_SLOT( slotFileSaveAs() ), actionCollection());
-    KStdAction::print  (TQT_TQOBJECT(this), TQT_SLOT( slotFilePrint() ), actionCollection());
-    (void)new TDEAction(i18n("Document Info"), "application-vnd.tde.info", 0, TQT_TQOBJECT(this), TQT_SLOT( slotHeader() ), actionCollection(), "info_doc");
-    KStdAction::quit(TQT_TQOBJECT(this), TQT_SLOT( close() ), actionCollection());
+    KStdAction::openNew(this, TQ_SLOT( slotFileOpenNew() ), actionCollection());
+    KStdAction::open   (this, TQ_SLOT( slotFileOpen() ), actionCollection());
+    (void)new TDEAction(i18n("Open &Gallery..."), 0, 0, this, TQ_SLOT( slotGallery() ), actionCollection(), "open_gallery");
+    _recentFiles = KStdAction::openRecent(this, TQ_SLOT ( slotFileOpenURL(const KURL &)), actionCollection());
+    KStdAction::save   (this, TQ_SLOT( slotFileSave() ), actionCollection());
+    KStdAction::saveAs (this, TQ_SLOT( slotFileSaveAs() ), actionCollection());
+    KStdAction::print  (this, TQ_SLOT( slotFilePrint() ), actionCollection());
+    (void)new TDEAction(i18n("Document Info"), "application-vnd.tde.info", 0, this, TQ_SLOT( slotHeader() ), actionCollection(), "info_doc");
+    KStdAction::quit(this, TQ_SLOT( close() ), actionCollection());
 
-    (void)new TDEAction(i18n("&Add..."), "addquestion", 0, TQT_TQOBJECT(this), TQT_SLOT( slotAdd() ), actionCollection(), "question_add");
-    (void)new TDEAction(i18n("&Edit..."), "editquestion", 0, TQT_TQOBJECT(this), TQT_SLOT( slotEdit() ), actionCollection(), "question_edit");
-    (void)new TDEAction(i18n("&Remove"), "delquestion", 0, TQT_TQOBJECT(this), TQT_SLOT( slotRemove() ), actionCollection(), "question_remove");
-    (void)new TDEAction(i18n("&Up"), "go-up", 0, TQT_TQOBJECT(this), TQT_SLOT( slotUp() ), actionCollection(), "question_up");
-    (void)new TDEAction(i18n("&Down"), "go-down", 0, TQT_TQOBJECT(this), TQT_SLOT( slotDown() ), actionCollection(), "question_down");
+    (void)new TDEAction(i18n("&Add..."), "addquestion", 0, this, TQ_SLOT( slotAdd() ), actionCollection(), "question_add");
+    (void)new TDEAction(i18n("&Edit..."), "editquestion", 0, this, TQ_SLOT( slotEdit() ), actionCollection(), "question_edit");
+    (void)new TDEAction(i18n("&Remove"), "delquestion", 0, this, TQ_SLOT( slotRemove() ), actionCollection(), "question_remove");
+    (void)new TDEAction(i18n("&Up"), "go-up", 0, this, TQ_SLOT( slotUp() ), actionCollection(), "question_up");
+    (void)new TDEAction(i18n("&Down"), "go-down", 0, this, TQ_SLOT( slotDown() ), actionCollection(), "question_down");
 }
 
 /** Delete current document and start new */
