@@ -19,7 +19,7 @@ class myPopup;
 
 class popupManager : public TQObject
 {
-Q_OBJECT
+TQ_OBJECT
   
 	public:
 		popupManager(TQWidget *parent);
