@@ -310,8 +310,8 @@ KGrHero :: KGrHero (KGrCanvas * view, int x, int y)
   walkFrozen = FALSE;
   fallFrozen = FALSE;
 
-  connect (walkTimer, TQT_SIGNAL (timeout ()), TQT_SLOT (walkTimeDone ()));
-  connect (fallTimer, TQT_SIGNAL (timeout ()), TQT_SLOT (fallTimeDone ()));
+  connect (walkTimer, TQ_SIGNAL (timeout ()), TQ_SLOT (walkTimeDone ()));
+  connect (fallTimer, TQ_SIGNAL (timeout ()), TQ_SLOT (fallTimeDone ()));
 }
 
 int KGrHero::WALKDELAY = 0;
@@ -713,7 +713,7 @@ void KGrHero::digRight(){
 #ifdef QT3
 void KGrHero::setEnemyList(TQPtrList<KGrEnemy> *e)
 #else
-void KGrHero::setEnemyList(TQList<KGrEnemy> *e)
+void KGrHero::setEnemyList(TQPtrList<KGrEnemy> *e)
 #endif
 {
   enemies = e;
@@ -817,9 +817,9 @@ KGrEnemy :: KGrEnemy (KGrCanvas * view, int x, int y)
   captiveFrozen = FALSE;
 
   captiveTimer = new TQTimer (this);
-  connect (captiveTimer,TQT_SIGNAL(timeout()),TQT_SLOT(captiveTimeDone()));
-  connect (walkTimer, TQT_SIGNAL (timeout ()), TQT_SLOT (walkTimeDone ()));
-  connect (fallTimer, TQT_SIGNAL (timeout ()), TQT_SLOT (fallTimeDone ()));
+  connect (captiveTimer,TQ_SIGNAL(timeout()),TQ_SLOT(captiveTimeDone()));
+  connect (walkTimer, TQ_SIGNAL (timeout ()), TQ_SLOT (walkTimeDone ()));
+  connect (fallTimer, TQ_SIGNAL (timeout ()), TQ_SLOT (fallTimeDone ()));
 }
 
 int KGrEnemy::WALKDELAY = 0;
@@ -1673,7 +1673,7 @@ bool KGrEnemy::willNotFall (int x, int y)
 #ifdef QT3
 void KGrEnemy::setEnemyList(TQPtrList<KGrEnemy> *e)
 #else
-void KGrEnemy::setEnemyList(TQList<KGrEnemy> *e)
+void KGrEnemy::setEnemyList(TQPtrList<KGrEnemy> *e)
 #endif
 {
   enemies = e;
