@@ -117,26 +117,26 @@ kgpgOptions::kgpgOptions(TQWidget *parent, const char *name)
 	page1->clear_fkey->setIconSet(TQIconSet(TQPixmap(SmallIcon("clear_left"))));
 
         // The following widgets are managed manually.
-        connect(page1->change_fkey, TQT_SIGNAL(clicked()), this, TQT_SLOT(insertFileKey()));
-	connect(page1->clear_fkey, TQT_SIGNAL(clicked()), page1->kcfg_FileKey, TQT_SLOT(clear()));
-	connect(page1->change_akey, TQT_SIGNAL(clicked()), this, TQT_SLOT(insertAlwaysKey()));
-	connect(page1->clear_akey, TQT_SIGNAL(clicked()), page1->alwaysKey, TQT_SLOT(clear()));
-	connect(page1->alwaysKey, TQT_SIGNAL(textChanged(const TQString&)), this, TQT_SLOT(updateButtons()));
-	connect(page4->gpg_conf_path, TQT_SIGNAL(textChanged(const TQString&)), this, TQT_SLOT(updateButtons()));
-	connect(page4->gpg_home_path, TQT_SIGNAL(textChanged(const TQString&)), this, TQT_SLOT(updateButtons()));
-        connect(page4->use_agent, TQT_SIGNAL(toggled(bool)), this, TQT_SLOT(updateButtons()));
-	connect(page4->changeHome, TQT_SIGNAL(clicked()), this, TQT_SLOT(slotChangeHome()));
-	connect(page4->kcfg_PubKeyring, TQT_SIGNAL(toggled (bool)), page4->kcfg_PubKeyringUrl, TQT_SLOT(setEnabled(bool)));
-	connect(page4->kcfg_PubKeyring, TQT_SIGNAL(toggled (bool)), this, TQT_SLOT(checkAdditionalState(bool)));
-	connect(page4->kcfg_PrivKeyring, TQT_SIGNAL(toggled (bool)), page4->kcfg_PrivKeyringUrl, TQT_SLOT(setEnabled(bool)));
-	connect(page4->kcfg_PrivKeyring, TQT_SIGNAL(toggled (bool)), this, TQT_SLOT(checkAdditionalState(bool)));
-	connect(page6->server_add, TQT_SIGNAL(clicked()), this, TQT_SLOT(slotAddKeyServer()));
-	connect(page6->server_del, TQT_SIGNAL(clicked()), this, TQT_SLOT(slotDelKeyServer()));
-	connect(page6->server_default, TQT_SIGNAL(clicked()), this, TQT_SLOT(slotDefaultKeyServer()));
-	connect(page6->ServerBox, TQT_SIGNAL(currentChanged ( TQListBoxItem *)), this, TQT_SLOT(updateButtons()));
-	connect(page7->pushShredder, TQT_SIGNAL(clicked ()), this, TQT_SIGNAL(installShredder()));
+        connect(page1->change_fkey, TQ_SIGNAL(clicked()), this, TQ_SLOT(insertFileKey()));
+	connect(page1->clear_fkey, TQ_SIGNAL(clicked()), page1->kcfg_FileKey, TQ_SLOT(clear()));
+	connect(page1->change_akey, TQ_SIGNAL(clicked()), this, TQ_SLOT(insertAlwaysKey()));
+	connect(page1->clear_akey, TQ_SIGNAL(clicked()), page1->alwaysKey, TQ_SLOT(clear()));
+	connect(page1->alwaysKey, TQ_SIGNAL(textChanged(const TQString&)), this, TQ_SLOT(updateButtons()));
+	connect(page4->gpg_conf_path, TQ_SIGNAL(textChanged(const TQString&)), this, TQ_SLOT(updateButtons()));
+	connect(page4->gpg_home_path, TQ_SIGNAL(textChanged(const TQString&)), this, TQ_SLOT(updateButtons()));
+        connect(page4->use_agent, TQ_SIGNAL(toggled(bool)), this, TQ_SLOT(updateButtons()));
+	connect(page4->changeHome, TQ_SIGNAL(clicked()), this, TQ_SLOT(slotChangeHome()));
+	connect(page4->kcfg_PubKeyring, TQ_SIGNAL(toggled (bool)), page4->kcfg_PubKeyringUrl, TQ_SLOT(setEnabled(bool)));
+	connect(page4->kcfg_PubKeyring, TQ_SIGNAL(toggled (bool)), this, TQ_SLOT(checkAdditionalState(bool)));
+	connect(page4->kcfg_PrivKeyring, TQ_SIGNAL(toggled (bool)), page4->kcfg_PrivKeyringUrl, TQ_SLOT(setEnabled(bool)));
+	connect(page4->kcfg_PrivKeyring, TQ_SIGNAL(toggled (bool)), this, TQ_SLOT(checkAdditionalState(bool)));
+	connect(page6->server_add, TQ_SIGNAL(clicked()), this, TQ_SLOT(slotAddKeyServer()));
+	connect(page6->server_del, TQ_SIGNAL(clicked()), this, TQ_SLOT(slotDelKeyServer()));
+	connect(page6->server_default, TQ_SIGNAL(clicked()), this, TQ_SLOT(slotDefaultKeyServer()));
+	connect(page6->ServerBox, TQ_SIGNAL(currentChanged ( TQListBoxItem *)), this, TQ_SLOT(updateButtons()));
+	connect(page7->pushShredder, TQ_SIGNAL(clicked ()), this, TQ_SIGNAL(installShredder()));
 
-	//connect(this, TQT_SIGNAL(settingsChanged()), TQT_SLOT(updateSettings()));
+	//connect(this, TQ_SIGNAL(settingsChanged()), TQ_SLOT(updateSettings()));
 
 	keyGood=KGpgSettings::colorGood();
 	keyUnknown=KGpgSettings::colorUnknown();
