@@ -264,7 +264,7 @@ bool KJotsBook::isBookFile(const TQString& filename)
     {
         if ( folder.open(IO_ReadWrite) )
         {
-            TQTextStream st(TQT_TQIODEVICE(&folder));
+            TQTextStream st(&folder);
             st.setEncoding( KJotsSettings::unicode() ? TQTextStream::UnicodeUTF8 : TQTextStream::Locale );
             TQString buf = st.readLine().stripWhiteSpace();
 
@@ -306,7 +306,7 @@ bool KJotsBook::openBook(const TQString& filename)
     
             if ( file.exists() && file.open(IO_ReadWrite) ) //TODO: Implement read-only mode?
             {
-                TQTextStream st(TQT_TQIODEVICE(&file));
+                TQTextStream st(&file);
                 st.setEncoding(  KJotsSettings::unicode() ? TQTextStream::UnicodeUTF8 : TQTextStream::Locale );
                 TQString data = st.read();
 
@@ -388,7 +388,7 @@ bool KJotsBook::openBook(const TQString& filename)
 */
 bool KJotsBook::loadOldBook(TQFile &file)
 {
-    TQTextStream st(TQT_TQIODEVICE(&file));
+    TQTextStream st(&file);
     st.setEncoding(  KJotsSettings::unicode() ? TQTextStream::UnicodeUTF8 : TQTextStream::Locale );
     TQString buf = st.readLine();
 
@@ -541,8 +541,8 @@ void KJotsBook::saveToFile(KURL url, bool plainText, const TQString& encoding)
     m_saveProgressDialog->showCancelButton(false);
     m_saveProgressDialog->setAutoClose(true);
 
-    connect(job, TQT_SIGNAL(dataReq(TDEIO::Job*, TQByteArray&)), TQT_SLOT(saveDataReq(TDEIO::Job*, TQByteArray&)));
-    connect(job, TQT_SIGNAL(result( TDEIO::Job *)), TQT_SLOT(slotSaveResult( TDEIO::Job *)));
+    connect(job, TQ_SIGNAL(dataReq(TDEIO::Job*, TQByteArray&)), TQ_SLOT(saveDataReq(TDEIO::Job*, TQByteArray&)));
+    connect(job, TQ_SIGNAL(result( TDEIO::Job *)), TQ_SLOT(slotSaveResult( TDEIO::Job *)));
 
     m_saveInProgress = true;
 }
@@ -939,8 +939,8 @@ void KJotsPage::saveToFile(KURL url, bool plainText, const TQString& encoding)
         return;
     }
 
-    connect(job, TQT_SIGNAL(dataReq(TDEIO::Job*, TQByteArray&)), TQT_SLOT(saveDataReq(TDEIO::Job*, TQByteArray&)));
-    connect(job, TQT_SIGNAL(result( TDEIO::Job *)), TQT_SLOT(slotSaveResult( TDEIO::Job *)));
+    connect(job, TQ_SIGNAL(dataReq(TDEIO::Job*, TQByteArray&)), TQ_SLOT(saveDataReq(TDEIO::Job*, TQByteArray&)));
+    connect(job, TQ_SIGNAL(result( TDEIO::Job *)), TQ_SLOT(slotSaveResult( TDEIO::Job *)));
     m_saveInProgress = true;
 }
 
