@@ -64,9 +64,9 @@ KMAcctImap::KMAcctImap(AccountManager* aOwner, const TQString& aAccountName, uin
   mScheduler = 0;
   mNoopTimer.start( 60000 ); // // send a noop every minute
   mOpenFolders.setAutoDelete(true);
-  connect(kmkernel->imapFolderMgr(), TQT_SIGNAL(changed()),
-      this, TQT_SLOT(slotUpdateFolderList()));
-  connect(&mErrorTimer, TQT_SIGNAL(timeout()), TQT_SLOT(slotResetConnectionError()));
+  connect(kmkernel->imapFolderMgr(), TQ_SIGNAL(changed()),
+      this, TQ_SLOT(slotUpdateFolderList()));
+  connect(&mErrorTimer, TQ_SIGNAL(timeout()), TQ_SLOT(slotResetConnectionError()));
 
   TQString serNumUri = locateLocal( "data", "kmail/unfiltered." +
 				   TQString("%1").arg(KAccount::id()) );
@@ -304,9 +304,9 @@ void KMAcctImap::processNewMail(bool interactive)
 
   mMailCheckProgressItem->setTotalItems( mMailCheckFolders.count() );
   connect ( mMailCheckProgressItem,
-            TQT_SIGNAL( progressItemCanceled( KPIM::ProgressItem*) ),
+            TQ_SIGNAL( progressItemCanceled( KPIM::ProgressItem*) ),
             this,
-            TQT_SLOT( slotMailCheckCanceled() ) );
+            TQ_SLOT( slotMailCheckCanceled() ) );
 
   TQValueList<TQGuardedPtr<KMFolder> >::Iterator it;
   // first get the current count of unread-messages
@@ -336,8 +336,8 @@ void KMAcctImap::processNewMail(bool interactive)
         mCountRemainChecks++;
 
         if (imapFolder->isSelected()) {
-          connect(imapFolder, TQT_SIGNAL(folderComplete(KMFolderImap*, bool)),
-              this, TQT_SLOT(postProcessNewMail(KMFolderImap*, bool)));
+          connect(imapFolder, TQ_SIGNAL(folderComplete(KMFolderImap*, bool)),
+              this, TQ_SLOT(postProcessNewMail(KMFolderImap*, bool)));
           imapFolder->getFolder();
         } else if ( kmkernel->filterMgr()->atLeastOneIncomingFilterAppliesTo( id() ) &&
                     imapFolder->folder()->isSystemFolder() &&
@@ -345,13 +345,13 @@ void KMAcctImap::processNewMail(bool interactive)
           imapFolder->open("acctimap"); // will be closed in the folderSelected slot
           // first get new headers before we select the folder
           imapFolder->setSelected( true );
-          connect( imapFolder, TQT_SIGNAL( folderComplete( KMFolderImap*, bool ) ),
-                   this, TQT_SLOT( slotFolderSelected( KMFolderImap*, bool) ) );
+          connect( imapFolder, TQ_SIGNAL( folderComplete( KMFolderImap*, bool ) ),
+                   this, TQ_SLOT( slotFolderSelected( KMFolderImap*, bool) ) );
           imapFolder->getFolder();
         }
         else {
-          connect(imapFolder, TQT_SIGNAL(numUnreadMsgsChanged(KMFolder*)),
-              this, TQT_SLOT(postProcessNewMail(KMFolder*)));
+          connect(imapFolder, TQ_SIGNAL(numUnreadMsgsChanged(KMFolder*)),
+              this, TQ_SLOT(postProcessNewMail(KMFolder*)));
           bool ok = imapFolder->processNewMail(interactive);
           if (!ok)
           {
@@ -382,15 +382,15 @@ void KMAcctImap::processNewMail(bool interactive)
 //-----------------------------------------------------------------------------
 void KMAcctImap::postProcessNewMail(KMFolderImap* folder, bool)
 {
-  disconnect(folder, TQT_SIGNAL(folderComplete(KMFolderImap*, bool)),
-      this, TQT_SLOT(postProcessNewMail(KMFolderImap*, bool)));
+  disconnect(folder, TQ_SIGNAL(folderComplete(KMFolderImap*, bool)),
+      this, TQ_SLOT(postProcessNewMail(KMFolderImap*, bool)));
   postProcessNewMail(static_cast<KMFolder*>(folder->folder()));
 }
 
 void KMAcctImap::postProcessNewMail( KMFolder * folder )
 {
-  disconnect( folder->storage(), TQT_SIGNAL(numUnreadMsgsChanged(KMFolder*)),
-              this, TQT_SLOT(postProcessNewMail(KMFolder*)) );
+  disconnect( folder->storage(), TQ_SIGNAL(numUnreadMsgsChanged(KMFolder*)),
+              this, TQ_SLOT(postProcessNewMail(KMFolder*)) );
 
   if ( mMailCheckProgressItem ) {
     mMailCheckProgressItem->incCompletedItems();
@@ -420,7 +420,7 @@ void KMAcctImap::postProcessNewMail( KMFolder * folder )
     if (!mScheduler) {
 	mScheduler = new KMail::ActionScheduler( set, filters );
 	mScheduler->setAccountId( id() );
-	connect( mScheduler, TQT_SIGNAL(filtered(TQ_UINT32)), this, TQT_SLOT(slotFiltered(TQ_UINT32)) );
+	connect( mScheduler, TQ_SIGNAL(filtered(TQ_UINT32)), this, TQ_SLOT(slotFiltered(TQ_UINT32)) );
     } else {
 	mScheduler->setFilterList( filters );
     }
@@ -469,8 +469,8 @@ void KMAcctImap::postProcessNewMail( KMFolder * folder )
 	msg->setTransferInProgress(true);
 	if ( !msg->isComplete() ) {
 	  FolderJob *job = folder->createJob(msg);
-	  connect(job, TQT_SIGNAL(messageRetrieved(KMMessage*)),
-		  TQT_SLOT(slotFilterMsg(KMMessage*)));
+	  connect(job, TQ_SIGNAL(messageRetrieved(KMMessage*)),
+		  TQ_SLOT(slotFilterMsg(KMMessage*)));
 	  job->start();
 	} else {
 	  mFilterSerNumsToSave.remove( TQString( "%1" ).arg( *filterIt ) );
@@ -571,8 +571,8 @@ void KMAcctImap::slotResetConnectionError()
 void KMAcctImap::slotFolderSelected( KMFolderImap* folder, bool )
 {
   folder->setSelected( false );
-  disconnect( folder, TQT_SIGNAL( folderComplete( KMFolderImap*, bool ) ),
-	      this, TQT_SLOT( slotFolderSelected( KMFolderImap*, bool) ) );
+  disconnect( folder, TQ_SIGNAL( folderComplete( KMFolderImap*, bool ) ),
+	      this, TQ_SLOT( slotFolderSelected( KMFolderImap*, bool) ) );
   postProcessNewMail( static_cast<KMFolder*>(folder->folder()) );
   folder->close( "acctimap" );
 }
