@@ -81,7 +81,7 @@ typedef TQMap<int,KMFolder*> KMMenuToFolder;
 
 class KDE_EXPORT KMMainWidget : public TQWidget
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 
 public:
