@@ -208,7 +208,7 @@ KMixApplet::KMixApplet( const TQString& configFile, Type t,
 	m_errorLabel->setGeometry(0, 0, m_errorLabel->sizeHint().width(),  m_errorLabel->sizeHint().height() );
 	TQToolTip::add(m_errorLabel, "Select one of the available mixers");
 	resize( m_errorLabel->sizeHint() );
-	connect( m_errorLabel, TQT_SIGNAL(clicked()), this, TQT_SLOT(selectMixer()) );
+	connect( m_errorLabel, TQ_SIGNAL(clicked()), this, TQ_SLOT(selectMixer()) );
     }
     else {
 	// We know which mixer to use: Call positionChange(), which does all the creating
@@ -288,7 +288,7 @@ void KMixApplet::loadConfig( TDEConfig *config, const TQString &grp )
     if ( m_mixerWidget ) {
 	//config->setGroup( grp );
 	KMixToolBox::loadConfig(m_mixerWidget->_mdws, config, grp, "PanelApplet" );
-	connect(m_mixerWidget, TQT_SIGNAL(selectMixer()), this, TQT_SLOT(selectMixer()));
+	connect(m_mixerWidget, TQ_SIGNAL(selectMixer()), this, TQ_SLOT(selectMixer()));
     }
 }
 
@@ -369,7 +369,7 @@ void KMixApplet::positionChange(Position pos) {
 	    delete m_mixerWidget;
 	}
 	m_mixerWidget = new ViewApplet( this, _mixer->name(), _mixer, 0, pos );
-	connect ( m_mixerWidget, TQT_SIGNAL(appletContentChanged()), this, TQT_SLOT(updateGeometrySlot()) );
+	connect ( m_mixerWidget, TQ_SIGNAL(appletContentChanged()), this, TQ_SLOT(updateGeometrySlot()) );
 	m_mixerWidget->createDeviceWidgets();
 	_layout->add(m_mixerWidget);
 	_layout->activate();
@@ -383,7 +383,7 @@ void KMixApplet::positionChange(Position pos) {
 	//setFixedSize(panelAppletConstrainedSize.width(), panelAppletConstrainedSize.height() );
 	//kdDebug(67100) << "KMixApplet::positionChange(). New MDW is at " << panelAppletConstrainedSize << endl;
 	m_mixerWidget->show();
-	//connect( _mixer, TQT_SIGNAL(newVolumeLevels()), m_mixerWidget, TQT_SLOT(refreshVolumeLevels()) );
+	//connect( _mixer, TQ_SIGNAL(newVolumeLevels()), m_mixerWidget, TQ_SLOT(refreshVolumeLevels()) );
     }
 }
 
@@ -479,8 +479,8 @@ void KMixApplet::preferences()
     if ( !m_pref )
     {
         m_pref = new AppletConfigDialog( this );
-        connect(m_pref, TQT_SIGNAL(finished()), TQT_SLOT(preferencesDone()));
-        connect( m_pref, TQT_SIGNAL(applied()), TQT_SLOT(applyPreferences()) );
+        connect(m_pref, TQ_SIGNAL(finished()), TQ_SLOT(preferencesDone()));
+        connect( m_pref, TQ_SIGNAL(applied()), TQ_SLOT(applyPreferences()) );
 
         m_pref->setActiveColors(_colors.high     , _colors.low     , _colors.back);
         m_pref->setMutedColors (_colors.mutedHigh, _colors.mutedLow, _colors.mutedBack);
