@@ -122,7 +122,7 @@ private:
 
 class CommandHistory : public TQObject
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 
 public:
