@@ -19,8 +19,8 @@ QCompletionEdit::QCompletionEdit( TQWidget *parent, const char *name )
     listbox->setHScrollBarMode( TQScrollView::AlwaysOn );
     listbox->setVScrollBarMode( TQScrollView::AlwaysOn );
     listbox->setCornerWidget( new TQSizeGrip( listbox, "completion sizegrip" ) );
-    connect( this, TQT_SIGNAL( textChanged( const TQString & ) ),
-	     this, TQT_SLOT( textDidChange( const TQString & ) ) );
+    connect( this, TQ_SIGNAL( textChanged( const TQString & ) ),
+	     this, TQ_SLOT( textDidChange( const TQString & ) ) );
     popup->setFocusProxy( listbox );
     installEventFilter( this );
 }
