@@ -22,7 +22,7 @@
 */
 class KDE_EXPORT FontDialog : public TQLabel, public KommanderWidget
 {
-  Q_OBJECT
+  TQ_OBJECT
   
   TQ_PROPERTY(TQString populationText READ populationText WRITE setPopulationText DESIGNABLE false)
   TQ_PROPERTY(TQStringList associations READ associatedText WRITE setAssociatedText DESIGNABLE false)
