@@ -48,7 +48,7 @@ enum Functions {
 
 
 Table::Table(TQWidget *a_parent, const char *a_name)
-  : TQTable(a_parent, a_name), KommanderWidget(TQT_TQOBJECT(this))
+  : TQTable(a_parent, a_name), KommanderWidget(this)
 {
   TQStringList states;
   states << "default";
@@ -131,7 +131,7 @@ void Table::setCellWidget(int row, int col, const TQString & _widgetName)
   KommanderWidget *w = widgetByName(_widgetName);
   if (w)
   {
-    TQWidget *widget = TQT_TQWIDGET(w->object());
+    TQWidget *widget = static_cast<TQWidget*>(w->object());
     if (TQTable::cellWidget(row, col) != widget)
     { 
       setCurrentCell(-1, -1); //hack to not delete the cellwidget after clicking away to another cell. 
