@@ -38,7 +38,7 @@
 using namespace Diff2;
 
 KompareNavTreePart::KompareNavTreePart( TQWidget* parent, const char* name )
-	: KParts::ReadOnlyPart( TQT_TQOBJECT(parent), name ),
+	: KParts::ReadOnlyPart( parent, name ),
 	m_splitter( 0 ),
 	m_modelList( 0 ),
 	m_srcDirTree( 0 ),
@@ -53,7 +53,7 @@ KompareNavTreePart::KompareNavTreePart( TQWidget* parent, const char* name )
 	m_destination( "" ),
 	m_info( 0 )
 {
-	m_splitter = new TQSplitter( Qt::Horizontal );
+	m_splitter = new TQSplitter( TQt::Horizontal );
 
 	setWidget( m_splitter );
 
@@ -82,14 +82,14 @@ KompareNavTreePart::KompareNavTreePart( TQWidget* parent, const char* name )
 	m_changesList->setRootIsDecorated( false );
 	m_changesList->setSorting( 0, true );
 
-	connect( m_srcDirTree, TQT_SIGNAL(selectionChanged( TQListViewItem* )),
-	         this, TQT_SLOT(slotSrcDirTreeSelectionChanged( TQListViewItem* )) );
-	connect( m_destDirTree, TQT_SIGNAL(selectionChanged( TQListViewItem* )),
-	         this, TQT_SLOT(slotDestDirTreeSelectionChanged( TQListViewItem* )) );
-	connect( m_fileList, TQT_SIGNAL(selectionChanged( TQListViewItem* )),
-	         this, TQT_SLOT(slotFileListSelectionChanged( TQListViewItem* )) );
-	connect( m_changesList, TQT_SIGNAL(selectionChanged( TQListViewItem* )),
-	         this, TQT_SLOT(slotChangesListSelectionChanged( TQListViewItem* )) );
+	connect( m_srcDirTree, TQ_SIGNAL(selectionChanged( TQListViewItem* )),
+	         this, TQ_SLOT(slotSrcDirTreeSelectionChanged( TQListViewItem* )) );
+	connect( m_destDirTree, TQ_SIGNAL(selectionChanged( TQListViewItem* )),
+	         this, TQ_SLOT(slotDestDirTreeSelectionChanged( TQListViewItem* )) );
+	connect( m_fileList, TQ_SIGNAL(selectionChanged( TQListViewItem* )),
+	         this, TQ_SLOT(slotFileListSelectionChanged( TQListViewItem* )) );
+	connect( m_changesList, TQ_SIGNAL(selectionChanged( TQListViewItem* )),
+	         this, TQ_SLOT(slotChangesListSelectionChanged( TQListViewItem* )) );
 }
 
 KompareNavTreePart::~KompareNavTreePart()
