@@ -66,10 +66,10 @@ ConfigDialog::ConfigDialog(TQWidget *parent, const char *name) : TQDialog(parent
   setIcon(SmallIcon("metabar"));
 
   ok = new KPushButton(KStdGuiItem::ok(), this);
-  connect(ok, TQT_SIGNAL(clicked()), this, TQT_SLOT(accept()));
+  connect(ok, TQ_SIGNAL(clicked()), this, TQ_SLOT(accept()));
   
   cancel = new KPushButton(KStdGuiItem::cancel(), this);
-  connect(cancel, TQT_SIGNAL(clicked()), this, TQT_SLOT(reject()));
+  connect(cancel, TQ_SIGNAL(clicked()), this, TQ_SLOT(reject()));
   
   TQTabWidget *tab = new TQTabWidget(this);
   
@@ -77,7 +77,7 @@ ConfigDialog::ConfigDialog(TQWidget *parent, const char *name) : TQDialog(parent
   config->setGroup("General");
   TQWidget *general = new TQWidget;
   
-  TQGroupBox *entries_group = new TQGroupBox(2, Qt::Horizontal, i18n("Items"), general);
+  TQGroupBox *entries_group = new TQGroupBox(2, TQt::Horizontal, i18n("Items"), general);
   entries_group->setSizePolicy(TQSizePolicy::Preferred, TQSizePolicy::Preferred);
   
   TQLabel *entries_label = new TQLabel(i18n("Open with:"), entries_group);
@@ -97,7 +97,7 @@ ConfigDialog::ConfigDialog(TQWidget *parent, const char *name) : TQDialog(parent
   actions_label->setBuddy(max_actions);
   
   
-  TQGroupBox *appearance_group = new TQGroupBox(1, Qt::Horizontal, i18n("Appearance"), general);
+  TQGroupBox *appearance_group = new TQGroupBox(1, TQt::Horizontal, i18n("Appearance"), general);
   appearance_group->setSizePolicy(TQSizePolicy::Preferred, TQSizePolicy::Preferred);
   
   animate = new TQCheckBox(i18n("Animate resize"), appearance_group);
@@ -109,7 +109,7 @@ ConfigDialog::ConfigDialog(TQWidget *parent, const char *name) : TQDialog(parent
   showframe = new TQCheckBox(i18n("Show frame"), appearance_group);
   showframe->setChecked(config->readBoolEntry("ShowFrame", true));
   
-  TQGroupBox *theme_group = new TQGroupBox(2, Qt::Horizontal, i18n("Themes"), general);
+  TQGroupBox *theme_group = new TQGroupBox(2, TQt::Horizontal, i18n("Themes"), general);
   theme_group->setSizePolicy(TQSizePolicy::Preferred, TQSizePolicy::Preferred);
   
   themes = new KComboBox(theme_group);
@@ -117,7 +117,7 @@ ConfigDialog::ConfigDialog(TQWidget *parent, const char *name) : TQDialog(parent
   
   install_theme = new KPushButton(i18n("Install New Theme..."), theme_group);
   install_theme->setSizePolicy(TQSizePolicy::Preferred, TQSizePolicy::Preferred);
-  connect(install_theme, TQT_SIGNAL(clicked()), this, TQT_SLOT(installTheme()));
+  connect(install_theme, TQ_SIGNAL(clicked()), this, TQ_SLOT(installTheme()));
   
   loadThemes();
   
@@ -125,23 +125,23 @@ ConfigDialog::ConfigDialog(TQWidget *parent, const char *name) : TQDialog(parent
   TQWidget *links = new TQWidget;
   
   link_create = new KPushButton(i18n("New..."), links);
-  connect(link_create, TQT_SIGNAL(clicked()), this, TQT_SLOT(createLink()));
+  connect(link_create, TQ_SIGNAL(clicked()), this, TQ_SLOT(createLink()));
   
   link_delete = new KPushButton(i18n("Delete"), links);
-  connect(link_delete, TQT_SIGNAL(clicked()), this, TQT_SLOT(deleteLink()));
+  connect(link_delete, TQ_SIGNAL(clicked()), this, TQ_SLOT(deleteLink()));
   
   link_edit = new KPushButton(i18n("Edit..."), links);
-  connect(link_edit, TQT_SIGNAL(clicked()), this, TQT_SLOT(editLink()));  
+  connect(link_edit, TQ_SIGNAL(clicked()), this, TQ_SLOT(editLink()));  
   
   link_up = new KPushButton(links);
   link_up->setIconSet(SmallIconSet("go-up"));
   link_up->setEnabled(false);
-  connect(link_up, TQT_SIGNAL(clicked()), this, TQT_SLOT(moveLinkUp()));
+  connect(link_up, TQ_SIGNAL(clicked()), this, TQ_SLOT(moveLinkUp()));
   
   link_down = new KPushButton(links);
   link_down->setIconSet(SmallIconSet("go-down"));
   link_down->setEnabled(false);
-  connect(link_down, TQT_SIGNAL(clicked()), this, TQT_SLOT(moveLinkDown()));
+  connect(link_down, TQ_SIGNAL(clicked()), this, TQ_SLOT(moveLinkDown()));
     
   link_list = new TDEListView(links);
   link_list->setSizePolicy(TQSizePolicy::Expanding, TQSizePolicy::Expanding);
@@ -149,8 +149,8 @@ ConfigDialog::ConfigDialog(TQWidget *parent, const char *name) : TQDialog(parent
   link_list->setItemsMovable(TRUE);
   link_list->addColumn(i18n("Name"));
   link_list->addColumn(i18n("Address"));
-  connect(link_list, TQT_SIGNAL(doubleClicked(TQListViewItem*)), this, TQT_SLOT(editLink(TQListViewItem*)));
-  connect(link_list, TQT_SIGNAL(selectionChanged()), TQT_SLOT(updateArrows()));
+  connect(link_list, TQ_SIGNAL(doubleClicked(TQListViewItem*)), this, TQ_SLOT(editLink(TQListViewItem*)));
+  connect(link_list, TQ_SIGNAL(selectionChanged()), TQ_SLOT(updateArrows()));
   
   TQWidget *actionPage = new TQWidget;
   
@@ -311,10 +311,10 @@ void ConfigDialog::createLink()
   main->setIcon(SmallIcon("metabar"));
   
   KPushButton *ok = new KPushButton(KStdGuiItem::ok(), main);
-  connect(ok, TQT_SIGNAL(clicked()), main, TQT_SLOT(accept()));
+  connect(ok, TQ_SIGNAL(clicked()), main, TQ_SLOT(accept()));
   
   KPushButton *cancel = new KPushButton(KStdGuiItem::cancel(), main);
-  connect(cancel, TQT_SIGNAL(clicked()), main, TQT_SLOT(reject()));
+  connect(cancel, TQ_SIGNAL(clicked()), main, TQ_SLOT(reject()));
   
   TQLineEdit *name = new TQLineEdit(i18n("New link"), main);
   TQLineEdit *url = new TQLineEdit("file:/", main);
@@ -394,10 +394,10 @@ void ConfigDialog::editLink(TQListViewItem *item)
     main->setIcon(SmallIcon("metabar"));
     
     KPushButton *ok = new KPushButton(KStdGuiItem::ok(), main);
-    connect(ok, TQT_SIGNAL(clicked()), main, TQT_SLOT(accept()));
+    connect(ok, TQ_SIGNAL(clicked()), main, TQ_SLOT(accept()));
     
     KPushButton *cancel = new KPushButton(KStdGuiItem::cancel(), main);
-    connect(cancel, TQT_SIGNAL(clicked()), main, TQT_SLOT(reject()));
+    connect(cancel, TQ_SIGNAL(clicked()), main, TQ_SLOT(reject()));
     
     TQLineEdit *name = new TQLineEdit(linkList[item]->name, main);
     TQLineEdit *url = new TQLineEdit(linkList[item]->url, main);
