@@ -56,7 +56,7 @@ class Picture;
  */
 class KOPETE_EXPORT MetaContact : public ContactListElement, public NotifyDataObject
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 
 	TQ_PROPERTY( TQString displayName READ displayName WRITE setDisplayName )
