@@ -50,20 +50,20 @@ IRCChannelContact::IRCChannelContact(IRCContactManager *contactManager, const TQ
 	KIRC::Engine *engine = kircEngine();
 
 	mInfoTimer = new TQTimer( this );
-	TQObject::connect(mInfoTimer, TQT_SIGNAL(timeout()), this, TQT_SLOT( slotUpdateInfo() ) );
+	TQObject::connect(mInfoTimer, TQ_SIGNAL(timeout()), this, TQ_SLOT( slotUpdateInfo() ) );
 
-	TQObject::connect(engine, TQT_SIGNAL(incomingUserIsAway(const TQString &, const TQString &)),
-		this, TQT_SLOT(slotIncomingUserIsAway(const TQString &, const TQString &)));
+	TQObject::connect(engine, TQ_SIGNAL(incomingUserIsAway(const TQString &, const TQString &)),
+		this, TQ_SLOT(slotIncomingUserIsAway(const TQString &, const TQString &)));
 
-	TQObject::connect(engine, TQT_SIGNAL(incomingListedChan(const TQString &, uint, const TQString &)),
-		this, TQT_SLOT(slotChannelListed(const TQString &, uint, const TQString &)));
+	TQObject::connect(engine, TQ_SIGNAL(incomingListedChan(const TQString &, uint, const TQString &)),
+		this, TQ_SLOT(slotChannelListed(const TQString &, uint, const TQString &)));
 
 	actionJoin = 0L;
-	actionModeT = new TDEToggleAction(i18n("Only Operators Can Change &Topic"), 0, this, TQT_SLOT(slotModeChanged()), this );
-	actionModeN = new TDEToggleAction(i18n("&No Outside Messages"), 0, this, TQT_SLOT(slotModeChanged()), this );
-	actionModeS = new TDEToggleAction(i18n("&Secret"), 0, this, TQT_SLOT(slotModeChanged()), this );
-	actionModeM = new TDEToggleAction(i18n("&Moderated"), 0, this, TQT_SLOT(slotModeChanged()), this );
-	actionModeI = new TDEToggleAction(i18n("&Invite Only"), 0, this, TQT_SLOT(slotModeChanged()), this );
+	actionModeT = new TDEToggleAction(i18n("Only Operators Can Change &Topic"), 0, this, TQ_SLOT(slotModeChanged()), this );
+	actionModeN = new TDEToggleAction(i18n("&No Outside Messages"), 0, this, TQ_SLOT(slotModeChanged()), this );
+	actionModeS = new TDEToggleAction(i18n("&Secret"), 0, this, TQ_SLOT(slotModeChanged()), this );
+	actionModeM = new TDEToggleAction(i18n("&Moderated"), 0, this, TQ_SLOT(slotModeChanged()), this );
+	actionModeI = new TDEToggleAction(i18n("&Invite Only"), 0, this, TQ_SLOT(slotModeChanged()), this );
 	actionHomePage = 0L;
 
 	updateStatus();
@@ -261,7 +261,7 @@ void IRCChannelContact::slotAddNicknames()
 		mJoinedNicks.pop_front();
 	}
 
-	TQTimer::singleShot( 0, this, TQT_SLOT( slotAddNicknames() ) );
+	TQTimer::singleShot( 0, this, TQ_SLOT( slotAddNicknames() ) );
 }
 
 void IRCChannelContact::channelTopic(const TQString &topic)
@@ -303,9 +303,9 @@ void IRCChannelContact::join()
 
 	if (manager()) {
 		connect(manager(),
-			TQT_SIGNAL(onlineStatusChanged(Kopete::Contact *, const Kopete::OnlineStatus &,
+			TQ_SIGNAL(onlineStatusChanged(Kopete::Contact *, const Kopete::OnlineStatus &,
 					const Kopete::OnlineStatus &)),
-			TQT_SLOT(slotOnlineStatusChanged(Kopete::Contact *, const Kopete::OnlineStatus &,
+			TQ_SLOT(slotOnlineStatusChanged(Kopete::Contact *, const Kopete::OnlineStatus &,
 					const Kopete::OnlineStatus &)));
 	}
 }
@@ -658,15 +658,15 @@ TQPtrList<TDEAction> *IRCChannelContact::customContextMenuActions()
 	TQPtrList<TDEAction> *mCustomActions = new TQPtrList<TDEAction>();
 	if( !actionJoin )
 	{
-		actionJoin = new TDEAction(i18n("&Join"), 0, this, TQT_SLOT(join()), this, "actionJoin");
-		actionPart = new TDEAction(i18n("&Part"), 0, this, TQT_SLOT(partAction()), this, "actionPart");
-		actionTopic = new TDEAction(i18n("Change &Topic..."), 0, this, TQT_SLOT(setTopic()), this, "actionTopic");
+		actionJoin = new TDEAction(i18n("&Join"), 0, this, TQ_SLOT(join()), this, "actionJoin");
+		actionPart = new TDEAction(i18n("&Part"), 0, this, TQ_SLOT(partAction()), this, "actionPart");
+		actionTopic = new TDEAction(i18n("Change &Topic..."), 0, this, TQ_SLOT(setTopic()), this, "actionTopic");
 		actionModeMenu = new TDEActionMenu(i18n("Channel Modes"), 0, this, "actionModeMenu");
 
 		if( !property(m_protocol->propHomepage).value().isNull() )
 		{
 			actionHomePage = new TDEAction( i18n("Visit &Homepage"), 0, this,
-				TQT_SLOT(slotHomepage()), this, "actionHomepage");
+				TQ_SLOT(slotHomepage()), this, "actionHomepage");
 		}
 		else if( actionHomePage )
 		{
@@ -681,8 +681,8 @@ TQPtrList<TDEAction> *IRCChannelContact::customContextMenuActions()
 		actionModeMenu->setEnabled( true );
 
 		codecAction = new KCodecAction( i18n("&Encoding"), 0, this, "selectcharset" );
-		connect( codecAction, TQT_SIGNAL( activated( const TQTextCodec * ) ),
-			this, TQT_SLOT( setCodec( const TQTextCodec *) ) );
+		connect( codecAction, TQ_SIGNAL( activated( const TQTextCodec * ) ),
+			this, TQ_SLOT( setCodec( const TQTextCodec *) ) );
 		codecAction->setCodec( codec() );
 	}
 
