@@ -270,7 +270,7 @@ void JT_UnRegister::onGo()
 
 	d->jt_reg = new JT_Register(this);
 	d->jt_reg->getForm(d->j);
-	connect(d->jt_reg, TQT_SIGNAL(finished()), TQT_SLOT(getFormFinished()));
+	connect(d->jt_reg, TQ_SIGNAL(finished()), TQ_SLOT(getFormFinished()));
 	d->jt_reg->go(false);
 }
 
@@ -279,7 +279,7 @@ void JT_UnRegister::getFormFinished()
 	disconnect(d->jt_reg, 0, this, 0);
 
 	d->jt_reg->unreg(d->j);
-	connect(d->jt_reg, TQT_SIGNAL(finished()), TQT_SLOT(unregFinished()));
+	connect(d->jt_reg, TQ_SIGNAL(finished()), TQ_SLOT(unregFinished()));
 	d->jt_reg->go(false);
 }
 
