@@ -31,7 +31,7 @@ class MSNDebugRawCommand_base;
  */
 class MSNDebugRawCmdDlg : public KDialogBase
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 
 public:
