@@ -31,7 +31,7 @@
 #include <tdefile.h>
 #include <korganizer/koeventviewer.h>
 #include <libkcal/scheduler.h>
-#include <tdepimmacros.h>
+#include <kdemacros.h>
 
 #include "koglobals.h"
 #include "interfaces/korganizer/calendarviewbase.h"
@@ -80,7 +80,7 @@ class CalendarViewExtension : public TQWidget
 */
 class KDE_EXPORT CalendarView : public KOrg::CalendarViewBase, public Calendar::Observer
 {
-    Q_OBJECT
+    TQ_OBJECT
   
   public:
     /**
