@@ -92,15 +92,15 @@ KOPrefsDialogMain::KOPrefsDialogMain( TQWidget *parent, const char *name )
 
   KPrefsWidBool *emailControlCenter =
       addWidBool( KOPrefs::instance()->emailControlCenterItem(), topFrame );
-  connect(emailControlCenter->checkBox(),TQT_SIGNAL(toggled(bool)),
-          TQT_SLOT(toggleEmailSettings(bool)));
+  connect(emailControlCenter->checkBox(),TQ_SIGNAL(toggled(bool)),
+          TQ_SLOT(toggleEmailSettings(bool)));
 
   mUserEmailSettings = new TQGrid( 2, topFrame );
 
   addWidString( KOPrefs::instance()->userNameItem(), mUserEmailSettings );
   addWidString( KOPrefs::instance()->userEmailItem(), mUserEmailSettings );
 
-  TQGroupBox *saveGroup = new TQGroupBox(1,Qt::Horizontal,i18n("Saving Calendar"),
+  TQGroupBox *saveGroup = new TQGroupBox(1,TQt::Horizontal,i18n("Saving Calendar"),
                                            topFrame);
 
   addWidBool( KOPrefs::instance()->htmlWithSaveItem(), saveGroup );
@@ -109,8 +109,8 @@ KOPrefsDialogMain::KOPrefsDialogMain( TQWidget *parent, const char *name )
 
   TQHBox *intervalBox = new TQHBox( saveGroup );
   addWidInt( KOPrefs::instance()->autoSaveIntervalItem(), intervalBox );
-  connect( autoSave->checkBox(), TQT_SIGNAL( toggled( bool ) ),
-           intervalBox, TQT_SLOT( setEnabled( bool ) ) );
+  connect( autoSave->checkBox(), TQ_SIGNAL( toggled( bool ) ),
+           intervalBox, TQ_SLOT( setEnabled( bool ) ) );
   intervalBox->setSpacing( KDialog::spacingHint() );
   new TQWidget( intervalBox );
 
@@ -171,8 +171,8 @@ class KOPrefsDialogTime : public KPrefsModule
       TQWhatsThis::add( timeZoneLabel, whatsThis );
       mTimeZoneCombo = new TQComboBox( timeZoneBox );
 
-      connect( mTimeZoneCombo, TQT_SIGNAL( activated( int ) ),
-               TQT_SLOT( slotWidChanged() ) );
+      connect( mTimeZoneCombo, TQ_SIGNAL( activated( int ) ),
+               TQ_SLOT( slotWidChanged() ) );
 
       FILE *f;
       char tempstring[101] = "Unknown";
@@ -264,8 +264,8 @@ class KOPrefsDialogTime : public KPrefsModule
       TQWhatsThis::add( holidayLabel, whatsThis );
 
       mHolidayCombo = new TQComboBox( holidayRegBox );
-      connect( mHolidayCombo, TQT_SIGNAL( activated( int ) ),
-               TQT_SLOT( slotWidChanged() ) );
+      connect( mHolidayCombo, TQ_SIGNAL( activated( int ) ),
+               TQ_SLOT( slotWidChanged() ) );
 
       TQWhatsThis::add( mHolidayCombo, whatsThis );
 
@@ -319,7 +319,7 @@ class KOPrefsDialogTime : public KPrefsModule
       topLayout->addWidget( defaultDuration->label(), 4, 0 );
       topLayout->addWidget( defaultDuration->timeEdit(), 4, 1 );
 
-      TQGroupBox *remindersGroupBox = new TQGroupBox( 1, Qt::Horizontal,
+      TQGroupBox *remindersGroupBox = new TQGroupBox( 1, TQt::Horizontal,
                                                     i18n( "Reminders" ),
                                                     topFrame );
       topLayout->addMultiCellWidget( remindersGroupBox, 5, 5, 0, 1 );
@@ -328,10 +328,10 @@ class KOPrefsDialogTime : public KPrefsModule
       new TQLabel( i18n( "Default reminder time:" ), remindersBox );
 
       mReminderTimeSpin  = new KIntSpinBox( remindersBox );
-      connect( mReminderTimeSpin, TQT_SIGNAL(valueChanged(int)), TQT_SLOT(slotWidChanged()) );
+      connect( mReminderTimeSpin, TQ_SIGNAL(valueChanged(int)), TQ_SLOT(slotWidChanged()) );
 
       mReminderUnitsCombo = new KComboBox( remindersBox );
-      connect( mReminderUnitsCombo, TQT_SIGNAL(activated(int)), TQT_SLOT(slotWidChanged()) );
+      connect( mReminderUnitsCombo, TQ_SIGNAL(activated(int)), TQ_SLOT(slotWidChanged()) );
       mReminderUnitsCombo->insertItem( i18n( "minute(s)" ) );
       mReminderUnitsCombo->insertItem( i18n( "hour(s)" ) );
       mReminderUnitsCombo->insertItem( i18n( "day(s)" ) );
@@ -351,8 +351,8 @@ class KOPrefsDialogTime : public KPrefsModule
       KURLRequester *rq = addWidPath( KOPrefs::instance()->audioFilePathItem(),
                                       audioFileRemindersBox, filter )->urlRequester();
       rq->setEnabled( cb->isChecked() );
-      connect( cb, TQT_SIGNAL(toggled(bool)),
-               rq, TQT_SLOT(setEnabled( bool)) );
+      connect( cb, TQ_SIGNAL(toggled(bool)),
+               rq, TQ_SLOT(setEnabled( bool)) );
 
       TQHBox *eventRemindersBox = new TQHBox( remindersGroupBox );
       addWidBool( KOPrefs::instance()->defaultEventRemindersItem(), eventRemindersBox )->checkBox();
@@ -364,10 +364,10 @@ class KOPrefsDialogTime : public KPrefsModule
       topLayout->addWidget( alarmDefaultLabel, 6, 0 );
       mAlarmTimeDefaultCheckBox = new TQCheckBox( topFrame );
       topLayout->addWidget( mAlarmTimeDefaultCheckBox, 6, 1 );
-      connect( mAlarmTimeDefaultCheckBox, TQT_SIGNAL( toggled( bool ) ),
-               TQT_SLOT( slotWidChanged() ) );
+      connect( mAlarmTimeDefaultCheckBox, TQ_SIGNAL( toggled( bool ) ),
+               TQ_SLOT( slotWidChanged() ) );
 
-      TQGroupBox *workingHoursGroup = new TQGroupBox(1,Qt::Horizontal,
+      TQGroupBox *workingHoursGroup = new TQGroupBox(1,TQt::Horizontal,
                                                    i18n("Working Hours"),
                                                    topFrame);
       topLayout->addMultiCellWidget( workingHoursGroup, 7, 7, 0, 1 );
@@ -390,8 +390,8 @@ class KOPrefsDialogTime : public KPrefsModule
                                "this box, or the working hours will not be "
                                "marked with color." ) );
 
-        connect( mWorkDays[ index ], TQT_SIGNAL( stateChanged( int ) ),
-               TQT_SLOT( slotWidChanged() ) );
+        connect( mWorkDays[ index ], TQ_SIGNAL( stateChanged( int ) ),
+               TQ_SLOT( slotWidChanged() ) );
       }
 
       TQHBox *workStartBox = new TQHBox(workingHoursGroup);
@@ -510,7 +510,7 @@ class KOPrefsDialogViews : public KPrefsModule
       topLayout->addWidget( showTodosAgenda->checkBox() );
 
       /*** Date Navigator Group ***/
-      TQGroupBox *dateNavGroup = new TQGroupBox( 1, Qt::Horizontal,
+      TQGroupBox *dateNavGroup = new TQGroupBox( 1, TQt::Horizontal,
                                                i18n("Date Navigator"),
                                                topFrame );
       addWidBool( KOPrefs::instance()->dailyRecurItem(), dateNavGroup );
@@ -520,7 +520,7 @@ class KOPrefsDialogViews : public KPrefsModule
 
 
       /*** Agenda View Group ***/
-      TQGroupBox *agendaGroup = new TQGroupBox( 1, Qt::Horizontal,
+      TQGroupBox *agendaGroup = new TQGroupBox( 1, TQt::Horizontal,
                                               i18n("Agenda View"),
                                               topFrame );
 
@@ -542,8 +542,8 @@ class KOPrefsDialogViews : public KPrefsModule
 
       KPrefsWidBool *marcusBainsShowSeconds =
           addWidBool( KOPrefs::instance()->marcusBainsShowSecondsItem(), agendaGroup );
-      connect( marcusBainsEnabled->checkBox(), TQT_SIGNAL( toggled( bool ) ),
-               marcusBainsShowSeconds->checkBox(), TQT_SLOT( setEnabled( bool ) ) );
+      connect( marcusBainsEnabled->checkBox(), TQ_SIGNAL( toggled( bool ) ),
+               marcusBainsShowSeconds->checkBox(), TQ_SLOT( setEnabled( bool ) ) );
 
       addWidBool( KOPrefs::instance()->selectionStartsEditorItem(), agendaGroup );
 
@@ -554,7 +554,7 @@ class KOPrefsDialogViews : public KPrefsModule
       topLayout->addWidget( agendaGroup );
 
       /*** Month View Group ***/
-      TQGroupBox *monthGroup = new TQGroupBox( 1, Qt::Horizontal,
+      TQGroupBox *monthGroup = new TQGroupBox( 1, TQt::Horizontal,
                                              i18n("Month View"),
                                              topFrame );
       addWidBool( KOPrefs::instance()->enableMonthScrollItem(), monthGroup );
@@ -564,7 +564,7 @@ class KOPrefsDialogViews : public KPrefsModule
 
 
       /*** Todo View Group ***/
-      TQGroupBox *todoGroup = new TQGroupBox( 1, Qt::Horizontal,
+      TQGroupBox *todoGroup = new TQGroupBox( 1, TQt::Horizontal,
                                             i18n("To-do View"),
                                             topFrame );
       addWidBool( KOPrefs::instance()->fullViewTodoItem(), todoGroup );
@@ -700,7 +700,7 @@ KOPrefsDialogColors::KOPrefsDialogColors( TQWidget *parent, const char *name )
   topLayout->addWidget( unsetCategoryColor->button(), 6, 1 );
 
   // categories colors
-  TQGroupBox *categoryGroup = new TQGroupBox(1,Qt::Horizontal,i18n("Categories"),
+  TQGroupBox *categoryGroup = new TQGroupBox(1,TQt::Horizontal,i18n("Categories"),
                                            topFrame);
   topLayout->addMultiCellWidget(categoryGroup,7,7,0,1);
 
@@ -711,17 +711,17 @@ KOPrefsDialogColors::KOPrefsDialogColors( TQWidget *parent, const char *name )
                    i18n( "Select here the event category you want to modify. "
                          "You can change the selected category color using "
                          "the button below." ) );
-  connect(mCategoryCombo,TQT_SIGNAL(activated(int)),TQT_SLOT(updateCategoryColor()));
+  connect(mCategoryCombo,TQ_SIGNAL(activated(int)),TQ_SLOT(updateCategoryColor()));
 
   mCategoryButton = new KColorButton(categoryGroup);
   TQWhatsThis::add( mCategoryButton,
                    i18n( "Choose here the color of the event category selected "
                          "using the combo box above." ) );
-  connect(mCategoryButton,TQT_SIGNAL(changed(const TQColor &)),TQT_SLOT(setCategoryColor()));
+  connect(mCategoryButton,TQ_SIGNAL(changed(const TQColor &)),TQ_SLOT(setCategoryColor()));
   updateCategoryColor();
 
   // resources colors
-  TQGroupBox *resourceGroup = new TQGroupBox(1,Qt::Horizontal,i18n("Resources"),
+  TQGroupBox *resourceGroup = new TQGroupBox(1,TQt::Horizontal,i18n("Resources"),
                                            topFrame);
   topLayout->addMultiCellWidget(resourceGroup,8,8,0,1);
 
@@ -730,13 +730,13 @@ KOPrefsDialogColors::KOPrefsDialogColors( TQWidget *parent, const char *name )
                    i18n( "Select here resource you want to modify. "
                          "You can change the selected resource color using "
                          "the button below." ) );
-  connect(mResourceCombo,TQT_SIGNAL(activated(int)),TQT_SLOT(updateResourceColor()));
+  connect(mResourceCombo,TQ_SIGNAL(activated(int)),TQ_SLOT(updateResourceColor()));
 
   mResourceButton = new KColorButton(resourceGroup);
   TQWhatsThis::add( mResourceButton,
                    i18n( "Choose here the color of the resource selected "
                          "using the combo box above." ) );
-  connect(mResourceButton,TQT_SIGNAL(changed(const TQColor &)),TQT_SLOT(setResourceColor()));
+  connect(mResourceButton,TQ_SIGNAL(changed(const TQColor &)),TQ_SLOT(setResourceColor()));
   updateResources();
 
   topLayout->setRowStretch(9,1);
@@ -865,8 +865,8 @@ KOPrefsDialogGroupScheduling::KOPrefsDialogGroupScheduling( TQWidget *parent, co
       topFrame );
   topLayout->addMultiCellWidget(useGroupwareBool->checkBox(),0,0,0,1);
   // FIXME: This radio button should only be available when KMail is chosen
-//   connect(thekmailradiobuttonupthere,TQT_SIGNAL(toggled(bool)),
-//           useGroupwareBool->checkBox(), TQT_SLOT(enabled(bool)));
+//   connect(thekmailradiobuttonupthere,TQ_SIGNAL(toggled(bool)),
+//           useGroupwareBool->checkBox(), TQ_SLOT(enabled(bool)));
 
   KPrefsWidBool *bcc =
       addWidBool( KOPrefs::instance()->bccItem(), topFrame );
@@ -927,10 +927,10 @@ KOPrefsDialogGroupScheduling::KOPrefsDialogGroupScheduling( TQWidget *parent, co
   topLayout->addWidget(del,6,1);
 
   //topLayout->setRowStretch(2,1);
-  connect(add, TQT_SIGNAL( clicked() ), this, TQT_SLOT(addItem()) );
-  connect(del, TQT_SIGNAL( clicked() ), this, TQT_SLOT(removeItem()) );
-  connect(aEmailsEdit,TQT_SIGNAL( textChanged(const TQString&) ), this,TQT_SLOT(updateItem()));
-  connect(mAMails,TQT_SIGNAL(selectionChanged(TQListViewItem *)),TQT_SLOT(updateInput()));
+  connect(add, TQ_SIGNAL( clicked() ), this, TQ_SLOT(addItem()) );
+  connect(del, TQ_SIGNAL( clicked() ), this, TQ_SLOT(removeItem()) );
+  connect(aEmailsEdit,TQ_SIGNAL( textChanged(const TQString&) ), this,TQ_SLOT(updateItem()));
+  connect(mAMails,TQ_SIGNAL(selectionChanged(TQListViewItem *)),TQ_SLOT(updateInput()));
 
   load();
 }
@@ -1018,7 +1018,7 @@ KOPrefsDialogGroupwareScheduling::KOPrefsDialogGroupwareScheduling( TQWidget *pa
   : KPrefsModule( KOPrefs::instance(), parent, name )
 {
   mGroupwarePage = new KOGroupwarePrefsPage( this );
-  connect( mGroupwarePage, TQT_SIGNAL( changed() ), TQT_SLOT( slotWidChanged() ) );
+  connect( mGroupwarePage, TQ_SIGNAL( changed() ), TQ_SLOT( slotWidChanged() ) );
   ( new TQVBoxLayout( this ) )->addWidget( mGroupwarePage );
 
   load();
@@ -1127,12 +1127,12 @@ KOPrefsDialogPlugins::KOPrefsDialogPlugins( TQWidget *parent, const char* name )
   buttonRowLayout->addWidget( mConfigureButton );
   buttonRowLayout->addItem( new TQSpacerItem(1, 1,  TQSizePolicy::Expanding) );
   topLayout->addWidget( buttonRow );
-  connect( mConfigureButton, TQT_SIGNAL( clicked() ), TQT_SLOT( configure() ) );
+  connect( mConfigureButton, TQ_SIGNAL( clicked() ), TQ_SLOT( configure() ) );
 
-  connect( mListView, TQT_SIGNAL( selectionChanged( TQListViewItem* ) ),
-           TQT_SLOT( selectionChanged( TQListViewItem* ) ) );
-  connect( mListView, TQT_SIGNAL( clicked( TQListViewItem* ) ),
-           TQT_SLOT( slotWidChanged() ) );
+  connect( mListView, TQ_SIGNAL( selectionChanged( TQListViewItem* ) ),
+           TQ_SLOT( selectionChanged( TQListViewItem* ) ) );
+  connect( mListView, TQ_SIGNAL( clicked( TQListViewItem* ) ),
+           TQ_SLOT( slotWidChanged() ) );
 
   load();
 //  usrReadConfig();
