@@ -26,7 +26,7 @@ class KStatusBar;
 class KRecExportItem;
 
 class KRecGlobal : public TQObject {
-   Q_OBJECT
+   TQ_OBJECT
   
 private:
 	KRecGlobal( TQObject* =0, const char* =0 );
