@@ -15,7 +15,7 @@
 
 class PageGeneral : public PageGeneralBase
 {
-Q_OBJECT
+TQ_OBJECT
   
 
 public:
