@@ -145,25 +145,25 @@ servercontroller::servercontroller( TQWidget*, const char* name )
   sci->setFrameStyle(TQFrame::Box | TQFrame::Raised);
   ConnectionTree = sci->ConnectionTree;
 
-  connect(ConnectionTree, TQT_SIGNAL(clicked( TQListViewItem * )),
-	  this, TQT_SLOT(WindowSelected(TQListViewItem *)));
+  connect(ConnectionTree, TQ_SIGNAL(clicked( TQListViewItem * )),
+	  this, TQ_SLOT(WindowSelected(TQListViewItem *)));
 
   setFrameBorderWidth(5);
 
   TQPopupMenu *file = new TQPopupMenu(this, TQCString(name) + "_menu_file");
-  KStdAction::quit(TQT_TQOBJECT(this), TQT_SLOT(endksirc()), actionCollection())->plug(file);
+  KStdAction::quit(this, TQ_SLOT(endksirc()), actionCollection())->plug(file);
 #ifndef NDEBUG
-  file->insertItem(i18n("Dump Object Tree"), this, TQT_SLOT(dump_obj()));
-  file->insertItem(i18n("Server Debug Window"), this, TQT_SLOT(server_debug()));
+  file->insertItem(i18n("Dump Object Tree"), this, TQ_SLOT(dump_obj()));
+  file->insertItem(i18n("Server Debug Window"), this, TQ_SLOT(server_debug()));
 #endif
   MenuBar->insertItem(i18n("&File"), file);
 
   connections = new TQPopupMenu(this, TQCString(name) + "_menu_connections");
 
-  server_id = connections->insertItem(i18n("&New Server..."), this, TQT_SLOT(new_connection()), Key_F2 );
-  join_id = connections->insertItem(i18n("&Join Channel..."), this, TQT_SLOT(new_channel()), Key_F3 );
+  server_id = connections->insertItem(i18n("&New Server..."), this, TQ_SLOT(new_connection()), Key_F2 );
+  join_id = connections->insertItem(i18n("&Join Channel..."), this, TQ_SLOT(new_channel()), Key_F3 );
   connections->insertSeparator();
-  connections->insertItem(i18n("&Do Autoconnect..."), this, TQT_SLOT(start_autoconnect_check()));
+  connections->insertItem(i18n("&Do Autoconnect..."), this, TQ_SLOT(start_autoconnect_check()));
   connections->setItemEnabled(join_id, FALSE);
   MenuBar->insertItem(i18n("&Connections"), connections);
 
@@ -171,24 +171,24 @@ servercontroller::servercontroller( TQWidget*, const char* name )
   options->setCheckable(TRUE);
 
   options->insertItem(SmallIcon( "filter" ), i18n("&Filter Rule Editor..."),
-		      this, TQT_SLOT(filter_rule_editor()));
+		      this, TQ_SLOT(filter_rule_editor()));
   options->insertSeparator();
-  KStdAction::configureNotifications(TQT_TQOBJECT(this), TQT_SLOT(notification_prefs()), actionCollection())->plug(options);
+  KStdAction::configureNotifications(this, TQ_SLOT(notification_prefs()), actionCollection())->plug(options);
 
-  KStdAction::preferences(TQT_TQOBJECT(this), TQT_SLOT(general_prefs()), actionCollection())->plug(options);
+  KStdAction::preferences(this, TQ_SLOT(general_prefs()), actionCollection())->plug(options);
 
   MenuBar->insertItem(i18n("&Settings"), options);
 
   KHelpMenu *help = new KHelpMenu( this, kapp->aboutData() );
   MenuBar->insertItem( KStdGuiItem::help().text(), help->menu() );
 
-  m_kga = new TDEGlobalAccel(TQT_TQOBJECT(this), "globalAccess");
+  m_kga = new TDEGlobalAccel(this, "globalAccess");
   m_kga->insert("New Server", i18n("New Server"),
 		i18n("This action allows you to open a new server more easily "
 		     "when in docked mode, since you don't need to click on the "
 		     "dock icon."),
-		ALT+CTRL+Key_C, KKey::QtWIN+CTRL+Key_C, TQT_TQOBJECT(this),
-		TQT_SLOT(new_connection()));
+		ALT+CTRL+Key_C, KKey::QtWIN+CTRL+Key_C, this,
+		TQ_SLOT(new_connection()));
 
   open_toplevels = 0;
 
@@ -239,8 +239,8 @@ void servercontroller::checkDocking()
 void servercontroller::new_connection()
 {
   open_ksirc *w = new open_ksirc(); // Create new ksirc popup
-  connect(w, TQT_SIGNAL(open_ksircprocess(KSircServer &)), // connected ok to process
-          this, TQT_SLOT(new_ksircprocess(KSircServer &))); // start
+  connect(w, TQ_SIGNAL(open_ksircprocess(KSircServer &)), // connected ok to process
+          this, TQ_SLOT(new_ksircprocess(KSircServer &))); // start
   w->exec();                                       // show the sucker!
   delete w;
 }
@@ -270,10 +270,10 @@ void servercontroller::new_ksircprocess(KSircServer &kss)
   //this->insertChild(proc);                           // Add it to out inheritance tree so we can retreive child widgets from it.
   objFinder::insert(proc);
   proc_list.insert(server_id, proc);                      // Add proc to hash
-  connect(proc, TQT_SIGNAL(ProcMessage(TQString, int, TQString)),
-	  this, TQT_SLOT(ProcMessage(TQString, int, TQString)));
-  connect(this, TQT_SIGNAL(ServMessage(TQString, int, TQString)),
-	  proc, TQT_SLOT(ServMessage(TQString, int, TQString)));
+  connect(proc, TQ_SIGNAL(ProcMessage(TQString, int, TQString)),
+	  this, TQ_SLOT(ProcMessage(TQString, int, TQString)));
+  connect(this, TQ_SIGNAL(ServMessage(TQString, int, TQString)),
+	  proc, TQ_SLOT(ServMessage(TQString, int, TQString)));
 
   if(!ConnectionTree->currentItem()){   // If nothing's highlighted
     ConnectionTree->setCurrentItem(rootItem);     // highlight it.
@@ -305,8 +305,8 @@ void servercontroller::new_channel()
 
   KSircChannel ci(server, TQString());
   NewWindowDialog w(ci);
-  connect(&w, TQT_SIGNAL(openTopLevel(const KSircChannel &)),
-	  this, TQT_SLOT(new_toplevel(const KSircChannel &)));
+  connect(&w, TQ_SIGNAL(openTopLevel(const KSircChannel &)),
+	  this, TQ_SLOT(new_toplevel(const KSircChannel &)));
   w.exec();
 }
 
@@ -330,8 +330,8 @@ void servercontroller::ToggleAutoCreate()
 void servercontroller::general_prefs()
 {
   KSPrefs *kp = new KSPrefs();
-  connect(kp, TQT_SIGNAL(update(int)),
-          this, TQT_SLOT(configChange()));
+  connect(kp, TQ_SIGNAL(update(int)),
+          this, TQ_SLOT(configChange()));
   kp->resize(550, 450);
   kp->show();
 }
@@ -373,8 +373,8 @@ void servercontroller::server_debug()
 void servercontroller::filter_rule_editor()
 {
   FilterRuleEditor *fe = new FilterRuleEditor();
-  connect(fe, TQT_SIGNAL(destroyed()),
-	  this, TQT_SLOT(slot_filters_update()));
+  connect(fe, TQ_SIGNAL(destroyed()),
+	  this, TQ_SLOT(slot_filters_update()));
   fe->show();
 }
 
@@ -917,7 +917,7 @@ void servercontroller::do_autoconnect()
 
 void servercontroller::start_autoconnect() {
     at = new TQTimer(this);
-    connect(at, TQT_SIGNAL(timeout()), this, TQT_SLOT(do_autoconnect()));
+    connect(at, TQ_SIGNAL(timeout()), this, TQ_SLOT(do_autoconnect()));
     at->start(250, FALSE);
 }
 
@@ -929,15 +929,15 @@ void servercontroller::start_autoconnect_check() {
 
     if(servers.count() == 0){
 	KSPrefs *kp = new KSPrefs();
-	connect(kp, TQT_SIGNAL(update(int)),
-		this, TQT_SLOT(configChange()));
+	connect(kp, TQ_SIGNAL(update(int)),
+		this, TQ_SLOT(configChange()));
 	kp->resize(550, 450);
         kp->showPage(7); /* Show auto connect page */
 	kp->show();
     }
     else {
 	at = new TQTimer(this);
-	connect(at, TQT_SIGNAL(timeout()), this, TQT_SLOT(do_autoconnect()));
+	connect(at, TQ_SIGNAL(timeout()), this, TQ_SLOT(do_autoconnect()));
 	at->start(250, FALSE);
     }
 
