@@ -105,7 +105,7 @@ KSMShutdownFeedback::KSMShutdownFeedback()
 	m_unfadedImage = m_grayImage;
 	resize(0, 0);
 	setShown(true);
-	TQTimer::singleShot( 500, this, TQT_SLOT( slotPaintEffect() ) );
+	TQTimer::singleShot( 500, this, TQ_SLOT( slotPaintEffect() ) );
 }
 
 // called after stopping shutdown-feedback -> smooth fade-back to color-mode
@@ -243,7 +243,7 @@ void KSMShutdownFeedback::slotPaintEffect()
 				bitBlt( this, 0, start_y1, &img );
 			}
 
-			TQTimer::singleShot( 5, this, TQT_SLOT( slotPaintEffect() ) );
+			TQTimer::singleShot( 5, this, TQ_SLOT( slotPaintEffect() ) );
 		}
 		else {
 			// if slotPaintEffect() is called first time, we have to initialize the gray image
@@ -370,7 +370,7 @@ void KSMShutdownFeedback::slotPaintEffect()
 				bitBlt( this, 0, start_y1, &img );
 			}
 
-			TQTimer::singleShot( 5, this, TQT_SLOT( slotPaintEffect() ) );
+			TQTimer::singleShot( 5, this, TQ_SLOT( slotPaintEffect() ) );
 		}
 	}
 	else {
@@ -486,7 +486,7 @@ void KSMShutdownFeedback::slotPaintEffect()
 					bitBlt( this, 0, start_y1, &img );
 				}
 
-				TQTimer::singleShot( 1, this, TQT_SLOT( slotPaintEffect() ) );
+				TQTimer::singleShot( 1, this, TQ_SLOT( slotPaintEffect() ) );
 			 }
 			 else {
 				if ( m_currentY >= height() ) {
@@ -511,13 +511,13 @@ void KSMShutdownFeedback::slotPaintEffect()
 				KPixmap pixmap;
 				pixmap = TQPixmap(TQPixmap::grabWindow( tqt_xrootwin(), 0, m_currentY, width(), 10 ));
 				TQImage image = pixmap.convertToImage();
-				KImageEffect::blend( Qt::black, image, 0.4 );
+				KImageEffect::blend( TQt::black, image, 0.4 );
 				KImageEffect::toGray( image, true );
 				pixmap.convertFromImage( image );
 				bitBlt( this, 0, m_currentY, &pixmap );
 				bitBlt( &m_root, 0, m_currentY, &pixmap );
 				m_currentY += 10;
-				TQTimer::singleShot( 1, this, TQT_SLOT( slotPaintEffect() ) );
+				TQTimer::singleShot( 1, this, TQ_SLOT( slotPaintEffect() ) );
 			}
 		}
 	}
@@ -529,7 +529,7 @@ void KSMShutdownFeedback::slotPaintEffect()
 KSMShutdownIPFeedback * KSMShutdownIPFeedback::s_pSelf = 0L;
 
 KSMShutdownIPFeedback::KSMShutdownIPFeedback()
-: TQWidget( 0L, "systemmodaldialogclass", Qt::WStyle_Customize | Qt::WStyle_NoBorder | Qt::WStyle_StaysOnTop ), m_timeout(0), m_isPainted(false), m_paintedFromSharedRootPixmap(false), m_sharedRootPixmap(NULL), mPixmapTimeout(0)
+: TQWidget( 0L, "systemmodaldialogclass", TQt::WStyle_Customize | TQt::WStyle_NoBorder | TQt::WStyle_StaysOnTop ), m_timeout(0), m_isPainted(false), m_paintedFromSharedRootPixmap(false), m_sharedRootPixmap(NULL), mPixmapTimeout(0)
 
 {
 	setShown(false);
@@ -539,7 +539,7 @@ KSMShutdownIPFeedback::KSMShutdownIPFeedback()
 
 	m_sharedRootPixmap = new KRootPixmap(this);
 	m_sharedRootPixmap->setCustomPainting(true);
-	connect(m_sharedRootPixmap, TQT_SIGNAL(backgroundUpdated(const TQPixmap &)), this, TQT_SLOT(slotSetBackgroundPixmap(const TQPixmap &)));
+	connect(m_sharedRootPixmap, TQ_SIGNAL(backgroundUpdated(const TQPixmap &)), this, TQ_SLOT(slotSetBackgroundPixmap(const TQPixmap &)));
 
 	if (TQPaintDevice::x11AppDepth() == 32) {
 		// The shared pixmap is 24 bits, but we are 32 bits
@@ -571,13 +571,13 @@ void KSMShutdownIPFeedback::showNow()
 
 	if (!m_isPainted) {
 		setGeometry( TQApplication::desktop()->geometry() );
-		TQTimer::singleShot( 0, this, SLOT(slotPaintEffect()) );
+		TQTimer::singleShot( 0, this, TQ_SLOT(slotPaintEffect()) );
 	}
 }
 
 void KSMShutdownIPFeedback::enableExports()
 {
-#ifdef Q_WS_X11
+#ifdef TQ_WS_X11
 	kdDebug(270) << k_lineinfo << "activating background exports.\n";
 	DCOPClient *client = kapp->dcopClient();
 	if (!client->isAttached()) {
@@ -632,7 +632,7 @@ void KSMShutdownIPFeedback::slotPaintEffect()
 			m_sharedRootPixmap->start();
 		}
 
-		TQTimer::singleShot( 100, this, SLOT(slotPaintEffect()) );
+		TQTimer::singleShot( 100, this, TQ_SLOT(slotPaintEffect()) );
 		mPixmapTimeout++;
 		return;
 	}
@@ -647,13 +647,13 @@ void KSMShutdownIPFeedback::slotPaintEffect()
 	}
 	if ((pm.isNull()) || (pm.width() != kapp->desktop()->width()) || (pm.height() != kapp->desktop()->height())) {
 		if (mPixmapTimeout < 10) {
-			TQTimer::singleShot( 100, this, SLOT(slotPaintEffect()) );
+			TQTimer::singleShot( 100, this, TQ_SLOT(slotPaintEffect()) );
 			mPixmapTimeout++;
 			return;
 		}
 		else {
 			pm = TQPixmap(kapp->desktop()->width(), kapp->desktop()->height());
-			pm.fill(Qt::black);
+			pm.fill(TQt::black);
 			m_paintedFromSharedRootPixmap = false;
 		}
 	}
@@ -711,7 +711,7 @@ KSMShutdownDlg::KSMShutdownDlg( TQWidget* parent,
 	TQVBoxLayout* vbox = new TQVBoxLayout( this );
 
 	if (m_selection) {
-		*m_selection = 0;
+		*m_selection = SuspendType::NotSpecified;
 	}
 
 	TQFrame* frame = new TQFrame( this );
@@ -757,27 +757,26 @@ KSMShutdownDlg::KSMShutdownDlg( TQWidget* parent,
 	{
 		// first line of buttons
 		hbuttonbox = new TQHBoxLayout( hbox, factor * KDialog::spacingHint() );
-		hbuttonbox->setAlignment( Qt::AlignHCenter );
+		hbuttonbox->setAlignment( TQt::AlignHCenter );
 		// End session
 		FlatButton* btnLogout = new FlatButton( frame );
 		btnLogout->setTextLabel( TQString("&") + i18n("Log out"), false );
 		btnLogout->setPixmap( DesktopIcon( "back") );
+		TQToolTip::add( btnLogout, i18n( "<qt><p>Log out of the current session to login as a different user.</p></qt>" ) );
 		int i = btnLogout->textLabel().find( TQRegExp("\\&"), 0 );    // i == 1
 		btnLogout->setAccel( "ALT+" + btnLogout->textLabel().lower()[i+1] ) ;
 		hbuttonbox->addWidget ( btnLogout );
-		connect(btnLogout, TQT_SIGNAL(clicked()), TQT_SLOT(slotLogout()));
-
+		connect(btnLogout, TQ_SIGNAL(clicked()), TQ_SLOT(slotLogout()));
 	}
 	else
 	{
-
 		// konqy
 		lfrm = new TQFrame( frame );
 		lfrm->setFrameStyle( TQFrame::Panel | TQFrame::Sunken );
 		hbox->addWidget( lfrm, AlignCenter );
 
 		buttonlay = new TQVBoxLayout( hbox, factor * KDialog::spacingHint() );
-		buttonlay->setAlignment( Qt::AlignHCenter );
+		buttonlay->setAlignment( TQt::AlignHCenter );
 
 		TQLabel* icon = new TQLabel( lfrm );
 		if (TDEConfigGroup(TDEGlobal::config(), "Logout").readBoolEntry("doNotUseKonqyPicture", false)) {
@@ -791,17 +790,13 @@ KSMShutdownDlg::KSMShutdownDlg( TQWidget* parent,
 
 		buttonlay->addStretch( 1 );
 		// End session
-		KPushButton* btnLogout = new KPushButton( KGuiItem( i18n("&End Current Session"), "edit-undo"), frame );
-				TQToolTip::add( btnLogout, i18n( "<qt><h3>End Current Session</h3><p>Log out of the current session to login with a different user</p></qt>" ) );
+		KPushButton* btnLogout = new KPushButton( KGuiItem( i18n("&Log out"), "edit-undo"), frame );
+		TQToolTip::add( btnLogout, i18n( "<qt><p>Log out of the current session to login as a different user.</p></qt>" ) );
 		btnFont = btnLogout->font();
 		buttonlay->addWidget( btnLogout );
-		connect(btnLogout, TQT_SIGNAL(clicked()), TQT_SLOT(slotLogout()));
+		connect(btnLogout, TQ_SIGNAL(clicked()), TQ_SLOT(slotLogout()));
 	}
 
-#ifdef COMPILE_HALBACKEND
-	m_halCtx = NULL;
-#endif
-
 	if ((maysd) || (mayrb)) {
 
 		// respect lock on resume & disable suspend/hibernate settings
@@ -814,88 +809,39 @@ KSMShutdownDlg::KSMShutdownDlg( TQWidget* parent,
 		bool canFreeze = false;
 		bool canSuspend = false;
 		bool canHibernate = false;
+		bool canHybridSuspend = false;
 
-#if defined(COMPILE_HALBACKEND)
-		// Query HAL for suspend/resume support
-		m_halCtx = libhal_ctx_new();
-
-		DBusError error;
-		dbus_error_init(&error);
-		m_dbusConn = dbus_connection_open_private(DBUS_SYSTEM_BUS, &error);
-		if (!m_dbusConn)
-		{
-			dbus_error_free(&error);
-			libhal_ctx_free(m_halCtx);
-			m_halCtx = NULL;
-		}
-		else
-		{
-			dbus_bus_register(m_dbusConn, &error);
-			if (dbus_error_is_set(&error))
-			{
-				dbus_error_free(&error);
-				libhal_ctx_free(m_halCtx);
-				m_dbusConn = NULL;
-				m_halCtx = NULL;
-			}
-			else
-			{
-				libhal_ctx_set_dbus_connection(m_halCtx, m_dbusConn);
-				if (!libhal_ctx_init(m_halCtx, &error))
-				{
-					if (dbus_error_is_set(&error))
-						dbus_error_free(&error);
-					libhal_ctx_free(m_halCtx);
-					m_dbusConn = NULL;
-					m_halCtx = NULL;
-				}
-			}
-		}
-
-		if (m_halCtx)
-		{
-			if (libhal_device_get_property_bool(m_halCtx,
-												"/org/freedesktop/Hal/devices/computer",
-												"power_management.can_suspend",
-												NULL))
-			{
-				canSuspend = true;
-			}
-
-			if (libhal_device_get_property_bool(m_halCtx,
-												"/org/freedesktop/Hal/devices/computer",
-												"power_management.can_hibernate",
-												NULL))
-			{
-				canHibernate = true;
-			}
-		}
-#elif defined(WITH_TDEHWLIB) // COMPILE_HALBACKEND
+#if defined(WITH_TDEHWLIB)
 		TDERootSystemDevice* rootDevice = TDEGlobal::hardwareDevices()->rootSystemDevice();
 		if (rootDevice) {
 			canFreeze = rootDevice->canFreeze();
 			canSuspend = rootDevice->canSuspend();
 			canHibernate = rootDevice->canHibernate();
+			canHybridSuspend = rootDevice->canHybridSuspend();
 		}
 		else {
 			canFreeze = false;
 			canSuspend = false;
 			canHibernate = false;
+			canHybridSuspend = false;
 		}
-#endif // COMPILE_HALBACKEND
+#endif
 
 		if(doUbuntuLogout) {
-
+      // Ubuntu style logout window
 			if (canFreeze && !disableSuspend)
 			{
 				// Freeze
 				FlatButton* btnFreeze = new FlatButton( frame );
 				btnFreeze->setTextLabel( i18n("&Freeze"), false );
 				btnFreeze->setPixmap( DesktopIcon( "suspend") );
+				TQToolTip::add(btnFreeze, i18n("<qt><p>Put the computer in software idle mode,"
+				" allowing for some powersaving. The system can be reactivated in a really short time,"
+				" almost instantly.</p><p>This correspond to ACPI S0 mode.</p></qt>"));
 				int i = btnFreeze->textLabel().find( TQRegExp("\\&"), 0 );    // i == 1
 				btnFreeze->setAccel( "ALT+" + btnFreeze->textLabel().lower()[i+1] ) ;
-				hbuttonbox->addWidget ( btnFreeze);
-				connect(btnFreeze, TQT_SIGNAL(clicked()), TQT_SLOT(slotFreeze()));
+				hbuttonbox->addWidget ( btnFreeze );
+				connect(btnFreeze, TQ_SIGNAL(clicked()), TQ_SLOT(slotFreeze()));
 			}
 
 			if (canSuspend && !disableSuspend)
@@ -904,10 +850,14 @@ KSMShutdownDlg::KSMShutdownDlg( TQWidget* parent,
 				FlatButton* btnSuspend = new FlatButton( frame );
 				btnSuspend->setTextLabel( i18n("&Suspend"), false );
 				btnSuspend->setPixmap( DesktopIcon( "suspend") );
+				TQToolTip::add(btnSuspend, i18n("<qt><p>Put the computer in suspend-to-memory mode."
+				" The system is stopped and its state saved to memory.</p><p> This allows more powersaving than 'Freeze'"
+				" but requires longer time to reactivate the system.</p><p>This correspond to ACPI S3 mode.</p>"
+				"<p>Also known as Suspend-to-RAM mode.</p></qt>"));
 				int i = btnSuspend->textLabel().find( TQRegExp("\\&"), 0 );    // i == 1
 				btnSuspend->setAccel( "ALT+" + btnSuspend->textLabel().lower()[i+1] ) ;
-				hbuttonbox->addWidget ( btnSuspend);
-				connect(btnSuspend, TQT_SIGNAL(clicked()), TQT_SLOT(slotSuspend()));
+				hbuttonbox->addWidget ( btnSuspend );
+				connect(btnSuspend, TQ_SIGNAL(clicked()), TQ_SLOT(slotSuspend()));
 			}
 
 			if (canHibernate && !disableHibernate)
@@ -916,28 +866,50 @@ KSMShutdownDlg::KSMShutdownDlg( TQWidget* parent,
 				FlatButton* btnHibernate = new FlatButton( frame );
 				btnHibernate->setTextLabel( i18n("&Hibernate"), false );
 				btnHibernate->setPixmap( DesktopIcon( "hibernate") );
+				TQToolTip::add(btnHibernate, i18n("<qt><p>Put the computer in suspend-to-disk mode."
+				" The system is stopped and its state saved to disk.</p><p>This offers the greatest powersaving but"
+				" considerable time is required to reactivate the system again.</p><p>This correspond to ACPI S4 mode.</p><p>Also known as Suspend-to-Disk mode.</p></qt>"));
 				int i = btnHibernate->textLabel().find( TQRegExp("\\&"), 0 );    // i == 1
 				btnHibernate->setAccel( "ALT+" + btnHibernate->textLabel().lower()[i+1] ) ;
-				hbuttonbox->addWidget ( btnHibernate);
-				connect(btnHibernate, TQT_SIGNAL(clicked()), TQT_SLOT(slotHibernate()));
+				hbuttonbox->addWidget ( btnHibernate );
+				connect(btnHibernate, TQ_SIGNAL(clicked()), TQ_SLOT(slotHibernate()));
 			}
 
+			if (canHybridSuspend && !disableSuspend && !disableHibernate)
+			{
+				// Hybrid suspend
+				FlatButton* btnHybridSuspend = new FlatButton( frame );
+				btnHybridSuspend->setTextLabel( i18n("H&ybrid Suspend"), false );
+				btnHybridSuspend->setPixmap( DesktopIcon( "hibernate") );
+				TQToolTip::add(btnHybridSuspend, i18n("<qt><p>Put the computer in both suspend-to-memory and"
+				" suspend-to-disk mode. The system is stopped and its state saved to memory and to disk.</p>"
+				"<p>This offers the best of both 'Suspend' and 'Hibernate' modes combined together. The system is"
+				" de facto in 'Suspend' mode but if power is lost, work can still be resumed as if the system"
+				" had been hibernated, preventing any data loss.</p><p>This correspond to ACPI S3+S4 mode.</p>"
+				"<p>Also known as Suspend-to-RAM + Suspend-to-Disk mode.</p></qt>"));
+				int i = btnHybridSuspend->textLabel().find( TQRegExp("\\&"), 0 );    // i == 1
+				btnHybridSuspend->setAccel( "ALT+" + btnHybridSuspend->textLabel().lower()[i+1] ) ;
+				hbuttonbox->addWidget ( btnHybridSuspend );
+				connect(btnHybridSuspend, TQ_SIGNAL(clicked()), TQ_SLOT(slotHybridSuspend()));
+			}
+			
 			// Separator (within buttonlay)
 			vbox->addWidget( new KSeparator( frame ) );
 
 			// bottom buttons
 			TQHBoxLayout* hbuttonbox2 = new TQHBoxLayout( vbox, factor * KDialog::spacingHint() );
-			hbuttonbox2->setAlignment( Qt::AlignHCenter );
+			hbuttonbox2->setAlignment( TQt::AlignHCenter );
 
 			if (mayrb) {
 				// Reboot
 				FlatButton* btnReboot = new FlatButton( frame );
 				btnReboot->setTextLabel( i18n("&Restart"), false );
 				btnReboot->setPixmap( DesktopIcon( "reload") );
+				TQToolTip::add( btnReboot, i18n( "<qt><p>Log out of the current session and restart the computer.</p></qt>" ) );
 				int i = btnReboot->textLabel().find( TQRegExp("\\&"), 0 );    // i == 1
 				btnReboot->setAccel( "ALT+" + btnReboot->textLabel().lower()[i+1] ) ;
 				hbuttonbox2->addWidget ( btnReboot);
-				connect(btnReboot, TQT_SIGNAL(clicked()), TQT_SLOT(slotReboot()));
+				connect(btnReboot, TQ_SIGNAL(clicked()), TQ_SLOT(slotReboot()));
 				if ( sdtype == TDEApplication::ShutdownTypeReboot ) {
 					btnReboot->setFocus();
 				}
@@ -964,7 +936,7 @@ KSMShutdownDlg::KSMShutdownDlg( TQWidget* parent,
 					}
 
 					btnReboot->setPopup(targets);
-					connect( targets, TQT_SIGNAL(activated(int)), TQT_SLOT(slotReboot(int)) );
+					connect( targets, TQ_SIGNAL(activated(int)), TQ_SLOT(slotReboot(int)) );
 				}
 				// BAD KARMA .. this code is copied line by line from standard konqy dialog [EOF]
 			}
@@ -972,12 +944,13 @@ KSMShutdownDlg::KSMShutdownDlg( TQWidget* parent,
 			if (maysd) {
 				// Shutdown
 				FlatButton* btnHalt = new FlatButton( frame );
-				btnHalt->setTextLabel( i18n("&Turn Off"), false );
+				btnHalt->setTextLabel( i18n("&Shutdown"), false );
 				btnHalt->setPixmap( DesktopIcon( "system-log-out") );
+				TQToolTip::add( btnHalt, i18n( "<qt><p>Log out of the current session and turn off the computer.</p></qt>" ) );
 				int i = btnHalt->textLabel().find( TQRegExp("\\&"), 0 );    // i == 1
 				btnHalt->setAccel( "ALT+" + btnHalt->textLabel().lower()[i+1] ) ;
 				hbuttonbox2->addWidget ( btnHalt );
-				connect(btnHalt, TQT_SIGNAL(clicked()), TQT_SLOT(slotHalt()));
+				connect(btnHalt, TQ_SIGNAL(clicked()), TQ_SLOT(slotHalt()));
 				if ( sdtype == TDEApplication::ShutdownTypeHalt ) {
 					btnHalt->setFocus();
 				}
@@ -985,23 +958,24 @@ KSMShutdownDlg::KSMShutdownDlg( TQWidget* parent,
 
 			// cancel buttonbox
 			TQHBoxLayout* hbuttonbox3 = new TQHBoxLayout( vbox, factor * KDialog::spacingHint() );
-			hbuttonbox3->setAlignment( Qt::AlignRight );
+			hbuttonbox3->setAlignment( TQt::AlignRight );
 
 			// Back to Desktop
 			KSMPushButton* btnBack = new KSMPushButton( KStdGuiItem::cancel(), frame );
 			hbuttonbox3->addWidget( btnBack );
-			connect(btnBack, TQT_SIGNAL(clicked()), TQT_SLOT(reject()));
+			connect(btnBack, TQ_SIGNAL(clicked()), TQ_SLOT(reject()));
 
 		}
 		else
 		{
+      // Standard style logout window
 			if (maysd) {
 				// Shutdown
-				KPushButton* btnHalt = new KPushButton( KGuiItem( i18n("&Turn Off Computer"), "system-log-out"), frame );
-				TQToolTip::add( btnHalt, i18n( "<qt><h3>Turn Off Computer</h3><p>Log out of the current session and turn off the computer</p></qt>" ) );
+				KPushButton* btnHalt = new KPushButton( KGuiItem( i18n("&Shutdown"), "system-log-out"), frame );
+				TQToolTip::add( btnHalt, i18n( "<qt><p>Log out of the current session and turn off the computer.</p></qt>" ) );
 				btnHalt->setFont( btnFont );
 				buttonlay->addWidget( btnHalt );
-				connect(btnHalt, TQT_SIGNAL(clicked()), TQT_SLOT(slotHalt()));
+				connect(btnHalt, TQ_SIGNAL(clicked()), TQ_SLOT(slotHalt()));
 				if ( sdtype == TDEApplication::ShutdownTypeHalt || getenv("TDM_AUTOLOGIN") ) {
 					btnHalt->setFocus();
 				}
@@ -1009,12 +983,12 @@ KSMShutdownDlg::KSMShutdownDlg( TQWidget* parent,
 
 			if (mayrb) {
 				// Reboot
-				KSMDelayedPushButton* btnReboot = new KSMDelayedPushButton( KGuiItem( i18n("&Restart Computer"), "reload"), frame );
-				TQToolTip::add( btnReboot, i18n( "<qt><h3>Restart Computer</h3><p>Log out of the current session and restart the computer</p><p>Hold the mouse button or the space bar for a short while to get a list of options what to boot</p></qt>" ) );
+				KSMDelayedPushButton* btnReboot = new KSMDelayedPushButton( KGuiItem( i18n("&Restart"), "reload"), frame );
+				TQToolTip::add( btnReboot, i18n( "<qt><p>Log out of the current session and restart the computer.</p></qt>" ) );
 				btnReboot->setFont( btnFont );
 				buttonlay->addWidget( btnReboot );
 
-				connect(btnReboot, TQT_SIGNAL(clicked()), TQT_SLOT(slotReboot()));
+				connect(btnReboot, TQ_SIGNAL(clicked()), TQ_SLOT(slotReboot()));
 				if ( sdtype == TDEApplication::ShutdownTypeReboot ) {
 					btnReboot->setFocus();
 				}
@@ -1040,37 +1014,58 @@ KSMShutdownDlg::KSMShutdownDlg( TQWidget* parent,
 					}
 
 					btnReboot->setPopup(targets);
-					connect( targets, TQT_SIGNAL(activated(int)), TQT_SLOT(slotReboot(int)) );
+					connect( targets, TQ_SIGNAL(activated(int)), TQ_SLOT(slotReboot(int)) );
 				}
 			}
 
 			if (canFreeze && !disableSuspend)
 			{
-				KPushButton* btnFreeze = new KPushButton( KGuiItem( i18n("&Freeze Computer"), "suspend"), frame );
-				TQToolTip::add(btnFreeze, i18n("<qt><h3>Freeze Computer</h3><p>Put the computer in software sleep mode, allowing for some powersaving. The system can be reactivated in a really short time, almost instantly.</p></qt>"));
+				KPushButton* btnFreeze = new KPushButton( KGuiItem( i18n("&Freeze"), "suspend"), frame );
+				TQToolTip::add(btnFreeze, i18n("<qt><p>Put the computer in software idle mode,"
+				" allowing for some powersaving. The system can be reactivated in a really short time,"
+				" almost instantly.</p><p>This correspond to ACPI S0 mode.</p></qt>"));
 				btnFreeze->setFont( btnFont );
 				buttonlay->addWidget( btnFreeze );
-				connect(btnFreeze, TQT_SIGNAL(clicked()), TQT_SLOT(slotFreeze()));
+				connect(btnFreeze, TQ_SIGNAL(clicked()), TQ_SLOT(slotFreeze()));
 			}
 
 			if (canSuspend && !disableSuspend)
 			{
-				KPushButton* btnSuspend = new KPushButton( KGuiItem( i18n("&Suspend Computer"), "suspend"), frame );
-				TQToolTip::add(btnSuspend, i18n("<qt><h3>Suspend Computer</h3><p>Put the computer in a suspend-to-memory mode. The system is stopped and its state saved to memory.</p><p> This allows more powersaving than 'Freeze Computer' but requires longer time to reactivate the system.</p></qt>"));
+				KPushButton* btnSuspend = new KPushButton( KGuiItem( i18n("&Suspend"), "suspend"), frame );
+				TQToolTip::add(btnSuspend, i18n("<qt><p>Put the computer in suspend-to-memory mode."
+				" The system is stopped and its state saved to memory.</p><p> This allows more powersaving than 'Freeze'"
+				" but requires longer time to reactivate the system.</p><p>This correspond to ACPI S3 mode.</p>"
+				"<p>Also known as Suspend-to-RAM mode.</p></qt>"));
 				btnSuspend->setFont( btnFont );
 				buttonlay->addWidget( btnSuspend );
-				connect(btnSuspend, TQT_SIGNAL(clicked()), TQT_SLOT(slotSuspend()));
+				connect(btnSuspend, TQ_SIGNAL(clicked()), TQ_SLOT(slotSuspend()));
 			}
 
 			if (canHibernate && !disableHibernate)
 			{
-				KPushButton* btnHibernate = new KPushButton( KGuiItem( i18n("&Hibernate Computer"), "hibernate"), frame );
-				TQToolTip::add(btnHibernate, i18n("<qt><h3>Hibernate Computer</h3><p>Put the computer in a suspend-to-disk mode. The system is stopped and its state saved to disk.</p><p>This offers the greatest powersaving but considerable time is required to reactivate the system again.</p></qt>"));
+				KPushButton* btnHibernate = new KPushButton( KGuiItem( i18n("&Hibernate"), "hibernate"), frame );
+				TQToolTip::add(btnHibernate, i18n("<qt><p>Put the computer in suspend-to-disk mode."
+				" The system is stopped and its state saved to disk.</p><p>This offers the greatest powersaving but"
+				" considerable time is required to reactivate the system again.</p><p>This correspond to ACPI S4 mode.</p><p>Also known as Suspend-to-Disk mode.</p></qt>"));
 				btnHibernate->setFont( btnFont );
 				buttonlay->addWidget( btnHibernate );
-				connect(btnHibernate, TQT_SIGNAL(clicked()), TQT_SLOT(slotHibernate()));
+				connect(btnHibernate, TQ_SIGNAL(clicked()), TQ_SLOT(slotHibernate()));
 			}
 
+			if (canHybridSuspend && !disableSuspend && !disableHibernate)
+			{
+				KPushButton* btnHybridSuspend = new KPushButton( KGuiItem( i18n("H&ybrid Suspend"), "hibernate"), frame );
+				TQToolTip::add(btnHybridSuspend, i18n("<qt><p>Put the computer in both suspend-to-memory and"
+				" suspend-to-disk mode. The system is stopped and its state saved to memory and to disk.</p>"
+				"<p>This offers the best of both 'Suspend' and 'Hibernate' modes combined together. The system is"
+				" de facto in 'Suspend' mode but if power is lost, work can still be resumed as if the system"
+				" had been hibernated, preventing any data loss.</p><p>This correspond to ACPI S3+S4 mode.</p>"
+				"<p>Also known as Suspend-to-RAM + Suspend-to-Disk mode.</p></qt>"));
+				btnHybridSuspend->setFont( btnFont );
+				buttonlay->addWidget( btnHybridSuspend );
+				connect(btnHybridSuspend, TQ_SIGNAL(clicked()), TQ_SLOT(slotHybridSuspend()));
+			}
+			
 			buttonlay->addStretch( 1 );
 
 			// Separator
@@ -1079,10 +1074,8 @@ KSMShutdownDlg::KSMShutdownDlg( TQWidget* parent,
 			// Back to Desktop
 			KPushButton* btnBack = new KPushButton( KStdGuiItem::cancel(), frame );
 			buttonlay->addWidget( btnBack );
-			connect(btnBack, TQT_SIGNAL(clicked()), TQT_SLOT(reject()));
-
+			connect(btnBack, TQ_SIGNAL(clicked()), TQ_SLOT(reject()));
 		}
-
 	}
 	else {
 		// finish the dialog correctly
@@ -1090,13 +1083,13 @@ KSMShutdownDlg::KSMShutdownDlg( TQWidget* parent,
 		{
 			// cancel buttonbox
 			TQHBoxLayout* hbuttonbox3 = new TQHBoxLayout( vbox, factor * KDialog::spacingHint() );
-			hbuttonbox3->setAlignment( Qt::AlignRight );
+			hbuttonbox3->setAlignment( TQt::AlignRight );
 
 			// Back to Desktop
 			KSMPushButton* btnBack = new KSMPushButton( KStdGuiItem::cancel(), frame );
 			hbuttonbox3->addWidget( btnBack );
 
-			connect(btnBack, TQT_SIGNAL(clicked()), TQT_SLOT(reject()));
+			connect(btnBack, TQ_SIGNAL(clicked()), TQ_SLOT(reject()));
 		}
 		else
 		{
@@ -1107,27 +1100,14 @@ KSMShutdownDlg::KSMShutdownDlg( TQWidget* parent,
 			KPushButton* btnBack = new KPushButton( KStdGuiItem::cancel(), frame );
 			buttonlay->addWidget( btnBack );
 
-			connect(btnBack, TQT_SIGNAL(clicked()), TQT_SLOT(reject()));
+			connect(btnBack, TQ_SIGNAL(clicked()), TQ_SLOT(reject()));
 		}
-
-
 	}
-
-
 }
 
 
 KSMShutdownDlg::~KSMShutdownDlg()
 {
-#ifdef COMPILE_HALBACKEND
-	if (m_halCtx)
-	{
-		DBusError error;
-		dbus_error_init(&error);
-		libhal_ctx_shutdown(m_halCtx, &error);
-		libhal_ctx_free(m_halCtx);
-	}
-#endif
 }
 
 
@@ -1164,53 +1144,26 @@ void KSMShutdownDlg::slotHalt()
 
 void KSMShutdownDlg::slotSuspend()
 {
-#ifndef COMPILE_HALBACKEND
-	*m_selection = 1;	// Suspend
-#else
-	if (m_dbusConn)
-	{
-		DBusMessage *msg = dbus_message_new_method_call(
-							  "org.freedesktop.Hal",
-							  "/org/freedesktop/Hal/devices/computer",
-							  "org.freedesktop.Hal.Device.SystemPowerManagement",
-							  "Suspend");
-
-		int wakeup=0;
-		dbus_message_append_args(msg, DBUS_TYPE_INT32, &wakeup, DBUS_TYPE_INVALID);
-
-		dbus_connection_send(m_dbusConn, msg, NULL);
-
-		dbus_message_unref(msg);
-	}
-#endif
+	*m_selection = SuspendType::Suspend;
 	reject(); // continue on resume
 }
 
 void KSMShutdownDlg::slotHibernate()
 {
-#ifndef COMPILE_HALBACKEND
-	*m_selection = 2;	// Hibernate
-#else
-	if (m_dbusConn)
-	{
-		DBusMessage *msg = dbus_message_new_method_call(
-							  "org.freedesktop.Hal",
-							  "/org/freedesktop/Hal/devices/computer",
-							  "org.freedesktop.Hal.Device.SystemPowerManagement",
-							  "Hibernate");
-
-		dbus_connection_send(m_dbusConn, msg, NULL);
-
-		dbus_message_unref(msg);
-	}
-#endif
+	*m_selection = SuspendType::Hibernate;
 	reject(); // continue on resume
 }
 
 void KSMShutdownDlg::slotFreeze()
 {
-	*m_selection = 3;	// Freeze
-	reject();
+	*m_selection = SuspendType::Freeze;
+	reject(); // continue on resume
+}
+
+void KSMShutdownDlg::slotHybridSuspend()
+{
+	*m_selection = SuspendType::HybridSuspend;
+	reject(); // continue on resume
 }
 
 bool KSMShutdownDlg::confirmShutdown( bool maysd, bool mayrb, TDEApplication::ShutdownType& sdtype, TQString& bootOption, int* selection )
@@ -1293,8 +1246,8 @@ KSMShutdownIPDlg::KSMShutdownIPDlg(TQWidget* parent)
 
 	setNotificationActionButtonsSkipText(i18n("Skip Notification"));
 	m_button2->setText(i18n("Abort Logout"));
-	connect(m_button1, SIGNAL(clicked()), this, SIGNAL(skipNotificationClicked()));
-	connect(m_button2, SIGNAL(clicked()), this, SIGNAL(abortLogoutClicked()));
+	connect(m_button1, TQ_SIGNAL(clicked()), this, TQ_SIGNAL(skipNotificationClicked()));
+	connect(m_button2, TQ_SIGNAL(clicked()), this, TQ_SIGNAL(abortLogoutClicked()));
 
 	show();
 	setActiveWindow();
@@ -1311,10 +1264,10 @@ KSMDelayedPushButton::KSMDelayedPushButton( const KGuiItem &item,
 						const char *name)
   : KPushButton( item, parent, name), pop(0), popt(0)
 {
-  connect(this, TQT_SIGNAL(pressed()), TQT_SLOT(slotPressed()));
-  connect(this, TQT_SIGNAL(released()), TQT_SLOT(slotReleased()));
+  connect(this, TQ_SIGNAL(pressed()), TQ_SLOT(slotPressed()));
+  connect(this, TQ_SIGNAL(released()), TQ_SLOT(slotReleased()));
   popt = new TQTimer(this);
-  connect(popt, TQT_SIGNAL(timeout()), TQT_SLOT(slotTimeout()));
+  connect(popt, TQ_SIGNAL(timeout()), TQ_SLOT(slotTimeout()));
 }
 
 void KSMDelayedPushButton::setPopup(TQPopupMenu *p)
@@ -1376,7 +1329,7 @@ KSMDelayedMessageBox::KSMDelayedMessageBox( TDEApplication::ShutdownType sdtype,
 	}
 	TQTimer *timer = new TQTimer( this );
 	timer->start( 1000 );
-	connect( timer, TQT_SIGNAL( timeout() ), TQT_SLOT( updateText() ) );
+	connect( timer, TQ_SIGNAL( timeout() ), TQ_SLOT( updateText() ) );
 	KDialog::centerOnScreen(this);
 }
 
@@ -1483,7 +1436,7 @@ void FlatButton::init()
 	setUsesBigPixmap(true);
 	setAutoRaise(true);
 	setTextPosition( TQToolButton::Under );
-	setFocusPolicy(TQ_StrongFocus);
+	setFocusPolicy(TQWidget::StrongFocus);
  }
 
 
