@@ -96,28 +96,28 @@ INDIDriver::INDIDriver(TQWidget *parent) : devManager( parent )
 
   lastGroup = NULL;
 
-  TQObject::connect(addB, TQT_SIGNAL(clicked()), this, TQT_SLOT(addINDIHost()));
-  TQObject::connect(modifyB, TQT_SIGNAL(clicked()), this, TQT_SLOT(modifyINDIHost()));
-  TQObject::connect(removeB, TQT_SIGNAL(clicked()), this, TQT_SLOT(removeINDIHost()));
+  TQObject::connect(addB, TQ_SIGNAL(clicked()), this, TQ_SLOT(addINDIHost()));
+  TQObject::connect(modifyB, TQ_SIGNAL(clicked()), this, TQ_SLOT(modifyINDIHost()));
+  TQObject::connect(removeB, TQ_SIGNAL(clicked()), this, TQ_SLOT(removeINDIHost()));
 
-  TQObject::connect(clientListView, TQT_SIGNAL(rightButtonPressed ( TQListViewItem *, const TQPoint &, int )), this, TQT_SLOT(ClientprocessRightButton( TQListViewItem *, const TQPoint &, int )));
+  TQObject::connect(clientListView, TQ_SIGNAL(rightButtonPressed ( TQListViewItem *, const TQPoint &, int )), this, TQ_SLOT(ClientprocessRightButton( TQListViewItem *, const TQPoint &, int )));
 
-TQObject::connect(ClientpopMenu, TQT_SIGNAL(activated(int)), this, TQT_SLOT(processHostStatus(int)));
+TQObject::connect(ClientpopMenu, TQ_SIGNAL(activated(int)), this, TQ_SLOT(processHostStatus(int)));
 
-TQObject::connect(localListView, TQT_SIGNAL(rightButtonPressed ( TQListViewItem *, const TQPoint &, int )), this, TQT_SLOT(LocalprocessRightButton( TQListViewItem *, const TQPoint &, int )));
+TQObject::connect(localListView, TQ_SIGNAL(rightButtonPressed ( TQListViewItem *, const TQPoint &, int )), this, TQ_SLOT(LocalprocessRightButton( TQListViewItem *, const TQPoint &, int )));
 
-TQObject::connect(LocalpopMenu, TQT_SIGNAL(activated(int)), this, TQT_SLOT(processDeviceStatus(int)));
+TQObject::connect(LocalpopMenu, TQ_SIGNAL(activated(int)), this, TQ_SLOT(processDeviceStatus(int)));
 
-TQObject::connect(ksw->getINDIMenu(), TQT_SIGNAL(driverDisconnected(int)), this, TQT_SLOT(shutdownHost(int)));
+TQObject::connect(ksw->getINDIMenu(), TQ_SIGNAL(driverDisconnected(int)), this, TQ_SLOT(shutdownHost(int)));
 
-TQObject::connect(connectHostB, TQT_SIGNAL(clicked()), this, TQT_SLOT(activateHostConnection()));
-TQObject::connect(disconnectHostB, TQT_SIGNAL(clicked()), this, TQT_SLOT(activateHostDisconnection()));
+TQObject::connect(connectHostB, TQ_SIGNAL(clicked()), this, TQ_SLOT(activateHostConnection()));
+TQObject::connect(disconnectHostB, TQ_SIGNAL(clicked()), this, TQ_SLOT(activateHostDisconnection()));
 
-TQObject::connect(runServiceB, TQT_SIGNAL(clicked()), this, TQT_SLOT(activateRunService()));
-TQObject::connect(stopServiceB, TQT_SIGNAL(clicked()), this, TQT_SLOT(activateStopService()));
+TQObject::connect(runServiceB, TQ_SIGNAL(clicked()), this, TQ_SLOT(activateRunService()));
+TQObject::connect(stopServiceB, TQ_SIGNAL(clicked()), this, TQ_SLOT(activateStopService()));
 
-TQObject::connect(localListView, TQT_SIGNAL(selectionChanged()), this, TQT_SLOT(updateLocalButtons()));
-TQObject::connect(clientListView, TQT_SIGNAL(selectionChanged()), this, TQT_SLOT(updateClientButtons()));
+TQObject::connect(localListView, TQ_SIGNAL(selectionChanged()), this, TQ_SLOT(updateLocalButtons()));
+TQObject::connect(clientListView, TQ_SIGNAL(selectionChanged()), this, TQ_SLOT(updateClientButtons()));
 
 readXMLDriver();
 resize( 500, 300);
@@ -415,7 +415,7 @@ bool INDIDriver::runDevice(IDevice *dev)
   else
     localListView->selectedItem()->setPixmap(2, serverMode);
 
-  connect(dev->proc, TQT_SIGNAL(receivedStderr (TDEProcess *, char *, int)),  dev, TQT_SLOT(processstd(TDEProcess *, char*, int)));
+  connect(dev->proc, TQ_SIGNAL(receivedStderr (TDEProcess *, char *, int)),  dev, TQ_SLOT(processstd(TDEProcess *, char*, int)));
 
   dev->proc->start(TDEProcess::NotifyOnExit, TDEProcess::Stderr);
   //dev->proc->start();
@@ -724,7 +724,7 @@ bool INDIDriver::buildDriverElement(XMLEle *root, TQListViewItem *DGroup, int gr
 
   dv = new IDevice(label, driver, version);
   dv->deviceType = groupType;
-  connect(dv, TQT_SIGNAL(newServerInput()), this, TQT_SLOT(updateLocalButtons()));
+  connect(dv, TQ_SIGNAL(newServerInput()), this, TQ_SLOT(updateLocalButtons()));
   if (focal_length > 0)
    dv->focal_length = focal_length;
   if (aperture > 0)
@@ -732,7 +732,7 @@ bool INDIDriver::buildDriverElement(XMLEle *root, TQListViewItem *DGroup, int gr
   
   devices.push_back(dv);
 
-  // SLOTS/SIGNAL, pop menu, indi server logic
+  // SLOTS/TQ_SIGNAL, pop menu, indi server logic
   return true;
 }
 
