@@ -126,7 +126,7 @@ void INDI_P::drawLt(PState lstate)
 	  case PS_OK:
 	  light->setColor(TQt::green);
 	  emit okState();
-	  disconnect( this, TQT_SIGNAL(okState()), 0, 0 );
+	  disconnect( this, TQ_SIGNAL(okState()), 0, 0 );
 	  break;
 
 	  case PS_BUSY:
@@ -508,12 +508,12 @@ int INDI_P::buildTextGUI(XMLEle *root, char errmsg[])
 	 if (name == "TIME")
 	 {
 	        setupSetButton("Time");
-	     	TQObject::connect(set_w, TQT_SIGNAL(clicked()), indistd, TQT_SLOT(newTime()));
+	     	TQObject::connect(set_w, TQ_SIGNAL(clicked()), indistd, TQ_SLOT(newTime()));
 	 }
 	 else
 	 {
 		setupSetButton("Set");
-        	TQObject::connect(set_w, TQT_SIGNAL(clicked()), this, TQT_SLOT(newText()));
+        	TQObject::connect(set_w, TQ_SIGNAL(clicked()), this, TQ_SLOT(newText()));
          }
 
 	 return 0;
@@ -591,7 +591,7 @@ int INDI_P::buildNumberGUI  (XMLEle *root, char errmsg[])
         else
 		  setupSetButton("Set");
 
-	TQObject::connect(set_w, TQT_SIGNAL(clicked()), this, TQT_SLOT(newText()));
+	TQObject::connect(set_w, TQ_SIGNAL(clicked()), this, TQ_SLOT(newText()));
 
 	return (0);
 }
@@ -682,7 +682,7 @@ int INDI_P::buildMenuGUI(XMLEle *root, char errmsg[])
 	PHBox->addWidget(om_w);
 	PHBox->addItem(HorSpacer);
 
-	TQObject::connect(om_w, TQT_SIGNAL(activated(int)), this, TQT_SLOT(newSwitch(int)));
+	TQObject::connect(om_w, TQ_SIGNAL(activated(int)), this, TQ_SLOT(newSwitch(int)));
 
        	return (0);
 }
@@ -703,7 +703,7 @@ int INDI_P::buildSwitchesGUI(XMLEle *root, char errmsg[])
 	if (guitype == PG_BUTTONS)
 	  groupB->setExclusive(true);
 
-	TQObject::connect(groupB, TQT_SIGNAL(clicked(int)), this, TQT_SLOT(newSwitch(int)));
+	TQObject::connect(groupB, TQ_SIGNAL(clicked(int)), this, TQ_SLOT(newSwitch(int)));
 
        for (sep = nextXMLEle (root, 1), j=-1; sep != NULL; sep = nextXMLEle (root, 0))
        {
@@ -900,7 +900,7 @@ int INDI_P::buildBLOBGUI(XMLEle *root, char errmsg[])
     return 0;
 
    setupSetButton(i18n("Upload"));
-   TQObject::connect(set_w, TQT_SIGNAL(clicked()), this, TQT_SLOT(newBlob()));
+   TQObject::connect(set_w, TQ_SIGNAL(clicked()), this, TQ_SLOT(newBlob()));
 
   return 0;
 
