@@ -1698,9 +1698,9 @@ void KStarsData::setMagnitude( float newMagnitude, bool forceReload ) {
 		if (reloadingData() == false) {  // if not already reloading data
 			source = new FileSource(this, newMagnitude);
 			loader = new StarDataSink(this);
-			connect(loader, TQT_SIGNAL(done()), this, TQT_SLOT(checkDataPumpAction()));
-			connect(loader, TQT_SIGNAL(updateSkymap()), this, TQT_SLOT(updateSkymap()));
-			connect(loader, TQT_SIGNAL(clearCache()), this, TQT_SLOT(sendClearCache()));
+			connect(loader, TQ_SIGNAL(done()), this, TQ_SLOT(checkDataPumpAction()));
+			connect(loader, TQ_SIGNAL(updateSkymap()), this, TQ_SLOT(updateSkymap()));
+			connect(loader, TQ_SIGNAL(clearCache()), this, TQ_SLOT(sendClearCache()));
 			// start reloading
 			pump = new TQDataPump (source, (TQDataSink*) loader);
 		}
@@ -1762,7 +1762,7 @@ void KStarsData::initialize() {
 	if (startupComplete) return;
 
 	initTimer = new TQTimer;
-	TQObject::connect(initTimer, TQT_SIGNAL(timeout()), this, TQT_SLOT( slotInitialize() ) );
+	TQObject::connect(initTimer, TQ_SIGNAL(timeout()), this, TQ_SLOT( slotInitialize() ) );
 	initCounter = 0;
 	initTimer->start(1);
 }
@@ -2219,7 +2219,7 @@ void KStarsData::updateTime( GeoLocation *geo, SkyMap *skymap, const bool automa
 		skymap->updateFocus();
 
 		if ( clock()->isManualMode() )
-			TQTimer::singleShot( 0, skymap, TQT_SLOT( forceUpdateNow() ) );
+			TQTimer::singleShot( 0, skymap, TQ_SLOT( forceUpdateNow() ) );
 		else skymap->forceUpdate();
 	}
 }
