@@ -57,7 +57,7 @@ class DeepSkyObject;
 	*/
 
 class SkyMap : public TQWidget  {
-   Q_OBJECT
+   TQ_OBJECT
 
 public:
 /**
@@ -161,8 +161,8 @@ public:
 	void setFocusAltAz(double alt, double az);
 
 /**@short sets the destination point of the sky map.
-	*@note setDestination() emits the destinationChanged() SIGNAL,
-	*which triggers the TQT_SLOT function SkyMap::slewFocus().  This
+	*@note setDestination() emits the destinationChanged() signal,
+	*which triggers the slot function SkyMap::slewFocus().  This
 	*function iteratively steps the Focus point toward Destination,
 	*repainting the sky at each step (if Options::useAnimatedSlewing()==true).
 	*@param f a pointer to the SkyPoint the map should slew to
@@ -445,7 +445,7 @@ public slots:
 /**@short Center the display at the point ClickedPoint.
 	*
 	*The essential part of the function is to simply set the Destination point, which will emit
-	*the destinationChanged() SIGNAL, which triggers the slewFocus() SLOT.  Additionally, this
+	*the destinationChanged() signal, which triggers the slewFocus() slot.  Additionally, this
 	*function performs some bookkeeping tasks, such updating whether we are tracking the new
 	*object/position, adding a Planet Trail if required, etc.
 	*
@@ -885,8 +885,8 @@ private:
 	*NULL pointer, and the TransientTimer is not already active.  These conditions
 	*are met when the mouse did not move for HOVER_INTERVAL msec (triggering a
 	*TransientLabel), but the mouse has since been moved, thus ending the Hover event.
-	*This function merely starts the TransientTimer, whose timeout TQT_SIGNAL is
-	*connected to the slotTransientTimeout() SLOT, which handles the actual fading
+	*This function merely starts the TransientTimer, whose timeout signal is
+	*connected to the slotTransientTimeout() slot, which handles the actual fading
 	*of the transient label, and eventually resets TransientObject to NULL.
 	*@sa SkyMap::slotTransientLabel(), SkyMap::slotTransientTimeout()
 	*/
