@@ -27,7 +27,7 @@ class FileView;
 
 class MainWidget : public TQWidget
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 
 public:
