@@ -63,7 +63,7 @@ KonqSidebarWeather::KonqSidebarWeather(TDEInstance* inst, TQObject* parent,
 		kdDebug() << "attached dcop signals..." << endl;
 
 	timeOut = new TQTimer(this, "timeOut" );
-	connect(timeOut, TQT_SIGNAL(timeout()), this, TQT_SLOT(updateWidgets()));
+	connect(timeOut, TQ_SIGNAL(timeout()), this, TQ_SLOT(updateWidgets()));
 
 	updateWidgets();
 }
