@@ -36,6 +36,7 @@
 #include "pixmap.h"
 #include "kcmmisc.h"
 #include "kcmlayoutwidget.h"
+#include "x11helper.h"
 
 #include "kcmlayout.h"
 #include "kcmlayout.moc"
@@ -105,50 +106,55 @@ LayoutConfig::LayoutConfig(TQWidget *parent, const char *name)
     m_rules(NULL),
     m_forceGrpOverwrite(false)
 {
+  X11Helper::initializeTranslations();
   TQVBoxLayout *main = new TQVBoxLayout(this, 0, KDialog::spacingHint());
 
   widget = new LayoutConfigWidget(this, "widget");
-  main->addWidget(TQT_TQWIDGET(widget));
+  main->addWidget(widget);
 
-  connect( TQT_TQOBJECT(widget->chkEnable), TQT_SIGNAL( toggled( bool )), TQT_TQOBJECT(this), TQT_SLOT(changed()));
-  connect( TQT_TQOBJECT(widget->chkShowSingle), TQT_SIGNAL( toggled( bool )), TQT_TQOBJECT(this), TQT_SLOT(changed()));
+  connect( widget->chkEnable, TQ_SIGNAL( toggled( bool )), this, TQ_SLOT(changed()));
+  connect( widget->chkShowSingle, TQ_SIGNAL( toggled( bool )), this, TQ_SLOT(changed()));
 
-  connect( TQT_TQOBJECT(widget->comboHotkey), TQT_SIGNAL(activated(int)), TQT_TQOBJECT(this), TQT_SLOT(hotkeyComboChanged()));
-  connect( TQT_TQOBJECT(widget->comboHotkey), TQT_SIGNAL(activated(int)), TQT_TQOBJECT(this), TQT_SLOT(updateOptionsCommand()));
-  connect( TQT_TQOBJECT(widget->comboHotkey), TQT_SIGNAL(activated(int)), TQT_TQOBJECT(this), TQT_SLOT(changed()));
-  connect( TQT_TQOBJECT(widget->comboModel), TQT_SIGNAL(activated(int)), TQT_TQOBJECT(this), TQT_SLOT(changed()));
+  connect( widget->comboHotkey, TQ_SIGNAL(activated(int)), this, TQ_SLOT(hotkeyComboChanged()));
+  connect( widget->comboHotkey, TQ_SIGNAL(activated(int)), this, TQ_SLOT(updateOptionsCommand()));
+  connect( widget->comboHotkey, TQ_SIGNAL(activated(int)), this, TQ_SLOT(changed()));
+  connect( widget->comboModel, TQ_SIGNAL(activated(int)), this, TQ_SLOT(changed()));
 
-  connect( TQT_TQOBJECT(widget->listLayoutsSrc), TQT_SIGNAL(doubleClicked(TQListViewItem*,const TQPoint&, int)),
-									TQT_TQOBJECT(this), TQT_SLOT(add()));
-  connect( TQT_TQOBJECT(widget->btnAdd), TQT_SIGNAL(clicked()), TQT_TQOBJECT(this), TQT_SLOT(add()));
-  connect( TQT_TQOBJECT(widget->btnRemove), TQT_SIGNAL(clicked()), TQT_TQOBJECT(this), TQT_SLOT(remove()));
+  connect( widget->listLayoutsSrc, TQ_SIGNAL(doubleClicked(TQListViewItem*,const TQPoint&, int)),
+									this, TQ_SLOT(add()));
+  connect( widget->btnAdd, TQ_SIGNAL(clicked()), this, TQ_SLOT(add()));
+  connect( widget->btnRemove, TQ_SIGNAL(clicked()), this, TQ_SLOT(remove()));
 
-  connect( TQT_TQOBJECT(widget->comboVariant), TQT_SIGNAL(activated(int)), TQT_TQOBJECT(this), TQT_SLOT(changed()));
-  connect( TQT_TQOBJECT(widget->comboVariant), TQT_SIGNAL(activated(int)), TQT_TQOBJECT(this), TQT_SLOT(variantChanged()));
-  connect( TQT_TQOBJECT(widget->listLayoutsDst), TQT_SIGNAL(selectionChanged(TQListViewItem *)),
-		TQT_TQOBJECT(this), TQT_SLOT(layoutSelChanged(TQListViewItem *)));
+  connect( widget->comboVariant, TQ_SIGNAL(activated(int)), this, TQ_SLOT(changed()));
+  connect( widget->comboVariant, TQ_SIGNAL(activated(int)), this, TQ_SLOT(variantChanged()));
+  connect( widget->listLayoutsDst, TQ_SIGNAL(selectionChanged(TQListViewItem *)),
+		this, TQ_SLOT(layoutSelChanged(TQListViewItem *)));
 
-  connect( widget->editDisplayName, TQT_SIGNAL(textChanged(const TQString&)), TQT_TQOBJECT(this), TQT_SLOT(displayNameChanged(const TQString&)));
+  connect( widget->editDisplayName, TQ_SIGNAL(textChanged(const TQString&)), this, TQ_SLOT(displayNameChanged(const TQString&)));
 
   widget->btnUp->setIconSet(SmallIconSet("1uparrow"));
-  connect( widget->btnUp, TQT_SIGNAL(clicked()), TQT_TQOBJECT(this), TQT_SLOT(changed()));
-  connect( widget->btnUp, TQT_SIGNAL(clicked()), TQT_TQOBJECT(this), TQT_SLOT(moveUp()));
+  connect( widget->btnUp, TQ_SIGNAL(clicked()), this, TQ_SLOT(changed()));
+  connect( widget->btnUp, TQ_SIGNAL(clicked()), this, TQ_SLOT(moveUp()));
   widget->btnDown->setIconSet(SmallIconSet("1downarrow"));
-  connect( widget->btnDown, TQT_SIGNAL(clicked()), TQT_TQOBJECT(this), TQT_SLOT(changed()));
-  connect( widget->btnDown, TQT_SIGNAL(clicked()), TQT_TQOBJECT(this), TQT_SLOT(moveDown()));
+  connect( widget->btnDown, TQ_SIGNAL(clicked()), this, TQ_SLOT(changed()));
+  connect( widget->btnDown, TQ_SIGNAL(clicked()), this, TQ_SLOT(moveDown()));
 
-  connect( widget->grpStyle, TQT_SIGNAL( clicked( int ) ), TQT_SLOT(changed()));
-  connect( widget->grpSwitching, TQT_SIGNAL( clicked( int ) ), TQT_SLOT(changed()));
-  connect( widget->grpLabel, TQT_SIGNAL( clicked( int ) ), TQT_SLOT(changed()));
+  connect( widget->grpStyle, TQ_SIGNAL( clicked( int ) ), TQ_SLOT(changed()));
+  connect( widget->grpSwitching, TQ_SIGNAL( clicked( int ) ), TQ_SLOT(changed()));
+  connect( widget->grpLabel, TQ_SIGNAL( clicked( int ) ), TQ_SLOT(changed()));
 
-  connect( widget->bgColor, TQT_SIGNAL( changed(const TQColor&) ), TQT_TQOBJECT(this), TQT_SLOT(changed()));
-  connect( widget->fgColor, TQT_SIGNAL( changed(const TQColor&) ), TQT_TQOBJECT(this), TQT_SLOT(changed()));
-  connect( widget->labelFont, TQT_SIGNAL( fontSelected(const TQFont&) ), TQT_TQOBJECT(this), TQT_SLOT(changed()));
-  connect( widget->chkLabelShadow, TQT_SIGNAL( toggled( bool ) ), TQT_TQOBJECT(this), TQT_SLOT(changed()));
-  connect( widget->shColor, TQT_SIGNAL( changed(const TQColor&) ), TQT_TQOBJECT(this), TQT_SLOT(changed()));
+  connect( widget->bgColor, TQ_SIGNAL( changed(const TQColor&) ), this, TQ_SLOT(changed()));
+  connect( widget->fgColor, TQ_SIGNAL( changed(const TQColor&) ), this, TQ_SLOT(changed()));
+  connect( widget->chkBgTransparent, TQ_SIGNAL( toggled(bool) ), this, TQ_SLOT(changed()));
+  connect( widget->labelFont, TQ_SIGNAL( fontSelected(const TQFont&) ), this, TQ_SLOT(changed()));
+  connect( widget->chkLabelShadow, TQ_SIGNAL( toggled( bool ) ), this, TQ_SLOT(changed()));
+  connect( widget->shColor, TQ_SIGNAL( changed(const TQColor&) ), this, TQ_SLOT(changed()));
 
-  connect( widget->chkEnableSticky, TQT_SIGNAL(toggled(bool)), TQT_TQOBJECT(this), TQT_SLOT(changed()));
-  connect( widget->spinStickyDepth, TQT_SIGNAL(valueChanged(int)), TQT_TQOBJECT(this), TQT_SLOT(changed()));
+  connect( widget->chkEnableSticky, TQ_SIGNAL(toggled(bool)), this, TQ_SLOT(changed()));
+  connect( widget->spinStickyDepth, TQ_SIGNAL(valueChanged(int)), this, TQ_SLOT(changed()));
+
+  connect(widget->chkEnableNotify,       TQ_SIGNAL(toggled(bool)), TQ_SLOT(changed()));
+  connect(widget->chkNotifyUseKMilo,     TQ_SIGNAL(toggled(bool)), TQ_SLOT(changed()));
 
   widget->listLayoutsSrc->setColumnText(LAYOUT_COLUMN_FLAG, "");
   widget->listLayoutsDst->setColumnText(LAYOUT_COLUMN_FLAG, "");
@@ -172,7 +178,7 @@ LayoutConfig::LayoutConfig(TQWidget *parent, const char *name)
 
   // Load global shortcuts
 #define NOSLOTS
-  keys = new TDEGlobalAccel(TQT_TQOBJECT(this));
+  keys = new TDEGlobalAccel(this);
 #include "kxkbbindings.cpp"
 
   makeOptionsTab();
@@ -240,7 +246,7 @@ void LayoutConfig::initUI() {
 		const char *hkOpt  = tqstrdup(TQString("grp:" + (*hk)).ascii());
 		const char *hkDesc = allOptions[hkOpt];
 		if (hkDesc != 0) { // the option exists
-			widget->comboHotkey->insertItem(i18n(hkDesc));
+			widget->comboHotkey->insertItem(XkbRules::trOpt(hkDesc));
 		}
 	}
 	widget->comboHotkey->insertItem(i18n("None"));
@@ -288,6 +294,9 @@ void LayoutConfig::initUI() {
 	widget->spinStickyDepth->setEnabled(m_kxkbConfig.m_stickySwitching);
 	widget->spinStickyDepth->setValue( m_kxkbConfig.m_stickySwitchingDepth);
 
+	widget->chkEnableNotify->setChecked(m_kxkbConfig.m_enableNotify);
+	widget->chkNotifyUseKMilo->setChecked(m_kxkbConfig.m_notifyUseKMilo);
+
 	updateStickyLimit();
 
 	widget->chkEnable->setChecked( m_kxkbConfig.m_useKxkb );
@@ -308,7 +317,7 @@ void LayoutConfig::initUI() {
 			foundGrp = true;
 		}
 
-		OptionListItem *item = m_optionGroups[i18n(optionKey.latin1())];
+		OptionListItem *item = m_optionGroups[optionKey];
 
 		if (item != NULL) {
 			OptionListItem *child = item->findChildItem( option );
@@ -397,6 +406,9 @@ void LayoutConfig::save()
 	m_kxkbConfig.m_stickySwitching = widget->chkEnableSticky->isChecked();
 	m_kxkbConfig.m_stickySwitchingDepth = widget->spinStickyDepth->value();
 
+	m_kxkbConfig.m_enableNotify = widget->chkEnableNotify->isChecked();
+	m_kxkbConfig.m_notifyUseKMilo = widget->chkNotifyUseKMilo->isChecked();
+
 	m_kxkbConfig.save();
 
 	// We might need to unset previous hotkey options
@@ -659,13 +671,13 @@ TQWidget* LayoutConfig::makeOptionsTab()
   listView->setColumnText( 0, i18n( "Options" ) );
   listView->clear();
 
-  connect(listView, TQT_SIGNAL(clicked(TQListViewItem *)), TQT_SLOT(changed()));
-  connect(listView, TQT_SIGNAL(clicked(TQListViewItem *)), TQT_SLOT(resolveConflicts(TQListViewItem *)));
-  connect(listView, TQT_SIGNAL(clicked(TQListViewItem *)), TQT_SLOT(updateHotkeyCombo()));
+  connect(listView, TQ_SIGNAL(clicked(TQListViewItem *)), TQ_SLOT(changed()));
+  connect(listView, TQ_SIGNAL(clicked(TQListViewItem *)), TQ_SLOT(resolveConflicts(TQListViewItem *)));
+  connect(listView, TQ_SIGNAL(clicked(TQListViewItem *)), TQ_SLOT(updateHotkeyCombo()));
 
-  connect(widget->xkbOptsMode, TQT_SIGNAL(released(int)), TQT_SLOT(changed()));
-  connect(widget->xkbOptsMode, TQT_SIGNAL(released(int)), TQT_SLOT(updateOptionsCommand()));
-  connect(widget->xkbOptsMode, TQT_SIGNAL(released(int)), TQT_SLOT(updateHotkeyCombo()));
+  connect(widget->xkbOptsMode, TQ_SIGNAL(released(int)), TQ_SLOT(changed()));
+  connect(widget->xkbOptsMode, TQ_SIGNAL(released(int)), TQ_SLOT(updateOptionsCommand()));
+  connect(widget->xkbOptsMode, TQ_SIGNAL(released(int)), TQ_SLOT(updateHotkeyCombo()));
 
   //Create controllers for all options
   TQDictIterator<char> it(m_rules->options());
@@ -676,25 +688,25 @@ TQWidget* LayoutConfig::makeOptionsTab()
     {
       if( it.currentKey() == "ctrl" || it.currentKey() == "caps"
           || it.currentKey() == "altwin") {
-        parent = new OptionListItem(listView, i18n( it.current() ),
+        parent = new OptionListItem(listView, XkbRules::trOpt( it.current() ),
             TQCheckListItem::RadioButtonController, it.currentKey());
         OptionListItem *item = new OptionListItem(parent, i18n( "None" ),
             TQCheckListItem::RadioButton, "none");
         item->setState(TQCheckListItem::On);
       }
       else if (it.currentKey() == "grp") {
-        parent = new OptionListItem(listView, i18n(it.current()),
+        parent = new OptionListItem(listView, XkbRules::trOpt(it.current()),
             TQCheckListItem::RadioButtonController, it.currentKey());
         parent->setSelectable(false);
         OptionListItem *item = new OptionListItem(parent, i18n("None"),
             TQCheckListItem::CheckBox, "grp:none");
       }
       else {
-        parent = new OptionListItem(listView, i18n( it.current() ),
+        parent = new OptionListItem(listView, XkbRules::trOpt( it.current() ),
             TQCheckListItem::CheckBoxController, it.currentKey());
       }
       parent->setOpen(true);
-      m_optionGroups.insert(i18n(it.currentKey().local8Bit()), parent);
+      m_optionGroups.insert(it.currentKey(), parent);
     }
   }
 
@@ -714,10 +726,10 @@ TQWidget* LayoutConfig::makeOptionsTab()
         text = text.replace( "Cap$", "Caps." );
         if ( parent->type() == TQCheckListItem::CheckBoxController
              || key.startsWith("grp:"))
-            new OptionListItem(parent, i18n(text.utf8()),
+            new OptionListItem(parent, XkbRules::trOpt(text),
                 TQCheckListItem::CheckBox, key);
         else
-            new OptionListItem(parent, i18n(text.utf8()),
+            new OptionListItem(parent, XkbRules::trOpt(text),
                 TQCheckListItem::RadioButton, key);
       }
     }
@@ -730,7 +742,7 @@ TQWidget* LayoutConfig::makeOptionsTab()
 
 TQWidget* LayoutConfig::makeShortcutsTab() {
   m_keyChooser = new KKeyChooser(keys, widget->tabShortcuts, false, false);
-  connect(m_keyChooser, SIGNAL(keyChange()), this, SLOT(changed()));
+  connect(m_keyChooser, TQ_SIGNAL(keyChange()), this, TQ_SLOT(changed()));
   widget->tabShortcuts->layout()->add(m_keyChooser);
   return m_keyChooser;
 }
@@ -1323,7 +1335,7 @@ extern "C"
 
 //these seem to be new in XFree86 4.4.0
  I18N_NOOP("Shift with numpad keys works as in MS Windows.");
- I18N_NOOP("Special keys (Ctrl+Alt+<key>) handled in a server.");
+ I18N_NOOP("Special keys (Ctrl+Alt+&lt;key&gt;) handled in a server.");
  I18N_NOOP("Miscellaneous compatibility options");
  I18N_NOOP("Right Control key works as Right Alt");
 
