@@ -79,20 +79,20 @@ CppNewClassDialog::CppNewClassDialog( CppSupportPart *part, TQWidget *parent, co
 
 	accessMenu = new TQPopupMenu( this );
 	accessMenu->insertItem( i18n( "Use as Private" ),
-	                        this, TQT_SLOT( changeToPrivate() ), 0, 1 );
+	                        this, TQ_SLOT( changeToPrivate() ), 0, 1 );
 	accessMenu->insertItem( i18n( "Use as Protected" ),
-	                        this, TQT_SLOT( changeToProtected() ), 0, 2 );
+	                        this, TQ_SLOT( changeToProtected() ), 0, 2 );
 	accessMenu->insertItem( i18n( "Use as Public" ),
-	                        this, TQT_SLOT( changeToPublic() ), 0, 3 );
+	                        this, TQ_SLOT( changeToPublic() ), 0, 3 );
 	accessMenu->insertSeparator();
 	accessMenu->insertItem( i18n( "Unset" ),
-	                        this, TQT_SLOT( changeToInherited() ), 0, 5 );
+	                        this, TQ_SLOT( changeToInherited() ), 0, 5 );
 
 	overMenu = new TQPopupMenu( this );
 	overMenu->insertItem( i18n( "Extend Base Class Functionality" ),
-	                      this, TQT_SLOT( extendFunctionality() ), 0, 11 );
+	                      this, TQ_SLOT( extendFunctionality() ), 0, 11 );
 	overMenu->insertItem( i18n( "Replace Base Class Method" ),
-	                      this, TQT_SLOT( replaceFunctionality() ), 0, 12 );
+	                      this, TQ_SLOT( replaceFunctionality() ), 0, 12 );
 
 	compBasename = basename_edit->completionObject();
 	setCompletionBasename( m_part->codeModel() );
@@ -1171,7 +1171,7 @@ void CppNewClassDialog::setAccessForBase( TQString baseclass, TQString newAccess
 
 void CppNewClassDialog::access_view_mouseButtonPressed( int button, TQListViewItem * item, const TQPoint &p, int /*c*/ )
 {
-	if ( item && ( ( button == Qt::LeftButton ) || ( button == Qt::RightButton ) ) && ( item->depth() > 1 ) )
+	if ( item && ( ( button == TQt::LeftButton ) || ( button == TQt::RightButton ) ) && ( item->depth() > 1 ) )
 	{
 		accessMenu->setItemEnabled( 1, true );
 		accessMenu->setItemEnabled( 2, true );
@@ -1196,7 +1196,7 @@ void CppNewClassDialog::access_view_mouseButtonPressed( int button, TQListViewIt
 
 void CppNewClassDialog::methods_view_mouseButtonPressed( int button , TQListViewItem * item, const TQPoint&p , int /*c*/ )
 {
-	if ( item && ( button == Qt::RightButton ) && ( item->depth() > 1 ) && ( ! item->text( 1 ).isEmpty() ) )
+	if ( item && ( button == TQt::RightButton ) && ( item->depth() > 1 ) && ( ! item->text( 1 ).isEmpty() ) )
 	{
 		overMenu->exec( p );
 	}
