@@ -2,7 +2,7 @@
 #include "rubyconfigwidget.h"
 #include "domutil.h"
 
-#include "qtdesignerrubyintegration.h"
+#include "tqtdesignerrubyintegration.h"
 #include "rubyimplementationwidget.h"
 
 #include "kdevcore.h"
@@ -49,26 +49,26 @@ RubySupportPart::RubySupportPart(TQObject *parent, const char *name, const TQStr
 
   TDEAction *action;
   action = new TDEAction( i18n("&Run"), "application-x-executable", SHIFT + Key_F9,
-                        this, TQT_SLOT(slotRun()),
+                        this, TQ_SLOT(slotRun()),
                         actionCollection(), "build_execute" );
   action->setToolTip(i18n("Run"));
   action->setWhatsThis(i18n("<b>Run</b><p>Starts an application."));
   action->setIcon("ruby_run.png");
 
   action = new TDEAction( i18n("Run Test Under Cursor"), "application-x-executable", ALT + Key_F9,
-                        this, TQT_SLOT(slotRunTestUnderCursor()),
+                        this, TQ_SLOT(slotRunTestUnderCursor()),
                         actionCollection(), "build_execute_test_function" );
   action->setToolTip(i18n("Run Test Under Cursor"));
   action->setWhatsThis(i18n("<b>Run Test Under Cursor</b><p>Runs the function under the cursor as test."));
 
-  action = new TDEAction( i18n("Launch Browser"), "network", 0, this, TQT_SLOT(slotBrowse()), actionCollection(), "build_launch_browser" );
+  action = new TDEAction( i18n("Launch Browser"), "network", 0, this, TQ_SLOT(slotBrowse()), actionCollection(), "build_launch_browser" );
   action->setToolTip(i18n("Launch Browser"));
   action->setWhatsThis(i18n("<b>Launch Browser</b><p>Opens a web browser pointing to the Ruby Rails server") );
 
-  action = new TDEAction( i18n("Switch To Controller"), 0, CTRL+ALT+Key_1, this, TQT_SLOT(slotSwitchToController()), actionCollection(), "switch_to_controller" );
-  action = new TDEAction( i18n("Switch To Model"), 0, CTRL+ALT+Key_2, this, TQT_SLOT(slotSwitchToModel()), actionCollection(), "switch_to_model" );
-  action = new TDEAction( i18n("Switch To View"), 0, CTRL+ALT+Key_3, this, TQT_SLOT(slotSwitchToView()), actionCollection(), "switch_to_view" );
-  action = new TDEAction( i18n("Switch To Test"), 0, CTRL+ALT+Key_4, this, TQT_SLOT(slotSwitchToTest()), actionCollection(), "switch_to_test" );
+  action = new TDEAction( i18n("Switch To Controller"), 0, CTRL+ALT+Key_1, this, TQ_SLOT(slotSwitchToController()), actionCollection(), "switch_to_controller" );
+  action = new TDEAction( i18n("Switch To Model"), 0, CTRL+ALT+Key_2, this, TQ_SLOT(slotSwitchToModel()), actionCollection(), "switch_to_model" );
+  action = new TDEAction( i18n("Switch To View"), 0, CTRL+ALT+Key_3, this, TQ_SLOT(slotSwitchToView()), actionCollection(), "switch_to_view" );
+  action = new TDEAction( i18n("Switch To Test"), 0, CTRL+ALT+Key_4, this, TQ_SLOT(slotSwitchToTest()), actionCollection(), "switch_to_test" );
 
   kdDebug() << "Creating RubySupportPart" << endl;
 
@@ -78,14 +78,14 @@ RubySupportPart::RubySupportPart(TQObject *parent, const char *name, const TQStr
   mainWindow()->embedOutputView( m_shellWidget, i18n("Ruby Shell"), i18n("Ruby Shell"));
   mainWindow()->raiseView( m_shellWidget );
 
-  connect( core(), TQT_SIGNAL(projectOpened()), this, TQT_SLOT(projectOpened()) );
-  connect( core(), TQT_SIGNAL(projectClosed()), this, TQT_SLOT(projectClosed()) );
-  connect( core(), TQT_SIGNAL(contextMenu(TQPopupMenu *, const Context *)),
-        this, TQT_SLOT(contextMenu(TQPopupMenu *, const Context *)) );
-  connect( partController(), TQT_SIGNAL(savedFile(const KURL&)),
-  	this, TQT_SLOT(savedFile(const KURL&)) );
-  connect( core(), TQT_SIGNAL(projectConfigWidget(KDialogBase*)),
-        this, TQT_SLOT(projectConfigWidget(KDialogBase*)) );
+  connect( core(), TQ_SIGNAL(projectOpened()), this, TQ_SLOT(projectOpened()) );
+  connect( core(), TQ_SIGNAL(projectClosed()), this, TQ_SLOT(projectClosed()) );
+  connect( core(), TQ_SIGNAL(contextMenu(TQPopupMenu *, const Context *)),
+        this, TQ_SLOT(contextMenu(TQPopupMenu *, const Context *)) );
+  connect( partController(), TQ_SIGNAL(savedFile(const KURL&)),
+  	this, TQ_SLOT(savedFile(const KURL&)) );
+  connect( core(), TQ_SIGNAL(projectConfigWidget(KDialogBase*)),
+        this, TQ_SLOT(projectConfigWidget(KDialogBase*)) );
 }
 
 
@@ -101,7 +101,7 @@ void RubySupportPart::projectConfigWidget(KDialogBase *dlg)
 {
     TQVBox *vbox = dlg->addVBoxPage(i18n("Ruby"), i18n("Ruby"), BarIcon("ruby_config.png", TDEIcon::SizeMedium, TDEIcon::DefaultState, RubySupportPart::instance()));
     RubyConfigWidget *w = new RubyConfigWidget(*projectDom(), (TQWidget *)vbox, "ruby config widget");
-    connect( dlg, TQT_SIGNAL(okClicked()), w, TQT_SLOT(accept()) );
+    connect( dlg, TQ_SIGNAL(okClicked()), w, TQ_SLOT(accept()) );
 }
 
 void RubySupportPart::projectOpened()
@@ -114,10 +114,10 @@ void RubySupportPart::projectOpened()
   m_shellWidget->activate();
   m_shellWidget->setAutoReactivateOnClose( true );
 
-  connect( project(), TQT_SIGNAL(addedFilesToProject(const TQStringList &)),
-  	this, TQT_SLOT(addedFilesToProject(const TQStringList &)) );
-  connect( project(), TQT_SIGNAL(removedFilesFromProject(const TQStringList &)),
-  	this, TQT_SLOT(removedFilesFromProject(const TQStringList &)) );
+  connect( project(), TQ_SIGNAL(addedFilesToProject(const TQStringList &)),
+  	this, TQ_SLOT(addedFilesToProject(const TQStringList &)) );
+  connect( project(), TQ_SIGNAL(removedFilesFromProject(const TQStringList &)),
+  	this, TQ_SLOT(removedFilesFromProject(const TQStringList &)) );
 
   TQFileInfo program(mainProgram());
 
@@ -134,7 +134,7 @@ void RubySupportPart::projectOpened()
 
   // We want to parse only after all components have been
   // properly initialized
-  TQTimer::singleShot(0, this, TQT_SLOT(initialParse()));
+  TQTimer::singleShot(0, this, TQ_SLOT(initialParse()));
 }
 
 void RubySupportPart::maybeParse(const TQString fileName)
@@ -668,7 +668,7 @@ void RubySupportPart::contextMenu( TQPopupMenu * popup, const Context * context
         if (url.fileName().endsWith(".ui"))
         {
             m_contextFileName = url.fileName();
-            int id = popup->insertItem(i18n("Create or Select Implementation..."), this, TQT_SLOT(slotCreateSubclass()));
+            int id = popup->insertItem(i18n("Create or Select Implementation..."), this, TQ_SLOT(slotCreateSubclass()));
             popup->setWhatsThis(id, i18n("<b>Create or select implementation</b><p>Creates or selects a subclass of selected form for use with integrated KDevDesigner."));
         }
     }
