@@ -61,7 +61,7 @@ class KGamePrivate;
  */
 class KDE_EXPORT KGame : public KGameNetwork
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 
 public:
