@@ -54,7 +54,7 @@ class TDEProcess;
  */
 class KDE_EXPORT KGameIO : public TQObject
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 
 public:
@@ -177,7 +177,7 @@ private:
  */
 class KDE_EXPORT KGameKeyIO : public KGameIO
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 
 public:
@@ -195,8 +195,8 @@ public:
      * \code
      * KGameKeyIO *input;
      *  input=new KGameKeyIO(myWidget);
-     *  connect(input,TQT_SIGNAL(signalKeyEvent(KGameIO *,TQDataStream &,TQKeyEvent *,bool *)),
-     *          this,TQT_SLOT(slotKeyInput(KGameIO *,TQDataStream &,TQKeyEvent *,bool *)));
+     *  connect(input,TQ_SIGNAL(signalKeyEvent(KGameIO *,TQDataStream &,TQKeyEvent *,bool *)),
+     *          this,TQ_SLOT(slotKeyInput(KGameIO *,TQDataStream &,TQKeyEvent *,bool *)));
      * \endcode
      *
      * @param parent The parents widget whose keyboard events * should be grabbed
@@ -249,7 +249,7 @@ protected:
  */
 class KDE_EXPORT KGameMouseIO : public KGameIO
 {
-  Q_OBJECT
+  TQ_OBJECT
   
     
 public:
@@ -261,8 +261,8 @@ public:
      * \code
      * KGameMouseIO *input;
      * input=new KGameMouseIO(mView);
-     * connect(input,TQT_SIGNAL(signalMouseEvent(KGameIO *,TQDataStream &,TQMouseEvent *,bool *)),
-     *        this,TQT_SLOT(slotMouseInput(KGameIO *,TQDataStream &,TQMouseEvent *,bool *)));
+     * connect(input,TQ_SIGNAL(signalMouseEvent(KGameIO *,TQDataStream &,TQMouseEvent *,bool *)),
+     *        this,TQ_SLOT(slotMouseInput(KGameIO *,TQDataStream &,TQMouseEvent *,bool *)));
      * \endcode
      *
      * @param parent The widget whose events should be captured
@@ -325,7 +325,7 @@ protected:
  */
 class KDE_EXPORT KGameProcessIO : public KGameIO
 {
-  Q_OBJECT
+  TQ_OBJECT
   
     
 public:
@@ -336,10 +336,10 @@ public:
      * \code
      * KGameProcessIO *input;
      *   input=new KGameProcessIO(executable_file);
-     *  connect(input,TQT_SIGNAL(signalPrepareTurn(TQDataStream &,bool,KGameIO *,bool *)),
-     *          this,TQT_SLOT(slotPrepareTurn(TQDataStream &,bool,KGameIO *,bool *)));
-     *  connect(input,TQT_SIGNAL(signalProcessQuery(TQDataStream &,KGameProcessIO *)),
-     *          this,TQT_SLOT(slotProcessQuery(TQDataStream &,KGameProcessIO *)));
+     *  connect(input,TQ_SIGNAL(signalPrepareTurn(TQDataStream &,bool,KGameIO *,bool *)),
+     *          this,TQ_SLOT(slotPrepareTurn(TQDataStream &,bool,KGameIO *,bool *)));
+     *  connect(input,TQ_SIGNAL(signalProcessQuery(TQDataStream &,KGameProcessIO *)),
+     *          this,TQ_SLOT(slotProcessQuery(TQDataStream &,KGameProcessIO *)));
      * \endcode
      *
      * @param name the filename of the process to start
@@ -480,7 +480,7 @@ private:
  */
 class KDE_EXPORT KGameComputerIO : public KGameIO
 {
-  Q_OBJECT
+  TQ_OBJECT
   
     
 public:
