@@ -30,7 +30,7 @@ namespace KPIM {
  * @author Marc Mutz <mutz@kde.org>
  **/
 class KDE_EXPORT ConfigManager : public TQObject {
-  Q_OBJECT
+  TQ_OBJECT
   
 public:
   /** Commit changes to disk and emit changed() if necessary. */
