@@ -302,7 +302,7 @@ private:
 // Manages the score rules.
 class KDE_EXPORT KScoringManager : public TQObject
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 
  public:
@@ -409,7 +409,7 @@ class KDE_EXPORT KScoringManager : public TQObject
 //----------------------------------------------------------------------------
 class KDE_EXPORT NotifyDialog : public KDialogBase
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 public:
   static void display(ScorableArticle&,const TQString&);
