@@ -521,7 +521,7 @@ namespace KPIM {
 
   class KDE_EXPORT KXFace : public TQObject
   {
-    Q_OBJECT
+    TQ_OBJECT
   
 
     public:
