@@ -1,5 +1,4 @@
-/* -*- C++ -*-
-
+/*
    This file declares the Weaver, Job and Thread classes.
 
    $ Author: Mirko Boehm $
@@ -30,7 +29,7 @@ extern "C"
 #include <tqmutex.h>
 #include <tqevent.h>
 
-#include <tdepimmacros.h>
+#include <kdemacros.h>
 
 namespace KPIM {
 namespace ThreadWeaver {
@@ -163,7 +162,7 @@ namespace ThreadWeaver {
     */
     class KDE_EXPORT Job : public TQObject
     {
-        Q_OBJECT
+        TQ_OBJECT
   
     public:
         /** Construct a Job object. */
@@ -296,7 +295,7 @@ namespace ThreadWeaver {
         which it assigns jobs from it's queue. */
     class KDE_EXPORT Weaver : public TQObject
     {
-        Q_OBJECT
+        TQ_OBJECT
   
     public:
         Weaver (TQObject* parent=0, const char* name=0,
