@@ -119,12 +119,12 @@ LSkatView::LSkatView(TQWidget *parent, const char *name) : TQWidget(parent, name
 
   moveTimer=new TQTimer(this);
   moveTimer->stop();
-  connect(moveTimer,TQT_SIGNAL(timeout()),this,TQT_SLOT(moveTimerReady()));
+  connect(moveTimer,TQ_SIGNAL(timeout()),this,TQ_SLOT(moveTimerReady()));
 
   introcnt=0;
   introTimer=new TQTimer(this);
   introTimer->stop();
-  connect(introTimer,TQT_SIGNAL(timeout()),this,TQT_SLOT(introTimerReady()));
+  connect(introTimer,TQ_SIGNAL(timeout()),this,TQ_SLOT(introTimerReady()));
   introTimer->start(75,FALSE);
 
   for (int i=0;i<NO_OF_CARDS;i++)
@@ -760,7 +760,7 @@ void LSkatView::paintEvent( TQPaintEvent * e)
     TQPixmap pm(this->rect().size());
     TQPainter p;
     TQBrush brush;
-    p.begin(TQT_TQPAINTDEVICE(&pm),this);
+    p.begin(&pm,this);
      brush.setPixmap( getDocument()->mPixBackground );
     p.fillRect(0,0,this->rect().width(),this->rect().height(),brush);
     drawIntro(&p);
@@ -790,7 +790,7 @@ TQPoint LSkatView::calcCardPos(int x,int y)
 // mouse click event
 void LSkatView::mousePressEvent( TQMouseEvent *mouse )
 {
-  if (mouse->button()!=Qt::LeftButton) return ;
+  if (mouse->button()!=TQt::LeftButton) return ;
   if (!getDocument()->IsRunning()) return ;
 
   if (getDocument()->GetMoveStatus()!=-1) return ;
