@@ -25,7 +25,7 @@
 
 extern "C"
 {
-	Plugin * create_plugin()
+	KDE_EXPORT Plugin* create_plugin()
 	{
 		TDEGlobal::locale()->insertCatalogue("charlatanui");
 		return new Charlatan;
