@@ -22,7 +22,7 @@
 #include "waWidget.h"
 
 class WaInfo : public WaWidget {
-    Q_OBJECT
+    TQ_OBJECT
   
 
   public:
