@@ -46,7 +46,7 @@ DistpartPart::DistpartPart(TQObject *parent, const char *name, const TQStringLis
     setXMLFile("kdevpart_distpart.rc");
 
     m_action =  new TDEAction( i18n("Distribution && Publishing"), "package", 0,
-                             this, TQT_SLOT(show()),
+                             this, TQ_SLOT(show()),
                              actionCollection(), "make_dist" );
 
     m_action->setToolTip(i18n("Make source and binary distribution"));
@@ -58,8 +58,8 @@ DistpartPart::DistpartPart(TQObject *parent, const char *name, const TQStringLis
     m_dialog = new DistpartDialog(this, m_dlg );
     m_dlg->setMainWidget(m_dialog);
 
-    connect( m_dlg, TQT_SIGNAL(okClicked()), m_dialog, TQT_SLOT(slotokayPushButtonPressed()));
-    connect( m_dlg, TQT_SIGNAL(cancelClicked()), m_dialog, TQT_SLOT(slotcancelPushButtonPressed()));
+    connect( m_dlg, TQ_SIGNAL(okClicked()), m_dialog, TQ_SLOT(slotokayPushButtonPressed()));
+    connect( m_dlg, TQ_SIGNAL(cancelClicked()), m_dialog, TQ_SLOT(slotcancelPushButtonPressed()));
     // Package types
     //RpmPackage = new SpecSupport(this);
     //LsmPackage = new LsmSupport(this);
