@@ -11,7 +11,7 @@ class Context;
 
 class OpenWithPart : public KDevPlugin
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 
 public:
