@@ -64,20 +64,20 @@ SnippetWidget::SnippetWidget(SnippetPart *part)
     setRootIsDecorated(true);
 
     //connect the signals
-    connect( this, TQT_SIGNAL( contextMenuRequested ( TQListViewItem *, const TQPoint & , int ) ),
-             this, TQT_SLOT( showPopupMenu(TQListViewItem *, const TQPoint & , int ) ) );
+    connect( this, TQ_SIGNAL( contextMenuRequested ( TQListViewItem *, const TQPoint & , int ) ),
+             this, TQ_SLOT( showPopupMenu(TQListViewItem *, const TQPoint & , int ) ) );
 
-    connect( this, TQT_SIGNAL( executed (TQListViewItem *) ),
-             this, TQT_SLOT( slotExecuted( TQListViewItem *) ) );
-    connect( this, TQT_SIGNAL( returnPressed (TQListViewItem *) ),
-             this, TQT_SLOT( slotExecuted( TQListViewItem *) ) );
+    connect( this, TQ_SIGNAL( executed (TQListViewItem *) ),
+             this, TQ_SLOT( slotExecuted( TQListViewItem *) ) );
+    connect( this, TQ_SIGNAL( returnPressed (TQListViewItem *) ),
+             this, TQ_SLOT( slotExecuted( TQListViewItem *) ) );
 
-    connect( this, TQT_SIGNAL( dropped(TQDropEvent *, TQListViewItem *) ),
-             this, TQT_SLOT( slotDropped(TQDropEvent *, TQListViewItem *) ) );
+    connect( this, TQ_SIGNAL( dropped(TQDropEvent *, TQListViewItem *) ),
+             this, TQ_SLOT( slotDropped(TQDropEvent *, TQListViewItem *) ) );
 
     _cfg = 0;
 
-    TQTimer::singleShot(0, this, TQT_SLOT(initConfig()));
+    TQTimer::singleShot(0, this, TQ_SLOT(initConfig()));
 }
 
 SnippetWidget::~SnippetWidget()
@@ -551,19 +551,19 @@ void SnippetWidget::showPopupMenu( TQListViewItem * item, const TQPoint & p, int
 	if ( item ) {
 		popup.insertTitle( selectedItem->getName() );
 
-		popup.insertItem( i18n("Add Item..."), this, TQT_SLOT( slotAdd() ) );
-		popup.insertItem( i18n("Add Group..."), this, TQT_SLOT( slotAddGroup() ) );
+		popup.insertItem( i18n("Add Item..."), this, TQ_SLOT( slotAdd() ) );
+		popup.insertItem( i18n("Add Group..."), this, TQ_SLOT( slotAddGroup() ) );
         if (dynamic_cast<SnippetGroup*>(item)) {
-            popup.insertItem( i18n("Edit..."), this, TQT_SLOT( slotEditGroup() ) );
+            popup.insertItem( i18n("Edit..."), this, TQ_SLOT( slotEditGroup() ) );
         } else {
-            popup.insertItem( i18n("Edit..."), this, TQT_SLOT( slotEdit() ) );
+            popup.insertItem( i18n("Edit..."), this, TQ_SLOT( slotEdit() ) );
         }
-		popup.insertItem( i18n("Remove"), this, TQT_SLOT( slotRemove() ) );
+		popup.insertItem( i18n("Remove"), this, TQ_SLOT( slotRemove() ) );
 
 	} else {
 		popup.insertTitle(i18n("Code Snippets"));
 
-		popup.insertItem( i18n("Add Group..."), this, TQT_SLOT( slotAddGroup() ) );
+		popup.insertItem( i18n("Add Group..."), this, TQ_SLOT( slotAddGroup() ) );
 	}
 
 	popup.exec(p);
@@ -735,8 +735,8 @@ bool SnippetWidget::showMultiVarDialog(TQMap<TQString, TQString> * map, TQMap<TQ
   // --END-- building a dynamic dialog
 
   //connect the buttons to the TQDialog default slots
-  connect(btn1, TQT_SIGNAL(clicked()), &dlg, TQT_SLOT(reject()) );
-  connect(btn2, TQT_SIGNAL(clicked()), &dlg, TQT_SLOT(accept()) );
+  connect(btn1, TQ_SIGNAL(clicked()), &dlg, TQ_SLOT(reject()) );
+  connect(btn2, TQ_SIGNAL(clicked()), &dlg, TQ_SLOT(accept()) );
 
   //prepare to execute the dialog
   bool bReturn = false;
@@ -848,8 +848,8 @@ TQString SnippetWidget::showSingleVarDialog(TQString var, TQMap<TQString, TQStri
   // --END-- building a dynamic dialog
 
   //connect the buttons to the TQDialog default slots
-  connect(btn1, TQT_SIGNAL(clicked()), &dlg, TQT_SLOT(reject()) );
-  connect(btn2, TQT_SIGNAL(clicked()), &dlg, TQT_SLOT(accept()) );
+  connect(btn1, TQ_SIGNAL(clicked()), &dlg, TQ_SLOT(reject()) );
+  connect(btn2, TQ_SIGNAL(clicked()), &dlg, TQ_SLOT(accept()) );
 
   //execute the dialog
   TQString strReturn = "";
