@@ -359,14 +359,7 @@ MakefileGenerator::generateDependencies(TQPtrList<MakefileDependDir> &dirs, cons
 		x++;
 	    if(*(big_buffer + x) == '<') {
 		x++;
-		if(total_size_read >= x + 12 && !strncmp(big_buffer + x, "includehint", 11) &&
-		    (*(big_buffer + x + 11) == ' ' || *(big_buffer + x + 11) == '>')) {
-		    for(x += 11; *(big_buffer + x) != '>'; x++);
-		    int inc_len = 0;
-		    for(x += 1 ; *(big_buffer + x + inc_len) != '<'; inc_len++);
-		    *(big_buffer + x + inc_len) = '\0';
-		    inc = big_buffer + x;
-		} else if(total_size_read >= x + 13 && !strncmp(big_buffer + x, "customwidget", 12) &&
+		if(total_size_read >= x + 13 && !strncmp(big_buffer + x, "customwidget", 12) &&
 			  (*(big_buffer + x + 12) == ' ' || *(big_buffer + x + 12) == '>')) {
 		    for(x += 13; *(big_buffer + x) != '>'; x++); //skip up to >
 		    while(x < total_size_read) {
@@ -655,7 +648,7 @@ MakefileGenerator::initOutPaths()
 	for(int x = 0; dirs[x] != TQString::null; x++) {
 	    if ( !v[dirs[x]].isEmpty() ) {
 		TQString orig_path = v[dirs[x]].first();
-#ifdef Q_WS_WIN
+#ifdef TQ_WS_WIN
 		// We don't want to add a separator for DLLDESTDIR on Windows
 		if (!(dirs[x] == "DLLDESTDIR"))
 #endif
@@ -678,7 +671,7 @@ MakefileGenerator::initOutPaths()
 		    d.cd(Option::dir_sep);
 		    path = path.right(path.length() - 1);
 		}
-#ifdef Q_WS_WIN
+#ifdef TQ_WS_WIN
 		bool driveExists = TRUE;
 		if ( !TQDir::isRelativePath( path ) ) {
 		    if ( TQFile::exists( path.left( 3 ) ) ) {
@@ -705,7 +698,7 @@ MakefileGenerator::initOutPaths()
 			    }
 			}
 		    }
-#ifdef Q_WS_WIN
+#ifdef TQ_WS_WIN
 		}
 #endif
 	    }
@@ -1183,7 +1176,7 @@ MakefileGenerator::init()
 	Option::fixPathToTargetOS(imgfile);
 	if(!project->isEmpty("UI_DIR") || !project->isEmpty("UI_SOURCES_DIR")) {
 	    if(imgfile.find(Option::dir_sep) != -1)
-		imgfile = imgfile.right(imgfile.findRev(Option::dir_sep) + 1);
+		imgfile = imgfile.mid(imgfile.findRev(Option::dir_sep) + 1);
 	    imgfile.prepend( (project->isEmpty("UI_DIR") ? project->first("UI_SOURCES_DIR") :
 			    project->first("UI_DIR")) );
 	    v["QMAKE_IMAGE_COLLECTION"] = TQStringList(imgfile);
@@ -1433,7 +1426,7 @@ MakefileGenerator::write()
 	TQString prl = var("TARGET");
 	int slsh = prl.findRev(Option::dir_sep);
 	if(slsh != -1)
-	    prl = prl.right(prl.length() - slsh);
+	    prl = prl.right(prl.length() - slsh - 1);
 	int dot = prl.find('.');
 	if(dot != -1)
 	    prl = prl.left(dot);
@@ -1485,8 +1478,8 @@ MakefileGenerator::usePlatformDir()
     project->variables()["OBJECTS_DIR"] = filePath 
 					+ (filePath.isEmpty() ? pltDir : slashPltDir);
 
-    filePath = project->first("QMAKE_LIBDIR_QT");
-    project->variables()["QMAKE_LIBDIR_QT"] = filePath 
+    filePath = project->first("QMAKE_LIBDIR_TQT");
+    project->variables()["QMAKE_LIBDIR_TQT"] = filePath 
 					    + (filePath.isEmpty() ? pltDir : slashPltDir);
 
     filePath = project->first("QMAKE_LIBS_QT");
@@ -1892,7 +1885,7 @@ MakefileGenerator::writeInstalls(TQTextStream &t, const TQString &installs)
 		    if(!uninst.isEmpty())
 			uninst.append("\n\t");
 		    uninst.append(
-#ifdef Q_WS_WIN
+#ifdef TQ_WS_WIN
 		    TQString("-$(DEL_FILE)")
 #else
 		    TQString("-$(DEL_FILE) -r")
@@ -1909,7 +1902,7 @@ MakefileGenerator::writeInstalls(TQTextStream &t, const TQString &installs)
 		    if(!uninst.isEmpty())
 			uninst.append("\n\t");
 		    uninst.append(
-#ifdef Q_WS_WIN
+#ifdef TQ_WS_WIN
 			TQString("-$(DEL_FILE)")
 #else
 			TQString("-$(DEL_FILE) -r")
@@ -1953,7 +1946,7 @@ MakefileGenerator::writeInstalls(TQTextStream &t, const TQString &installs)
 	    const TQStringList &dirs = project->variables()[pvar];
 	    for(TQStringList::ConstIterator pit = dirs.begin(); pit != dirs.end(); ++pit) {
 		TQString tmp_dst = fileFixify((*pit));
-#ifndef Q_WS_WIN
+#ifndef TQ_WS_WIN
 		if(tmp_dst.right(1) != Option::dir_sep)
 		    tmp_dst += Option::dir_sep;
 #endif
@@ -2142,10 +2135,9 @@ TQString MakefileGenerator::build_args()
 bool
 MakefileGenerator::writeHeader(TQTextStream &t)
 {
-    time_t foo = time(NULL);
     t << "#############################################################################" << endl;
     t << "# Makefile for building: " << var("TARGET") << endl;
-    t << "# Generated by qmake (" << qmake_version() << ") (TQt " << TQT_VERSION_STR << ") on: " << ctime(&foo);
+    t << "# Generated by qmake (" << qmake_version() << ") (TQt " << TQT_VERSION_STR << ")" << endl;
     t << "# Project:  " << fileFixify(project->projectFile()) << endl;
     t << "# Template: " << var("TEMPLATE") << endl;
     t << "# Command: " << build_args() << endl;
@@ -2393,7 +2385,7 @@ MakefileGenerator::specdir()
 	return spec;
     spec = Option::mkfile::qmakespec;
 #if 0
-    if(const char *d = getenv("QTDIR")) {
+    if(const char *d = getenv("TQTDIR")) {
 	TQString qdir = Option::fixPathToTargetOS(TQString(d));
 	if(qdir.endsWith(TQString(TQChar(TQDir::separator()))))
 	    qdir.truncate(qdir.length()-1);
@@ -2403,7 +2395,7 @@ MakefileGenerator::specdir()
 	absSpec = Option::fixPathToTargetOS(absSpec);
 	//replace what you can
 	if(absSpec.startsWith(qdir)) {
-	    absSpec.replace(0, qdir.length(), "$(QTDIR)");
+	    absSpec.replace(0, qdir.length(), "$(TQTDIR)");
 	    spec = absSpec;
 	}
     }
