@@ -23,18 +23,6 @@ Boston, MA 02110-1301, USA.
 #define TQT_TQINTERNAL_P_H
 
 #include <tqt.h>
-
-#ifdef USE_QT3
-
-// Reimplement the QSharedDoubleBuffer class
-// For Qt3, no changes are needed
-
 #include <private/qinternal_p.h>
 
-#endif // USE_QT3
-
-#ifdef USE_QT4
-
-#endif // USE_QT4
-
 #endif /* TQT_TQINTERNAL_P_H */
