@@ -23,21 +23,6 @@ Boston, MA 02110-1301, USA.
 #define TQT_TQASYNCIMAGEIO_H
 
 #include <tqt.h>
-
-#ifdef USE_QT3
-
-// Reimplement the QAsyncImageIO class
-// For Qt3, no changes are needed
-
 #include <ntqasyncimageio.h>
 
-#endif // USE_QT3
-
-#ifdef USE_QT4
-
-// Reimplement the QAsyncImageIO class
-// For Qt4, this class no longer exists!
-
-#endif // USE_QT4
-
 #endif /* TQT_TQASYNCIMAGEIO_H */
