@@ -21,16 +21,3 @@ Boston, MA 02110-1301, USA.
 
 #include <tqt.h>
 #include <ntqeventloop.h>
-
-#ifdef USE_QT4
-
-TQEventLoop *TQEventLoop::eventLoop ()
-{
-	return static_cast<TQEventLoop *>(QAbstractEventDispatcher::instance());
-}
-
-bool TQEventLoop::processEvents( ProcessEventsFlags flags ) {
-	return QEventLoop::processEvents((ProcessEventsFlag)flags);
-}
-
-#endif
