@@ -23,23 +23,6 @@ Boston, MA 02110-1301, USA.
 #define TQT_TQINPUTCONTEXT_H
 
 #include <tqt.h>
-
-#ifdef USE_QT3
-
-// Reimplement the QInputContext class
-// For Qt3, no changes are needed
-
 #include <ntqinputcontext.h>
 
-#endif // USE_QT3
-
-#ifdef USE_QT4
-
-// Reimplement the QInputContext class
-// For Qt4, some changes are needed
-
-#include <Qt/ntqinputcontext.h>
-
-#endif // USE_QT4
-
 #endif /* TQT_TQINPUTCONTEXT_H */
