@@ -21,11 +21,3 @@ Boston, MA 02110-1301, USA.
 
 #include <tqt.h>
 #include <ntqscrollbar.h>
-
-#ifdef USE_QT4
-
-int QScrollBar::sliderStart() const {
-	return sliderPosition();
-}
-
-#endif // USE_QT4
