@@ -21,19 +21,3 @@ Boston, MA 02110-1301, USA.
 
 #include <tqt.h>
 #include <ntqtooltip.h>
-
-#ifdef USE_QT4
-
-static bool globally_enabled = TRUE;
-
-void QToolTip::setGloballyEnabled( bool enable )
-{
-    //globally_enabled = enable;
-}
-
-bool QToolTip::isGloballyEnabled()
-{
-    return globally_enabled;
-}
-
-#endif // USE_QT4
