@@ -21,15 +21,3 @@ Boston, MA 02110-1301, USA.
 
 #include <tqt.h>
 #include <ntqwidget.h>
-
-#ifdef USE_QT4
-
-Qt::WidgetAttribute QWidget::testWState( Qt::WidgetAttribute s ) const {
-	return (Qt::WidgetAttribute)(data->widget_attributes & s);
-}
-
-Qt::WindowFlags QWidget::testWFlags( Qt::WindowFlags f ) const {
-	return (Qt::WindowFlags)(data->window_flags & f);
-}
-
-#endif // USE_QT4
