@@ -13,7 +13,7 @@ def initialize(grid)
     slider.setRange(0, 99)
     slider.setValue(0)
 
-    lcd.connect(slider, SIGNAL('valueChanged(int)'), SLOT('display(int)'))
+    lcd.connect(slider, TQ_SIGNAL('valueChanged(int)'), TQ_SLOT('display(int)'))
 end
 
 end
@@ -25,7 +25,7 @@ def initialize()
     quit = TQt::PushButton.new('Quit', self, 'quit')
     quit.setFont(TQt::Font.new('Times', 18, TQt::Font::Bold))
     
-	connect(quit, SIGNAL('clicked()'), $qApp, SLOT('quit()'))
+	connect(quit, TQ_SIGNAL('clicked()'), $qApp, TQ_SLOT('quit()'))
 	grid = TQt::Grid.new( 4, self )
 	
 	for c in 0..3
