@@ -86,7 +86,7 @@ namespace Qt {
 			signals = new ArrayList();
 		}
 
-		[DllImport("libqtc", CharSet=CharSet.Ansi)]
+		[DllImport("libtqtc", CharSet=CharSet.Ansi)]
 		private static extern void qt_del_QObject (IntPtr obj);
 		internal override void Delete ()
 		{
@@ -162,120 +162,120 @@ namespace Qt {
 					switch (slotobj.Args) {
 					case "()":
 						del = Delegate.CreateDelegate (typeof (del_void), receiver, slotobj.Name);
-						slotobj.WrapperPtr = csharp_connect_void (sender.RawObject, TQT_SIGNAL (signal), receiver.RawObject, del);
+						slotobj.WrapperPtr = csharp_connect_void (sender.RawObject, TQ_SIGNAL (signal), receiver.RawObject, del);
 						break;
 					case "(bool)":
 						del = Delegate.CreateDelegate (typeof (del_bool), receiver, slotobj.Name);
-						slotobj.WrapperPtr = csharp_connect_bool (sender.RawObject, TQT_SIGNAL (signal), receiver.RawObject, del);
+						slotobj.WrapperPtr = csharp_connect_bool (sender.RawObject, TQ_SIGNAL (signal), receiver.RawObject, del);
 						break;
 					case "(short)":
 						del = Delegate.CreateDelegate (typeof (del_short), receiver, slotobj.Name);
-						slotobj.WrapperPtr = csharp_connect_short (sender.RawObject, TQT_SIGNAL (signal), receiver.RawObject, del);
+						slotobj.WrapperPtr = csharp_connect_short (sender.RawObject, TQ_SIGNAL (signal), receiver.RawObject, del);
 						break;
 					case "(int)":
 						del = Delegate.CreateDelegate (typeof (del_int), receiver, slotobj.Name);
-						slotobj.WrapperPtr = csharp_connect_int (sender.RawObject, TQT_SIGNAL (signal), receiver.RawObject, del);
+						slotobj.WrapperPtr = csharp_connect_int (sender.RawObject, TQ_SIGNAL (signal), receiver.RawObject, del);
 						break;
 					case "(long)":
 						del = Delegate.CreateDelegate (typeof (del_long), receiver, slotobj.Name);
-						slotobj.WrapperPtr = csharp_connect_long (sender.RawObject, TQT_SIGNAL (signal), receiver.RawObject, del);
+						slotobj.WrapperPtr = csharp_connect_long (sender.RawObject, TQ_SIGNAL (signal), receiver.RawObject, del);
 						break;
 					case "(float)":
 						del = Delegate.CreateDelegate (typeof (del_float), receiver, slotobj.Name);
-						slotobj.WrapperPtr = csharp_connect_float (sender.RawObject, TQT_SIGNAL (signal), receiver.RawObject, del);
+						slotobj.WrapperPtr = csharp_connect_float (sender.RawObject, TQ_SIGNAL (signal), receiver.RawObject, del);
 						break;
 					case "(double)":
 						del = Delegate.CreateDelegate (typeof (del_double), receiver, slotobj.Name);
-						slotobj.WrapperPtr = csharp_connect_double (sender.RawObject, TQT_SIGNAL (signal), receiver.RawObject, del);
+						slotobj.WrapperPtr = csharp_connect_double (sender.RawObject, TQ_SIGNAL (signal), receiver.RawObject, del);
 						break;
 					case "(TQString)":
 						realsignal = sigobj.Name + "(const TQString&)";
 						Console.WriteLine("Connecting signal, sigobj.Name = {0}, realsignal = {1}",
 							sigobj.Name, realsignal);
 						del = Delegate.CreateDelegate (typeof (del_QString), slotobj, "SlotBridge_QString");
-						slotobj.WrapperPtr = csharp_connect_QString (sender.RawObject, TQT_SIGNAL (realsignal), receiver.RawObject, del);
+						slotobj.WrapperPtr = csharp_connect_QString (sender.RawObject, TQ_SIGNAL (realsignal), receiver.RawObject, del);
 						break;						
 					case "(TQDockWindow)":
 						realsignal = sigobj.Name + "(TQDockWindow*)";
 						del = Delegate.CreateDelegate (typeof (del_QDockWindow), slotobj, "SlotBridge_QDockWindow");
-						slotobj.WrapperPtr = csharp_connect_QDockWindow (sender.RawObject, TQT_SIGNAL (realsignal), receiver.RawObject, del);
+						slotobj.WrapperPtr = csharp_connect_QDockWindow (sender.RawObject, TQ_SIGNAL (realsignal), receiver.RawObject, del);
 						break;
 					case "(TQDropEvent)":
 						realsignal = sigobj.Name + "(TQDropEvent*)";
 						del = Delegate.CreateDelegate (typeof (del_QDropEvent), slotobj, "SlotBridge_QDropEvent");
-						slotobj.WrapperPtr = csharp_connect_QDropEvent (sender.RawObject, TQT_SIGNAL (realsignal), receiver.RawObject, del);
+						slotobj.WrapperPtr = csharp_connect_QDropEvent (sender.RawObject, TQ_SIGNAL (realsignal), receiver.RawObject, del);
 						break;
 					case "(TQDropEvent,TQListViewItem)":
 						realsignal = sigobj.Name + "(TQDropEvent*,TQListViewItem*)";
 						del = Delegate.CreateDelegate (typeof (del_QDropEventTQListViewItem), slotobj, "SlotBridge_QDropEventTQListViewItem");
-						slotobj.WrapperPtr = csharp_connect_QDropEventTQListViewItem (sender.RawObject, TQT_SIGNAL (realsignal), receiver.RawObject, del);
+						slotobj.WrapperPtr = csharp_connect_QDropEventTQListViewItem (sender.RawObject, TQ_SIGNAL (realsignal), receiver.RawObject, del);
 						break;
 					case "(TQIconViewItem)":
 						realsignal = sigobj.Name + "(TQIconViewItem*)";
 						del = Delegate.CreateDelegate (typeof (del_QIconViewItem), slotobj, "SlotBridge_QIconViewItem");
-						slotobj.WrapperPtr = csharp_connect_QIconViewItem (sender.RawObject, TQT_SIGNAL (realsignal), receiver.RawObject, del);
+						slotobj.WrapperPtr = csharp_connect_QIconViewItem (sender.RawObject, TQ_SIGNAL (realsignal), receiver.RawObject, del);
 						break;
 					case "(TQListBoxItem)":
 						realsignal = sigobj.Name + "(TQListBoxItem*)";
 						del = Delegate.CreateDelegate (typeof (del_QListBoxItem), slotobj, "SlotBridge_QListBoxItem");
-						slotobj.WrapperPtr = csharp_connect_QListBoxItem (sender.RawObject, TQT_SIGNAL (realsignal), receiver.RawObject, del);
+						slotobj.WrapperPtr = csharp_connect_QListBoxItem (sender.RawObject, TQ_SIGNAL (realsignal), receiver.RawObject, del);
 						break;
 					case "(TQListViewItem)":
 						realsignal = sigobj.Name + "(TQListViewItem*)";
 						del = Delegate.CreateDelegate (typeof (del_QListViewItem), slotobj, "SlotBridge_QListViewItem");
-						slotobj.WrapperPtr = csharp_connect_QListViewItem (sender.RawObject, TQT_SIGNAL (realsignal), receiver.RawObject, del);
+						slotobj.WrapperPtr = csharp_connect_QListViewItem (sender.RawObject, TQ_SIGNAL (realsignal), receiver.RawObject, del);
 						break;
 					case "(TQListViewItem,TQListViewItem)":
 						realsignal = sigobj.Name + "(TQListViewItem*,TQListViewItem*)";
 						del = Delegate.CreateDelegate (typeof (del_QListViewItemTQListViewItem), slotobj, "SlotBridge_QListViewItemTQListViewItem");
-						slotobj.WrapperPtr = csharp_connect_QListViewItemTQListViewItem (sender.RawObject, TQT_SIGNAL (realsignal), receiver.RawObject, del);
+						slotobj.WrapperPtr = csharp_connect_QListViewItemTQListViewItem (sender.RawObject, TQ_SIGNAL (realsignal), receiver.RawObject, del);
 						break;
 					case "(TQListViewItem,TQListViewItem,TQListViewItem)":
 						realsignal = sigobj.Name + "(TQListViewItem*,TQListViewItem*,TQListViewItem*)";
 						del = Delegate.CreateDelegate (typeof (del_QListViewItemTQListViewItemTQListViewItem), slotobj, "SlotBridge_QListViewItemTQListViewItemTQListViewItem");
-						slotobj.WrapperPtr = csharp_connect_QListViewItemTQListViewItemTQListViewItem (sender.RawObject, TQT_SIGNAL (realsignal), receiver.RawObject, del);
+						slotobj.WrapperPtr = csharp_connect_QListViewItemTQListViewItemTQListViewItem (sender.RawObject, TQ_SIGNAL (realsignal), receiver.RawObject, del);
 						break;
 					case "(TQNetworkOperation)":
 						realsignal = sigobj.Name + "(TQNetworkOperation*)";
 						del = Delegate.CreateDelegate (typeof (del_QNetworkOperation), slotobj, "SlotBridge_QNetworkOperation");
-						slotobj.WrapperPtr = csharp_connect_QNetworkOperation (sender.RawObject, TQT_SIGNAL (realsignal), receiver.RawObject, del);
+						slotobj.WrapperPtr = csharp_connect_QNetworkOperation (sender.RawObject, TQ_SIGNAL (realsignal), receiver.RawObject, del);
 						break;
 					case "(TQObject)":
 						realsignal = sigobj.Name + "(TQObject*)";
 						del = Delegate.CreateDelegate (typeof (del_QObject), slotobj, "SlotBridge_QObject");
-						slotobj.WrapperPtr = csharp_connect_QObject (sender.RawObject, TQT_SIGNAL (realsignal), receiver.RawObject, del);
+						slotobj.WrapperPtr = csharp_connect_QObject (sender.RawObject, TQ_SIGNAL (realsignal), receiver.RawObject, del);
 						break;
 					case "(TQToolBar)":
 						realsignal = sigobj.Name + "(TQToolBar*)";
 						del = Delegate.CreateDelegate (typeof (del_QToolBar), slotobj, "SlotBridge_QToolBar");
-						slotobj.WrapperPtr = csharp_connect_QToolBar (sender.RawObject, TQT_SIGNAL (realsignal), receiver.RawObject, del);
+						slotobj.WrapperPtr = csharp_connect_QToolBar (sender.RawObject, TQ_SIGNAL (realsignal), receiver.RawObject, del);
 						break;
 					case "(TQWidget)":
 						realsignal = sigobj.Name + "(TQWidget*)";
 						del = Delegate.CreateDelegate (typeof (del_QWidget), slotobj, "SlotBridge_QWidget");
-						slotobj.WrapperPtr = csharp_connect_QWidget (sender.RawObject, TQT_SIGNAL (realsignal), receiver.RawObject, del);
+						slotobj.WrapperPtr = csharp_connect_QWidget (sender.RawObject, TQ_SIGNAL (realsignal), receiver.RawObject, del);
 						break;
 					case "(int,TQIconViewItem)":
 						realsignal = sigobj.Name + "(int,TQIconViewItem*)";
 						del = Delegate.CreateDelegate (typeof (del_intTQIconViewItem), slotobj, "SlotBridge_intTQIconViewItem");
-						slotobj.WrapperPtr = csharp_connect_intTQIconViewItem (sender.RawObject, TQT_SIGNAL (realsignal), receiver.RawObject, del);
+						slotobj.WrapperPtr = csharp_connect_intTQIconViewItem (sender.RawObject, TQ_SIGNAL (realsignal), receiver.RawObject, del);
 						break;
 					case "(int,TQListBoxItem)":
 						realsignal = sigobj.Name + "(int,TQListBoxItem*)";
 						del = Delegate.CreateDelegate (typeof (del_intTQListBoxItem), slotobj, "SlotBridge_intTQListBoxItem");
-						slotobj.WrapperPtr = csharp_connect_intTQListBoxItem (sender.RawObject, TQT_SIGNAL (realsignal), receiver.RawObject, del);
+						slotobj.WrapperPtr = csharp_connect_intTQListBoxItem (sender.RawObject, TQ_SIGNAL (realsignal), receiver.RawObject, del);
 						break;
 					case "(int,bool)":
 						del = Delegate.CreateDelegate (typeof (del_intbool), receiver, slotobj.Name);
-						slotobj.WrapperPtr = csharp_connect_intbool (sender.RawObject, TQT_SIGNAL (signal), receiver.RawObject, del);
+						slotobj.WrapperPtr = csharp_connect_intbool (sender.RawObject, TQ_SIGNAL (signal), receiver.RawObject, del);
 						break;
 					case "(int,int)":
 						del = Delegate.CreateDelegate (typeof (del_intint), receiver, slotobj.Name);
-						slotobj.WrapperPtr = csharp_connect_intint (sender.RawObject, TQT_SIGNAL (signal), receiver.RawObject, del);
+						slotobj.WrapperPtr = csharp_connect_intint (sender.RawObject, TQ_SIGNAL (signal), receiver.RawObject, del);
 						break;
 					case "(int,int,int)":
 						del = Delegate.CreateDelegate (typeof (del_intintint), receiver, slotobj.Name);
-						slotobj.WrapperPtr = csharp_connect_intintint (sender.RawObject, TQT_SIGNAL (signal), receiver.RawObject, del);
+						slotobj.WrapperPtr = csharp_connect_intintint (sender.RawObject, TQ_SIGNAL (signal), receiver.RawObject, del);
 						break;
 					default:
 						throw new ArgumentException ("Unsupported method prototype for C++ signal -> C# slot connection: " + slotobj.Args);
@@ -292,7 +292,7 @@ namespace Qt {
 				// ...a C++ slot. C++ slots are C# methods, so we should never get here.
 				else {
 					throw new ArgumentException(receiver+" has no slot '"+slot+"'");
-					// return qt_QObject_connect1(sender.RawObject, TQT_SIGNAL(signal), receiver.RawObject, TQT_SLOT(slot));
+					// return qt_QObject_connect1(sender.RawObject, TQ_SIGNAL(signal), receiver.RawObject, TQ_SLOT(slot));
 				}
 			}
 		}
@@ -330,11 +330,11 @@ namespace Qt {
 					string mangle = MangleArgs(args);
 
 					// HACK Wrap target signal in a slot and connect the slot to the sender.
-					return Connect(sender, TQT_SIGNAL(signal), targetobj, TQT_SLOT("Emit_"+mangle+args));
+					return Connect(sender, TQ_SIGNAL(signal), targetobj, TQ_SLOT("Emit_"+mangle+args));
 				}
 				// ...a C++ signal
 				else
-					return qt_QObject_connect1(sender.RawObject, TQT_SIGNAL(signal), receiver.RawObject, TQT_SIGNAL(target));
+					return qt_QObject_connect1(sender.RawObject, TQ_SIGNAL(signal), receiver.RawObject, TQ_SIGNAL(target));
 			}
 		}
 
@@ -410,7 +410,7 @@ namespace Qt {
 				// ...a C++ slot. C++ slots are C# methods, so we should never get here.
 				else {
 					throw new ArgumentException(receiver+" has no slot '"+slot+"'");
-					// return qt_QObject_disconnect2(sender.RawObject, TQT_SIGNAL(signal), receiver.RawObject, TQT_SLOT(slot));
+					// return qt_QObject_disconnect2(sender.RawObject, TQ_SIGNAL(signal), receiver.RawObject, TQ_SLOT(slot));
 				}
 			}
 		}
@@ -449,11 +449,11 @@ namespace Qt {
 				if (receiver.CsSignalMap.Contains(target)) {
 					QtSignal targetobj = receiver.CsSignalMap[target];
 					string args = "(" + target.Split(new char[] {'('})[1];
-					return Disconnect(sender, TQT_SIGNAL(signal), targetobj, TQT_SLOT("emit_"+args));
+					return Disconnect(sender, TQ_SIGNAL(signal), targetobj, TQ_SLOT("emit_"+args));
 				}
 				// ...a C++ signal
 				else {
-					return qt_QObject_disconnect2(sender.RawObject, TQT_SIGNAL(signal), receiver.RawObject, TQT_SLOT(target));
+					return qt_QObject_disconnect2(sender.RawObject, TQ_SIGNAL(signal), receiver.RawObject, TQ_SLOT(target));
 				}
 			}
 		}
@@ -474,7 +474,7 @@ namespace Qt {
 
 			foreach (QtSignal signal in signals)
 				foreach (QtSlot slot in new ArrayList (signal.Slots))
-					Disconnect (sender, TQT_SIGNAL (signal.Signal), slot.Receiver, TQT_SLOT (slot.Slot));
+					Disconnect (sender, TQ_SIGNAL (signal.Signal), slot.Receiver, TQ_SLOT (slot.Slot));
 
 			return true;
 		}
@@ -495,7 +495,7 @@ namespace Qt {
 
 			foreach (QtSignal signal in signals)
 				foreach (QtSlot slot in new ArrayList (signal.Slots))
-					Disconnect (signal.Sender, TQT_SIGNAL (signal.Name), receiver, TQT_SLOT (slot.Name));
+					Disconnect (signal.Sender, TQ_SIGNAL (signal.Name), receiver, TQ_SLOT (slot.Name));
 
 			return true;
 		}
@@ -509,7 +509,7 @@ namespace Qt {
 				QtSignal sig = map[signal];
 				if (sig != null) {
 					foreach (QtSlot slot in new ArrayList (sig.Slots))
-						Disconnect (sender, TQT_SIGNAL(signal), slot.Receiver, TQT_SLOT(slot.Slot));
+						Disconnect (sender, TQ_SIGNAL(signal), slot.Receiver, TQ_SLOT(slot.Slot));
 				}
 			}
 
@@ -527,7 +527,7 @@ namespace Qt {
 				if (sig != null) {
 					foreach (QtSlot slot in new ArrayList (sig.Slots))
 						if (slot.Receiver == receiver)
-							Disconnect (sender, signal, receiver, TQT_SLOT (slot.Name));
+							Disconnect (sender, signal, receiver, TQ_SLOT (slot.Name));
 				}
 			}
 
@@ -738,85 +738,85 @@ namespace Qt {
 			Emit (new object[] { value0, value1, value2 });
 		}
 
-		[DllImport("libqtc", CharSet=CharSet.Ansi)]
+		[DllImport("libtqtc", CharSet=CharSet.Ansi)]
 		private static extern bool qt_QObject_connect1 (IntPtr sender, string signal, IntPtr receiver, string member);
 
-		[DllImport("libqtc", CharSet=CharSet.Ansi)]
+		[DllImport("libtqtc", CharSet=CharSet.Ansi)]
 		private static extern bool qt_QObject_disconnect2 (IntPtr sender, string signal, IntPtr receiver, string member);
 
-		[DllImport("libqtsharp", CharSet=CharSet.Ansi)]
+		[DllImport("libtqtsharp", CharSet=CharSet.Ansi)]
 		private static extern IntPtr csharp_connect_void (IntPtr sender, string signal, IntPtr receiver, Delegate cb);
 		
-		[DllImport("libqtsharp", CharSet=CharSet.Ansi)]
+		[DllImport("libtqtsharp", CharSet=CharSet.Ansi)]
 		private static extern IntPtr csharp_connect_bool (IntPtr sender, string signal, IntPtr receiver, Delegate cb);
 		
-		[DllImport("libqtsharp", CharSet=CharSet.Ansi)]
+		[DllImport("libtqtsharp", CharSet=CharSet.Ansi)]
 		private static extern IntPtr csharp_connect_short (IntPtr sender, string signal, IntPtr receiver, Delegate cb);
 		
-		[DllImport("libqtsharp", CharSet=CharSet.Ansi)]
+		[DllImport("libtqtsharp", CharSet=CharSet.Ansi)]
 		private static extern IntPtr csharp_connect_int (IntPtr sender, string signal, IntPtr receiver, Delegate cb);
 		
-		[DllImport("libqtsharp", CharSet=CharSet.Ansi)]
+		[DllImport("libtqtsharp", CharSet=CharSet.Ansi)]
 		private static extern IntPtr csharp_connect_long (IntPtr sender, string signal, IntPtr receiver, Delegate cb);
 		
-		[DllImport("libqtsharp", CharSet=CharSet.Ansi)]
+		[DllImport("libtqtsharp", CharSet=CharSet.Ansi)]
 		private static extern IntPtr csharp_connect_float (IntPtr sender, string signal, IntPtr receiver, Delegate cb);
 		
-		[DllImport("libqtsharp", CharSet=CharSet.Ansi)]
+		[DllImport("libtqtsharp", CharSet=CharSet.Ansi)]
 		private static extern IntPtr csharp_connect_double (IntPtr sender, string signal, IntPtr receiver, Delegate cb);
 		
-		[DllImport("libqtsharp", CharSet=CharSet.Ansi)]
+		[DllImport("libtqtsharp", CharSet=CharSet.Ansi)]
 		private static extern IntPtr csharp_connect_QString (IntPtr sender, string signal, IntPtr receiver, Delegate cb);
 	
-		[DllImport("libqtsharp", CharSet=CharSet.Ansi)]
+		[DllImport("libtqtsharp", CharSet=CharSet.Ansi)]
 		private static extern IntPtr csharp_connect_QDockWindow (IntPtr sender, string signal, IntPtr receiver, Delegate cb);
 		
-		[DllImport("libqtsharp", CharSet=CharSet.Ansi)]
+		[DllImport("libtqtsharp", CharSet=CharSet.Ansi)]
 		private static extern IntPtr csharp_connect_QDropEvent (IntPtr sender, string signal, IntPtr receiver, Delegate cb);
 		
-		[DllImport("libqtsharp", CharSet=CharSet.Ansi)]
+		[DllImport("libtqtsharp", CharSet=CharSet.Ansi)]
 		private static extern IntPtr csharp_connect_QDropEventTQListViewItem (IntPtr sender, string signal, IntPtr receiver, Delegate cb);
 		
-		[DllImport("libqtsharp", CharSet=CharSet.Ansi)]
+		[DllImport("libtqtsharp", CharSet=CharSet.Ansi)]
 		private static extern IntPtr csharp_connect_QIconViewItem (IntPtr sender, string signal, IntPtr receiver, Delegate cb);
 		
-		[DllImport("libqtsharp", CharSet=CharSet.Ansi)]
+		[DllImport("libtqtsharp", CharSet=CharSet.Ansi)]
 		private static extern IntPtr csharp_connect_QListBoxItem (IntPtr sender, string signal, IntPtr receiver, Delegate cb);
 		
-		[DllImport("libqtsharp", CharSet=CharSet.Ansi)]
+		[DllImport("libtqtsharp", CharSet=CharSet.Ansi)]
 		private static extern IntPtr csharp_connect_QListViewItem (IntPtr sender, string signal, IntPtr receiver, Delegate cb);
 		
-		[DllImport("libqtsharp", CharSet=CharSet.Ansi)]
+		[DllImport("libtqtsharp", CharSet=CharSet.Ansi)]
 		private static extern IntPtr csharp_connect_QListViewItemTQListViewItem (IntPtr sender, string signal, IntPtr receiver, Delegate cb);
 		
-		[DllImport("libqtsharp", CharSet=CharSet.Ansi)]
+		[DllImport("libtqtsharp", CharSet=CharSet.Ansi)]
 		private static extern IntPtr csharp_connect_QListViewItemTQListViewItemTQListViewItem (IntPtr sender, string signal, IntPtr receiver, Delegate cb);
 		
-		[DllImport("libqtsharp", CharSet=CharSet.Ansi)]
+		[DllImport("libtqtsharp", CharSet=CharSet.Ansi)]
 		private static extern IntPtr csharp_connect_QNetworkOperation (IntPtr sender, string signal, IntPtr receiver, Delegate cb);
 
-		[DllImport("libqtsharp", CharSet=CharSet.Ansi)]
+		[DllImport("libtqtsharp", CharSet=CharSet.Ansi)]
 		private static extern IntPtr csharp_connect_QObject (IntPtr sender, string signal, IntPtr receiver, Delegate cb);
 
-		[DllImport("libqtsharp", CharSet=CharSet.Ansi)]
+		[DllImport("libtqtsharp", CharSet=CharSet.Ansi)]
 		private static extern IntPtr csharp_connect_QToolBar (IntPtr sender, string signal, IntPtr receiver, Delegate cb);
 
-		[DllImport("libqtsharp", CharSet=CharSet.Ansi)]
+		[DllImport("libtqtsharp", CharSet=CharSet.Ansi)]
 		private static extern IntPtr csharp_connect_QWidget (IntPtr sender, string signal, IntPtr receiver, Delegate cb);
 
-		[DllImport("libqtsharp", CharSet=CharSet.Ansi)]
+		[DllImport("libtqtsharp", CharSet=CharSet.Ansi)]
 		private static extern IntPtr csharp_connect_intTQIconViewItem (IntPtr sender, string signal, IntPtr receiver, Delegate cb);
 
-		[DllImport("libqtsharp", CharSet=CharSet.Ansi)]
+		[DllImport("libtqtsharp", CharSet=CharSet.Ansi)]
 		private static extern IntPtr csharp_connect_intTQListBoxItem (IntPtr sender, string signal, IntPtr receiver, Delegate cb);
 
-		[DllImport("libqtsharp", CharSet=CharSet.Ansi)]
+		[DllImport("libtqtsharp", CharSet=CharSet.Ansi)]
 		private static extern IntPtr csharp_connect_intbool (IntPtr sender, string signal, IntPtr receiver, Delegate cb);
 
-		[DllImport("libqtsharp", CharSet=CharSet.Ansi)]
+		[DllImport("libtqtsharp", CharSet=CharSet.Ansi)]
 		private static extern IntPtr csharp_connect_intint (IntPtr sender, string signal, IntPtr receiver, Delegate cb);
 
-		[DllImport("libqtsharp", CharSet=CharSet.Ansi)]
+		[DllImport("libtqtsharp", CharSet=CharSet.Ansi)]
 		private static extern IntPtr csharp_connect_intintint (IntPtr sender, string signal, IntPtr receiver, Delegate cb);
 
 		public delegate void del_void ();
