@@ -518,7 +518,7 @@ namespace QtCSharp {
 		public string DefaultConnections ()
 		{
 			if (qtype.IsTQObject)
-				return "\n\t\t\tConnect (this, TQT_SIGNAL (\"destroyed ()\"), TQT_SLOT (\"NativeDestroyed ()\"));";
+				return "\n\t\t\tConnect (this, TQ_SIGNAL (\"destroyed ()\"), TQ_SLOT (\"NativeDestroyed ()\"));";
 			else
 				return "";
 		}
