@@ -40,7 +40,7 @@
 
 #include "ntqasyncimageio.h"
 
-#ifndef QT_NO_ASYNC_IMAGE_IO
+#ifndef TQT_NO_ASYNC_IMAGE_IO
 
 #include "ntqptrlist.h"
 #include "ntqgif.h"
@@ -1316,4 +1316,4 @@ TQRgb TQGIFFormat::color( uchar index ) const
 
 #endif // QT_BUILTIN_GIF_READER
 
-#endif // QT_NO_ASYNC_IMAGE_IO
+#endif // TQT_NO_ASYNC_IMAGE_IO
