@@ -433,12 +433,12 @@ bool qKillTimer( TQObject *obj )
 
 
 TQEventLoopPrivate::TQEventLoopPrivate() {
-#if defined(Q_WS_X11)
+#if defined(TQ_WS_X11)
 	xfd = -1;
 	x_gPollFD.fd = -1;
 	x_gPollFD.events = 0;
 	x_gPollFD.revents = 0;
-#endif // Q_WS_X11
+#endif // TQ_WS_X11
 	singletoolkit = TRUE;
 	ctx = 0;
 	ctx_is_default = false;
