@@ -1433,7 +1433,7 @@ void TQFontEngineLatinXLFD::setScale( double scale )
 // ------------------------------------------------------------------
 // #define FONTENGINE_DEBUG
 
-#ifndef QT_NO_XFTFREETYPE
+#ifndef TQT_NO_XFTFREETYPE
 class Q_HackPaintDevice : public TQPaintDevice
 {
 public:
@@ -2232,7 +2232,7 @@ TQFontEngine::Type TQFontEngineXft::type() const
 // Open type support
 //  --------------------------------------------------------------------------------------------------------------------
 
-#ifndef QT_NO_XFTFREETYPE
+#ifndef TQT_NO_XFTFREETYPE
 
 #include "qscriptengine_p.h"
 
@@ -2610,14 +2610,14 @@ bool TQOpenType::shape(TQShaperItem *item, const unsigned int *properties)
 bool TQOpenType::positionAndAdd(TQShaperItem *item, bool doLogClusters)
 {
     if (gpos) {
-#ifdef Q_WS_X11
+#ifdef TQ_WS_X11
         Q_ASSERT(fontEngine->type() == TQFontEngine::Xft);
         face = lockFTFace(static_cast<TQFontEngineXft *>(fontEngine)->font());
 #endif
         memset(otl_buffer->positions, 0, otl_buffer->in_length*sizeof(OTL_PositionRec));
         // #### check that passing "FALSE,FALSE" is correct
         TT_GPOS_Apply_String(face, gpos, loadFlags, otl_buffer, FALSE, FALSE);
-#ifdef Q_WS_X11
+#ifdef TQ_WS_X11
         unlockFTFace(static_cast<TQFontEngineXft *>(fontEngine)->font());
 #endif
     }
