@@ -2392,7 +2392,7 @@ bool TQPixmap::hasAlphaChannel() const
 
     copyBlt() does nothing if \a src and \a dst have different depths.
 */
-Q_EXPORT void copyBlt( TQPixmap *dst, int dx, int dy,
+TQ_EXPORT void copyBlt( TQPixmap *dst, int dx, int dy,
 		       const TQPixmap *src, int sx, int sy, int sw, int sh )
 {
     if ( ! dst || ! src || sw == 0 || sh == 0 || dst->depth() != src->depth() ) {
