@@ -182,7 +182,7 @@ public:
 	bool operator<( const Offset&k ) const {
 	    return ( h != k.h ) ? h < k.h : o < k.o;
 	}
-	Q_DUMMY_COMPARISON_OPERATOR(TQTranslatorPrivate::Offset)
+	TQ_DUMMY_COMPARISON_OPERATOR(TQTranslatorPrivate::Offset)
 	uint h;
 	uint o;
     };
@@ -210,7 +210,7 @@ public:
 #ifndef TQT_NO_TRANSLATION_BUILDER
     TQMap<TQTranslatorMessage, void *> * messages;
 #endif
-#ifdef Q_WS_WIN
+#ifdef TQ_WS_WIN
     int oldPermissionLookup;
 #endif
 };
@@ -340,7 +340,7 @@ public:
     explicitly documented as such.
 */
 
-#if defined(Q_WS_WIN)
+#if defined(TQ_WS_WIN)
 extern int qt_ntfs_permission_lookup;
 #endif
 
@@ -353,7 +353,7 @@ TQTranslator::TQTranslator( TQObject * parent, const char * name )
     : TQObject( parent, name )
 {
     d = new TQTranslatorPrivate;
-#if defined(Q_WS_WIN)
+#if defined(TQ_WS_WIN)
     d->oldPermissionLookup = qt_ntfs_permission_lookup;
 #endif
 }
@@ -419,7 +419,7 @@ bool TQTranslator::load( const TQString & filename, const TQString & directory,
     TQString prefix;
 
     if ( filename[0] == '/'
-#ifdef Q_WS_WIN
+#ifdef TQ_WS_WIN
 	 || (filename[0] && filename[1] == ':') || filename[0] == '\\'
 #endif
 	 )
@@ -438,7 +438,7 @@ bool TQTranslator::load( const TQString & filename, const TQString & directory,
     delims = search_delimiters.isNull() ?
 	     TQString::fromLatin1( "_." ) : search_delimiters;
 
-#if defined(Q_WS_WIN)
+#if defined(TQ_WS_WIN)
     qt_ntfs_permission_lookup--;
 #endif
     for ( ;; ) {
@@ -463,7 +463,7 @@ bool TQTranslator::load( const TQString & filename, const TQString & directory,
 
 	// no truncations? fail
         if ( rightmost == 0 ) {
-#if defined(Q_WS_WIN)
+#if defined(TQ_WS_WIN)
             if (d->oldPermissionLookup != qt_ntfs_permission_lookup)
                 qt_ntfs_permission_lookup++;
 #endif
@@ -472,7 +472,7 @@ bool TQTranslator::load( const TQString & filename, const TQString & directory,
 
 	fname.truncate( rightmost );
     }
-#if defined(Q_WS_WIN)
+#if defined(TQ_WS_WIN)
     if (d->oldPermissionLookup != qt_ntfs_permission_lookup)
         qt_ntfs_permission_lookup++;
 #endif
