@@ -552,7 +552,7 @@
 
 
 /*
-   The window system, must be one of: (Q_WS_x)
+   The window system, must be one of: (TQ_WS_x)
 
      MACX	- Mac OS X
      MAC9	- Mac OS 9
@@ -564,40 +564,40 @@
 */
 
 #if defined(Q_OS_MAC9)
-#  define Q_WS_MAC9
+#  define TQ_WS_MAC9
 #elif defined(Q_OS_MSDOS)
-#  define Q_WS_WIN16
+#  define TQ_WS_WIN16
 #  error "TQt requires Win32 and does not work with Windows 3.x"
 #elif defined(_WIN32_X11_)
-#  define Q_WS_X11
+#  define TQ_WS_X11
 #elif defined(Q_OS_WIN32)
-#  define Q_WS_WIN32
+#  define TQ_WS_WIN32
 #  if defined(Q_OS_WIN64)
-#    define Q_WS_WIN64
+#    define TQ_WS_WIN64
 #  endif
 #elif defined(Q_OS_OS2)
-#  define Q_WS_PM
+#  define TQ_WS_PM
 #  error "TQt does not work with OS/2 Presentation Manager or Workplace Shell"
 #elif defined(Q_OS_UNIX)
 #  if defined(TQWS)
-#    define Q_WS_QWS
+#    define TQ_WS_QWS
 #    define TQT_NO_QWS_IM
 #  elif defined(Q_OS_MACX)
-#    define Q_WS_MACX
+#    define TQ_WS_MACX
 #  else
-#    define Q_WS_X11
+#    define TQ_WS_X11
 #  endif
 #endif
 #if defined(Q_OS_MAC) && !defined(TQMAC_PASCAL)
 #  define TQMAC_PASCAL
 #endif
 
-#if defined(Q_WS_WIN16) || defined(Q_WS_WIN32)
-#  define Q_WS_WIN
+#if defined(TQ_WS_WIN16) || defined(TQ_WS_WIN32)
+#  define TQ_WS_WIN
 #endif
 
-#if (defined(Q_WS_MAC9) || defined(Q_WS_MACX)) && !defined(Q_WS_QWS) && !defined(Q_WS_X11)
-#  define Q_WS_MAC
+#if (defined(TQ_WS_MAC9) || defined(TQ_WS_MACX)) && !defined(TQ_WS_QWS) && !defined(TQ_WS_X11)
+#  define TQ_WS_MAC
 #endif
 
 
@@ -669,19 +669,6 @@ const bool true = TRUE;
 #endif
 
 
-//
-// Workaround for static const members on MSVC++.
-//
-
-#if defined(Q_CC_MSVC)
-#  define QT_STATIC_CONST static
-#  define QT_STATIC_CONST_IMPL
-#else
-#  define QT_STATIC_CONST static const
-#  define QT_STATIC_CONST_IMPL const
-#endif
-
-
 //
 // Utility macros and inline functions
 //
@@ -780,6 +767,9 @@ class TQString;
 #ifndef TQT_MODULE_DIALOGS
 # define TQT_NO_DIALOG
 #endif
+#ifndef TQT_MODULE_INPUTMETHOD
+# define TQT_NO_IM
+#endif
 #ifndef TQT_MODULE_WORKSPACE
 # define TQT_NO_WORKSPACE
 #endif
@@ -802,7 +792,7 @@ class TQString;
 # define TQT_NO_SQL
 #endif
 
-#if defined(Q_WS_MAC9)
+#if defined(TQ_WS_MAC9)
 //No need for menu merging
 #  ifndef TQMAC_QMENUBAR_NO_MERGE
 #    define TQMAC_QMENUBAR_NO_MERGE
@@ -815,7 +805,7 @@ class TQString;
 #    define TQMAC_QMENUBAR_NO_EVENT
 #  endif
 #endif
-#if defined(Q_WS_MACX) //for no nobody uses quartz, just putting in first level hooks
+#if defined(TQ_WS_MACX) //for no nobody uses quartz, just putting in first level hooks
 #  ifndef TQMAC_NO_QUARTZ
 #    define TQMAC_NO_QUARTZ
 #  endif
@@ -824,7 +814,7 @@ class TQString;
 #  endif
 #endif
 
-#if !defined(Q_WS_QWS) && !defined(TQT_NO_COP)
+#if !defined(TQ_WS_QWS) && !defined(TQT_NO_COP)
 #  define TQT_NO_COP
 #endif
 
@@ -891,7 +881,7 @@ class TQString;
 // Some platform specific stuff
 //
 
-#if defined(Q_WS_WIN)
+#if defined(TQ_WS_WIN)
 extern TQ_EXPORT bool qt_winunicode;
 #endif
 
@@ -905,7 +895,7 @@ TQ_EXPORT bool tqSysInfo( int *wordSize, bool *bigEndian );
 TQ_EXPORT bool tqSharedBuild();
 #if defined(Q_OS_MAC)
 int qMacVersion();
-#elif defined(Q_WS_WIN)
+#elif defined(TQ_WS_WIN)
 TQ_EXPORT int qWinVersion();
 #if defined(UNICODE)
 #define QT_WA( uni, ansi ) if ( qt_winunicode ) { uni } else { ansi }
