@@ -40,7 +40,7 @@
 
 #include "ntqdatastream.h"
 
-#ifndef QT_NO_DATASTREAM
+#ifndef TQT_NO_DATASTREAM
 #include "ntqbuffer.h"
 #include <stdio.h>
 #include <ctype.h>
@@ -1177,4 +1177,4 @@ TQDataStream &TQDataStream::writeRawBytes( const char *s, uint len )
     return *this;
 }
 
-#endif // QT_NO_DATASTREAM
+#endif // TQT_NO_DATASTREAM
