@@ -42,7 +42,7 @@
 #if defined(Q_CC_BOR)
     // needed for qsort() because of a std namespace problem on Borland
 #   include "qplatformdefs.h"
-#elif defined(Q_WS_WIN)
+#elif defined(TQ_WS_WIN)
     // needed for bsearch on some platforms
 #   include "qt_windows.h"
 #endif
@@ -52,9 +52,9 @@
 #include <stdlib.h>
 #include <string.h>
 
-#ifdef QT_THREAD_SUPPORT
+#ifdef TQT_THREAD_SUPPORT
 #  include <private/qmutexpool_p.h>
-#endif // QT_THREAD_SUPPORT
+#endif // TQT_THREAD_SUPPORT
 
 /*
   If USE_MALLOC isn't defined, we use new[] and delete[] to allocate
@@ -733,10 +733,10 @@ void TQGArray::sort( uint sz )
     if ( numItems < 2 )
 	return;
 
-#ifdef QT_THREAD_SUPPORT
+#ifdef TQT_THREAD_SUPPORT
     TQMutexLocker locker( tqt_global_mutexpool ?
 			 tqt_global_mutexpool->get( &cmp_item_size ) : 0 );
-#endif // QT_THREAD_SUPPORT
+#endif // TQT_THREAD_SUPPORT
 
     cmp_item_size = sz;
     qsort( shd->data, numItems, sz, cmp_arr );
@@ -752,10 +752,10 @@ int TQGArray::bsearch( const char *d, uint sz ) const
     if ( !numItems )
 	return -1;
 
-#ifdef QT_THREAD_SUPPORT
+#ifdef TQT_THREAD_SUPPORT
     TQMutexLocker locker( tqt_global_mutexpool ?
 			 tqt_global_mutexpool->get( &cmp_item_size ) : 0 );
-#endif // QT_THREAD_SUPPORT
+#endif // TQT_THREAD_SUPPORT
 
     cmp_item_size = sz;
     char* r = (char*)::bsearch( d, shd->data, numItems, sz, cmp_arr );
