@@ -42,7 +42,7 @@
 
 #include <ntqthread.h>
 
-Q_EXPORT TQMutexPool *tqt_global_mutexpool = 0;
+TQ_EXPORT TQMutexPool *tqt_global_mutexpool = 0;
 
 
 /*!
