@@ -268,10 +268,10 @@ int TQButtonGroup::insert( TQButton *button, int id )
     button->setGroup(this);
     buttons->append( bi );
 
-    connect( button, SIGNAL(pressed()) , SLOT(buttonPressed()) );
-    connect( button, SIGNAL(released()), SLOT(buttonReleased()) );
-    connect( button, SIGNAL(clicked()) , SLOT(buttonClicked()) );
-    connect( button, SIGNAL(toggled(bool)) , SLOT(buttonToggled(bool)) );
+    connect( button, TQ_SIGNAL(pressed()) , TQ_SLOT(buttonPressed()) );
+    connect( button, TQ_SIGNAL(released()), TQ_SLOT(buttonReleased()) );
+    connect( button, TQ_SIGNAL(clicked()) , TQ_SLOT(buttonClicked()) );
+    connect( button, TQ_SIGNAL(toggled(bool)) , TQ_SLOT(buttonToggled(bool)) );
 
     if ( button->isToggleButton() && !button->isOn() &&
 	 selected() && (selected()->focusPolicy() & TabFocus) != 0 )
