@@ -157,7 +157,7 @@ TDEIconLoader::TDEIconLoader(const TQString& _appname, TDEStandardDirs *_dirs)
 
     if (kapp) {
         kapp->addKipcEventMask(KIPC::IconChanged);
-        TQObject::connect(kapp, TQT_SIGNAL(updateIconLoaders()), d, TQT_SLOT(reconfigure()));
+        TQObject::connect(kapp, TQ_SIGNAL(updateIconLoaders()), d, TQ_SLOT(reconfigure()));
     }
 
     init( _appname, _dirs );
