@@ -427,14 +427,14 @@ TQString TDEStandardDirs::findResourceDir( const char *type,
     for (TQStringList::ConstIterator it = candidates.begin();
       it != candidates.end(); ++it) {
       if (exists(*it + filename)) {
-#ifdef Q_WS_WIN //this ensures we're using installed .la files
+#ifdef TQ_WS_WIN //this ensures we're using installed .la files
           if ((*it).isEmpty() && filename.right(3)==".la") {
 #ifndef NDEBUG
               fprintf(stderr, "TDEStandardDirs::findResourceDir() found .la in cwd: skipping. (fname=%s)\n", filename.ascii());
 #endif
               continue;
           }
-#endif //Q_WS_WIN
+#endif //TQ_WS_WIN
           return *it;
       }
     }
@@ -480,7 +480,7 @@ static void lookupDirectory(const TQString& path, const TQString &relPart,
     if (!dp)
       return;
 
-#ifdef Q_WS_WIN
+#ifdef TQ_WS_WIN
     assert(path.at(path.length() - 1) == TQChar('/') || path.at(path.length() - 1) == TQChar('\\'));
 #else
     assert(path.at(path.length() - 1) == TQChar('/'));
@@ -571,7 +571,7 @@ static void lookupPrefix(const TQString& prefix, const TQString& relpath,
 
     if (prefix.isEmpty()) //for sanity
       return;
-#ifdef Q_WS_WIN
+#ifdef TQ_WS_WIN
     assert(prefix.at(prefix.length() - 1) == TQChar('/') || prefix.at(prefix.length() - 1) == TQChar('\\'));
 #else
     assert(prefix.at(prefix.length() - 1) == TQChar('/'));
@@ -754,7 +754,7 @@ void TDEStandardDirs::createSpecialResource(const char *type)
          }
       }
    }
-#ifdef Q_WS_WIN
+#ifdef TQ_WS_WIN
    if (relink)
    {
       if (!makeDir(dir, 0700))
@@ -932,7 +932,7 @@ TQStringList TDEStandardDirs::systemPaths( const TQString& pstr )
 TQString TDEStandardDirs::findExe( const TQString& appname,
 				const TQString& pstr, bool ignore)
 {
-#ifdef Q_WS_WIN
+#ifdef TQ_WS_WIN
     TQString real_appname = appname + ".exe";
 #else
     TQString real_appname = appname;
@@ -981,7 +981,7 @@ TQString TDEStandardDirs::findExe( const TQString& appname,
 int TDEStandardDirs::findAllExe( TQStringList& list, const TQString& appname,
 			const TQString& pstr, bool ignore )
 {
-#ifdef Q_WS_WIN
+#ifdef TQ_WS_WIN
     TQString real_appname = appname + ".exe";
 #else
     TQString real_appname = appname;
@@ -1259,7 +1259,7 @@ TQString TDEStandardDirs::kfsstnd_defaultprefix()
    TDEStandardDirsSingleton* s = TDEStandardDirsSingleton::self();
    if (!s->defaultprefix.isEmpty())
       return s->defaultprefix;
-#ifdef Q_WS_WIN
+#ifdef TQ_WS_WIN
    s->defaultprefix = readEnvPath("TDEDIR");
    if (s->defaultprefix.isEmpty()) {
       s->defaultprefix = TQFile::decodeName("c:\\kde");
@@ -1279,7 +1279,7 @@ TQString TDEStandardDirs::kfsstnd_defaultbindir()
    TDEStandardDirsSingleton* s = TDEStandardDirsSingleton::self();
    if (!s->defaultbindir.isEmpty())
       return s->defaultbindir;
-#ifdef Q_WS_WIN
+#ifdef TQ_WS_WIN
    s->defaultbindir = kfsstnd_defaultprefix() + TQString::fromLatin1("/bin");
 #else //UNIX
    s->defaultbindir = __TDE_BINDIR;
@@ -1374,7 +1374,7 @@ void TDEStandardDirs::addKDEDefaults()
     {
 	xdgdirList.clear();
         xdgdirList.append("/etc/xdg");
-#ifdef Q_WS_WIN
+#ifdef TQ_WS_WIN
         xdgdirList.append(kfsstnd_defaultprefix() + "/etc/xdg");
 #else
         xdgdirList.append(KDESYSCONFDIR "/xdg");
