@@ -29,7 +29,7 @@
 
 #include "tdelibs_export.h"
 #include <tqwidget.h>
-#ifdef Q_WS_X11
+#ifdef TQ_WS_X11
 #include <X11/Xlib.h>
 #include <X11/Xutil.h>
 #include <X11/Xatom.h>
