@@ -429,13 +429,13 @@ TQVariant TDEConfigBase::readPropertyEntry( const char *pKey,
       case TQVariant::ULongLong:
           return TQVariant( readUnsignedNum64Entry( pKey, aDefault.toULongLong() ) );
       case TQVariant::Bool:
-          return TQVariant( readBoolEntry( pKey, aDefault.toBool() ), 0 );
+          return TQVariant( readBoolEntry( pKey, aDefault.toBool() ) );
       case TQVariant::Double:
           return TQVariant( readDoubleNumEntry( pKey, aDefault.toDouble() ) );
       case TQVariant::DateTime:
           return TQVariant( readDateTimeEntry( pKey, &tmp.asDateTime() ) );
       case TQVariant::Date:
-          return TQVariant(TQT_TQDATE_OBJECT(readDateTimeEntry( pKey, &tmp.asDateTime() ).date()));
+          return TQVariant(readDateTimeEntry( pKey, &tmp.asDateTime() ).date());
 
       case TQVariant::Pixmap:
       case TQVariant::Image:
@@ -451,35 +451,13 @@ TQVariant TDEConfigBase::readPropertyEntry( const char *pKey,
       case TQVariant::Cursor:
       case TQVariant::SizePolicy:
       case TQVariant::Time:
-#ifdef USE_QT3
       case TQVariant::ByteArray:
-#endif // USE_QT3
       case TQVariant::BitArray:
       case TQVariant::KeySequence:
       case TQVariant::Pen:
-#ifdef USE_QT4
-      case TQVariant::Char:
-      case TQVariant::Url:
-      case TQVariant::Locale:
-      case TQVariant::RectF:
-      case TQVariant::SizeF:
-      case TQVariant::Line:
-      case TQVariant::LineF:
-      case TQVariant::PointF:
-      case TQVariant::RegExp:
-      case TQVariant::Hash:
-      case TQVariant::TextLength:
-      case QVariant::TextFormat:
-      case TQVariant::Matrix:
-      case TQVariant::Transform:
-      case TQVariant::Matrix4x4:
-      case TQVariant::Vector2D:
-      case TQVariant::Vector3D:
-      case TQVariant::Vector4D:
-      case TQVariant::Quaternion:
-      case TQVariant::UserType:
-#endif // USE_QT4
+      {
           break;
+      }
   }
 
   Q_ASSERT( 0 );
@@ -981,7 +959,7 @@ TQColor TDEConfigBase::readColorEntry( const char *pKey,
   TQString aValue = readEntry( pKey );
   if( !aValue.isEmpty() )
     {
-      if ( aValue.at(0) == (QChar)'#' )
+      if ( aValue.at(0) == (TQChar)'#' )
         {
           aRetColor.setNamedColor(aValue);
         }
@@ -1122,7 +1100,7 @@ void TDEConfigBase::writePathEntry( const TQString& pKey, const TQString & path,
 
 static bool cleanHomeDirPath( TQString &path, const TQString &homeDir )
 {
-#ifdef Q_WS_WIN //safer
+#ifdef TQ_WS_WIN //safer
    if (!TQDir::convertSeparators(path).startsWith(TQDir::convertSeparators(homeDir)))
         return false;
 #else
@@ -1376,35 +1354,13 @@ void TDEConfigBase::writeEntry ( const char *pKey, const TQVariant &prop,
     case TQVariant::Cursor:
     case TQVariant::SizePolicy:
     case TQVariant::Time:
-#ifdef USE_QT3
     case TQVariant::ByteArray:
-#endif // USE_QT3
     case TQVariant::BitArray:
     case TQVariant::KeySequence:
     case TQVariant::Pen:
-#ifdef USE_QT4
-    case TQVariant::Char:
-    case TQVariant::Url:
-    case TQVariant::Locale:
-    case TQVariant::RectF:
-    case TQVariant::SizeF:
-    case TQVariant::Line:
-    case TQVariant::LineF:
-    case TQVariant::PointF:
-    case TQVariant::RegExp:
-    case TQVariant::Hash:
-    case TQVariant::TextLength:
-    case QVariant::TextFormat:
-    case TQVariant::Matrix:
-    case TQVariant::Transform:
-    case TQVariant::Matrix4x4:
-    case TQVariant::Vector2D:
-    case TQVariant::Vector3D:
-    case TQVariant::Vector4D:
-    case TQVariant::Quaternion:
-    case TQVariant::UserType:
-#endif // USE_QT4
+      {
         break;
+      }
     }
 
   Q_ASSERT( 0 );
@@ -1445,7 +1401,7 @@ void TDEConfigBase::writeEntry ( const char *pKey, const TQStrList &list,
         }
       str_list += sep;
     }
-  if( str_list.at(str_list.length() - 1) == (QChar)sep )
+  if( str_list.at(str_list.length() - 1) == (TQChar)sep )
     str_list.truncate( str_list.length() -1 );
   writeEntry( pKey, str_list, bPersistent, bGlobal, bNLS );
 }
@@ -1489,7 +1445,7 @@ void TDEConfigBase::writeEntry ( const char *pKey, const TQStringList &list,
         }
       str_list += sep;
     }
-  if( str_list.at(str_list.length() - 1) == (QChar)sep )
+  if( str_list.at(str_list.length() - 1) == (TQChar)sep )
     str_list.truncate( str_list.length() -1 );
   writeEntry( pKey, str_list, bPersistent, bGlobal, bNLS, bExpand );
 }
@@ -1753,8 +1709,8 @@ void TDEConfigBase::writeEntry( const char *pKey, const TQDateTime& rDateTime,
   TQStrList list;
   TQCString tempstr;
 
-  TQTime time = TQT_TQTIME_OBJECT(rDateTime.time());
-  TQDate date = TQT_TQDATE_OBJECT(rDateTime.date());
+  TQTime time = rDateTime.time();
+  TQDate date = rDateTime.date();
 
   list.insert( 0, tempstr.setNum( date.year() ) );
   list.insert( 1, tempstr.setNum( date.month() ) );
