@@ -42,7 +42,7 @@
 #include "kcalendarsystemfactory.h"
 #include "tdelocale.h"
 
-#ifdef Q_WS_WIN
+#ifdef TQ_WS_WIN
 #include <windows.h>
 #endif
 
@@ -72,7 +72,7 @@ public:
   KCalendarSystem * calendar;
   bool utf8FileEncoding;
   TQString appName;
-#ifdef Q_WS_WIN
+#ifdef TQ_WS_WIN
   char win32SystemEncoding[3+7]; //"cp " + lang ID
 #endif
   bool useMainCatalogue;
@@ -2264,7 +2264,7 @@ TQString TDELocale::defaultCountry()
 
 const char * TDELocale::encoding() const
 {
-#ifdef Q_WS_WIN
+#ifdef TQ_WS_WIN
   if (0==qstrcmp("System", codecForEncoding()->name()))
   {
     //win32 returns "System" codec name here but KDE apps expect a real name:
