@@ -157,7 +157,11 @@ bool KNSPluginInstallEngine::findPlugin()
 
     // get system infos
     // TODO/FIX : correct this to work with x86-64 machines
+#ifdef Q_OS_SOLARIS
+    struct utsname sysinfo;
+#else /* default */
     utsname sysinfo;
+#endif /* default */
     if(uname(&sysinfo))
         return false;
     TQString sysname(sysinfo.sysname);
@@ -234,8 +238,8 @@ void KNSPluginInstallEngine::startInstall(KNSPluginInfo info)
     // start the download job
     m_downloadJob  = TDEIO::copy(info.pluginURL(), "file://"+m_tmpPluginFileName, false );
     // connect signals 
-    connect(m_downloadJob, TQT_SIGNAL(percent (TDEIO::Job *, unsigned long)), this , TQT_SLOT(slotDownLoadProgress(TDEIO::Job *, unsigned long)));
-    connect(m_downloadJob, TQT_SIGNAL(result(TDEIO::Job *)), this, TQT_SLOT(slotDownloadResult(TDEIO::Job *)) );
+    connect(m_downloadJob, TQ_SIGNAL(percent (TDEIO::Job *, unsigned long)), this , TQ_SLOT(slotDownLoadProgress(TDEIO::Job *, unsigned long)));
+    connect(m_downloadJob, TQ_SIGNAL(result(TDEIO::Job *)), this, TQ_SLOT(slotDownloadResult(TDEIO::Job *)) );
     kdDebug(DEBUG_NUMBER) << "download plugin " << m_tmpPluginFileName << endl;
 } 
 
@@ -280,8 +284,8 @@ void KNSPluginInstallEngine::slotDownloadResult(TDEIO::Job *job)
            urlList.append( KURL("tar://"+m_tmpPluginFileName+"/"+(*it)) );
         }
        m_installFileJob  = TDEIO::copy(urlList , destURL, false );
-       connect(m_installFileJob, TQT_SIGNAL(percent (TDEIO::Job *, unsigned long)), this , TQT_SLOT(slotCopyProgress(TDEIO::Job *, unsigned long)));
-       connect(m_installFileJob, TQT_SIGNAL(result(TDEIO::Job *)), this, TQT_SLOT(slotCopyResult(TDEIO::Job *)) );
+       connect(m_installFileJob, TQ_SIGNAL(percent (TDEIO::Job *, unsigned long)), this , TQ_SLOT(slotCopyProgress(TDEIO::Job *, unsigned long)));
+       connect(m_installFileJob, TQ_SIGNAL(result(TDEIO::Job *)), this, TQ_SLOT(slotCopyResult(TDEIO::Job *)) );
     }
     kdDebug(DEBUG_NUMBER) << "COPY FILE " << m_tmpPluginFileName << endl;
 
@@ -308,10 +312,10 @@ void KNSPluginInstallEngine::slotCopyResult(TDEIO::Job *job)
        m_scanProc->addArgument( "nspluginscan" );
        m_scanProc->addArgument( "--verbose" );
 
-       connect( m_scanProc, TQT_SIGNAL(readyReadStdout()),
-               this, TQT_SLOT(readScanProcFromStdout()) );
-       connect( m_scanProc, TQT_SIGNAL(processExited()),
-               this, TQT_SLOT(endScanProc()) );
+       connect( m_scanProc, TQ_SIGNAL(readyReadStdout()),
+               this, TQ_SLOT(readScanProcFromStdout()) );
+       connect( m_scanProc, TQ_SIGNAL(processExited()),
+               this, TQ_SLOT(endScanProc()) );
        if ( !m_scanProc->start() ) {
             emit installFailed();
        }
@@ -422,7 +426,7 @@ void KNSPluginWizard::initLicencePage()
     addPage (m_licenceVBox, i18n("Plugin licence"));
 
 
-    connect(buttonGroup, TQT_SIGNAL(clicked(int)), this, TQT_SLOT(slotAgreementClicked(int)));
+    connect(buttonGroup, TQ_SIGNAL(clicked(int)), this, TQ_SLOT(slotAgreementClicked(int)));
 }
 
 void KNSPluginWizard::initInstallationProgressPage() {
@@ -482,9 +486,9 @@ void KNSPluginWizard::initPagesButtonStates()
 
 
 void KNSPluginWizard::connectSignals() {
-    connect(&m_installEngine, TQT_SIGNAL(installProgress(int)), m_installationProgressBar, TQT_SLOT(setProgress(int)) );
-    connect(&m_installEngine, TQT_SIGNAL(installCompleted()), this, TQT_SLOT(slotInstallationCompleted()) );
-     connect(&m_installEngine, TQT_SIGNAL(installFailed()), this, TQT_SLOT(slotInstallationFailed()) );
+    connect(&m_installEngine, TQ_SIGNAL(installProgress(int)), m_installationProgressBar, TQ_SLOT(setProgress(int)) );
+    connect(&m_installEngine, TQ_SIGNAL(installCompleted()), this, TQ_SLOT(slotInstallationCompleted()) );
+     connect(&m_installEngine, TQ_SIGNAL(installFailed()), this, TQ_SLOT(slotInstallationFailed()) );
      
 
 }
