@@ -75,7 +75,7 @@ struct KFileDialogPrivate;
  */
 class TDEIO_EXPORT KFileDialog : public KDialogBase
 {
-    Q_OBJECT
+    TQ_OBJECT
 
 public:
 
@@ -713,7 +713,7 @@ public:
      * items into it, e.g.:
      * \code
      *      yourAction = new TDEAction( i18n("Your Action"), 0,
-     *                                this, TQT_SLOT( yourSlot() ),
+     *                                this, TQ_SLOT( yourSlot() ),
      *                                this, "action name" );
      *      yourAction->plug( tdefileDialog->toolBar() );
      * \endcode
