@@ -1144,22 +1144,34 @@ TDEIO_EXPORT TQByteArray TDEIO::rawErrorDetail(int errorCode, const TQString &er
       break;
 
     case  TDEIO::ERR_SERVER_TIMEOUT:
+    {
+      int connTimeout   = KProtocolManager::connectTimeout();
+      int respTimeout   = KProtocolManager::responseTimeout();
+      int prConnTimeout = KProtocolManager::proxyConnectTimeout();
       errorName = i18n( "Timeout Error" );
-      description = i18n( "Although contact was made with the server, a "
-        "response was not received within the amount of time allocated for "
-        "the request as follows:<ul>"
-        "<li>Timeout for establishing a connection: %1 seconds</li>"
-        "<li>Timeout for receiving a response: %2 seconds</li>"
-        "<li>Timeout for accessing proxy servers: %3 seconds</li></ul>"
-        "Please note that you can alter these timeout settings in the TDE "
-        "Control Center, by selecting Network -> Preferences." )
-        .arg( KProtocolManager::connectTimeout() )
-        .arg( KProtocolManager::responseTimeout() )
-        .arg( KProtocolManager::proxyConnectTimeout() );
+      description = i18n("Although contact was made with the server, a "
+          "response was not received within the amount of time allocated for "
+          "the request as follows:")
+        .append(TQString::fromLatin1("<ul><li>"))
+        .append(i18n("Timeout for establishing a connection: %n second",
+                     "Timeout for establishing a connection: %n seconds",
+                     connTimeout))
+        .append(TQString::fromLatin1("</li><li>"))
+        .append(i18n("Timeout for receiving a response: %n second",
+                     "Timeout for receiving a response: %n seconds",
+                     respTimeout))
+        .append(TQString::fromLatin1("</li><li>"))
+        .append(i18n("Timeout for accessing proxy servers: %n second",
+                     "Timeout for accessing proxy servers: %n seconds",
+                     prConnTimeout))
+        .append(TQString::fromLatin1("</li></ul>"))
+        .append(i18n("Please note that you can alter these timeout settings in the TDE "
+                     "Control Center, by selecting Network -> Preferences." ));
       causes << cNetpath << i18n( "The server was too busy responding to other "
         "requests to respond." );
       solutions << sTryagain << sServeradmin;
       break;
+    }
 
     case  TDEIO::ERR_UNKNOWN:
       errorName = i18n( "Unknown Error" );
@@ -1295,6 +1307,8 @@ TDEIO_EXPORT TQByteArray TDEIO::rawErrorDetail(int errorCode, const TQString &er
 #endif
 #ifdef HAVE_SYS_UCRED_H
 #include <sys/ucred.h>
+#elif defined(HAVE_UCRED_H)
+#include <ucred.h>
 #endif
 #ifdef HAVE_SYS_MOUNT_H
 #include <sys/mount.h>
