@@ -1333,12 +1333,12 @@ void KURLCompletion::slotIOFinished( TDEIO::Job * job )
 		assert( d->list_job );
 
 		connect( d->list_job,
-				TQT_SIGNAL(result(TDEIO::Job*)),
-				TQT_SLOT(slotIOFinished(TDEIO::Job*)) );
+				TQ_SIGNAL(result(TDEIO::Job*)),
+				TQ_SLOT(slotIOFinished(TDEIO::Job*)) );
 
 		connect( d->list_job,
-				TQT_SIGNAL( entries( TDEIO::Job*, const TDEIO::UDSEntryList&)),
-				TQT_SLOT( slotEntries( TDEIO::Job*, const TDEIO::UDSEntryList&)) );
+				TQ_SIGNAL( entries( TDEIO::Job*, const TDEIO::UDSEntryList&)),
+				TQ_SLOT( slotEntries( TDEIO::Job*, const TDEIO::UDSEntryList&)) );
 
 		delete kurl;
 	}
