@@ -74,20 +74,20 @@ KCMLirc::KCMLirc(TQWidget *parent, const char *name, TQStringList /*args*/) : DC
 
 	(new TQHBoxLayout(this))->setAutoAdd(true);
 	theKCMLircBase = new KCMLircBase(this);
-	connect(theKCMLircBase->theModes, TQT_SIGNAL( selectionChanged(TQListViewItem *) ), this, TQT_SLOT( updateActions() ));
-	connect(theKCMLircBase->theModes, TQT_SIGNAL( selectionChanged(TQListViewItem *) ), this, TQT_SLOT( updateModesStatus(TQListViewItem *) ));
-	connect(theKCMLircBase->theActions, TQT_SIGNAL( currentChanged(TQListViewItem *) ), this, TQT_SLOT( updateActionsStatus(TQListViewItem *) ));
-	connect(theKCMLircBase->theExtensions, TQT_SIGNAL( selectionChanged(TQListViewItem *) ), this, TQT_SLOT( updateInformation() ));
-	connect(theKCMLircBase->theModes, TQT_SIGNAL( itemRenamed(TQListViewItem *) ), this, TQT_SLOT( slotRenamed(TQListViewItem *) ));
-	connect(theKCMLircBase->theModes, TQT_SIGNAL(dropped(TDEListView*, TQDropEvent*, TQListViewItem*, TQListViewItem*)), this, TQT_SLOT(slotDrop(TDEListView*, TQDropEvent*, TQListViewItem*, TQListViewItem*)));
-	connect((TQObject *)(theKCMLircBase->theAddActions), TQT_SIGNAL( clicked() ), this, TQT_SLOT( slotAddActions() ));
-	connect((TQObject *)(theKCMLircBase->theAddAction), TQT_SIGNAL( clicked() ), this, TQT_SLOT( slotAddAction() ));
-	connect((TQObject *)(theKCMLircBase->theEditAction), TQT_SIGNAL( clicked() ), this, TQT_SLOT( slotEditAction() ));
-	connect((TQObject *)(theKCMLircBase->theActions), TQT_SIGNAL( doubleClicked(TQListViewItem *) ), this, TQT_SLOT( slotEditAction() ));
-	connect((TQObject *)(theKCMLircBase->theRemoveAction), TQT_SIGNAL( clicked() ), this, TQT_SLOT( slotRemoveAction() ));
-	connect((TQObject *)(theKCMLircBase->theAddMode), TQT_SIGNAL( clicked() ), this, TQT_SLOT( slotAddMode() ));
-	connect((TQObject *)(theKCMLircBase->theEditMode), TQT_SIGNAL( clicked() ), this, TQT_SLOT( slotEditMode() ));
-	connect((TQObject *)(theKCMLircBase->theRemoveMode), TQT_SIGNAL( clicked() ), this, TQT_SLOT( slotRemoveMode() ));
+	connect(theKCMLircBase->theModes, TQ_SIGNAL( selectionChanged(TQListViewItem *) ), this, TQ_SLOT( updateActions() ));
+	connect(theKCMLircBase->theModes, TQ_SIGNAL( selectionChanged(TQListViewItem *) ), this, TQ_SLOT( updateModesStatus(TQListViewItem *) ));
+	connect(theKCMLircBase->theActions, TQ_SIGNAL( currentChanged(TQListViewItem *) ), this, TQ_SLOT( updateActionsStatus(TQListViewItem *) ));
+	connect(theKCMLircBase->theExtensions, TQ_SIGNAL( selectionChanged(TQListViewItem *) ), this, TQ_SLOT( updateInformation() ));
+	connect(theKCMLircBase->theModes, TQ_SIGNAL( itemRenamed(TQListViewItem *) ), this, TQ_SLOT( slotRenamed(TQListViewItem *) ));
+	connect(theKCMLircBase->theModes, TQ_SIGNAL(dropped(TDEListView*, TQDropEvent*, TQListViewItem*, TQListViewItem*)), this, TQ_SLOT(slotDrop(TDEListView*, TQDropEvent*, TQListViewItem*, TQListViewItem*)));
+	connect((TQObject *)(theKCMLircBase->theAddActions), TQ_SIGNAL( clicked() ), this, TQ_SLOT( slotAddActions() ));
+	connect((TQObject *)(theKCMLircBase->theAddAction), TQ_SIGNAL( clicked() ), this, TQ_SLOT( slotAddAction() ));
+	connect((TQObject *)(theKCMLircBase->theEditAction), TQ_SIGNAL( clicked() ), this, TQ_SLOT( slotEditAction() ));
+	connect((TQObject *)(theKCMLircBase->theActions), TQ_SIGNAL( doubleClicked(TQListViewItem *) ), this, TQ_SLOT( slotEditAction() ));
+	connect((TQObject *)(theKCMLircBase->theRemoveAction), TQ_SIGNAL( clicked() ), this, TQ_SLOT( slotRemoveAction() ));
+	connect((TQObject *)(theKCMLircBase->theAddMode), TQ_SIGNAL( clicked() ), this, TQ_SLOT( slotAddMode() ));
+	connect((TQObject *)(theKCMLircBase->theEditMode), TQ_SIGNAL( clicked() ), this, TQ_SLOT( slotEditMode() ));
+	connect((TQObject *)(theKCMLircBase->theRemoveMode), TQ_SIGNAL( clicked() ), this, TQ_SLOT( slotRemoveMode() ));
 	load();
 }
 
@@ -163,7 +163,7 @@ void KCMLirc::slotAddAction()
 	Mode m = modeMap[theKCMLircBase->theModes->selectedItem()];
 
 	AddAction theDialog(this, 0, m);
-	connect(this, TQT_SIGNAL(haveButton(const TQString &, const TQString &)), &theDialog, TQT_SLOT(updateButton(const TQString &, const TQString &)));
+	connect(this, TQ_SIGNAL(haveButton(const TQString &, const TQString &)), &theDialog, TQ_SLOT(updateButton(const TQString &, const TQString &)));
 
 	// populate the modes list box
 	TQListViewItem *item = theKCMLircBase->theModes->selectedItem();
