@@ -90,10 +90,10 @@ tdemidClient::tdemidClient(TQWidget *parent, TDEActionCollection *ac, const char
     //	currentsl=slman->getCollection(activecollection);
     itsme=0;
     m_kMid.pid=0;
-    timebar = new TQSlider(0,240000,30000,60000,Qt::Horizontal, this);
+    timebar = new TQSlider(0,240000,30000,60000,TQt::Horizontal, this);
     timebar->setSteps(30000,60000);
     timebar->setValue(0);
-    connect (timebar,TQT_SIGNAL(valueChanged(int)),this,TQT_SLOT(slotSeek(int)));
+    connect (timebar,TQ_SIGNAL(valueChanged(int)),this,TQ_SLOT(slotSeek(int)));
 
     timetags = new QSliderTime(timebar,this);
     timetags->setMinimumSize(timetags->sizeHint());
@@ -109,14 +109,14 @@ tdemidClient::tdemidClient(TQWidget *parent, TDEActionCollection *ac, const char
     tempoLCD->setDefaultValue(120);
     tempoLCD->setUserSetDefaultValue(true);
     tempoLCD->setMinimumSize(tempoLCD->sizeHint());
-    connect(tempoLCD,TQT_SIGNAL(valueChanged(double)),this,TQT_SLOT(slotSetTempo(double)));
+    connect(tempoLCD,TQ_SIGNAL(valueChanged(double)),this,TQ_SLOT(slotSetTempo(double)));
 
     comboSongs = new TQComboBox(FALSE, this,"Songs");
-    connect (comboSongs,TQT_SIGNAL(activated(int)),this,TQT_SLOT(slotSelectSong(int)));
+    connect (comboSongs,TQ_SIGNAL(activated(int)),this,TQ_SLOT(slotSelectSong(int)));
     comboSongs->setMinimumWidth(200);
     
     comboEncodings = new TQComboBox(FALSE, this, "Encodings");
-    connect (comboEncodings,TQT_SIGNAL(activated(int)),this,TQT_SLOT(slotSelectEncoding(int)));
+    connect (comboEncodings,TQ_SIGNAL(activated(int)),this,TQ_SLOT(slotSelectEncoding(int)));
     comboEncodings->insertItem(i18n("Default"));
     comboEncodings->insertStringList( TDEGlobal::charsets()->descriptiveEncodingNames() );
     comboEncodings->setCurrentItem(0);
@@ -125,12 +125,12 @@ tdemidClient::tdemidClient(TQWidget *parent, TDEActionCollection *ac, const char
     rhythmview->setMaximumHeight(7);
     rhythmview->setMinimumHeight(7);
 
-    volumebar = new TQSlider(0,200,10,100,Qt::Vertical, this );
+    volumebar = new TQSlider(0,200,10,100,TQt::Vertical, this );
     volumebar->setSteps(10,20);
     volumebar->setValue(100);
     volumebar->setTickmarks(TQSlider::NoMarks);
     volumebar->setTickInterval(50);
-    connect (volumebar,TQT_SIGNAL(valueChanged(int)),this,TQT_SLOT(slotSetVolume(int)));
+    connect (volumebar,TQ_SIGNAL(valueChanged(int)),this,TQ_SLOT(slotSetVolume(int)));
 
     visiblevolumebar=cfg->readNumEntry("ShowVolumeBar",0);
     if (visiblevolumebar) volumebar->show();
@@ -141,9 +141,9 @@ tdemidClient::tdemidClient(TQWidget *parent, TDEActionCollection *ac, const char
     kdispt->show();
 
     timer4timebar=new TQTimer(this);
-    connect (timer4timebar,TQT_SIGNAL(timeout()),this,TQT_SLOT(timebarUpdate()));
+    connect (timer4timebar,TQ_SIGNAL(timeout()),this,TQ_SLOT(timebarUpdate()));
     timer4events=new TQTimer(this);
-    connect (timer4events,TQT_SIGNAL(timeout()),this,TQT_SLOT(processSpecialEvent()));
+    connect (timer4events,TQ_SIGNAL(timeout()),this,TQ_SLOT(processSpecialEvent()));
 
     TQString samplefile =
       TDEGlobal::dirs()->findAllResources("appdata", "fm/*.o3").last();
@@ -372,7 +372,7 @@ int tdemidClient::openURL(const TQString _url)
 	filename = TQString("/tmp/") + u.filename();
 	TDEIO::Job *iojob = TDEIO::copy( u, KURL::fromPathOrURL( filename ) );
 	downloaded=false;
-	connect( iojob, TQT_SIGNAL( result( TDEIO::Job *) ), this, TQT_SLOT(downloadFinished( TDEIO::Job * ) ) );
+	connect( iojob, TQ_SIGNAL( result( TDEIO::Job *) ), this, TQ_SLOT(downloadFinished( TDEIO::Job * ) ) );
 
 	if (!downloaded)
             kapp->enter_loop();
@@ -1373,8 +1373,8 @@ void tdemidClient::visibleChannelView(int i)
             }
         }
         channelView->show();
-        connect(channelView,TQT_SIGNAL(signalToKMidClient(int *)),this,TQT_SLOT(communicationFromChannelView(int *)));
-	connect(kapp,TQT_SIGNAL(shutDown()),parentWidget(),TQT_SLOT(shuttingDown()));
+        connect(channelView,TQ_SIGNAL(signalToKMidClient(int *)),this,TQ_SLOT(communicationFromChannelView(int *)));
+	connect(kapp,TQ_SIGNAL(shutDown()),parentWidget(),TQ_SLOT(shuttingDown()));
 
     }
     else if ((channelView!=NULL)&&(i==0))
