@@ -48,7 +48,7 @@ class KIntSpinBox;
  */
 class TDEUI_EXPORT KNumInput : public TQWidget
 {
-    Q_OBJECT
+    TQ_OBJECT
     
     TQ_PROPERTY( TQString label READ label WRITE setLabel )
 public:
@@ -187,7 +187,7 @@ private:
 
 class TDEUI_EXPORT KIntNumInput : public KNumInput
 {
-    Q_OBJECT
+    TQ_OBJECT
     
     TQ_PROPERTY( int value READ value WRITE setValue )
     TQ_PROPERTY( int minValue READ minValue WRITE setMinValue )
@@ -213,7 +213,7 @@ public:
      *
      * @param value  initial value for the control
      * @param base   numeric base used for display
-     * @param parent parent QWidget
+     * @param parent parent TQWidget
      * @param name   internal name for this widget
      */
     KIntNumInput(int value, TQWidget* parent=0, int base = 10, const char *name=0);
@@ -232,7 +232,7 @@ public:
      * @param below  append KIntNumInput to the KNumInput chain
      * @param value  initial value for the control
      * @param base   numeric base used for display
-     * @param parent parent QWidget
+     * @param parent parent TQWidget
      * @param name   internal name for this widget
      */
     KIntNumInput(KNumInput* below, int value, TQWidget* parent=0, int base = 10, const char *name=0);
@@ -433,7 +433,7 @@ class KDoubleLine;
 
 class TDEUI_EXPORT KDoubleNumInput : public KNumInput
 {
-    Q_OBJECT
+    TQ_OBJECT
     
     TQ_PROPERTY( double value READ value WRITE setValue )
     TQ_PROPERTY( double minValue READ minValue WRITE setMinValue )
@@ -457,7 +457,7 @@ public:
      * Constructor
      *
      * @param value  initial value for the control
-     * @param parent parent QWidget
+     * @param parent parent TQWidget
      * @param name   internal name for this widget
      */
     KDoubleNumInput(double value, TQWidget *parent=0, const char *name=0) KDE_DEPRECATED;
@@ -470,7 +470,7 @@ public:
      * @param value  initial value for the control
      * @param step   step size to use for up/down arrow clicks
      * @param precision number of digits after the decimal point
-     * @param parent parent QWidget
+     * @param parent parent TQWidget
      * @param name   internal name for this widget
      * @since 3.1
      */
@@ -490,7 +490,7 @@ public:
      *
      * @param  below
      * @param  value  initial value for the control
-     * @param  parent parent QWidget
+     * @param  parent parent TQWidget
      * @param  name   internal name for this widget
      **/
     KDoubleNumInput(KNumInput* below, double value, TQWidget* parent=0, const char* name=0) KDE_DEPRECATED;
@@ -512,7 +512,7 @@ public:
      * @param value  initial value for the control
      * @param step   step size to use for up/down arrow clicks
      * @param precision number of digits after the decimal point
-     * @param parent parent QWidget
+     * @param parent parent TQWidget
      * @param name   internal name for this widget
      * @since 3.1
      */
@@ -706,7 +706,7 @@ private:
  */
 class TDEUI_EXPORT KIntSpinBox : public TQSpinBox
 {
-    Q_OBJECT
+    TQ_OBJECT
     
     TQ_PROPERTY( int base READ base WRITE setBase )
 
@@ -836,7 +836,7 @@ private:
 **/
 
 class TDEUI_EXPORT KDoubleSpinBox : public TQSpinBox {
-  Q_OBJECT
+  TQ_OBJECT
   
   TQ_PROPERTY( bool acceptLocalizedNumbers READ acceptLocalizedNumbers WRITE setAcceptLocalizedNumbers )
   TQ_OVERRIDE( double maxValue READ maxValue WRITE setMaxValue )
