@@ -28,7 +28,7 @@
 #include <sys/shm.h>
 #endif
 
-#ifdef Q_WS_X11
+#ifdef TQ_WS_X11
 #include <X11/X.h> 
 #include <X11/Xlib.h> 
 #include <X11/Xutil.h> 
@@ -51,7 +51,7 @@ struct KPixmapIOPrivate
     int threshold;
     int bpp;
     int byteorder;
-#ifdef Q_WS_X11
+#ifdef TQ_WS_X11
     XImage *ximage;
 #ifdef HAVE_MITSHM
     XShmSegmentInfo *shminfo;
@@ -664,7 +664,7 @@ void KPixmapIO::convertToXImage(const TQImage &img)
 	{
 	    uchar *src;
 	    TQ_INT32 val, *dst;
-	    TQRgb pixel, *clut = img.tqcolorTable();
+	    TQRgb pixel, *clut = img.colorTable();
 	    for (y=0; y<height; y++)
 	    {
 		src = const_cast<TQImage&>(img).scanLine(y);
@@ -721,7 +721,7 @@ void KPixmapIO::convertToXImage(const TQImage &img)
 	{
 	    uchar *src;
 	    TQ_INT32 val, *dst;
-	    TQRgb pixel, *clut = img.tqcolorTable();
+	    TQRgb pixel, *clut = img.colorTable();
 	    for (y=0; y<height; y++)
 	    {
 		src = const_cast<TQImage&>(img).scanLine(y);
@@ -780,7 +780,7 @@ void KPixmapIO::convertToXImage(const TQImage &img)
 	{
 	    uchar *src, *dst;
 	    int w1 = width/4;
-	    TQRgb *clut = img.tqcolorTable(), d1, d2, d3, d4;
+	    TQRgb *clut = img.colorTable(), d1, d2, d3, d4;
 	    for (y=0; y<height; y++)
 	    {
 		src = const_cast<TQImage&>(img).scanLine(y);
@@ -841,7 +841,7 @@ void KPixmapIO::convertToXImage(const TQImage &img)
 	{
 	    uchar *src, *dst;
 	    int w1 = width/4;
-	    TQRgb *clut = img.tqcolorTable(), d1, d2, d3, d4;
+	    TQRgb *clut = img.colorTable(), d1, d2, d3, d4;
 	    for (y=0; y<height; y++)
 	    {
 		src = const_cast<TQImage&>(img).scanLine(y);
@@ -878,7 +878,7 @@ void KPixmapIO::convertToXImage(const TQImage &img)
 	} else
 	{
 	    uchar *src;
-	    TQRgb *dst, *clut = img.tqcolorTable();
+	    TQRgb *dst, *clut = img.colorTable();
 	    for (y=0; y<height; y++)
 	    {
 		src = const_cast<TQImage&>(img).scanLine(y);
