@@ -49,7 +49,7 @@ class TDEAboutContainerPrivate;
  */
 class TDEUI_EXPORT TDEAboutContainer : public TQFrame
 {
-  Q_OBJECT
+  TQ_OBJECT
 
   public:
     TDEAboutContainer( TQWidget *parent=0, const char *name=0,
@@ -91,7 +91,7 @@ class TDEAboutContributorPrivate;
  */
 class TDEUI_EXPORT TDEAboutContributor : public TQFrame
 {
-  Q_OBJECT
+  TQ_OBJECT
 
   public:
     TDEAboutContributor( TQWidget *parent=0, const char *name=0,
@@ -149,7 +149,7 @@ class TDEUI_EXPORT TDEAboutContributor : public TQFrame
  */
 class TDEUI_EXPORT TDEAboutWidget : public TQWidget
 {
-  Q_OBJECT
+  TQ_OBJECT
 
 public:
 
@@ -282,7 +282,7 @@ class TDEAboutDialogPrivate;
  */
 class TDEUI_EXPORT TDEAboutDialog : public KDialogBase
 {
-  Q_OBJECT
+  TQ_OBJECT
 
   public:
   /**
