@@ -109,12 +109,12 @@ class TDEMainWindow;
  *
  * \code
  * TQSignalMapper *desktopNumberMapper = new TQSignalMapper( this );
- * connect( desktopNumberMapper, TQT_SIGNAL( mapped( int ) ),
- *          this, TQT_SLOT( moveWindowToDesktop( int ) ) );
+ * connect( desktopNumberMapper, TQ_SIGNAL( mapped( int ) ),
+ *          this, TQ_SLOT( moveWindowToDesktop( int ) ) );
  *
  * for ( uint i = 0; i < numberOfDesktops; ++i ) {
  *     TDEAction *desktopAction = new TDEAction( i18n( "Move Window to Desktop %i" ).arg( i ), ... );
- *     connect( desktopAction, TQT_SIGNAL( activated() ), desktopNumberMapper, TQT_SLOT( map() ) );
+ *     connect( desktopAction, TQ_SIGNAL( activated() ), desktopNumberMapper, TQ_SLOT( map() ) );
  *     desktopNumberMapper->setMapping( desktopAction, i );
  * }
  * \endcode
@@ -135,7 +135,7 @@ class TDEMainWindow;
  * \code
  * TDEAction *newAct = new TDEAction(i18n("&New"), "document-new",
  *                               TDEStdAccel::shortcut(TDEStdAccel::New),
- *                               this, TQT_SLOT(fileNew()),
+ *                               this, TQ_SLOT(fileNew()),
  *                               actionCollection(), "new");
  * \endcode
  * This line creates our action.  It says that wherever this action is
@@ -202,7 +202,7 @@ class TDEMainWindow;
 class TDEUI_EXPORT TDEAction : public TQObject
 {
   friend class TDEActionCollection;
-  Q_OBJECT
+  TQ_OBJECT
   TQ_PROPERTY( int containerCount READ containerCount )
   TQ_PROPERTY( TQString plainText READ plainText )
   TQ_PROPERTY( TQString text READ text WRITE setText )
@@ -215,7 +215,7 @@ class TDEUI_EXPORT TDEAction : public TQObject
 public:
     /**
      * Constructs an action with text, potential keyboard
-     * shortcut, and a TQT_SLOT to call when this action is invoked by
+     * shortcut, and a slot to call when this action is invoked by
      * the user.
      *
      * If you do not want or have a keyboard shortcut,
@@ -228,8 +228,8 @@ public:
      *
      * @param text The text that will be displayed.
      * @param cut The corresponding keyboard shortcut.
-     * @param receiver The SLOT's parent.
-     * @param slot The TQT_SLOT to invoke to execute this action.
+     * @param receiver The slot's parent.
+     * @param slot The slot to invoke to execute this action.
      * @param parent This action's parent.
      * @param name An internal name for this action.
      */
@@ -239,7 +239,7 @@ public:
 
     /**
      * Constructs an action with text, icon, potential keyboard
-     * shortcut, and a TQT_SLOT to call when this action is invoked by
+     * shortcut, and a slot to call when this action is invoked by
      * the user.
      *
      * If you do not want or have a keyboard shortcut, set the
@@ -251,8 +251,8 @@ public:
      * @param text The text that will be displayed.
      * @param pix The icon to display.
      * @param cut The corresponding keyboard shortcut.
-     * @param receiver The SLOT's parent.
-     * @param slot The TQT_SLOT to invoke to execute this action.
+     * @param receiver The slot's parent.
+     * @param slot The slot to invoke to execute this action.
      * @param parent This action's parent.
      * @param name An internal name for this action.
      */
@@ -262,7 +262,7 @@ public:
 
     /**
      * Constructs an action with text, icon, potential keyboard
-     * shortcut, and a TQT_SLOT to call when this action is invoked by
+     * shortcut, and a slot to call when this action is invoked by
      * the user.  The icon is loaded on demand later based on where it
      * is plugged in.
      *
@@ -275,8 +275,8 @@ public:
      * @param text The text that will be displayed.
      * @param pix The icon to display.
      * @param cut The corresponding keyboard shortcut (shortcut).
-     * @param receiver The SLOT's parent.
-     * @param slot The TQT_SLOT to invoke to execute this action.
+     * @param receiver The slot's parent.
+     * @param slot The slot to invoke to execute this action.
      * @param parent This action's parent.
      * @param name An internal name for this action.
      */
@@ -290,8 +290,8 @@ public:
      *
      * @param item The KGuiItem with the label and (optional) icon.
      * @param cut The corresponding keyboard shortcut (shortcut).
-     * @param receiver The SLOT's parent.
-     * @param slot The TQT_SLOT to invoke to execute this action.
+     * @param receiver The slot's parent.
+     * @param slot The slot to invoke to execute this action.
      * @param parent This action's parent.
      * @param name An internal name for this action.
      */
