@@ -54,6 +54,8 @@ from the copyright holder.
 #endif
 
 #ifdef HAVE_PTHREAD_SETNAME_NP
+#define _GNU_SOURCE
+#define __BSD_VISIBLE 1
 #include <pthread.h>
 #endif /* pthread_setname_np() */
 
