@@ -48,7 +48,7 @@ public:
     virtual ~StandardTemplateWizardInterface();
 
     TQRESULT queryInterface( const TQUuid&, TQUnknownInterface** );
-    Q_REFCOUNT;
+    TQ_REFCOUNT;
 
     TQStringList featureList() const;
 
