@@ -43,7 +43,7 @@
 // on embedded, we do not compress image data. Rationale: by mapping
 // the ready-only data directly into memory we are both faster and
 // more memory efficient
-#if defined(Q_WS_QWS) && !defined(TQT_NO_IMAGE_COLLECTION_COMPRESSION)
+#if defined(TQ_WS_QWS) && !defined(TQT_NO_IMAGE_COLLECTION_COMPRESSION)
 #define TQT_NO_IMAGE_COLLECTION_COMPRESSION
 #endif
 
