@@ -279,42 +279,42 @@ Main::Main()
     info->setFrameStyle(TQFrame::WinPanel|TQFrame::Sunken);
     info->setAlignment(AlignTop);
 
-    connect(info, SIGNAL(idClicked(const TQString&)),
-	    this, SLOT(selectId(const TQString&)));
+    connect(info, TQ_SIGNAL(idClicked(const TQString&)),
+	    this, TQ_SLOT(selectId(const TQString&)));
 
 #ifdef FIXED_LAYOUT
     horizontal->setStretchFactor(info,2);
 #endif
 
-    connect(lv, SIGNAL(pressed(TQListViewItem*)),
-	    this, SLOT(updateAvailability(TQListViewItem*)));
-    connect(lv, SIGNAL(selectionChanged(TQListViewItem*)),
-	    this, SLOT(showInfo(TQListViewItem*)));
+    connect(lv, TQ_SIGNAL(pressed(TQListViewItem*)),
+	    this, TQ_SLOT(updateAvailability(TQListViewItem*)));
+    connect(lv, TQ_SIGNAL(selectionChanged(TQListViewItem*)),
+	    this, TQ_SLOT(showInfo(TQListViewItem*)));
 
     setCentralWidget(horizontal);
 
     TQToolBar* tb = new TQToolBar( this, "browser controls" );
     tb->setLabel( "Browser Controls" );
     (void)new TQToolButton( TQPixmap(back_xpm), "Back", TQString::null,
-                           info, SLOT(back()), tb, "back" );
+                           info, TQ_SLOT(back()), tb, "back" );
     (void)new TQToolButton( TQPixmap(forward_xpm), "Forward", TQString::null,
-                           info, SLOT(forward()), tb, "forward" );
+                           info, TQ_SLOT(forward()), tb, "forward" );
 
     TQPopupMenu* file = new TQPopupMenu( menuBar() );
-    file->insertItem( "&Open",  this, SLOT(open()), CTRL+Key_O );
-    file->insertItem( "&Save", this, SLOT(save()), CTRL+Key_S );
+    file->insertItem( "&Open",  this, TQ_SLOT(open()), CTRL+Key_O );
+    file->insertItem( "&Save", this, TQ_SLOT(save()), CTRL+Key_S );
     file->insertSeparator();
-    file->insertItem( "&Test all", this, SLOT(testAll()), CTRL+Key_T );
+    file->insertItem( "&Test all", this, TQ_SLOT(testAll()), CTRL+Key_T );
     file->insertSeparator();
-    file->insertItem( "E&xit",  tqApp, SLOT(quit()), CTRL+Key_Q );
+    file->insertItem( "E&xit",  tqApp, TQ_SLOT(quit()), CTRL+Key_Q );
 
     menuBar()->insertItem( "&File",file );
 
     menuBar()->insertSeparator();
 
     TQPopupMenu *help = new TQPopupMenu( menuBar() );
-    help->insertItem( "&About", this, SLOT(about()) );
-    help->insertItem( "About &TQt", this, SLOT(aboutTQt()) );
+    help->insertItem( "&About", this, TQ_SLOT(about()) );
+    help->insertItem( "About &TQt", this, TQ_SLOT(aboutTQt()) );
 
     menuBar()->insertItem( "&Help", help );
 
