@@ -7,6 +7,7 @@
 #include <tqlabel.h>
 #include <tqtooltip.h>
 #include <kdebug.h>
+#include <tdeglobal.h>
 #include <tdelocale.h>
 #include <kpixmapeffect.h>
 
@@ -255,13 +256,13 @@ static void create_pixmaps(NextClientFactory *f)
                             KPixmapEffect::DiagonalGradient);
     KPixmapEffect::gradient(internal, c.dark(120), c.light(120),
                             KPixmapEffect::DiagonalGradient);
-    bitBlt(TQT_TQPAINTDEVICE(iBtn), 3, 3, TQT_TQPAINTDEVICE(&internal), 0, 0, internalHeight, internalHeight, TQt::CopyROP, true);
+    bitBlt(iBtn, 3, 3, &internal, 0, 0, internalHeight, internalHeight, TQt::CopyROP, true);
 
     KPixmapEffect::gradient(*iBtnDown, c.dark(120), c.light(120),
                             KPixmapEffect::DiagonalGradient);
     KPixmapEffect::gradient(internal, c.light(120), c.dark(120),
                             KPixmapEffect::DiagonalGradient);
-    bitBlt(TQT_TQPAINTDEVICE(iBtnDown), 3, 3, TQT_TQPAINTDEVICE(&internal), 0, 0, internalHeight, internalHeight, TQt::CopyROP, true);
+    bitBlt(iBtnDown, 3, 3, &internal, 0, 0, internalHeight, internalHeight, TQt::CopyROP, true);
 
     // active buttons
     c = options()->color(KDecoration::ColorButtonBg, true);
@@ -269,13 +270,13 @@ static void create_pixmaps(NextClientFactory *f)
                             KPixmapEffect::DiagonalGradient);
     KPixmapEffect::gradient(internal, c.dark(120), c.light(120),
                             KPixmapEffect::DiagonalGradient);
-    bitBlt(TQT_TQPAINTDEVICE(aBtn), 3, 3, TQT_TQPAINTDEVICE(&internal), 0, 0, internalHeight, internalHeight, TQt::CopyROP, true);
+    bitBlt(aBtn, 3, 3, &internal, 0, 0, internalHeight, internalHeight, TQt::CopyROP, true);
 
     KPixmapEffect::gradient(*aBtnDown, c.dark(120), c.light(120),
                             KPixmapEffect::DiagonalGradient);
     KPixmapEffect::gradient(internal, c.light(120), c.dark(120),
                             KPixmapEffect::DiagonalGradient);
-    bitBlt(TQT_TQPAINTDEVICE(aBtnDown), 3, 3, TQT_TQPAINTDEVICE(&internal), 0, 0, internalHeight, internalHeight, TQt::CopyROP, true);
+    bitBlt(aBtnDown, 3, 3, &internal, 0, 0, internalHeight, internalHeight, TQt::CopyROP, true);
 
     TQPainter p;
     p.begin(aBtn);
@@ -324,7 +325,7 @@ NextButton::NextButton(NextClient *parent, const char *name,
                        const unsigned char *bitmap, int bw, int bh,
                        const TQString& tip, const int realizeBtns)
     : TQButton(parent->widget(), name),
-      deco(NULL), client(parent), last_button(Qt::NoButton)
+      deco(NULL), client(parent), last_button(TQt::NoButton)
 {
     realizeButtons = realizeBtns;
 
@@ -376,7 +377,7 @@ void NextButton::mousePressEvent( TQMouseEvent* e )
 {
     last_button = e->button();
     TQMouseEvent me( e->type(), e->pos(), e->globalPos(),
-                    (e->button()&realizeButtons)?Qt::LeftButton:Qt::NoButton, e->state() );
+                    (e->button()&realizeButtons)?TQt::LeftButton:TQt::NoButton, e->state() );
     TQButton::mousePressEvent( &me );
 }
 
@@ -384,7 +385,7 @@ void NextButton::mouseReleaseEvent( TQMouseEvent* e )
 {
     last_button = e->button();
     TQMouseEvent me( e->type(), e->pos(), e->globalPos(),
-                    (e->button()&realizeButtons)?Qt::LeftButton:Qt::NoButton, e->state() );
+                    (e->button()&realizeButtons)?TQt::LeftButton:TQt::NoButton, e->state() );
     TQButton::mouseReleaseEvent( &me );
 }
 
@@ -478,10 +479,10 @@ void NextClient::addButtons(TQBoxLayout* titleLayout, const TQString& spec)
             if (isMaximizable()) {
                 button[MAXIMIZE_IDX] =
                     new NextButton(this, "maximize", maximize_bits, 10, 10,
-                                   i18n("Maximize"), Qt::LeftButton|Qt::MidButton|Qt::RightButton);
+                                   i18n("Maximize"), TQt::LeftButton|TQt::MidButton|TQt::RightButton);
                 titleLayout->addWidget( button[MAXIMIZE_IDX] );
-                connect( button[MAXIMIZE_IDX], TQT_SIGNAL(clicked()),
-                         this, TQT_SLOT(maximizeButtonClicked()) );
+                connect( button[MAXIMIZE_IDX], TQ_SIGNAL(clicked()),
+                         this, TQ_SLOT(maximizeButtonClicked()) );
             }
             break;
 
@@ -490,8 +491,8 @@ void NextClient::addButtons(TQBoxLayout* titleLayout, const TQString& spec)
 		button[HELP_IDX] = new NextButton(this,
 			"help", question_bits, 10, 10, i18n("Help"));
 		titleLayout->addWidget( button[HELP_IDX] );
-		connect( button[HELP_IDX], TQT_SIGNAL(clicked()),
-			 this, TQT_SLOT(showContextHelp()) );
+		connect( button[HELP_IDX], TQ_SIGNAL(clicked()),
+			 this, TQ_SLOT(showContextHelp()) );
 	    }
             break;
 
@@ -501,26 +502,26 @@ void NextClient::addButtons(TQBoxLayout* titleLayout, const TQString& spec)
                     new NextButton(this, "iconify", iconify_bits, 10, 10,
                                    i18n("Minimize"));
                 titleLayout->addWidget( button[ICONIFY_IDX] );
-                connect( button[ICONIFY_IDX], TQT_SIGNAL(clicked()),
-                         this, TQT_SLOT(minimize()) );
+                connect( button[ICONIFY_IDX], TQ_SIGNAL(clicked()),
+                         this, TQ_SLOT(minimize()) );
             }
             break;
 
         case 'M':
             button[MENU_IDX] =
-                new NextButton(this, "menu", NULL, 10, 10, i18n("Menu"), Qt::LeftButton|Qt::RightButton);
+                new NextButton(this, "menu", NULL, 10, 10, i18n("Menu"), TQt::LeftButton|TQt::RightButton);
             titleLayout->addWidget( button[MENU_IDX] );
             // NOTE DIFFERENCE: capture pressed(), not clicked()
-            connect( button[MENU_IDX], TQT_SIGNAL(pressed()),
-                     this, TQT_SLOT(menuButtonPressed()) );
+            connect( button[MENU_IDX], TQ_SIGNAL(pressed()),
+                     this, TQ_SLOT(menuButtonPressed()) );
             break;
 
         case 'L':
             button[SHADE_IDX] =
                 new NextButton(this, "shade", NULL, 0, 0, i18n("Shade"));
             titleLayout->addWidget( button[SHADE_IDX] );
-            connect( button[SHADE_IDX], TQT_SIGNAL(clicked()),
-                     this, TQT_SLOT(shadeClicked()) );
+            connect( button[SHADE_IDX], TQ_SIGNAL(clicked()),
+                     this, TQ_SLOT(shadeClicked()) );
             // NOTE DIFFERENCE: set the pixmap separately (2 states)
 	    shadeChange();
             break;
@@ -529,8 +530,8 @@ void NextClient::addButtons(TQBoxLayout* titleLayout, const TQString& spec)
             button[STICKY_IDX] =
                 new NextButton(this, "sticky", NULL, 0, 0, i18n("On all desktops"));
             titleLayout->addWidget( button[STICKY_IDX] );
-            connect( button[STICKY_IDX], TQT_SIGNAL(clicked()),
-                     this, TQT_SLOT(toggleOnAllDesktops()) );
+            connect( button[STICKY_IDX], TQ_SIGNAL(clicked()),
+                     this, TQ_SLOT(toggleOnAllDesktops()) );
             // NOTE DIFFERENCE: set the pixmap separately (2 states)
 	    desktopChange();
             break;
@@ -538,20 +539,20 @@ void NextClient::addButtons(TQBoxLayout* titleLayout, const TQString& spec)
 	case 'F':
             button[ABOVE_IDX] = new NextButton(this, "above", NULL, 0, 0, "");
             titleLayout->addWidget( button[ABOVE_IDX] );
-            connect( button[ABOVE_IDX], TQT_SIGNAL(clicked()),
-                     this, TQT_SLOT(aboveClicked()) );
-	    connect(this, TQT_SIGNAL(keepAboveChanged(bool)), 
-		    TQT_SLOT(keepAboveChange(bool)));
+            connect( button[ABOVE_IDX], TQ_SIGNAL(clicked()),
+                     this, TQ_SLOT(aboveClicked()) );
+	    connect(this, TQ_SIGNAL(keepAboveChanged(bool)), 
+		    TQ_SLOT(keepAboveChange(bool)));
 	    keepAboveChange(keepAbove());
 	    break;
 	    
 	case 'B':
             button[BELOW_IDX] = new NextButton(this, "below", NULL, 0, 0, "");
             titleLayout->addWidget( button[BELOW_IDX] );
-            connect( button[BELOW_IDX], TQT_SIGNAL(clicked()),
-                     this, TQT_SLOT(belowClicked()) );
-	    connect(this, TQT_SIGNAL(keepBelowChanged(bool)), 
-		    TQT_SLOT(keepBelowChange(bool)));
+            connect( button[BELOW_IDX], TQ_SIGNAL(clicked()),
+                     this, TQ_SLOT(belowClicked()) );
+	    connect(this, TQ_SIGNAL(keepBelowChanged(bool)), 
+		    TQ_SLOT(keepBelowChange(bool)));
 	    keepBelowChange(keepBelow());
 	    break;
         
@@ -561,8 +562,8 @@ void NextClient::addButtons(TQBoxLayout* titleLayout, const TQString& spec)
 		    new NextButton(this, "close", close_bits, 10, 10,
 				   i18n("Close"));
 		titleLayout->addWidget(button[CLOSE_IDX]);
-		connect(button[CLOSE_IDX], TQT_SIGNAL(clicked()),
-			 this, TQT_SLOT(closeWindow()));
+		connect(button[CLOSE_IDX], TQ_SIGNAL(clicked()),
+			 this, TQ_SLOT(closeWindow()));
             }
             break;
 
@@ -573,8 +574,8 @@ void NextClient::addButtons(TQBoxLayout* titleLayout, const TQString& spec)
 				   i18n("Resize"));
 		titleLayout->addWidget(button[RESIZE_IDX]);
 		// NOTE DIFFERENCE: capture pressed(), not clicked()
-		connect(button[RESIZE_IDX], TQT_SIGNAL(pressed()),
-			 this, TQT_SLOT(resizePressed()));
+		connect(button[RESIZE_IDX], TQ_SIGNAL(pressed()),
+			 this, TQ_SLOT(resizePressed()));
             }
 	    break;
         case '_':
@@ -741,7 +742,7 @@ void NextClient::paintEvent( TQPaintEvent* )
 
 void NextClient::mouseDoubleClickEvent( TQMouseEvent * e )
 {
-    if (e->button() == Qt::LeftButton && titlebar->geometry().contains( e->pos() ) )
+    if (e->button() == TQt::LeftButton && titlebar->geometry().contains( e->pos() ) )
 	titlebarDblClickOperation();
 }
 
@@ -875,26 +876,26 @@ void NextClient::reset(unsigned long)
 
 bool NextClient::eventFilter(TQObject *o, TQEvent *e)
 {
-    if (TQT_BASE_OBJECT(o) != TQT_BASE_OBJECT(widget()))
+    if (o != widget())
 	return false;
     switch (e->type()) {
     case TQEvent::Resize:
-	resizeEvent(TQT_TQRESIZEEVENT( e ));
+	resizeEvent(static_cast<TQResizeEvent*>( e ));
 	return true;
     case TQEvent::Paint:
-	paintEvent(TQT_TQPAINTEVENT( e ));
+	paintEvent(static_cast<TQPaintEvent*>( e ));
 	return true;
     case TQEvent::MouseButtonDblClick:
-	mouseDoubleClickEvent(TQT_TQMOUSEEVENT( e ));
+	mouseDoubleClickEvent(static_cast<TQMouseEvent*>( e ));
 	return true;
     case TQEvent::Wheel:
-	wheelEvent( TQT_TQWHEELEVENT( e ));
+	wheelEvent( static_cast<TQWheelEvent*>( e ));
 	return true;
     case TQEvent::MouseButtonPress:
-	processMousePressEvent(TQT_TQMOUSEEVENT( e ));
+	processMousePressEvent(static_cast<TQMouseEvent*>( e ));
 	return true;
     case TQEvent::Show:
-	showEvent(TQT_TQSHOWEVENT( e ));
+	showEvent(static_cast<TQShowEvent*>( e ));
 	return true;
     default:
 	break;
@@ -922,6 +923,8 @@ bool NextClient::drawbound(const TQRect& geom, bool /* clear */)
 
 NextClientFactory::NextClientFactory()
 {
+    TDEGlobal::locale()->insertCatalogue("twin_clients");
+    TDEGlobal::locale()->insertCatalogue("twin_art_clients");
     create_pixmaps(this);
 }
 
