@@ -168,7 +168,7 @@ smoothblendButton::smoothblendButton(smoothblendClient *parent, const char *name
      type_(type), 
      size_(button_size), 
      deco_(0), 
-     lastmouse_(Qt::NoButton), 
+     lastmouse_(TQt::NoButton), 
      hover_(false)
 {
     setBackgroundMode(NoBackground);
@@ -178,9 +178,9 @@ smoothblendButton::smoothblendButton(smoothblendClient *parent, const char *name
     setToggleButton(toggle);
     //button animation setup
     animTmr = new TQTimer(this);
-    connect(animTmr, TQT_SIGNAL(timeout() ), this, TQT_SLOT(animate() ) );
-    connect(this, TQT_SIGNAL(pressed() ), this, TQT_SLOT(buttonClicked() ) );
-    connect(this, TQT_SIGNAL(released() ), this, TQT_SLOT(buttonReleased() ) );
+    connect(animTmr, TQ_SIGNAL(timeout() ), this, TQ_SLOT(animate() ) );
+    connect(this, TQ_SIGNAL(pressed() ), this, TQ_SLOT(buttonClicked() ) );
+    connect(this, TQ_SIGNAL(released() ), this, TQ_SLOT(buttonReleased() ) );
     animProgress = 0;
     m_clicked=false;
 }
@@ -282,9 +282,9 @@ void smoothblendButton::mousePressEvent(TQMouseEvent* e) {
     lastmouse_ = e->button();
 
     // translate and pass on mouse event
-    int button = Qt::LeftButton;
-    if ((type_ != ButtonMax) && (e->button() != Qt::LeftButton)) {
-        button = Qt::NoButton; // middle & right buttons inappropriate
+    int button = TQt::LeftButton;
+    if ((type_ != ButtonMax) && (e->button() != TQt::LeftButton)) {
+        button = TQt::NoButton; // middle & right buttons inappropriate
     }
     TQMouseEvent me(e->type(), e->pos(), e->globalPos(),
                    button, e->state());
@@ -300,9 +300,9 @@ void smoothblendButton::mouseReleaseEvent(TQMouseEvent* e) {
     lastmouse_ = e->button();
 
     // translate and pass on mouse event
-    int button = Qt::LeftButton;
-    if ((type_ != ButtonMax) && (e->button() != Qt::LeftButton)) {
-        button = Qt::NoButton; // middle & right buttons inappropriate
+    int button = TQt::LeftButton;
+    if ((type_ != ButtonMax) && (e->button() != TQt::LeftButton)) {
+        button = TQt::NoButton; // middle & right buttons inappropriate
     }
     TQMouseEvent me(e->type(), e->pos(), e->globalPos(), button, e->state());
     TQButton::mouseReleaseEvent(&me);
@@ -697,8 +697,8 @@ void smoothblendClient::_resetLayout()
     mainLayout_->addItem( bottomSpacer_ );
     
     // connections
-    connect(this, TQT_SIGNAL(keepAboveChanged(bool)), TQT_SLOT(keepAboveChange(bool)));
-    connect(this, TQT_SIGNAL(keepBelowChanged(bool)), TQT_SLOT(keepBelowChange(bool)));
+    connect(this, TQ_SIGNAL(keepAboveChanged(bool)), TQ_SLOT(keepAboveChange(bool)));
+    connect(this, TQ_SIGNAL(keepBelowChanged(bool)), TQ_SLOT(keepBelowChange(bool)));
 }
 
 //////////////////////////////////////////////////////////////////////////////
@@ -715,8 +715,8 @@ void smoothblendClient::addButtons(TQBoxLayout *layout, const TQString& s, int b
                 if (!button[ButtonMenu]) {
                     button[ButtonMenu] =
                         new smoothblendButton(this, "splat.png", i18n("Menu"),ButtonMenu,button_size);
-                    connect(button[ButtonMenu], TQT_SIGNAL(pressed()), this, TQT_SLOT(menuButtonPressed()));
-                    connect(button[ButtonMenu], TQT_SIGNAL(released()), this, TQT_SLOT(menuButtonReleased()));
+                    connect(button[ButtonMenu], TQ_SIGNAL(pressed()), this, TQ_SLOT(menuButtonPressed()));
+                    connect(button[ButtonMenu], TQ_SIGNAL(released()), this, TQ_SLOT(menuButtonReleased()));
                     layout->addWidget(button[ButtonMenu]);
                     if (n < s.length()-1) layout->addSpacing(1);
                 }
@@ -731,8 +731,8 @@ void smoothblendClient::addButtons(TQBoxLayout *layout, const TQString& s, int b
                     }
                     button[ButtonSticky] =
                         new smoothblendButton(this, "circle.png", tip, ButtonSticky, button_size, true);
-                    connect(button[ButtonSticky], TQT_SIGNAL(clicked()),
-                            this, TQT_SLOT(toggleOnAllDesktops()));
+                    connect(button[ButtonSticky], TQ_SIGNAL(clicked()),
+                            this, TQ_SLOT(toggleOnAllDesktops()));
                     layout->addWidget(button[ButtonSticky]);
                     if (n < s.length()-1) layout->addSpacing(1);
                 }
@@ -742,8 +742,8 @@ void smoothblendClient::addButtons(TQBoxLayout *layout, const TQString& s, int b
                 if ((!button[ButtonHelp]) && providesContextHelp()) {
                     button[ButtonHelp] =
                         new smoothblendButton(this, "help.png", i18n("Help"), ButtonHelp, button_size);
-                    connect(button[ButtonHelp], TQT_SIGNAL(clicked()),
-                            this, TQT_SLOT(showContextHelp()));
+                    connect(button[ButtonHelp], TQ_SIGNAL(clicked()),
+                            this, TQ_SLOT(showContextHelp()));
                     layout->addWidget(button[ButtonHelp]);
                     if (n < s.length()-1) layout->addSpacing(1);
                 }
@@ -753,8 +753,8 @@ void smoothblendClient::addButtons(TQBoxLayout *layout, const TQString& s, int b
                 if ((!button[ButtonMin]) && isMinimizable())  {
                     button[ButtonMin] =
                         new smoothblendButton(this, "minimize.png", i18n("Minimize"), ButtonMin, button_size);
-                    connect(button[ButtonMin], TQT_SIGNAL(clicked()),
-                            this, TQT_SLOT(minimize()));
+                    connect(button[ButtonMin], TQ_SIGNAL(clicked()),
+                            this, TQ_SLOT(minimize()));
                     layout->addWidget(button[ButtonMin]);
                     if (n < s.length()-1) layout->addSpacing(1);
                 }
@@ -769,8 +769,8 @@ void smoothblendClient::addButtons(TQBoxLayout *layout, const TQString& s, int b
                     }
                     button[ButtonMax]  =
                         new smoothblendButton(this, "maximize.png", tip, ButtonMax, button_size, true);
-                    connect(button[ButtonMax], TQT_SIGNAL(clicked()),
-                            this, TQT_SLOT(maxButtonPressed()));
+                    connect(button[ButtonMax], TQ_SIGNAL(clicked()),
+                            this, TQ_SLOT(maxButtonPressed()));
                     layout->addWidget(button[ButtonMax]);
                     if (n < s.length()-1) layout->addSpacing(1);
                 }
@@ -780,8 +780,8 @@ void smoothblendClient::addButtons(TQBoxLayout *layout, const TQString& s, int b
                 if ((!button[ButtonClose]) && isCloseable()) {
                     button[ButtonClose] =
                         new smoothblendButton(this, "close.png", i18n("Close"), ButtonClose, button_size);
-                    connect(button[ButtonClose], TQT_SIGNAL(clicked()),
-                            this, TQT_SLOT(closeWindow()));
+                    connect(button[ButtonClose], TQ_SIGNAL(clicked()),
+                            this, TQ_SLOT(closeWindow()));
                     layout->addWidget(button[ButtonClose]);
                     if (n < s.length()-1) layout->addSpacing(1);
                 }
@@ -792,8 +792,8 @@ void smoothblendClient::addButtons(TQBoxLayout *layout, const TQString& s, int b
                     button[ButtonAbove] =
                         new smoothblendButton(this, "keep_above.png",
                                           i18n("Keep Above Others"), ButtonAbove, button_size, true);
-                    connect(button[ButtonAbove], TQT_SIGNAL(clicked()),
-                            this, TQT_SLOT(aboveButtonPressed()));
+                    connect(button[ButtonAbove], TQ_SIGNAL(clicked()),
+                            this, TQ_SLOT(aboveButtonPressed()));
                     layout->addWidget(button[ButtonAbove]);
                     if (n < s.length()-1) layout->addSpacing(1);
                 }
@@ -804,8 +804,8 @@ void smoothblendClient::addButtons(TQBoxLayout *layout, const TQString& s, int b
                     button[ButtonBelow] =
                         new smoothblendButton(this, "keep_below.png",
                                           i18n("Keep Below Others"), ButtonBelow, button_size, true);
-                    connect(button[ButtonBelow], TQT_SIGNAL(clicked()),
-                            this, TQT_SLOT(belowButtonPressed()));
+                    connect(button[ButtonBelow], TQ_SIGNAL(clicked()),
+                            this, TQ_SLOT(belowButtonPressed()));
                     layout->addWidget(button[ButtonBelow]);
                     if (n < s.length()-1) layout->addSpacing(1);
                 }
@@ -820,8 +820,8 @@ void smoothblendClient::addButtons(TQBoxLayout *layout, const TQString& s, int b
                     }
                     button[ButtonShade] =
                         new smoothblendButton(this, "shade.png", tip, ButtonShade, button_size, true);
-                    connect(button[ButtonShade], TQT_SIGNAL(clicked()),
-                            this, TQT_SLOT(shadeButtonPressed()));
+                    connect(button[ButtonShade], TQ_SIGNAL(clicked()),
+                            this, TQ_SLOT(shadeButtonPressed()));
                     layout->addWidget(button[ButtonShade]);
                     if (n < s.length()-1) layout->addSpacing(1);
                 }
@@ -1042,32 +1042,32 @@ KDecoration::Position smoothblendClient::mousePosition(const TQPoint &point) con
 // Event filter
 
 bool smoothblendClient::eventFilter(TQObject *obj, TQEvent *e) {
-    if (TQT_BASE_OBJECT(obj) != TQT_BASE_OBJECT(widget()))
+    if (obj != widget())
         return false;
 
     switch (e->type()) {
     case TQEvent::MouseButtonDblClick: {
-            mouseDoubleClickEvent(TQT_TQMOUSEEVENT(e));
+            mouseDoubleClickEvent(static_cast<TQMouseEvent*>(e));
             return true;
         }
     case TQEvent::MouseButtonPress: {
-            processMousePressEvent(TQT_TQMOUSEEVENT(e));
+            processMousePressEvent(static_cast<TQMouseEvent*>(e));
             return true;
         }
     case TQEvent::Paint: {
-            paintEvent(TQT_TQPAINTEVENT(e));
+            paintEvent(static_cast<TQPaintEvent*>(e));
             return true;
         }
     case TQEvent::Resize: {
-            resizeEvent(TQT_TQRESIZEEVENT(e));
+            resizeEvent(static_cast<TQResizeEvent*>(e));
             return true;
         }
     case TQEvent::Show: {
-            showEvent(TQT_TQSHOWEVENT(e));
+            showEvent(static_cast<TQShowEvent*>(e));
             return true;
         }
     case TQEvent::Wheel: {
-            wheelEvent(TQT_TQWHEELEVENT( e ));
+            wheelEvent(static_cast<TQWheelEvent*>( e ));
             return true;
         }
     default: {
