@@ -22,7 +22,7 @@
 #define EGROUPWAREWIZARD_H
 
 #include <tdeconfigwizard.h>
-#include <tdepimmacros.h>
+#include <kdemacros.h>
 
 class KLineEdit;
 class TQCheckBox;
